AccentColor class final

Contains information about supported accent color for user/chat name, background of empty chat photo, replies to messages and link previews

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AccentColor({required int id, required int builtInAccentColorId, required List<int> lightThemeColors, required List<int> darkThemeColors, required int minChannelChatBoostLevel})

Properties

builtInAccentColorId int
builtInAccentColorId Identifier of a built-in color to use in places, where only one color is needed; 0-6
final
darkThemeColors List<int>
darkThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in dark themes
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Accent color identifier
final
lightThemeColors List<int>
lightThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in light themes
final
minChannelChatBoostLevel int
minChannelChatBoostLevel The minimum chat boost level required to use the color in a channel chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? builtInAccentColorId, List<int>? lightThemeColors, List<int>? darkThemeColors, int? minChannelChatBoostLevel}) AccentColor

Available on AccentColor, provided by the AccentColorExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AccentColor?

Constants

constructor → const String