builtInAccentColorId property
builtInAccentColorId Identifier of a built-in color to use in places, where only one color is needed; 0-6
Implementation
final int builtInAccentColorId;
builtInAccentColorId Identifier of a built-in color to use in places, where only one color is needed; 0-6
final int builtInAccentColorId;