darkThemeColors property
darkThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in dark themes
Implementation
final List<int> darkThemeColors;
darkThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in dark themes
final List<int> darkThemeColors;