lightThemeColors property
lightThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in light themes
Implementation
final List<int> lightThemeColors;
lightThemeColors The list of 1-3 colors in RGB format, describing the accent color, as expected to be shown in light themes
final List<int> lightThemeColors;