AcceptOauthRequest class final
Accepts an OAuth authorization request. Returns an HTTP URL to open after successful authorization. May return an empty link if just a toast about successful login has to be shown Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- AcceptOauthRequest
- Available extensions
- Annotations
-
- @immutable
Constructors
- AcceptOauthRequest({required String url, required String matchCode, required bool allowWriteAccess, required bool allowPhoneNumberAccess})
Properties
- allowPhoneNumberAccess → bool
-
allowPhoneNumberAccess Pass true if the current user allowed the bot
that was returned in getOauthLinkInfo, to access their phone number
final
- allowWriteAccess → bool
-
allowWriteAccess Pass true if the current user allowed the bot that was
returned in getOauthLinkInfo, to send them messages
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- matchCode → String
-
matchCode The matching code chosen by the user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url URL of the OAuth deep link
final
Methods
-
copyWith(
{String? url, String? matchCode, bool? allowWriteAccess, bool? allowPhoneNumberAccess}) → AcceptOauthRequest -
Available on AcceptOauthRequest, provided by the AcceptOauthRequestExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String