allowPhoneNumberAccess property
allowPhoneNumberAccess Pass true if the current user allowed the bot that was returned in getOauthLinkInfo, to access their phone number
Implementation
final bool allowPhoneNumberAccess;
allowPhoneNumberAccess Pass true if the current user allowed the bot that was returned in getOauthLinkInfo, to access their phone number
final bool allowPhoneNumberAccess;