upgradedGifts property
upgradedGifts True, if upgraded gifts and regular gifts that can be upgraded for free are accepted
Implementation
final bool upgradedGifts;
upgradedGifts True, if upgraded gifts and regular gifts that can be upgraded for free are accepted
final bool upgradedGifts;