AccountInfo class final

Contains basic information about another user who started a chat with the current user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AccountInfo({required int registrationMonth, required int registrationYear, required String phoneNumberCountryCode, required int lastNameChangeDate, required int lastPhotoChangeDate})

Properties

hashCode int
The hash code for this object.
no setteroverride
lastNameChangeDate int
lastNameChangeDate Point in time (Unix timestamp) when the user changed name last time; 0 if unknown
final
lastPhotoChangeDate int
lastPhotoChangeDate Point in time (Unix timestamp) when the user changed photo last time; 0 if unknown
final
phoneNumberCountryCode String
phoneNumberCountryCode A two-letter ISO 3166-1 alpha-2 country code based on the phone number of the user; may be empty if unknown
final
registrationMonth int
registrationMonth Month when the user was registered in Telegram; 0-12; may be 0 if unknown
final
registrationYear int
registrationYear Year when the user was registered in Telegram; 0-9999; may be 0 if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? registrationMonth, int? registrationYear, String? phoneNumberCountryCode, int? lastNameChangeDate, int? lastPhotoChangeDate}) AccountInfo

Available on AccountInfo, provided by the AccountInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AccountInfo?

Constants

constructor → const String