phoneNumberCountryCode property
phoneNumberCountryCode A two-letter ISO 3166-1 alpha-2 country code based on the phone number of the user; may be empty if unknown
Implementation
final String phoneNumberCountryCode;
phoneNumberCountryCode A two-letter ISO 3166-1 alpha-2 country code based on the phone number of the user; may be empty if unknown
final String phoneNumberCountryCode;