registrationMonth property
registrationMonth Month when the user was registered in Telegram; 0-12; may be 0 if unknown
Implementation
final int registrationMonth;
registrationMonth Month when the user was registered in Telegram; 0-12; may be 0 if unknown
final int registrationMonth;