AccountTtl class final

Contains information about the period of inactivity after which the current user's account will automatically be deleted

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AccountTtl({required int days})

Properties

days int
days Number of days of inactivity before the account will be flagged for deletion; 30-730 days
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? days}) AccountTtl

Available on AccountTtl, provided by the AccountTtlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AccountTtl?

Constants

constructor → const String