ActiveStoryStateRead class final

The chat has active stories, all of which were read

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ActiveStoryStateRead()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult live(ActiveStoryStateLive value), required TResult read(ActiveStoryStateRead value), required TResult unread(ActiveStoryStateUnread value)}) → TResult

Available on ActiveStoryState, provided by the ActiveStoryStateExtensions extension

maybeMap<TResult extends Object?>({TResult live(ActiveStoryStateLive value)?, TResult read(ActiveStoryStateRead value)?, TResult unread(ActiveStoryStateUnread value)?, required TResult orElse()}) → TResult

Available on ActiveStoryState, provided by the ActiveStoryStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ActiveStoryStateRead?
Inherited by: ActiveStoryStateLive ActiveStoryStateRead ActiveStoryStateUnread
override

Constants

constructor → const String