AddBotMediaPreview class final

Adds a new media preview to the beginning of the list of media previews of a bot. Returns the added preview after addition is completed server-side. The total number of previews must not exceed getOption("bot_media_preview_count_max") for the given language Returns BotMediaPreview

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddBotMediaPreview({required int botUserId, required String languageCode, InputStoryContent? content})

Properties

botUserId int
botUserId Identifier of the target bot. The bot must be owned and must have the main Web App
final
content InputStoryContent?
content Content of the added preview
final
hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode A two-letter ISO 639-1 language code for which preview is added. If empty, then the preview will be shown to all users for whose languages there are no dedicated previews. If non-empty, then there must be an official language pack of the same name, which is returned by getLocalizationTargetInfo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? languageCode, InputStoryContent? content}) AddBotMediaPreview

Available on AddBotMediaPreview, provided by the AddBotMediaPreviewExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String