AddChatFolderByInviteLink class final

Adds a chat folder by an invite link Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddChatFolderByInviteLink({required String inviteLink, required List<int> chatIds})

Properties

chatIds List<int>
chatIds Identifiers of the chats added to the chat folder. The chats are automatically joined if they aren't joined yet
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link for the chat folder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink, List<int>? chatIds}) AddChatFolderByInviteLink

Available on AddChatFolderByInviteLink, provided by the AddChatFolderByInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String