AddChatMembers class final

Adds multiple new members to a chat; requires can_invite_users member right. Currently, this method is available only in supergroups and channels. This method can't be used to join a chat. Members can't be added to a channel if it has more than 200 members. Returns information about members that weren't added Returns FailedToAddMembers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddChatMembers({required int chatId, required List<int> userIds})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<int>
userIds Identifiers of the users to be added to the chat. The maximum number of added users is 20 for supergroups and 100 for channels
final

Methods

copyWith({int? chatId, List<int>? userIds}) AddChatMembers

Available on AddChatMembers, provided by the AddChatMembersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String