AddChatToList class final

Adds a chat to a chat list. A chat can't be simultaneously in Main and Archive chat lists, so it is automatically removed from another one if needed Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddChatToList({required int chatId, ChatList? chatList})

Properties

chatId int
chatId Chat identifier
final
chatList ChatList?
chatList The chat list. Use getChatListsToAddChat to get suitable chat lists
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatList? chatList}) AddChatToList

Available on AddChatToList, provided by the AddChatToListExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String