AddContact class final

Adds a user to the contact list or edits an existing contact by their user identifier Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddContact({required int userId, ImportedContact? contact, required bool sharePhoneNumber})

Properties

contact ImportedContact?
contact The contact to add or edit; phone number may be empty and needs to be specified only if known
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharePhoneNumber bool
sharePhoneNumber Pass true to share the current user's phone number with the new contact. A corresponding rule to userPrivacySettingShowPhoneNumber will be added if needed. Use the field userFullInfo.need_phone_number_privacy_exception to check whether the current user needs to be asked to share their phone number
final
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId, ImportedContact? contact, bool? sharePhoneNumber}) AddContact

Available on AddContact, provided by the AddContactExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String