AddCustomServerLanguagePack class final

Adds a custom server language pack to the list of installed language packs in current localization target. Can be called before authorization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddCustomServerLanguagePack({required String languagePackId})

Properties

hashCode int
The hash code for this object.
no setteroverride
languagePackId String
languagePackId Identifier of a language pack to be added
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackId}) AddCustomServerLanguagePack

Available on AddCustomServerLanguagePack, provided by the AddCustomServerLanguagePackExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String