AddFileToDownloads class final
Adds a file from a message to the list of file downloads. Download progress and completion of the download will be notified through updateFile updates. If message database is used, the list of file downloads is persistent across application restarts. The downloading is independent of download using downloadFile, i.e. it continues if downloadFile is canceled or is used to download a part of the file Returns File
- Inheritance
-
- Object
- TdFunction
- AddFileToDownloads
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddFileToDownloads({required int fileId, required int chatId, required int messageId, required int priority})
Properties
- chatId → int
-
chatId Chat identifier of the message with the file
final
- fileId → int
-
fileId Identifier of the file to download
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Message identifier
final
- priority → int
-
priority Priority of the download (1-32). The higher the priority, the
earlier the file will be downloaded. If the priorities of two files are
equal, then the last one for which downloadFile/addFileToDownloads was
called will be downloaded first
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? fileId, int? chatId, int? messageId, int? priority}) → AddFileToDownloads -
Available on AddFileToDownloads, provided by the AddFileToDownloadsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String