AddGiftCollectionGifts class final

Adds gifts to the beginning of a previously created collection. If the collection is owned by a channel chat, then requires can_post_messages administrator right in the channel chat. Returns the changed collection Returns GiftCollection

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddGiftCollectionGifts({MessageSender? ownerId, required int collectionId, required List<String> receivedGiftIds})

Properties

collectionId → int
collectionId Identifier of the gift collection
final
hashCode → int
The hash code for this object.
no setteroverride
ownerId → MessageSender?
ownerId Identifier of the user or the channel chat that owns the collection
final
receivedGiftIds → List<String>
receivedGiftIds Identifier of the gifts to add to the collection; 1-getOption("gift_collection_size_max") identifiers. If after addition the collection has more than getOption("gift_collection_size_max") gifts, then the last one are removed from the collection
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, int? collectionId, List<String>? receivedGiftIds}) → AddGiftCollectionGifts

Available on AddGiftCollectionGifts, provided by the AddGiftCollectionGiftsExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

constructor → const String