receivedGiftIds property

List<String> receivedGiftIds
final

receivedGiftIds Identifier of the gifts to add to the collection; 1-getOption("gift_collection_size_max") identifiers. If after addition the collection has more than getOption("gift_collection_size_max") gifts, then the last one are removed from the collection

Implementation

final List<String> receivedGiftIds;