AddLocalMessage class final

Adds a local message to a chat. The message is persistent across application restarts only if the message database is used. Returns the added message Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddLocalMessage({required int chatId, MessageSender? senderId, InputMessageReplyTo? replyTo, required bool disableNotification, InputMessageContent? inputMessageContent})

Properties

chatId int
chatId Target chat; channel direct messages chats aren't supported
final
disableNotification bool
disableNotification Pass true to disable notification for the message
final
hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be added
final
replyTo InputMessageReplyTo?
replyTo Information about the message or story to be replied; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of the message
final

Methods

copyWith({int? chatId, MessageSender? senderId, InputMessageReplyTo? replyTo, bool? disableNotification, InputMessageContent? inputMessageContent}) AddLocalMessage

Available on AddLocalMessage, provided by the AddLocalMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String