updateRecentReactions property
updateRecentReactions Pass true if the reaction needs to be added to recent reactions; tags are never added to the list of recent reactions
Implementation
final bool updateRecentReactions;
updateRecentReactions Pass true if the reaction needs to be added to recent reactions; tags are never added to the list of recent reactions
final bool updateRecentReactions;