entry property
entry The network statistics entry with the data to be added to statistics
Implementation
final NetworkStatisticsEntry? entry;
entry The network statistics entry with the data to be added to statistics
final NetworkStatisticsEntry? entry;