options property
options Options to be used to send the message. New information about the suggested post must always be specified
Implementation
final MessageSendOptions? options;
options Options to be used to send the message. New information about the suggested post must always be specified
final MessageSendOptions? options;