starCount property

int starCount
final

starCount Number of Telegram Stars to be used for the reaction. The total number of pending paid reactions must not exceed getOption("paid_reaction_star_count_max")

Implementation

final int starCount;