AddProfileAudio class final

Adds an audio file to the beginning of the profile audio files of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddProfileAudio({InputAudio? audio})

Properties

audio InputAudio?
audio The audio to add
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputAudio? audio}) AddProfileAudio

Available on AddProfileAudio, provided by the AddProfileAudioExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String