AddProxy class final
Adds a proxy server for network requests. Can be called before authorization Returns AddedProxy
- Inheritance
-
- Object
- TdFunction
- AddProxy
- Available extensions
- Annotations
-
- @immutable
Properties
- comment → String
-
comment Comment to set for the proxy
final
- enable → bool
-
enable Pass true to immediately enable the proxy
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- proxy → Proxy?
-
proxy The proxy to add
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Proxy? proxy, bool? enable, String? comment}) → AddProxy -
Available on AddProxy, provided by the AddProxyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String