AddQuickReplyShortcutInlineQueryResultMessage class final

Adds a message to a quick reply shortcut via inline bot. If shortcut doesn't exist and there are less than getOption("quick_reply_shortcut_count_max") shortcuts, then a new shortcut is created. The shortcut must not contain more than getOption("quick_reply_shortcut_message_count_max") messages after adding the new message. Returns the added message Returns QuickReplyMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddQuickReplyShortcutInlineQueryResultMessage({required String shortcutName, required int replyToMessageId, required int queryId, required String resultId, required bool hideViaBot})

Properties

hashCode int
The hash code for this object.
no setteroverride
hideViaBot bool
hideViaBot Pass true to hide the bot, via which the message is sent. Can be used only for bots getOption("animation_search_bot_username"), getOption("photo_search_bot_username"), and getOption("venue_search_bot_username")
final
queryId int
queryId Identifier of the inline query
final
replyToMessageId int
replyToMessageId Identifier of a quick reply message in the same shortcut to be replied; pass 0 if none
final
resultId String
resultId Identifier of the inline query result
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutName String
shortcutName Name of the target shortcut
final

Methods

copyWith({String? shortcutName, int? replyToMessageId, int? queryId, String? resultId, bool? hideViaBot}) AddQuickReplyShortcutInlineQueryResultMessage

Available on AddQuickReplyShortcutInlineQueryResultMessage, provided by the AddQuickReplyShortcutInlineQueryResultMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String