AddQuickReplyShortcutMessage class final

Adds a message to a quick reply shortcut. If shortcut doesn't exist and there are less than getOption("quick_reply_shortcut_count_max") shortcuts, then a new shortcut is created. The shortcut must not contain more than getOption("quick_reply_shortcut_message_count_max") messages after adding the new message. Returns the added message Returns QuickReplyMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddQuickReplyShortcutMessage({required String shortcutName, required int replyToMessageId, InputMessageContent? inputMessageContent})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be added; inputMessagePaidMedia, inputMessageForwarded and inputMessageLiveLocation
final
replyToMessageId int
replyToMessageId Identifier of a quick reply message in the same shortcut to be replied; pass 0 if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutName String
shortcutName Name of the target shortcut
final

Methods

copyWith({String? shortcutName, int? replyToMessageId, InputMessageContent? inputMessageContent}) AddQuickReplyShortcutMessage

Available on AddQuickReplyShortcutMessage, provided by the AddQuickReplyShortcutMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String