AddQuickReplyShortcutMessageAlbum class final

Adds 2-10 messages grouped together into an album to a quick reply shortcut. Currently, only audio, document, photo and video messages can be grouped into an album. Documents and audio files can be only grouped in an album with messages of the same type. Returns sent messages Returns QuickReplyMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddQuickReplyShortcutMessageAlbum({required String shortcutName, required int replyToMessageId, required List<InputMessageContent> inputMessageContents})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputMessageContents List<InputMessageContent>
inputMessageContents Contents of messages to be sent. At most 10 messages can be added to an album. All messages must have the same value of show_caption_above_media
final
replyToMessageId int
replyToMessageId Identifier of a quick reply message in the same shortcut to be replied; pass 0 if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutName String
shortcutName Name of the target shortcut
final

Methods

copyWith({String? shortcutName, int? replyToMessageId, List<InputMessageContent>? inputMessageContents}) AddQuickReplyShortcutMessageAlbum

Available on AddQuickReplyShortcutMessageAlbum, provided by the AddQuickReplyShortcutMessageAlbumExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String