AddRecentSticker class final
Manually adds a new sticker to the list of recently used stickers. The new sticker is added to the top of the list. If the sticker was already in the list, it is removed from the list first. Only stickers belonging to a sticker set or in WEBP or WEBM format can be added to this list. Emoji stickers can't be added to recent stickers Returns Stickers
- Inheritance
-
- Object
- TdFunction
- AddRecentSticker
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddRecentSticker({required bool isAttached, InputFile? sticker})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAttached → bool
-
isAttached Pass true to add the sticker to the list of stickers recently
attached to photo or video files; pass false to add the sticker to the
list of recently sent stickers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputFile?
-
sticker Sticker file to add
final
Methods
-
copyWith(
{bool? isAttached, InputFile? sticker}) → AddRecentSticker -
Available on AddRecentSticker, provided by the AddRecentStickerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String