AddSavedNotificationSound class final

Adds a new notification sound to the list of saved notification sounds. The new notification sound is added to the top of the list. If it is already in the list, its position isn't changed Returns NotificationSound

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddSavedNotificationSound({InputFile? sound})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sound InputFile?
sound Notification sound file to add
final

Methods

copyWith({InputFile? sound}) AddSavedNotificationSound

Available on AddSavedNotificationSound, provided by the AddSavedNotificationSoundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String