AddStoryAlbumStories class final
Adds stories to the beginning of a previously created story album. If the album is owned by a supergroup or a channel chat, then requires can_edit_stories administrator right in the chat. Returns the changed album Returns StoryAlbum
- Inheritance
-
- Object
- TdFunction
- AddStoryAlbumStories
- Available extensions
- Annotations
-
- @immutable
Constructors
-
AddStoryAlbumStories({required int chatId, required int storyAlbumId, required List<
int> storyIds})
Properties
- chatId → int
-
chatId Identifier of the chat that owns the stories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyAlbumId → int
-
storyAlbumId Identifier of the story album
final
-
storyIds
→ List<
int> -
storyIds Identifier of the stories to add to the album;
1-getOption("story_album_size_max") identifiers. If after addition the
album has more than getOption("story_album_size_max") stories, then the
last one are removed from the album
final
Methods
-
copyWith(
{int? chatId, int? storyAlbumId, List< int> ? storyIds}) → AddStoryAlbumStories -
Available on AddStoryAlbumStories, provided by the AddStoryAlbumStoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String