storyIds property

List<int> storyIds
final

storyIds Identifier of the stories to add to the album; 1-getOption("story_album_size_max") identifiers. If after addition the album has more than getOption("story_album_size_max") stories, then the last one are removed from the album

Implementation

final List<int> storyIds;