AddTextCompositionStyle class final

Adds a custom text composition style to the list of used by the user styles. May return an error with a message "TONES_SAVED_TOO_MANY" if the maximum number of added custom styles getOption("added_text_composition_style_count_max") has been reached Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddTextCompositionStyle({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) AddTextCompositionStyle

Available on AddTextCompositionStyle, provided by the AddTextCompositionStyleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String