AddedProxies class final

Represents a list of added proxy servers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddedProxies({required List<AddedProxy> proxies})

Properties

hashCode int
The hash code for this object.
no setteroverride
proxies List<AddedProxy>
proxies List of proxy servers
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<AddedProxy>? proxies}) AddedProxies

Available on AddedProxies, provided by the AddedProxiesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AddedProxies?

Constants

constructor → const String