AddedProxy class final

Contains information about a proxy server added to the list of proxies

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddedProxy({required int id, required int lastUsedDate, required bool isEnabled, required String comment, Proxy? proxy})

Properties

comment String
comment Comment for the proxy added by the user
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the proxy
final
isEnabled bool
isEnabled True, if the proxy is enabled now
final
lastUsedDate int
lastUsedDate Point in time (Unix timestamp) when the proxy was last used; 0 if never
final
proxy Proxy?
proxy The proxy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? lastUsedDate, bool? isEnabled, String? comment, Proxy? proxy}) AddedProxy

Available on AddedProxy, provided by the AddedProxyExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AddedProxy?

Constants

constructor → const String