AddedReaction class final

Represents a reaction applied to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddedReaction({ReactionType? type, MessageSender? senderId, required bool isOutgoing, required int date})

Properties

date int
date Point in time (Unix timestamp) when the reaction was added
final
hashCode int
The hash code for this object.
no setteroverride
isOutgoing bool
isOutgoing True, if the reaction was added by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the chat member, applied the reaction
final
type ReactionType?
type Type of the reaction
final

Methods

copyWith({ReactionType? type, MessageSender? senderId, bool? isOutgoing, int? date}) AddedReaction

Available on AddedReaction, provided by the AddedReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AddedReaction?

Constants

constructor → const String