AddedReactions class final

Represents a list of reactions added to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddedReactions({required int totalCount, required List<AddedReaction> reactions, required String nextOffset})

Properties

hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
reactions List<AddedReaction>
reactions The list of added reactions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount The total number of found reactions
final

Methods

copyWith({int? totalCount, List<AddedReaction>? reactions, String? nextOffset}) AddedReactions

Available on AddedReactions, provided by the AddedReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AddedReactions?

Constants

constructor → const String