Address class final

Describes an address

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Address({required String countryCode, required String state, required String city, required String streetLine1, required String streetLine2, required String postalCode})

Properties

city String
city City
final
countryCode String
countryCode A two-letter ISO 3166-1 alpha-2 country code
final
hashCode int
The hash code for this object.
no setteroverride
postalCode String
postalCode Address postal code
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
state State, if applicable
final
streetLine1 String
streetLine1 First line of the address
final
streetLine2 String
streetLine2 Second line of the address
final

Methods

copyWith({String? countryCode, String? state, String? city, String? streetLine1, String? streetLine2, String? postalCode}) Address

Available on Address, provided by the AddressExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Address?

Constants

constructor → const String