AdvertisementSponsor class final

Information about the sponsor of an advertisement

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AdvertisementSponsor({required String url, Photo? photo, String? info})

Properties

hashCode int
The hash code for this object.
no setteroverride
info String?
info Additional optional information about the sponsor to be shown along with the advertisement
final
photo Photo?
photo Photo of the sponsor; may be null if must not be shown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url URL of the sponsor to be opened when the advertisement is clicked
final

Methods

copyWith({String? url, Photo? photo, String? info}) AdvertisementSponsor

Available on AdvertisementSponsor, provided by the AdvertisementSponsorExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AdvertisementSponsor?

Constants

constructor → const String