AffiliateInfo class final

Contains information about an affiliate that received commission from a Telegram Star transaction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AffiliateInfo({required int commissionPerMille, required int affiliateChatId, StarAmount? starAmount})

Properties

affiliateChatId int
affiliateChatId Identifier of the chat which received the commission
final
commissionPerMille int
commissionPerMille The number of Telegram Stars received by the affiliate for each 1000 Telegram Stars received by the program owner
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starAmount StarAmount?
starAmount The Telegram Star amount that was received by the affiliate; can be negative for refunds
final

Methods

copyWith({int? commissionPerMille, int? affiliateChatId, StarAmount? starAmount}) AffiliateInfo

Available on AffiliateInfo, provided by the AffiliateInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AffiliateInfo?

Constants

constructor → const String