AffiliateProgramInfo class final

Contains information about an active affiliate program

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AffiliateProgramInfo({AffiliateProgramParameters? parameters, required int endDate, StarAmount? dailyRevenuePerUserAmount})

Properties

dailyRevenuePerUserAmount StarAmount?
dailyRevenuePerUserAmount The amount of daily revenue per user in Telegram Stars of the bot that created the affiliate program
final
endDate int
endDate Point in time (Unix timestamp) when the affiliate program will be closed; 0 if the affiliate program isn't scheduled to be closed. If positive, then the program can't be connected using connectAffiliateProgram, but active connections will work until the date
final
hashCode int
The hash code for this object.
no setteroverride
parameters AffiliateProgramParameters?
parameters Parameters of the affiliate program
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AffiliateProgramParameters? parameters, int? endDate, StarAmount? dailyRevenuePerUserAmount}) AffiliateProgramInfo

Available on AffiliateProgramInfo, provided by the AffiliateProgramInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AffiliateProgramInfo?

Constants

constructor → const String