monthCount property
monthCount Number of months the program will be active; 0-36. If 0, then the program is eternal
Implementation
final int monthCount;
monthCount Number of months the program will be active; 0-36. If 0, then the program is eternal
final int monthCount;