AffiliateProgramSortOrderRevenue class final

The affiliate programs must be sorted by the expected revenue

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AffiliateProgramSortOrderRevenue()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult creationDate(AffiliateProgramSortOrderCreationDate value), required TResult profitability(AffiliateProgramSortOrderProfitability value), required TResult revenue(AffiliateProgramSortOrderRevenue value)}) → TResult

Available on AffiliateProgramSortOrder, provided by the AffiliateProgramSortOrderExtensions extension

maybeMap<TResult extends Object?>({TResult creationDate(AffiliateProgramSortOrderCreationDate value)?, TResult profitability(AffiliateProgramSortOrderProfitability value)?, TResult revenue(AffiliateProgramSortOrderRevenue value)?, required TResult orElse()}) → TResult

Available on AffiliateProgramSortOrder, provided by the AffiliateProgramSortOrderExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String