AffiliateTypeBot class final
The affiliate is a bot owned by the current user
- Inheritance
-
- Object
- TdObject
- AffiliateType
- AffiliateTypeBot
- Available extensions
- Annotations
-
- @immutable
Constructors
- AffiliateTypeBot({required int userId})
Properties
Methods
-
copyWith(
{int? userId}) → AffiliateTypeBot -
Available on AffiliateTypeBot, provided by the AffiliateTypeBotExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bot(AffiliateTypeBot value), required TResult channel(AffiliateTypeChannel value), required TResult currentUser(AffiliateTypeCurrentUser value)}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bot(AffiliateTypeBot value)?, TResult channel(AffiliateTypeChannel value)?, TResult currentUser(AffiliateTypeCurrentUser value)?, required TResult orElse()}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AffiliateTypeBot? -
Inherited by:
AffiliateTypeBot
AffiliateTypeChannel
AffiliateTypeCurrentUser
override
Constants
- constructor → const String