AffiliateTypeChannel class final
The affiliate is a channel chat where the current user has can_post_messages administrator right
- Inheritance
-
- Object
- TdObject
- AffiliateType
- AffiliateTypeChannel
- Available extensions
- Annotations
-
- @immutable
Constructors
- AffiliateTypeChannel({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → AffiliateTypeChannel -
Available on AffiliateTypeChannel, provided by the AffiliateTypeChannelExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bot(AffiliateTypeBot value), required TResult channel(AffiliateTypeChannel value), required TResult currentUser(AffiliateTypeCurrentUser value)}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bot(AffiliateTypeBot value)?, TResult channel(AffiliateTypeChannel value)?, TResult currentUser(AffiliateTypeCurrentUser value)?, required TResult orElse()}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AffiliateTypeChannel? -
Inherited by:
AffiliateTypeBot
AffiliateTypeChannel
AffiliateTypeCurrentUser
override
Constants
- constructor → const String