AffiliateTypeCurrentUser class final
The affiliate is the current user
- Inheritance
-
- Object
- TdObject
- AffiliateType
- AffiliateTypeCurrentUser
- Available extensions
- Annotations
-
- @immutable
Constructors
- AffiliateTypeCurrentUser()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bot(AffiliateTypeBot value), required TResult channel(AffiliateTypeChannel value), required TResult currentUser(AffiliateTypeCurrentUser value)}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bot(AffiliateTypeBot value)?, TResult channel(AffiliateTypeChannel value)?, TResult currentUser(AffiliateTypeCurrentUser value)?, required TResult orElse()}) → TResult -
Available on AffiliateType, provided by the AffiliateTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AffiliateTypeCurrentUser? -
Inherited by:
AffiliateTypeBot
AffiliateTypeChannel
AffiliateTypeCurrentUser
override
Constants
- constructor → const String