AgeVerificationParameters class final
Describes parameters for age verification of the current user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AgeVerificationParameters({required int minAge, required String verificationBotUsername, required String country})
Properties
- country → String
-
country Unique name for the country or region, which legislation
required age verification. May be used to get the corresponding
localization key
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- minAge → int
-
minAge The minimum age required to view restricted content
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verificationBotUsername → String
-
verificationBotUsername Username of the bot which main Web App may be
used to verify age of the user
final
Methods
-
copyWith(
{int? minAge, String? verificationBotUsername, String? country}) → AgeVerificationParameters -
Available on AgeVerificationParameters, provided by the AgeVerificationParametersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AgeVerificationParameters?
Constants
- constructor → const String