country property

String country
final

country Unique name for the country or region, which legislation required age verification. May be used to get the corresponding localization key

Implementation

final String country;