verificationBotUsername property
verificationBotUsername Username of the bot which main Web App may be used to verify age of the user
Implementation
final String verificationBotUsername;
verificationBotUsername Username of the bot which main Web App may be used to verify age of the user
final String verificationBotUsername;