AllowBotToSendMessages class final

Allows the specified bot to send messages to the user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AllowBotToSendMessages({required int botUserId})

Properties

botUserId int
botUserId Identifier of the target bot
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) AllowBotToSendMessages

Available on AllowBotToSendMessages, provided by the AllowBotToSendMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String