AllowUnpaidMessagesFromUser class final

Allows the specified user to send unpaid private messages to the current user by adding a rule to userPrivacySettingAllowUnpaidMessages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AllowUnpaidMessagesFromUser({required int userId, required bool refundPayments})

Properties

hashCode int
The hash code for this object.
no setteroverride
refundPayments bool
refundPayments Pass true to refund the user previously paid messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId, bool? refundPayments}) AllowUnpaidMessagesFromUser

Available on AllowUnpaidMessagesFromUser, provided by the AllowUnpaidMessagesFromUserExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String