AnimatedEmoji class final
Describes an animated or custom representation of an emoji
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- fitzpatrickType → int
-
fitzpatrickType Emoji modifier fitzpatrick type; 0-6; 0 if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → File?
-
sound File containing the sound to be played when the sticker is
clicked; may be null. The sound is encoded with the Opus codec, and stored
inside an OGG container
final
- sticker → Sticker?
-
sticker Sticker for the emoji; may be null if yet unknown for a custom
emoji. If the sticker is a custom emoji, then it can have arbitrary format
final
- stickerHeight → int
-
stickerHeight Expected height of the sticker, which can be used if the
sticker is null
final
- stickerWidth → int
-
stickerWidth Expected width of the sticker, which can be used if the
sticker is null
final
Methods
-
copyWith(
{Sticker? sticker, int? stickerWidth, int? stickerHeight, int? fitzpatrickType, File? sound}) → AnimatedEmoji -
Available on AnimatedEmoji, provided by the AnimatedEmojiExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AnimatedEmoji?
Constants
- constructor → const String