AnswerCustomQuery class final
Answers a custom query; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- AnswerCustomQuery
- Available extensions
- Annotations
-
- @immutable
Constructors
- AnswerCustomQuery({required int customQueryId, required String data})
Properties
- customQueryId → int
-
customQueryId Identifier of a custom query
final
- data → String
-
data JSON-serialized answer to the query
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? customQueryId, String? data}) → AnswerCustomQuery -
Available on AnswerCustomQuery, provided by the AnswerCustomQueryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String