AnswerPreCheckoutQuery class final

Sets the result of a pre-checkout query; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AnswerPreCheckoutQuery({required int preCheckoutQueryId, required String errorMessage})

Properties

errorMessage String
errorMessage An error message, empty on success
final
hashCode int
The hash code for this object.
no setteroverride
preCheckoutQueryId int
preCheckoutQueryId Identifier of the pre-checkout query
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? preCheckoutQueryId, String? errorMessage}) AnswerPreCheckoutQuery

Available on AnswerPreCheckoutQuery, provided by the AnswerPreCheckoutQueryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String