AnswerShippingQuery class final

Sets the result of a shipping query; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AnswerShippingQuery({required int shippingQueryId, required List<ShippingOption> shippingOptions, required String errorMessage})

Properties

errorMessage String
errorMessage An error message, empty on success
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingOptions List<ShippingOption>
shippingOptions Available shipping options
final
shippingQueryId int
shippingQueryId Identifier of the shipping query
final

Methods

copyWith({int? shippingQueryId, List<ShippingOption>? shippingOptions, String? errorMessage}) AnswerShippingQuery

Available on AnswerShippingQuery, provided by the AnswerShippingQueryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String