AnswerWebAppQuery class final
Sets the result of interaction with a Web App and sends corresponding message on behalf of the user to the chat from which the query originated; for bots only Returns InlineMessageId
- Inheritance
-
- Object
- TdFunction
- AnswerWebAppQuery
- Available extensions
- Annotations
-
- @immutable
Constructors
- AnswerWebAppQuery({required String webAppQueryId, InputInlineQueryResult? result})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- result → InputInlineQueryResult?
-
result The result of the query
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webAppQueryId → String
-
webAppQueryId Identifier of the Web App query
final
Methods
-
copyWith(
{String? webAppQueryId, InputInlineQueryResult? result}) → AnswerWebAppQuery -
Available on AnswerWebAppQuery, provided by the AnswerWebAppQueryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String