ApplyPremiumGiftCode class final

Applies a Telegram Premium gift code Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ApplyPremiumGiftCode({required String code})

Properties

code String
code The code to apply
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? code}) ApplyPremiumGiftCode

Available on ApplyPremiumGiftCode, provided by the ApplyPremiumGiftCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String