messageId property

int messageId
final

messageId Identifier of the message with the suggested post. Use messageProperties.can_be_approved to check whether the suggested post can be approved

Implementation

final int messageId;