ArchiveChatListSettings class final
Contains settings for automatic moving of chats to and from the Archive chat lists
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ArchiveChatListSettings({required bool archiveAndMuteNewChatsFromUnknownUsers, required bool keepUnmutedChatsArchived, required bool keepChatsFromFoldersArchived})
Properties
- archiveAndMuteNewChatsFromUnknownUsers → bool
-
archiveAndMuteNewChatsFromUnknownUsers True, if new chats from
non-contacts will be automatically archived and muted. Can be set to true
only if the option "can_archive_and_mute_new_chats_from_unknown_users" is
true
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- keepChatsFromFoldersArchived → bool
-
keepChatsFromFoldersArchived True, if unmuted chats, that are always
included or pinned in a folder, will be kept in the Archive chat list when
they get a new message. Ignored if keep_unmuted_chats_archived == true
final
- keepUnmutedChatsArchived → bool
-
keepUnmutedChatsArchived True, if unmuted chats will be kept in the
Archive chat list when they get a new message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? archiveAndMuteNewChatsFromUnknownUsers, bool? keepUnmutedChatsArchived, bool? keepChatsFromFoldersArchived}) → ArchiveChatListSettings -
Available on ArchiveChatListSettings, provided by the ArchiveChatListSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ArchiveChatListSettings?
Constants
- constructor → const String