androidSideMenuIcon property
androidSideMenuIcon Icon for the bot in SVG format for the official Android app side menu; may be null
Implementation
final File? androidSideMenuIcon;
androidSideMenuIcon Icon for the bot in SVG format for the official Android app side menu; may be null
final File? androidSideMenuIcon;