requestWriteAccess property
requestWriteAccess True, if the user must be asked for the permission to send messages to the bot
Implementation
final bool requestWriteAccess;
requestWriteAccess True, if the user must be asked for the permission to send messages to the bot
final bool requestWriteAccess;