showDisclaimerInSideMenu property
showDisclaimerInSideMenu True, if a disclaimer, why the bot is shown in the side menu, is needed
Implementation
final bool showDisclaimerInSideMenu;
showDisclaimerInSideMenu True, if a disclaimer, why the bot is shown in the side menu, is needed
final bool showDisclaimerInSideMenu;