showInAttachmentMenu property
showInAttachmentMenu True, if the bot must be shown in the attachment menu
Implementation
final bool showInAttachmentMenu;
showInAttachmentMenu True, if the bot must be shown in the attachment menu
final bool showInAttachmentMenu;