AttributeCraftPersistenceProbability class final

Describes chance of the crafted gift to have the backdrop or symbol of one of the original gifts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AttributeCraftPersistenceProbability({required List<int> persistenceChancePerMille})

Properties

hashCode int
The hash code for this object.
no setteroverride
persistenceChancePerMille List<int>
persistenceChancePerMille The 4 numbers that describe probability of the craft result to have the same attribute as one of the original gifts if 1, 2, 3, or 4 gifts with the attribute are used in the craft. Each number represents the number of crafted gifts with the original attribute per 1000 successful craftings
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? persistenceChancePerMille}) AttributeCraftPersistenceProbability

Available on AttributeCraftPersistenceProbability, provided by the AttributeCraftPersistenceProbabilityExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AttributeCraftPersistenceProbability?

Constants

constructor → const String