persistenceChancePerMille property

List<int> persistenceChancePerMille
final

persistenceChancePerMille The 4 numbers that describe probability of the craft result to have the same attribute as one of the original gifts if 1, 2, 3, or 4 gifts with the attribute are used in the craft. Each number represents the number of crafted gifts with the original attribute per 1000 successful craftings

Implementation

final List<int> persistenceChancePerMille;