AuctionBid class final

Describes a bid in an auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuctionBid({required int starCount, required int bidDate, required int position})

Properties

bidDate int
bidDate Point in time (Unix timestamp) when the bid was made
final
hashCode int
The hash code for this object.
no setteroverride
position int
position Position of the bid in the list of all bids
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars that were put in the bid
final

Methods

copyWith({int? starCount, int? bidDate, int? position}) AuctionBid

Available on AuctionBid, provided by the AuctionBidExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AuctionBid?

Constants

constructor → const String