extendTime property
extendTime The number of seconds for which the round will be extended if there are changes in the top winners
Implementation
final int extendTime;
extendTime The number of seconds for which the round will be extended if there are changes in the top winners
final int extendTime;