AuctionState class sealed

Describes state of an auction

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult active(AuctionStateActive value), required TResult finished(AuctionStateFinished value)}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

maybeMap<TResult extends Object?>({TResult active(AuctionStateActive value)?, TResult finished(AuctionStateFinished value)?, required TResult orElse()}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AuctionState?
Inherited by: AuctionStateActive AuctionStateFinished

Constants

constructor → const String