AuctionStateActive class final

Contains information about an ongoing or scheduled auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuctionStateActive({required int startDate, required int endDate, required int minBid, required List<AuctionBid> bidLevels, required List<int> topBidderUserIds, required List<AuctionRound> rounds, required int currentRoundEndDate, required int currentRoundNumber, required int totalRoundCount, required int distributedItemCount, required int leftItemCount, required int acquiredItemCount, UserAuctionBid? userBid})

Properties

acquiredItemCount → int
acquiredItemCount The number of items that were purchased by the current user on the auction
final
bidLevels → List<AuctionBid>
bidLevels A sparse list of bids that were made in the auction
final
currentRoundEndDate → int
currentRoundEndDate Point in time (Unix timestamp) when the current round will end
final
currentRoundNumber → int
currentRoundNumber 1-based number of the current round
final
distributedItemCount → int
distributedItemCount The number of items that were purchased on the auction by all users
final
endDate → int
endDate Point in time (Unix timestamp) when the auction will be ended
final
hashCode → int
The hash code for this object.
no setteroverride
leftItemCount → int
leftItemCount The number of items that have to be distributed on the auction
final
minBid → int
minBid The minimum possible bid in the auction in Telegram Stars
final
rounds → List<AuctionRound>
rounds Rounds of the auction in which their duration or extension rules are changed
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int
startDate Point in time (Unix timestamp) when the auction started or will start
final
topBidderUserIds → List<int>
topBidderUserIds User identifiers of at most 3 users with the biggest bids
final
totalRoundCount → int
totalRoundCount The total number of rounds
final
userBid → UserAuctionBid?
userBid Bid of the current user in the auction; may be null if none
final

Methods

copyWith({int? startDate, int? endDate, int? minBid, List<AuctionBid>? bidLevels, List<int>? topBidderUserIds, List<AuctionRound>? rounds, int? currentRoundEndDate, int? currentRoundNumber, int? totalRoundCount, int? distributedItemCount, int? leftItemCount, int? acquiredItemCount, UserAuctionBid? userBid}) → AuctionStateActive

Available on AuctionStateActive, provided by the AuctionStateActiveExtensions extension

getConstructor() → String
override
map<TResult extends Object?>({required TResult active(AuctionStateActive value), required TResult finished(AuctionStateFinished value)}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

maybeMap<TResult extends Object?>({TResult active(AuctionStateActive value)?, TResult finished(AuctionStateFinished value)?, required TResult orElse()}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → AuctionStateActive?
Inherited by: AuctionStateActive AuctionStateFinished
override

Constants

constructor → const String