distributedItemCount property
distributedItemCount The number of items that were purchased on the auction by all users
Implementation
final int distributedItemCount;
distributedItemCount The number of items that were purchased on the auction by all users
final int distributedItemCount;