AuctionStateFinished class final

Contains information about a finished auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuctionStateFinished({required int startDate, required int endDate, required int averagePrice, required int acquiredItemCount, required int telegramListedItemCount, required int fragmentListedItemCount, required String fragmentUrl})

Properties

acquiredItemCount → int
acquiredItemCount The number of items that were purchased by the current user on the auction
final
averagePrice → int
averagePrice Average price of bought items in Telegram Stars
final
endDate → int
endDate Point in time (Unix timestamp) when the auction will be ended
final
fragmentListedItemCount → int
fragmentListedItemCount Number of items from the auction being resold on Fragment
final
fragmentUrl → String
fragmentUrl The HTTPS link to the Fragment for the resold items; may be empty if there are no such items being sold on Fragment
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate → int
startDate Point in time (Unix timestamp) when the auction started
final
telegramListedItemCount → int
telegramListedItemCount Number of items from the auction being resold on Telegram
final

Methods

copyWith({int? startDate, int? endDate, int? averagePrice, int? acquiredItemCount, int? telegramListedItemCount, int? fragmentListedItemCount, String? fragmentUrl}) → AuctionStateFinished

Available on AuctionStateFinished, provided by the AuctionStateFinishedExtensions extension

getConstructor() → String
override
map<TResult extends Object?>({required TResult active(AuctionStateActive value), required TResult finished(AuctionStateFinished value)}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

maybeMap<TResult extends Object?>({TResult active(AuctionStateActive value)?, TResult finished(AuctionStateFinished value)?, required TResult orElse()}) → TResult

Available on AuctionState, provided by the AuctionStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → AuctionStateFinished?
Inherited by: AuctionStateActive AuctionStateFinished
override

Constants

constructor → const String