acquiredItemCount property
acquiredItemCount The number of items that were purchased by the current user on the auction
Implementation
final int acquiredItemCount;
acquiredItemCount The number of items that were purchased by the current user on the auction
final int acquiredItemCount;