Audios class final
Contains a list of audio files
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Properties
-
audios
→ List<
Audio> -
audios List of audio files
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Approximate total number of audio files found
final
Methods
-
copyWith(
{int? totalCount, List< Audio> ? audios}) → Audios -
Available on Audios, provided by the AudiosExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String