pushTimeout property
pushTimeout Time after the next authentication method is expected to be used if verification push notification isn't received, in seconds
Implementation
final int pushTimeout;
pushTimeout Time after the next authentication method is expected to be used if verification push notification isn't received, in seconds
final int pushTimeout;