AuthenticationCodeTypeSms class final

A digit-only authentication code is delivered via an SMS message to the specified phone number; non-official applications may not receive this type of code

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuthenticationCodeTypeSms({required int length})

Properties

hashCode int
The hash code for this object.
no setteroverride
length int
length Length of the code
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? length}) AuthenticationCodeTypeSms

Available on AuthenticationCodeTypeSms, provided by the AuthenticationCodeTypeSmsExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult call(AuthenticationCodeTypeCall value), required TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value), required TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value), required TResult flashCall(AuthenticationCodeTypeFlashCall value), required TResult fragment(AuthenticationCodeTypeFragment value), required TResult missedCall(AuthenticationCodeTypeMissedCall value), required TResult sms(AuthenticationCodeTypeSms value), required TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value), required TResult smsWord(AuthenticationCodeTypeSmsWord value), required TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)}) → TResult

Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension

maybeMap<TResult extends Object?>({TResult call(AuthenticationCodeTypeCall value)?, TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value)?, TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value)?, TResult flashCall(AuthenticationCodeTypeFlashCall value)?, TResult fragment(AuthenticationCodeTypeFragment value)?, TResult missedCall(AuthenticationCodeTypeMissedCall value)?, TResult sms(AuthenticationCodeTypeSms value)?, TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value)?, TResult smsWord(AuthenticationCodeTypeSmsWord value)?, TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)?, required TResult orElse()}) → TResult

Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String