AuthenticationCodeTypeSmsPhrase class final
An authentication code is a phrase from multiple words delivered via an SMS message to the specified phone number; non-official applications may not receive this type of code
- Inheritance
-
- Object
- TdObject
- AuthenticationCodeType
- AuthenticationCodeTypeSmsPhrase
- Available extensions
- Annotations
-
- @immutable
Constructors
- AuthenticationCodeTypeSmsPhrase({required String firstWord})
Properties
Methods
-
copyWith(
{String? firstWord}) → AuthenticationCodeTypeSmsPhrase -
Available on AuthenticationCodeTypeSmsPhrase, provided by the AuthenticationCodeTypeSmsPhraseExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult call(AuthenticationCodeTypeCall value), required TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value), required TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value), required TResult flashCall(AuthenticationCodeTypeFlashCall value), required TResult fragment(AuthenticationCodeTypeFragment value), required TResult missedCall(AuthenticationCodeTypeMissedCall value), required TResult sms(AuthenticationCodeTypeSms value), required TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value), required TResult smsWord(AuthenticationCodeTypeSmsWord value), required TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult call(AuthenticationCodeTypeCall value)?, TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value)?, TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value)?, TResult flashCall(AuthenticationCodeTypeFlashCall value)?, TResult fragment(AuthenticationCodeTypeFragment value)?, TResult missedCall(AuthenticationCodeTypeMissedCall value)?, TResult sms(AuthenticationCodeTypeSms value)?, TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value)?, TResult smsWord(AuthenticationCodeTypeSmsWord value)?, TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)?, required TResult orElse()}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AuthenticationCodeTypeSmsPhrase? -
Inherited by:
AuthenticationCodeTypeCall
AuthenticationCodeTypeFirebaseAndroid
AuthenticationCodeTypeFirebaseIos
AuthenticationCodeTypeFlashCall
AuthenticationCodeTypeFragment
AuthenticationCodeTypeMissedCall
AuthenticationCodeTypeSms
AuthenticationCodeTypeSmsPhrase
AuthenticationCodeTypeSmsWord
AuthenticationCodeTypeTelegramMessage
override
Constants
- constructor → const String