AuthorizationStateClosed class final
TDLib client is in its final state. All databases are closed and all resources are released. No other updates will be received after this. All queries will be responded to with error code 500. To continue working, one must create a new instance of the TDLib client
- Inheritance
-
- Object
- TdObject
- AuthorizationState
- AuthorizationStateClosed
- Available extensions
- Annotations
-
- @immutable
Constructors
- AuthorizationStateClosed()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult closed(AuthorizationStateClosed value), required TResult closing(AuthorizationStateClosing value), required TResult loggingOut(AuthorizationStateLoggingOut value), required TResult ready(AuthorizationStateReady value), required TResult waitCode(AuthorizationStateWaitCode value), required TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value), required TResult waitEmailCode(AuthorizationStateWaitEmailCode value), required TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value), required TResult waitPassword(AuthorizationStateWaitPassword value), required TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value), required TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value), required TResult waitRegistration(AuthorizationStateWaitRegistration value), required TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)}) → TResult -
Available on AuthorizationState, provided by the AuthorizationStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult closed(AuthorizationStateClosed value)?, TResult closing(AuthorizationStateClosing value)?, TResult loggingOut(AuthorizationStateLoggingOut value)?, TResult ready(AuthorizationStateReady value)?, TResult waitCode(AuthorizationStateWaitCode value)?, TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value)?, TResult waitEmailCode(AuthorizationStateWaitEmailCode value)?, TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value)?, TResult waitPassword(AuthorizationStateWaitPassword value)?, TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value)?, TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value)?, TResult waitRegistration(AuthorizationStateWaitRegistration value)?, TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)?, required TResult orElse()}) → TResult -
Available on AuthorizationState, provided by the AuthorizationStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AuthorizationStateClosed? -
Inherited by:
AuthorizationStateClosed
AuthorizationStateClosing
AuthorizationStateLoggingOut
AuthorizationStateReady
AuthorizationStateWaitCode
AuthorizationStateWaitEmailAddress
AuthorizationStateWaitEmailCode
AuthorizationStateWaitOtherDeviceConfirmation
AuthorizationStateWaitPassword
AuthorizationStateWaitPhoneNumber
AuthorizationStateWaitPremiumPurchase
AuthorizationStateWaitRegistration
AuthorizationStateWaitTdlibParameters
override
Constants
- constructor → const String