AuthorizationStateWaitEmailCode class final

TDLib needs the user's authentication code sent to an email address to authorize. Call checkAuthenticationEmailCode to provide the code

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuthorizationStateWaitEmailCode({required bool allowAppleId, required bool allowGoogleId, EmailAddressAuthenticationCodeInfo? codeInfo, EmailAddressResetState? emailAddressResetState})

Properties

allowAppleId bool
allowAppleId True, if authorization through Apple ID is allowed
final
allowGoogleId bool
allowGoogleId True, if authorization through Google ID is allowed
final
codeInfo EmailAddressAuthenticationCodeInfo?
codeInfo Information about the sent authentication code
final
emailAddressResetState EmailAddressResetState?
emailAddressResetState Reset state of the email address; may be null if the email address can't be reset
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowAppleId, bool? allowGoogleId, EmailAddressAuthenticationCodeInfo? codeInfo, EmailAddressResetState? emailAddressResetState}) AuthorizationStateWaitEmailCode

Available on AuthorizationStateWaitEmailCode, provided by the AuthorizationStateWaitEmailCodeExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult closed(AuthorizationStateClosed value), required TResult closing(AuthorizationStateClosing value), required TResult loggingOut(AuthorizationStateLoggingOut value), required TResult ready(AuthorizationStateReady value), required TResult waitCode(AuthorizationStateWaitCode value), required TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value), required TResult waitEmailCode(AuthorizationStateWaitEmailCode value), required TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value), required TResult waitPassword(AuthorizationStateWaitPassword value), required TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value), required TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value), required TResult waitRegistration(AuthorizationStateWaitRegistration value), required TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

maybeMap<TResult extends Object?>({TResult closed(AuthorizationStateClosed value)?, TResult closing(AuthorizationStateClosing value)?, TResult loggingOut(AuthorizationStateLoggingOut value)?, TResult ready(AuthorizationStateReady value)?, TResult waitCode(AuthorizationStateWaitCode value)?, TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value)?, TResult waitEmailCode(AuthorizationStateWaitEmailCode value)?, TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value)?, TResult waitPassword(AuthorizationStateWaitPassword value)?, TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value)?, TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value)?, TResult waitRegistration(AuthorizationStateWaitRegistration value)?, TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)?, required TResult orElse()}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String