AuthorizationStateWaitPassword class final

The user has been authorized, but needs to enter a 2-step verification password to start using the application. Call checkAuthenticationPassword to provide the password, or requestAuthenticationPasswordRecovery to recover the password, or deleteAccount to delete the account after a week

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuthorizationStateWaitPassword({required String passwordHint, required bool hasRecoveryEmailAddress, required bool hasPassportData, required String recoveryEmailAddressPattern})

Properties

hashCode int
The hash code for this object.
no setteroverride
hasPassportData bool
hasPassportData True, if some Telegram Passport elements were saved
final
hasRecoveryEmailAddress bool
hasRecoveryEmailAddress True, if a recovery email address has been set up
final
passwordHint String
passwordHint Hint for the password; may be empty
final
recoveryEmailAddressPattern String
recoveryEmailAddressPattern Pattern of the email address to which the recovery email was sent; empty until a recovery email has been sent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? passwordHint, bool? hasRecoveryEmailAddress, bool? hasPassportData, String? recoveryEmailAddressPattern}) AuthorizationStateWaitPassword

Available on AuthorizationStateWaitPassword, provided by the AuthorizationStateWaitPasswordExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult closed(AuthorizationStateClosed value), required TResult closing(AuthorizationStateClosing value), required TResult loggingOut(AuthorizationStateLoggingOut value), required TResult ready(AuthorizationStateReady value), required TResult waitCode(AuthorizationStateWaitCode value), required TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value), required TResult waitEmailCode(AuthorizationStateWaitEmailCode value), required TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value), required TResult waitPassword(AuthorizationStateWaitPassword value), required TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value), required TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value), required TResult waitRegistration(AuthorizationStateWaitRegistration value), required TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

maybeMap<TResult extends Object?>({TResult closed(AuthorizationStateClosed value)?, TResult closing(AuthorizationStateClosing value)?, TResult loggingOut(AuthorizationStateLoggingOut value)?, TResult ready(AuthorizationStateReady value)?, TResult waitCode(AuthorizationStateWaitCode value)?, TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value)?, TResult waitEmailCode(AuthorizationStateWaitEmailCode value)?, TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value)?, TResult waitPassword(AuthorizationStateWaitPassword value)?, TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value)?, TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value)?, TResult waitRegistration(AuthorizationStateWaitRegistration value)?, TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)?, required TResult orElse()}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String