AuthorizationStateWaitPremiumPurchase class final

The user must buy Telegram Premium as an in-store purchase to log in. Call checkAuthenticationPremiumPurchase and then setAuthenticationPremiumPurchaseTransaction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuthorizationStateWaitPremiumPurchase({required String storeProductId, required int premiumDayCount, required String supportEmailAddress, required String supportEmailSubject})

Properties

hashCode int
The hash code for this object.
no setteroverride
premiumDayCount int
premiumDayCount Duration of the Telegram Premium subscription after the purchase; may be 0 if Telegram Premium subscription will not be granted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeProductId String
storeProductId Identifier of the store product that must be bought
final
supportEmailAddress String
supportEmailAddress Email address to use for support if the user has issues with Telegram Premium purchase
final
supportEmailSubject String
supportEmailSubject Subject for the email sent to the support email address
final

Methods

copyWith({String? storeProductId, int? premiumDayCount, String? supportEmailAddress, String? supportEmailSubject}) AuthorizationStateWaitPremiumPurchase

Available on AuthorizationStateWaitPremiumPurchase, provided by the AuthorizationStateWaitPremiumPurchaseExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult closed(AuthorizationStateClosed value), required TResult closing(AuthorizationStateClosing value), required TResult loggingOut(AuthorizationStateLoggingOut value), required TResult ready(AuthorizationStateReady value), required TResult waitCode(AuthorizationStateWaitCode value), required TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value), required TResult waitEmailCode(AuthorizationStateWaitEmailCode value), required TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value), required TResult waitPassword(AuthorizationStateWaitPassword value), required TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value), required TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value), required TResult waitRegistration(AuthorizationStateWaitRegistration value), required TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

maybeMap<TResult extends Object?>({TResult closed(AuthorizationStateClosed value)?, TResult closing(AuthorizationStateClosing value)?, TResult loggingOut(AuthorizationStateLoggingOut value)?, TResult ready(AuthorizationStateReady value)?, TResult waitCode(AuthorizationStateWaitCode value)?, TResult waitEmailAddress(AuthorizationStateWaitEmailAddress value)?, TResult waitEmailCode(AuthorizationStateWaitEmailCode value)?, TResult waitOtherDeviceConfirmation(AuthorizationStateWaitOtherDeviceConfirmation value)?, TResult waitPassword(AuthorizationStateWaitPassword value)?, TResult waitPhoneNumber(AuthorizationStateWaitPhoneNumber value)?, TResult waitPremiumPurchase(AuthorizationStateWaitPremiumPurchase value)?, TResult waitRegistration(AuthorizationStateWaitRegistration value)?, TResult waitTdlibParameters(AuthorizationStateWaitTdlibParameters value)?, required TResult orElse()}) → TResult

Available on AuthorizationState, provided by the AuthorizationStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String