AutoDownloadSettingsPresets class final

Contains auto-download settings presets for the current user

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
high AutoDownloadSettings?
high Preset with highest settings; expected to be used by default when connected on Wi-Fi
final
low AutoDownloadSettings?
low Preset with lowest settings; expected to be used by default when roaming
final
medium AutoDownloadSettings?
medium Preset with medium settings; expected to be used by default when using mobile data
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AutoDownloadSettings? low, AutoDownloadSettings? medium, AutoDownloadSettings? high}) AutoDownloadSettingsPresets

Available on AutoDownloadSettingsPresets, provided by the AutoDownloadSettingsPresetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AutoDownloadSettingsPresets?

Constants

constructor → const String