high property
high Preset with highest settings; expected to be used by default when connected on Wi-Fi
Implementation
final AutoDownloadSettings? high;
high Preset with highest settings; expected to be used by default when connected on Wi-Fi
final AutoDownloadSettings? high;