AutosaveSettingsScopePrivateChats class final
Autosave settings applied to all private chats without chat-specific settings
- Inheritance
-
- Object
- TdObject
- AutosaveSettingsScope
- AutosaveSettingsScopePrivateChats
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult channelChats(AutosaveSettingsScopeChannelChats value), required TResult chat(AutosaveSettingsScopeChat value), required TResult groupChats(AutosaveSettingsScopeGroupChats value), required TResult privateChats(AutosaveSettingsScopePrivateChats value)}) → TResult -
Available on AutosaveSettingsScope, provided by the AutosaveSettingsScopeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult channelChats(AutosaveSettingsScopeChannelChats value)?, TResult chat(AutosaveSettingsScopeChat value)?, TResult groupChats(AutosaveSettingsScopeGroupChats value)?, TResult privateChats(AutosaveSettingsScopePrivateChats value)?, required TResult orElse()}) → TResult -
Available on AutosaveSettingsScope, provided by the AutosaveSettingsScopeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AutosaveSettingsScopePrivateChats? -
Inherited by:
AutosaveSettingsScopeChannelChats
AutosaveSettingsScopeChat
AutosaveSettingsScopeGroupChats
AutosaveSettingsScopePrivateChats
override
Constants
- constructor → const String