AvailableReaction class final

Represents an available reaction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AvailableReaction({ReactionType? type, required bool needsPremium})

Properties

hashCode int
The hash code for this object.
no setteroverride
needsPremium bool
needsPremium True, if Telegram Premium is needed to send the reaction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ReactionType?
type Type of the reaction
final

Methods

copyWith({ReactionType? type, bool? needsPremium}) AvailableReaction

Available on AvailableReaction, provided by the AvailableReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AvailableReaction?

Constants

constructor → const String