AvailableReactions class final

Represents a list of reactions that can be added to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AvailableReactions({required List<AvailableReaction> topReactions, required List<AvailableReaction> recentReactions, required List<AvailableReaction> popularReactions, required bool allowCustomEmoji, required bool areTags, ReactionUnavailabilityReason? unavailabilityReason})

Properties

allowCustomEmoji bool
allowCustomEmoji True, if any custom emoji reaction can be added by Telegram Premium subscribers
final
areTags bool
areTags True, if the reactions will be tags and the message can be found by them
final
hashCode int
The hash code for this object.
no setteroverride
popularReactions List<AvailableReaction>
popularReactions List of popular reactions
final
recentReactions List<AvailableReaction>
recentReactions List of recently used reactions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topReactions List<AvailableReaction>
topReactions List of reactions to be shown at the top
final
unavailabilityReason ReactionUnavailabilityReason?
unavailabilityReason The reason why the current user can't add reactions to the message, despite some other users can; may be null if none
final

Methods

copyWith({List<AvailableReaction>? topReactions, List<AvailableReaction>? recentReactions, List<AvailableReaction>? popularReactions, bool? allowCustomEmoji, bool? areTags, ReactionUnavailabilityReason? unavailabilityReason}) AvailableReactions

Available on AvailableReactions, provided by the AvailableReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AvailableReactions?

Constants

constructor → const String