allowCustomEmoji property
allowCustomEmoji True, if any custom emoji reaction can be added by Telegram Premium subscribers
Implementation
final bool allowCustomEmoji;
allowCustomEmoji True, if any custom emoji reaction can be added by Telegram Premium subscribers
final bool allowCustomEmoji;