unavailabilityReason property
unavailabilityReason The reason why the current user can't add reactions to the message, despite some other users can; may be null if none
Implementation
final ReactionUnavailabilityReason? unavailabilityReason;
unavailabilityReason The reason why the current user can't add reactions to the message, despite some other users can; may be null if none
final ReactionUnavailabilityReason? unavailabilityReason;