Background class final

Describes a chat background

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Background({required int id, required bool isDefault, required bool isDark, required String name, Document? document, BackgroundType? type})

Properties

document Document?
document Document with the background; may be null. Null only for filled and chat theme backgrounds
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique background identifier
final
isDark bool
isDark True, if the background is dark and is recommended to be used with dark theme
final
isDefault bool
isDefault True, if this is one of default backgrounds
final
name String
name Unique background name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type BackgroundType?
type Type of the background
final

Methods

copyWith({int? id, bool? isDefault, bool? isDark, String? name, Document? document, BackgroundType? type}) Background

Available on Background, provided by the BackgroundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Background?

Constants

constructor → const String