BackgroundFill class sealed

Describes a fill of a background

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult freeformGradient(BackgroundFillFreeformGradient value), required TResult gradient(BackgroundFillGradient value), required TResult solid(BackgroundFillSolid value)}) → TResult

Available on BackgroundFill, provided by the BackgroundFillExtensions extension

maybeMap<TResult extends Object?>({TResult freeformGradient(BackgroundFillFreeformGradient value)?, TResult gradient(BackgroundFillGradient value)?, TResult solid(BackgroundFillSolid value)?, required TResult orElse()}) → TResult

Available on BackgroundFill, provided by the BackgroundFillExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String