BackgroundFillSolid class final

Describes a solid fill of a background

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BackgroundFillSolid({required int color})

Properties

color int
color A color of the background in the RGB format
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? color}) BackgroundFillSolid

Available on BackgroundFillSolid, provided by the BackgroundFillSolidExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult freeformGradient(BackgroundFillFreeformGradient value), required TResult gradient(BackgroundFillGradient value), required TResult solid(BackgroundFillSolid value)}) → TResult

Available on BackgroundFill, provided by the BackgroundFillExtensions extension

maybeMap<TResult extends Object?>({TResult freeformGradient(BackgroundFillFreeformGradient value)?, TResult gradient(BackgroundFillGradient value)?, TResult solid(BackgroundFillSolid value)?, required TResult orElse()}) → TResult

Available on BackgroundFill, provided by the BackgroundFillExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String