BackgroundTypeChatTheme class final
A background from a chat theme based on an emoji; can be used only as a chat background in channels
- Inheritance
-
- Object
- TdObject
- BackgroundType
- BackgroundTypeChatTheme
- Available extensions
- Annotations
-
- @immutable
Constructors
- BackgroundTypeChatTheme({required String themeName})
Properties
Methods
-
copyWith(
{String? themeName}) → BackgroundTypeChatTheme -
Available on BackgroundTypeChatTheme, provided by the BackgroundTypeChatThemeExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chatTheme(BackgroundTypeChatTheme value), required TResult fill(BackgroundTypeFill value), required TResult pattern(BackgroundTypePattern value), required TResult wallpaper(BackgroundTypeWallpaper value)}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chatTheme(BackgroundTypeChatTheme value)?, TResult fill(BackgroundTypeFill value)?, TResult pattern(BackgroundTypePattern value)?, TResult wallpaper(BackgroundTypeWallpaper value)?, required TResult orElse()}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BackgroundTypeChatTheme? -
Inherited by:
BackgroundTypeChatTheme
BackgroundTypeFill
BackgroundTypePattern
BackgroundTypeWallpaper
override
Constants
- constructor → const String