BackgroundTypeWallpaper class final

A wallpaper in JPEG format

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BackgroundTypeWallpaper({required bool isBlurred, required bool isMoving})

Properties

hashCode int
The hash code for this object.
no setteroverride
isBlurred bool
isBlurred True, if the wallpaper must be downscaled to fit in 450x450 square and then box-blurred with radius 12
final
isMoving bool
isMoving True, if the background needs to be slightly moved when device is tilted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isBlurred, bool? isMoving}) BackgroundTypeWallpaper

Available on BackgroundTypeWallpaper, provided by the BackgroundTypeWallpaperExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult chatTheme(BackgroundTypeChatTheme value), required TResult fill(BackgroundTypeFill value), required TResult pattern(BackgroundTypePattern value), required TResult wallpaper(BackgroundTypeWallpaper value)}) → TResult

Available on BackgroundType, provided by the BackgroundTypeExtensions extension

maybeMap<TResult extends Object?>({TResult chatTheme(BackgroundTypeChatTheme value)?, TResult fill(BackgroundTypeFill value)?, TResult pattern(BackgroundTypePattern value)?, TResult wallpaper(BackgroundTypeWallpaper value)?, required TResult orElse()}) → TResult

Available on BackgroundType, provided by the BackgroundTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String