Backgrounds class final
Contains a list of backgrounds
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Backgrounds({required List<
Background> backgrounds})
Properties
-
backgrounds
→ List<
Background> -
backgrounds A list of backgrounds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< Background> ? backgrounds}) → Backgrounds -
Available on Backgrounds, provided by the BackgroundsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → Backgrounds?
Constants
- constructor → const String