BanChatMember class final
Bans a member in a chat; requires can_restrict_members administrator right. Members can't be banned in private or secret chats. In supergroups and channels, the user will not be able to return to the group on their own using invite links, etc., unless unbanned first Returns Ok
- Inheritance
-
- Object
- TdFunction
- BanChatMember
- Available extensions
- Annotations
-
- @immutable
Constructors
- BanChatMember({required int chatId, MessageSender? memberId, required int bannedUntilDate, required bool revokeMessages})
Properties
- bannedUntilDate → int
-
bannedUntilDate Point in time (Unix timestamp) when the user will be
unbanned; 0 if never. If the user is banned for more than 366 days or for
less than 30 seconds from the current time, the user is considered to be
banned forever. Ignored in basic groups and if a chat is banned
final
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- memberId → MessageSender?
-
memberId Member identifier
final
- revokeMessages → bool
-
revokeMessages Pass true to delete all messages in the chat for the user
who is being removed. Always true for supergroups and channels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, MessageSender? memberId, int? bannedUntilDate, bool? revokeMessages}) → BanChatMember -
Available on BanChatMember, provided by the BanChatMemberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String