BanGroupCallParticipants class final

Bans users from a group call not bound to a chat; requires groupCall.is_owned. Only the owner of the group call can invite the banned users back Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BanGroupCallParticipants({required int groupCallId, required List<int> userIds})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<int>
userIds Identifiers of group call participants to ban; identifiers of unknown users from the update updateGroupCallParticipants can be also passed to the method
final

Methods

copyWith({int? groupCallId, List<int>? userIds}) BanGroupCallParticipants

Available on BanGroupCallParticipants, provided by the BanGroupCallParticipantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String