BankCardActionOpenUrl class final
Describes an action associated with a bank card number
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BankCardActionOpenUrl({required String text, required String url})
Properties
Methods
-
copyWith(
{String? text, String? url}) → BankCardActionOpenUrl -
Available on BankCardActionOpenUrl, provided by the BankCardActionOpenUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BankCardActionOpenUrl?
Constants
- constructor → const String