BankCardInfo class final

Information about a bank card

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BankCardInfo({required String title, required List<BankCardActionOpenUrl> actions})

Properties

actions List<BankCardActionOpenUrl>
actions Actions that can be done with the bank card number
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Title of the bank card description
final

Methods

copyWith({String? title, List<BankCardActionOpenUrl>? actions}) BankCardInfo

Available on BankCardInfo, provided by the BankCardInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BankCardInfo?

Constants

constructor → const String