BasicGroupFullInfo class final
Contains full information about a basic group
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BasicGroupFullInfo({ChatPhoto? photo, required String description, required int creatorUserId, required List<
ChatMember> members, required bool canHideMembers, required bool canToggleAggressiveAntiSpam, ChatInviteLink? inviteLink, required List<BotCommands> botCommands})
Properties
-
botCommands
→ List<
BotCommands> -
botCommands List of commands of bots in the group
final
- canHideMembers → bool
-
canHideMembers True, if non-administrators and non-bots can be hidden in
responses to getSupergroupMembers and searchChatMembers for
non-administrators after upgrading the basic group to a supergroup
final
- canToggleAggressiveAntiSpam → bool
-
canToggleAggressiveAntiSpam True, if aggressive anti-spam checks can be
enabled or disabled in the supergroup after upgrading the basic group to a
supergroup
final
- creatorUserId → int
-
creatorUserId User identifier of the creator of the group; 0 if unknown
final
- description → String
-
param_description Group description. Updated only after the basic group
is opened
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → ChatInviteLink?
-
inviteLink Primary invite link for this group; may be null. For chat
administrators with can_invite_users right only. Updated only after the
basic group is opened
final
-
members
→ List<
ChatMember> -
members Group members
final
- photo → ChatPhoto?
-
photo Chat photo; may be null if empty or unknown. If non-null, then it
is the same photo as in chat.photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatPhoto? photo, String? description, int? creatorUserId, List< ChatMember> ? members, bool? canHideMembers, bool? canToggleAggressiveAntiSpam, ChatInviteLink? inviteLink, List<BotCommands> ? botCommands}) → BasicGroupFullInfo -
Available on BasicGroupFullInfo, provided by the BasicGroupFullInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BasicGroupFullInfo?
Constants
- constructor → const String