BlockListMain class final

The main block list that disallows writing messages to the current user, receiving their status and photo, viewing of stories, and some other actions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BlockListMain()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult main(BlockListMain value), required TResult stories(BlockListStories value)}) → TResult

Available on BlockList, provided by the BlockListExtensions extension

maybeMap<TResult extends Object?>({TResult main(BlockListMain value)?, TResult stories(BlockListStories value)?, required TResult orElse()}) → TResult

Available on BlockList, provided by the BlockListExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BlockListMain?
Inherited by: BlockListMain BlockListStories
override

Constants

constructor → const String