BlockListStories class final

The block list that disallows viewing of stories of the current user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BlockListStories()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult main(BlockListMain value), required TResult stories(BlockListStories value)}) → TResult

Available on BlockList, provided by the BlockListExtensions extension

maybeMap<TResult extends Object?>({TResult main(BlockListMain value)?, TResult stories(BlockListStories value)?, required TResult orElse()}) → TResult

Available on BlockList, provided by the BlockListExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BlockListStories?
Inherited by: BlockListMain BlockListStories
override

Constants

constructor → const String