BlockMessageSenderFromReplies class final

Blocks an original sender of a message in the Replies chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BlockMessageSenderFromReplies({required int messageId, required bool deleteMessage, required bool deleteAllMessages, required bool reportSpam})

Properties

deleteAllMessages bool
deleteAllMessages Pass true to delete all messages from the same sender
final
deleteMessage bool
deleteMessage Pass true to delete the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId The identifier of an incoming message in the Replies chat
final
reportSpam bool
reportSpam Pass true to report the sender to the Telegram moderators
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageId, bool? deleteMessage, bool? deleteAllMessages, bool? reportSpam}) BlockMessageSenderFromReplies

Available on BlockMessageSenderFromReplies, provided by the BlockMessageSenderFromRepliesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String