BoostChat class final

Boosts a chat and returns the list of available chat boost slots for the current user after the boost Returns ChatBoostSlots

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BoostChat({required int chatId, required List<int> slotIds})

Properties

chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotIds List<int>
slotIds Identifiers of boost slots of the current user from which to apply boosts to the chat
final

Methods

copyWith({int? chatId, List<int>? slotIds}) BoostChat

Available on BoostChat, provided by the BoostChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String