addedUserIds property
addedUserIds Identifiers of the users who can use the bot additionally to the owner of the bot
Implementation
final List<int> addedUserIds;
addedUserIds Identifiers of the users who can use the bot additionally to the owner of the bot
final List<int> addedUserIds;