isRestricted property
isRestricted True, if access to the bot is restricted to its owner and selected users
Implementation
final bool isRestricted;
isRestricted True, if access to the bot is restricted to its owner and selected users
final bool isRestricted;