isEphemeral property
isEphemeral True, if the command must send an ephemeral message instead of a regular one
Implementation
final bool isEphemeral;
isEphemeral True, if the command must send an ephemeral message instead of a regular one
final bool isEphemeral;