BotCommandScopeChat class final

A scope covering all members of a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BotCommandScopeChat({required int chatId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) BotCommandScopeChat

Available on BotCommandScopeChat, provided by the BotCommandScopeChatExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult allChatAdministrators(BotCommandScopeAllChatAdministrators value), required TResult allGroupChats(BotCommandScopeAllGroupChats value), required TResult allPrivateChats(BotCommandScopeAllPrivateChats value), required TResult chat(BotCommandScopeChat value), required TResult chatAdministrators(BotCommandScopeChatAdministrators value), required TResult chatMember(BotCommandScopeChatMember value), required TResult $default(BotCommandScopeDefault value)}) → TResult

Available on BotCommandScope, provided by the BotCommandScopeExtensions extension

maybeMap<TResult extends Object?>({TResult allChatAdministrators(BotCommandScopeAllChatAdministrators value)?, TResult allGroupChats(BotCommandScopeAllGroupChats value)?, TResult allPrivateChats(BotCommandScopeAllPrivateChats value)?, TResult chat(BotCommandScopeChat value)?, TResult chatAdministrators(BotCommandScopeChatAdministrators value)?, TResult chatMember(BotCommandScopeChatMember value)?, TResult $default(BotCommandScopeDefault value)?, required TResult orElse()}) → TResult

Available on BotCommandScope, provided by the BotCommandScopeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String