BotCommands class final

Contains a list of bot commands

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BotCommands({required int botUserId, required List<BotCommand> commands})

Properties

botUserId int
botUserId Bot's user identifier
final
commands List<BotCommand>
commands List of bot commands
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, List<BotCommand>? commands}) BotCommands

Available on BotCommands, provided by the BotCommandsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BotCommands?

Constants

constructor → const String