canGetRevenueStatistics property
canGetRevenueStatistics True, if the bot's revenue statistics are available to the current user
Implementation
final bool canGetRevenueStatistics;
canGetRevenueStatistics True, if the bot's revenue statistics are available to the current user
final bool canGetRevenueStatistics;