managerBotUserId property
managerBotUserId Identifier of the bot, which manages the bot; 0 if none or unknown; for owner of the bot only
Implementation
final int managerBotUserId;
managerBotUserId Identifier of the bot, which manages the bot; 0 if none or unknown; for owner of the bot only
final int managerBotUserId;