webAppBackgroundDarkColor property
webAppBackgroundDarkColor Default dark background color for bot Web Apps; -1 if not specified
Implementation
final int webAppBackgroundDarkColor;
webAppBackgroundDarkColor Default dark background color for bot Web Apps; -1 if not specified
final int webAppBackgroundDarkColor;