webAppBackgroundLightColor property
webAppBackgroundLightColor Default light background color for bot Web Apps; -1 if not specified
Implementation
final int webAppBackgroundLightColor;
webAppBackgroundLightColor Default light background color for bot Web Apps; -1 if not specified
final int webAppBackgroundLightColor;