webAppHeaderLightColor property
webAppHeaderLightColor Default light header color for bot Web Apps; -1 if not specified
Implementation
final int webAppHeaderLightColor;
webAppHeaderLightColor Default light header color for bot Web Apps; -1 if not specified
final int webAppHeaderLightColor;