BotMediaPreviewInfo class final

Contains a list of media previews of a bot for the given language and the list of languages for which the bot has dedicated previews

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BotMediaPreviewInfo({required List<BotMediaPreview> previews, required List<String> languageCodes})

Properties

hashCode int
The hash code for this object.
no setteroverride
languageCodes List<String>
languageCodes List of language codes for which the bot has dedicated previews
final
previews List<BotMediaPreview>
previews List of media previews
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<BotMediaPreview>? previews, List<String>? languageCodes}) BotMediaPreviewInfo

Available on BotMediaPreviewInfo, provided by the BotMediaPreviewInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BotMediaPreviewInfo?

Constants

constructor → const String