languageCodes property
languageCodes List of language codes for which the bot has dedicated previews
Implementation
final List<String> languageCodes;
languageCodes List of language codes for which the bot has dedicated previews
final List<String> languageCodes;