BotVerification class final

Describes verification status provided by a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BotVerification({required int botUserId, required int iconCustomEmojiId, FormattedText? customDescription})

Properties

botUserId int
botUserId Identifier of the bot that provided the verification
final
customDescription FormattedText?
customDescription Custom description of verification reason set by the bot. Can contain only Mention, Hashtag, Cashtag, PhoneNumber, BankCardNumber, Url, and EmailAddress entities
final
hashCode int
The hash code for this object.
no setteroverride
iconCustomEmojiId int
iconCustomEmojiId Identifier of the custom emoji that is used as the verification sign
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, int? iconCustomEmojiId, FormattedText? customDescription}) BotVerification

Available on BotVerification, provided by the BotVerificationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BotVerification?

Constants

constructor → const String