iconCustomEmojiId property
iconCustomEmojiId Identifier of the custom emoji that is used as the verification sign
Implementation
final int iconCustomEmojiId;
iconCustomEmojiId Identifier of the custom emoji that is used as the verification sign
final int iconCustomEmojiId;