BotVerificationParameters class final

Describes parameters of verification that is provided by a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BotVerificationParameters({required int iconCustomEmojiId, required String organizationName, FormattedText? defaultCustomDescription, required bool canSetCustomDescription})

Properties

canSetCustomDescription bool
canSetCustomDescription True, if the bot is allowed to provide custom description for verified entities
final
defaultCustomDescription FormattedText?
defaultCustomDescription Default custom description of verification reason to be used as placeholder in setMessageSenderBotVerification; may be null if none
final
hashCode int
The hash code for this object.
no setteroverride
iconCustomEmojiId int
iconCustomEmojiId Identifier of the custom emoji that is used as the verification sign
final
organizationName String
organizationName Name of the organization that provides verification
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? iconCustomEmojiId, String? organizationName, FormattedText? defaultCustomDescription, bool? canSetCustomDescription}) BotVerificationParameters

Available on BotVerificationParameters, provided by the BotVerificationParametersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BotVerificationParameters?

Constants

constructor → const String