BotWriteAccessAllowReason class sealed
Describes a reason why a bot was allowed to write messages to the current user
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult acceptedRequest(BotWriteAccessAllowReasonAcceptedRequest value), required TResult addedToAttachmentMenu(BotWriteAccessAllowReasonAddedToAttachmentMenu value), required TResult connectedWebsite(BotWriteAccessAllowReasonConnectedWebsite value), required TResult launchedWebApp(BotWriteAccessAllowReasonLaunchedWebApp value)}) → TResult -
Available on BotWriteAccessAllowReason, provided by the BotWriteAccessAllowReasonExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult acceptedRequest(BotWriteAccessAllowReasonAcceptedRequest value)?, TResult addedToAttachmentMenu(BotWriteAccessAllowReasonAddedToAttachmentMenu value)?, TResult connectedWebsite(BotWriteAccessAllowReasonConnectedWebsite value)?, TResult launchedWebApp(BotWriteAccessAllowReasonLaunchedWebApp value)?, required TResult orElse()}) → TResult -
Available on BotWriteAccessAllowReason, provided by the BotWriteAccessAllowReasonExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String