BuiltInThemeDay class final
Regular light theme
- Inheritance
-
- Object
- TdObject
- BuiltInTheme
- BuiltInThemeDay
- Available extensions
- Annotations
-
- @immutable
Constructors
- BuiltInThemeDay()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult arctic(BuiltInThemeArctic value), required TResult classic(BuiltInThemeClassic value), required TResult day(BuiltInThemeDay value), required TResult night(BuiltInThemeNight value), required TResult tinted(BuiltInThemeTinted value)}) → TResult -
Available on BuiltInTheme, provided by the BuiltInThemeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult arctic(BuiltInThemeArctic value)?, TResult classic(BuiltInThemeClassic value)?, TResult day(BuiltInThemeDay value)?, TResult night(BuiltInThemeNight value)?, TResult tinted(BuiltInThemeTinted value)?, required TResult orElse()}) → TResult -
Available on BuiltInTheme, provided by the BuiltInThemeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BuiltInThemeDay? -
Inherited by:
BuiltInThemeArctic
BuiltInThemeClassic
BuiltInThemeDay
BuiltInThemeNight
BuiltInThemeTinted
override
Constants
- constructor → const String