BusinessAwayMessageScheduleCustom class final

Send away messages only in the specified time span

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessAwayMessageScheduleCustom({required int startDate, required int endDate})

Properties

endDate int
endDate Point in time (Unix timestamp) when the away messages will stop to be sent
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate int
startDate Point in time (Unix timestamp) when the away messages will start to be sent
final

Methods

copyWith({int? startDate, int? endDate}) BusinessAwayMessageScheduleCustom

Available on BusinessAwayMessageScheduleCustom, provided by the BusinessAwayMessageScheduleCustomExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult always(BusinessAwayMessageScheduleAlways value), required TResult custom(BusinessAwayMessageScheduleCustom value), required TResult outsideOfOpeningHours(BusinessAwayMessageScheduleOutsideOfOpeningHours value)}) → TResult

Available on BusinessAwayMessageSchedule, provided by the BusinessAwayMessageScheduleExtensions extension

maybeMap<TResult extends Object?>({TResult always(BusinessAwayMessageScheduleAlways value)?, TResult custom(BusinessAwayMessageScheduleCustom value)?, TResult outsideOfOpeningHours(BusinessAwayMessageScheduleOutsideOfOpeningHours value)?, required TResult orElse()}) → TResult

Available on BusinessAwayMessageSchedule, provided by the BusinessAwayMessageScheduleExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String