schedule property
schedule Settings used to check whether the current user is away
Implementation
final BusinessAwayMessageSchedule? schedule;
schedule Settings used to check whether the current user is away
final BusinessAwayMessageSchedule? schedule;