canChangeGiftSettings property
canChangeGiftSettings True, if the bot can change gift receiving settings of the business account
Implementation
final bool canChangeGiftSettings;
canChangeGiftSettings True, if the bot can change gift receiving settings of the business account
final bool canChangeGiftSettings;