canSellGifts property
canSellGifts True, if the bot can sell regular gifts received by the business account
Implementation
final bool canSellGifts;
canSellGifts True, if the bot can sell regular gifts received by the business account
final bool canSellGifts;