canViewGiftsAndStars property
canViewGiftsAndStars True, if the bot can view gifts and Telegram Star amount owned by the business account
Implementation
final bool canViewGiftsAndStars;
canViewGiftsAndStars True, if the bot can view gifts and Telegram Star amount owned by the business account
final bool canViewGiftsAndStars;