BusinessChatLink class final

Contains information about a business chat link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessChatLink({required String link, FormattedText? text, required String title, required int viewCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The HTTPS link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Message draft text that will be added to the input field
final
title String
title Link title
final
viewCount int
viewCount Number of times the link was used
final

Methods

copyWith({String? link, FormattedText? text, String? title, int? viewCount}) BusinessChatLink

Available on BusinessChatLink, provided by the BusinessChatLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessChatLink?

Constants

constructor → const String