BusinessChatLinkInfo class final

Contains information about a business chat link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessChatLinkInfo({required int chatId, FormattedText? text})

Properties

chatId int
chatId Identifier of the private chat that created the link
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Message draft text that must be added to the input field
final

Methods

copyWith({int? chatId, FormattedText? text}) BusinessChatLinkInfo

Available on BusinessChatLinkInfo, provided by the BusinessChatLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessChatLinkInfo?

Constants

constructor → const String