BusinessConnectedBot class final
Describes a business bot connected to an account
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessConnectedBot({required int botUserId, BusinessRecipients? recipients, BusinessBotRights? rights})
Properties
- botUserId → int
-
botUserId User identifier of the bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- recipients → BusinessRecipients?
-
recipients Private chats that will be accessible to the bot
final
- rights → BusinessBotRights?
-
rights Rights of the bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, BusinessRecipients? recipients, BusinessBotRights? rights}) → BusinessConnectedBot -
Available on BusinessConnectedBot, provided by the BusinessConnectedBotExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessConnectedBot?
Constants
- constructor → const String