BusinessConnectedBotInfo class final

Describes a connection of a bot to an account

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessConnectedBotInfo({BusinessConnectedBot? bot, required int connectionDate, required String deviceModel, required String location})

Properties

bot BusinessConnectedBot?
bot Information about the bot
final
connectionDate int
connectionDate Point in time (Unix timestamp) when the bot was added; may be 0 if unknown
final
deviceModel String
deviceModel Model of the device that was used for the bot connection, as provided by the application; may be empty if unknown
final
hashCode int
The hash code for this object.
no setteroverride
location String
location A human-readable description of the location from which the bot was connected, based on the IP address; may be empty if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BusinessConnectedBot? bot, int? connectionDate, String? deviceModel, String? location}) BusinessConnectedBotInfo

Available on BusinessConnectedBotInfo, provided by the BusinessConnectedBotInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessConnectedBotInfo?

Constants

constructor → const String