BusinessFeaturePromotionAnimation class final

Describes a promotion animation for a Business feature

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessFeaturePromotionAnimation({BusinessFeature? feature, Animation? animation})

Properties

animation Animation?
animation Promotion animation for the feature
final
feature BusinessFeature?
feature Business feature
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BusinessFeature? feature, Animation? animation}) BusinessFeaturePromotionAnimation

Available on BusinessFeaturePromotionAnimation, provided by the BusinessFeaturePromotionAnimationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessFeaturePromotionAnimation?

Constants

constructor → const String