BusinessFeatures class final
Contains information about features, available to Business user accounts
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BusinessFeatures({required List<
BusinessFeature> features})
Properties
-
features
→ List<
BusinessFeature> -
features The list of available business features
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< BusinessFeature> ? features}) → BusinessFeatures -
Available on BusinessFeatures, provided by the BusinessFeaturesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessFeatures?
Constants
- constructor → const String