BusinessGreetingMessageSettings class final

Describes settings for greeting messages that are automatically sent by a Telegram Business account as response to incoming messages in an inactive private chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessGreetingMessageSettings({required int shortcutId, BusinessRecipients? recipients, required int inactivityDays})

Properties

hashCode int
The hash code for this object.
no setteroverride
inactivityDays int
inactivityDays The number of days after which a chat will be considered as inactive; currently, must be one of 7, 14, 21, or 28
final
recipients BusinessRecipients?
recipients Chosen recipients of the greeting messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutId int
shortcutId Unique quick reply shortcut identifier for the greeting messages
final

Methods

copyWith({int? shortcutId, BusinessRecipients? recipients, int? inactivityDays}) BusinessGreetingMessageSettings

Available on BusinessGreetingMessageSettings, provided by the BusinessGreetingMessageSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessGreetingMessageSettings?

Constants

constructor → const String