inactivityDays property
inactivityDays The number of days after which a chat will be considered as inactive; currently, must be one of 7, 14, 21, or 28
Implementation
final int inactivityDays;
inactivityDays The number of days after which a chat will be considered as inactive; currently, must be one of 7, 14, 21, or 28
final int inactivityDays;