BusinessInfo class final

Contains information about a Telegram Business account

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessInfo({BusinessLocation? location, BusinessOpeningHours? openingHours, BusinessOpeningHours? localOpeningHours, required int nextOpenIn, required int nextCloseIn, BusinessGreetingMessageSettings? greetingMessageSettings, BusinessAwayMessageSettings? awayMessageSettings, BusinessStartPage? startPage})

Properties

awayMessageSettings BusinessAwayMessageSettings?
awayMessageSettings The away message; may be null if none or the Business account is not of the current user
final
greetingMessageSettings BusinessGreetingMessageSettings?
greetingMessageSettings The greeting message; may be null if none or the Business account is not of the current user
final
hashCode int
The hash code for this object.
no setteroverride
localOpeningHours BusinessOpeningHours?
localOpeningHours Opening hours of the business in the local time; may be null if none. The hours are guaranteed to be valid and have already been split by week days. Local time zone identifier will be empty. An updateUserFullInfo update is not triggered when value of this field changes
final
location BusinessLocation?
location Location of the business; may be null if none
final
nextCloseIn int
nextCloseIn Time left before the business will close the next time, in seconds; 0 if unknown. An updateUserFullInfo update is not triggered when value of this field changes
final
nextOpenIn int
nextOpenIn Time left before the business will open the next time, in seconds; 0 if unknown. An updateUserFullInfo update is not triggered when value of this field changes
final
openingHours BusinessOpeningHours?
openingHours Opening hours of the business; may be null if none. The hours are guaranteed to be valid and have already been split by week days
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPage BusinessStartPage?
startPage Information about start page of the account; may be null if none
final

Methods

copyWith({BusinessLocation? location, BusinessOpeningHours? openingHours, BusinessOpeningHours? localOpeningHours, int? nextOpenIn, int? nextCloseIn, BusinessGreetingMessageSettings? greetingMessageSettings, BusinessAwayMessageSettings? awayMessageSettings, BusinessStartPage? startPage}) BusinessInfo

Available on BusinessInfo, provided by the BusinessInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessInfo?

Constants

constructor → const String