nextCloseIn property

int nextCloseIn
final

nextCloseIn Time left before the business will close the next time, in seconds; 0 if unknown. An updateUserFullInfo update is not triggered when value of this field changes

Implementation

final int nextCloseIn;