nextOpenIn property

int nextOpenIn
final

nextOpenIn Time left before the business will open the next time, in seconds; 0 if unknown. An updateUserFullInfo update is not triggered when value of this field changes

Implementation

final int nextOpenIn;