BusinessMessage class final

Describes a message from a business account as received by a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessMessage({Message? message, Message? replyToMessage})

Properties

hashCode int
The hash code for this object.
no setteroverride
message Message?
message The message
final
replyToMessage Message?
replyToMessage Message that is replied by the message in the same chat; may be null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message, Message? replyToMessage}) BusinessMessage

Available on BusinessMessage, provided by the BusinessMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessMessage?

Constants

constructor → const String