replyToMessage property
replyToMessage Message that is replied by the message in the same chat; may be null if none
Implementation
final Message? replyToMessage;
replyToMessage Message that is replied by the message in the same chat; may be null if none
final Message? replyToMessage;