BusinessMessages class final

Contains a list of messages from a business account as received by a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessMessages({required List<BusinessMessage> messages})

Properties

hashCode int
The hash code for this object.
no setteroverride
messages List<BusinessMessage>
messages List of business messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<BusinessMessage>? messages}) BusinessMessages

Available on BusinessMessages, provided by the BusinessMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessMessages?

Constants

constructor → const String