BusinessOpeningHours class final
Describes opening hours of a business
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BusinessOpeningHours({required String timeZoneId, required List<
BusinessOpeningHoursInterval> openingHours})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
openingHours
→ List<
BusinessOpeningHoursInterval> -
openingHours Intervals of the time when the business is open
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeZoneId → String
-
timeZoneId Unique time zone identifier
final
Methods
-
copyWith(
{String? timeZoneId, List< BusinessOpeningHoursInterval> ? openingHours}) → BusinessOpeningHours -
Available on BusinessOpeningHours, provided by the BusinessOpeningHoursExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessOpeningHours?
Constants
- constructor → const String