openingHours property
openingHours Intervals of the time when the business is open
Implementation
final List<BusinessOpeningHoursInterval> openingHours;
openingHours Intervals of the time when the business is open
final List<BusinessOpeningHoursInterval> openingHours;