startMinute property
startMinute The minute's sequence number in a week, starting on Monday, marking the start of the time interval during which the business is open; 0-72460
Implementation
final int startMinute;
startMinute The minute's sequence number in a week, starting on Monday, marking the start of the time interval during which the business is open; 0-72460
final int startMinute;