BusinessRecipients class final

Describes private chats chosen for automatic interaction with a business

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessRecipients({required List<int> chatIds, required List<int> excludedChatIds, required bool selectExistingChats, required bool selectNewChats, required bool selectContacts, required bool selectNonContacts, required bool excludeSelected})

Properties

chatIds List<int>
chatIds Identifiers of selected private chats
final
excludedChatIds List<int>
excludedChatIds Identifiers of private chats that are always excluded; for businessConnectedBot only
final
excludeSelected bool
excludeSelected If true, then all private chats except the selected are chosen. Otherwise, only the selected chats are chosen
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectContacts bool
selectContacts True, if all private chats with contacts are selected
final
selectExistingChats bool
selectExistingChats True, if all existing private chats are selected
final
selectNewChats bool
selectNewChats True, if all new private chats are selected
final
selectNonContacts bool
selectNonContacts True, if all private chats with non-contacts are selected
final

Methods

copyWith({List<int>? chatIds, List<int>? excludedChatIds, bool? selectExistingChats, bool? selectNewChats, bool? selectContacts, bool? selectNonContacts, bool? excludeSelected}) BusinessRecipients

Available on BusinessRecipients, provided by the BusinessRecipientsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessRecipients?

Constants

constructor → const String