excludeSelected property
excludeSelected If true, then all private chats except the selected are chosen. Otherwise, only the selected chats are chosen
Implementation
final bool excludeSelected;
excludeSelected If true, then all private chats except the selected are chosen. Otherwise, only the selected chats are chosen
final bool excludeSelected;