excludedChatIds property
excludedChatIds Identifiers of private chats that are always excluded; for businessConnectedBot only
Implementation
final List<int> excludedChatIds;
excludedChatIds Identifiers of private chats that are always excluded; for businessConnectedBot only
final List<int> excludedChatIds;