BusinessStartPage class final

Describes settings for a business account start page

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessStartPage({required String title, required String message, Sticker? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
message String
message Message text of the start page
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker Sticker?
sticker Greeting sticker of the start page; may be null if none
final
title String
title Title text of the start page
final

Methods

copyWith({String? title, String? message, Sticker? sticker}) BusinessStartPage

Available on BusinessStartPage, provided by the BusinessStartPageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessStartPage?

Constants

constructor → const String