ButtonStylePrimary class final

The button has dark blue color

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ButtonStylePrimary()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult danger(ButtonStyleDanger value), required TResult $default(ButtonStyleDefault value), required TResult primary(ButtonStylePrimary value), required TResult success(ButtonStyleSuccess value)}) → TResult

Available on ButtonStyle, provided by the ButtonStyleExtensions extension

maybeMap<TResult extends Object?>({TResult danger(ButtonStyleDanger value)?, TResult $default(ButtonStyleDefault value)?, TResult primary(ButtonStylePrimary value)?, TResult success(ButtonStyleSuccess value)?, required TResult orElse()}) → TResult

Available on ButtonStyle, provided by the ButtonStyleExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String