BuyGiftUpgrade class final

Pays for upgrade of a regular gift that is owned by another user or channel chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BuyGiftUpgrade({MessageSender? ownerId, required String prepaidUpgradeHash, required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that owns the gift
final
prepaidUpgradeHash String
prepaidUpgradeHash Prepaid upgrade hash as received along with the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount the user agreed to pay for the upgrade; must be equal to gift.upgrade_star_count
final

Methods

copyWith({MessageSender? ownerId, String? prepaidUpgradeHash, int? starCount}) BuyGiftUpgrade

Available on BuyGiftUpgrade, provided by the BuyGiftUpgradeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String