CallProblemPixelatedVideo class final
The video was pixelated
- Inheritance
-
- Object
- TdObject
- CallProblem
- CallProblemPixelatedVideo
- Available extensions
- Annotations
-
- @immutable
Constructors
- CallProblemPixelatedVideo()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult distortedSpeech(CallProblemDistortedSpeech value), required TResult distortedVideo(CallProblemDistortedVideo value), required TResult dropped(CallProblemDropped value), required TResult echo(CallProblemEcho value), required TResult interruptions(CallProblemInterruptions value), required TResult noise(CallProblemNoise value), required TResult pixelatedVideo(CallProblemPixelatedVideo value), required TResult silentLocal(CallProblemSilentLocal value), required TResult silentRemote(CallProblemSilentRemote value)}) → TResult -
Available on CallProblem, provided by the CallProblemExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult distortedSpeech(CallProblemDistortedSpeech value)?, TResult distortedVideo(CallProblemDistortedVideo value)?, TResult dropped(CallProblemDropped value)?, TResult echo(CallProblemEcho value)?, TResult interruptions(CallProblemInterruptions value)?, TResult noise(CallProblemNoise value)?, TResult pixelatedVideo(CallProblemPixelatedVideo value)?, TResult silentLocal(CallProblemSilentLocal value)?, TResult silentRemote(CallProblemSilentRemote value)?, required TResult orElse()}) → TResult -
Available on CallProblem, provided by the CallProblemExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String