CallProtocol class final

Specifies the supported call protocols

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallProtocol({required bool udpP2p, required bool udpReflector, required int minLayer, required int maxLayer, required List<String> libraryVersions})

Properties

hashCode int
The hash code for this object.
no setteroverride
libraryVersions List<String>
libraryVersions List of supported tgcalls versions
final
maxLayer int
maxLayer The maximum supported API layer; use 92
final
minLayer int
minLayer The minimum supported API layer; use 65
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
udpP2p bool
udpP2p True, if UDP peer-to-peer connections are supported
final
udpReflector bool
udpReflector True, if connection through UDP reflectors is supported
final

Methods

copyWith({bool? udpP2p, bool? udpReflector, int? minLayer, int? maxLayer, List<String>? libraryVersions}) CallProtocol

Available on CallProtocol, provided by the CallProtocolExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CallProtocol?

Constants

constructor → const String