CallServer class final
Describes a server for relaying call data
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- CallServer({required int id, required String ipAddress, required String ipv6Address, required int port, CallServerType? type})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Server identifier
final
- ipAddress → String
-
ipAddress Server IPv4 address
final
- ipv6Address → String
-
ipv6Address Server IPv6 address
final
- port → int
-
port Server port number
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CallServerType?
-
type Server type
final
Methods
-
copyWith(
{int? id, String? ipAddress, String? ipv6Address, int? port, CallServerType? type}) → CallServer -
Available on CallServer, provided by the CallServerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CallServer?
Constants
- constructor → const String