CallServerType class sealed

Describes the type of call server

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult telegramReflector(CallServerTypeTelegramReflector value), required TResult webrtc(CallServerTypeWebrtc value)}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

maybeMap<TResult extends Object?>({TResult telegramReflector(CallServerTypeTelegramReflector value)?, TResult webrtc(CallServerTypeWebrtc value)?, required TResult orElse()}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CallServerType?
Inherited by: CallServerTypeTelegramReflector CallServerTypeWebrtc

Constants

constructor → const String