CallServerTypeTelegramReflector class final

A Telegram call reflector

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallServerTypeTelegramReflector({required String peerTag, required bool isTcp})

Properties

hashCode int
The hash code for this object.
no setteroverride
isTcp bool
isTcp True, if the server uses TCP instead of UDP
final
peerTag String
peerTag A peer tag to be used with the reflector
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? peerTag, bool? isTcp}) CallServerTypeTelegramReflector

Available on CallServerTypeTelegramReflector, provided by the CallServerTypeTelegramReflectorExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult telegramReflector(CallServerTypeTelegramReflector value), required TResult webrtc(CallServerTypeWebrtc value)}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

maybeMap<TResult extends Object?>({TResult telegramReflector(CallServerTypeTelegramReflector value)?, TResult webrtc(CallServerTypeWebrtc value)?, required TResult orElse()}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CallServerTypeTelegramReflector?
Inherited by: CallServerTypeTelegramReflector CallServerTypeWebrtc
override

Constants

constructor → const String