CallServerTypeWebrtc class final

A WebRTC server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallServerTypeWebrtc({required String username, required String password, required bool supportsTurn, required bool supportsStun})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password Authentication password
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsStun bool
supportsStun True, if the server supports STUN
final
supportsTurn bool
supportsTurn True, if the server supports TURN
final
username String
username Username to be used for authentication
final

Methods

copyWith({String? username, String? password, bool? supportsTurn, bool? supportsStun}) CallServerTypeWebrtc

Available on CallServerTypeWebrtc, provided by the CallServerTypeWebrtcExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult telegramReflector(CallServerTypeTelegramReflector value), required TResult webrtc(CallServerTypeWebrtc value)}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

maybeMap<TResult extends Object?>({TResult telegramReflector(CallServerTypeTelegramReflector value)?, TResult webrtc(CallServerTypeWebrtc value)?, required TResult orElse()}) → TResult

Available on CallServerType, provided by the CallServerTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CallServerTypeWebrtc?
Inherited by: CallServerTypeTelegramReflector CallServerTypeWebrtc
override

Constants

constructor → const String