CallStateDiscarded class final

The call has ended successfully

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallStateDiscarded({CallDiscardReason? reason, required bool needRating, required bool needDebugInformation, required bool needLog})

Properties

hashCode int
The hash code for this object.
no setteroverride
needDebugInformation bool
needDebugInformation True, if the call debug information must be sent to the server
final
needLog bool
needLog True, if the call log must be sent to the server
final
needRating bool
needRating True, if the call rating must be sent to the server
final
reason CallDiscardReason?
reason The reason why the call has ended
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({CallDiscardReason? reason, bool? needRating, bool? needDebugInformation, bool? needLog}) CallStateDiscarded

Available on CallStateDiscarded, provided by the CallStateDiscardedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult discarded(CallStateDiscarded value), required TResult error(CallStateError value), required TResult exchangingKeys(CallStateExchangingKeys value), required TResult hangingUp(CallStateHangingUp value), required TResult pending(CallStatePending value), required TResult ready(CallStateReady value)}) → TResult

Available on CallState, provided by the CallStateExtensions extension

maybeMap<TResult extends Object?>({TResult discarded(CallStateDiscarded value)?, TResult error(CallStateError value)?, TResult exchangingKeys(CallStateExchangingKeys value)?, TResult hangingUp(CallStateHangingUp value)?, TResult pending(CallStatePending value)?, TResult ready(CallStateReady value)?, required TResult orElse()}) → TResult

Available on CallState, provided by the CallStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String