CallStateError class final

The call has ended with an error

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallStateError({TdError? error})

Properties

error TdError?
error Error. An error with the code 4005000 will be returned if an outgoing call is missed because of an expired timeout
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TdError? error}) CallStateError

Available on CallStateError, provided by the CallStateErrorExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult discarded(CallStateDiscarded value), required TResult error(CallStateError value), required TResult exchangingKeys(CallStateExchangingKeys value), required TResult hangingUp(CallStateHangingUp value), required TResult pending(CallStatePending value), required TResult ready(CallStateReady value)}) → TResult

Available on CallState, provided by the CallStateExtensions extension

maybeMap<TResult extends Object?>({TResult discarded(CallStateDiscarded value)?, TResult error(CallStateError value)?, TResult exchangingKeys(CallStateExchangingKeys value)?, TResult hangingUp(CallStateHangingUp value)?, TResult pending(CallStatePending value)?, TResult ready(CallStateReady value)?, required TResult orElse()}) → TResult

Available on CallState, provided by the CallStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String