CallStateReady class final

The call is ready to use

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallStateReady({CallProtocol? protocol, required List<CallServer> servers, required String config, required String encryptionKey, required List<String> emojis, required bool allowP2p, required bool isGroupCallSupported, required String customParameters})

Properties

allowP2p bool
allowP2p True, if peer-to-peer connection is allowed by users privacy settings
final
config String
config A JSON-encoded call config
final
customParameters String
customParameters Custom JSON-encoded call parameters to be passed to tgcalls
final
emojis List<String>
emojis Encryption key fingerprint represented as 4 emoji
final
encryptionKey String
encryptionKey Call encryption key
final
hashCode int
The hash code for this object.
no setteroverride
isGroupCallSupported bool
isGroupCallSupported True, if the other party supports upgrading of the call to a group call
final
protocol CallProtocol?
protocol Call protocols supported by the other call participant
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<CallServer>
servers List of available call servers
final

Methods

copyWith({CallProtocol? protocol, List<CallServer>? servers, String? config, String? encryptionKey, List<String>? emojis, bool? allowP2p, bool? isGroupCallSupported, String? customParameters}) CallStateReady

Available on CallStateReady, provided by the CallStateReadyExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult discarded(CallStateDiscarded value), required TResult error(CallStateError value), required TResult exchangingKeys(CallStateExchangingKeys value), required TResult hangingUp(CallStateHangingUp value), required TResult pending(CallStatePending value), required TResult ready(CallStateReady value)}) → TResult

Available on CallState, provided by the CallStateExtensions extension

maybeMap<TResult extends Object?>({TResult discarded(CallStateDiscarded value)?, TResult error(CallStateError value)?, TResult exchangingKeys(CallStateExchangingKeys value)?, TResult hangingUp(CallStateHangingUp value)?, TResult pending(CallStatePending value)?, TResult ready(CallStateReady value)?, required TResult orElse()}) → TResult

Available on CallState, provided by the CallStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String