isGroupCallSupported property
isGroupCallSupported True, if the other party supports upgrading of the call to a group call
Implementation
final bool isGroupCallSupported;
isGroupCallSupported True, if the other party supports upgrading of the call to a group call
final bool isGroupCallSupported;