CallbackQueryPayload class sealed

Represents a payload of a callback query

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult data(CallbackQueryPayloadData value), required TResult dataWithPassword(CallbackQueryPayloadDataWithPassword value), required TResult game(CallbackQueryPayloadGame value)}) → TResult

Available on CallbackQueryPayload, provided by the CallbackQueryPayloadExtensions extension

maybeMap<TResult extends Object?>({TResult data(CallbackQueryPayloadData value)?, TResult dataWithPassword(CallbackQueryPayloadDataWithPassword value)?, TResult game(CallbackQueryPayloadGame value)?, required TResult orElse()}) → TResult

Available on CallbackQueryPayload, provided by the CallbackQueryPayloadExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String