CallbackQueryPayloadDataWithPassword class final

The payload for a callback button requiring password

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CallbackQueryPayloadDataWithPassword({required String password, required String data})

Properties

data String
data Data that was attached to the callback button
final
hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password for the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? password, String? data}) CallbackQueryPayloadDataWithPassword

Available on CallbackQueryPayloadDataWithPassword, provided by the CallbackQueryPayloadDataWithPasswordExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult data(CallbackQueryPayloadData value), required TResult dataWithPassword(CallbackQueryPayloadDataWithPassword value), required TResult game(CallbackQueryPayloadGame value)}) → TResult

Available on CallbackQueryPayload, provided by the CallbackQueryPayloadExtensions extension

maybeMap<TResult extends Object?>({TResult data(CallbackQueryPayloadData value)?, TResult dataWithPassword(CallbackQueryPayloadDataWithPassword value)?, TResult game(CallbackQueryPayloadGame value)?, required TResult orElse()}) → TResult

Available on CallbackQueryPayload, provided by the CallbackQueryPayloadExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String