CanPostStory class final

Checks whether the current user can post a story on behalf of a chat; requires can_post_stories administrator right for supergroup and channel chats Returns CanPostStoryResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CanPostStory({required int chatId})

Properties

chatId int
chatId Chat identifier. Pass Saved Messages chat identifier when posting a story on behalf of the current user
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) CanPostStory

Available on CanPostStory, provided by the CanPostStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String