CanPostStoryResultOk class final

A story can be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CanPostStoryResultOk({required int storyCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyCount int
storyCount Number of stories that can be posted by the user
final

Methods

copyWith({int? storyCount}) CanPostStoryResultOk

Available on CanPostStoryResultOk, provided by the CanPostStoryResultOkExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult activeStoryLimitExceeded(CanPostStoryResultActiveStoryLimitExceeded value), required TResult boostNeeded(CanPostStoryResultBoostNeeded value), required TResult liveStoryIsActive(CanPostStoryResultLiveStoryIsActive value), required TResult monthlyLimitExceeded(CanPostStoryResultMonthlyLimitExceeded value), required TResult ok(CanPostStoryResultOk value), required TResult premiumNeeded(CanPostStoryResultPremiumNeeded value), required TResult weeklyLimitExceeded(CanPostStoryResultWeeklyLimitExceeded value)}) → TResult

Available on CanPostStoryResult, provided by the CanPostStoryResultExtensions extension

maybeMap<TResult extends Object?>({TResult activeStoryLimitExceeded(CanPostStoryResultActiveStoryLimitExceeded value)?, TResult boostNeeded(CanPostStoryResultBoostNeeded value)?, TResult liveStoryIsActive(CanPostStoryResultLiveStoryIsActive value)?, TResult monthlyLimitExceeded(CanPostStoryResultMonthlyLimitExceeded value)?, TResult ok(CanPostStoryResultOk value)?, TResult premiumNeeded(CanPostStoryResultPremiumNeeded value)?, TResult weeklyLimitExceeded(CanPostStoryResultWeeklyLimitExceeded value)?, required TResult orElse()}) → TResult

Available on CanPostStoryResult, provided by the CanPostStoryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String