CanSendGift class final
Checks whether a gift with next_send_date in the future can be sent already Returns CanSendGiftResult
- Inheritance
-
- Object
- TdFunction
- CanSendGift
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanSendGift({required int giftId})
Properties
Methods
-
copyWith(
{int? giftId}) → CanSendGift -
Available on CanSendGift, provided by the CanSendGiftExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String