CanSendGiftResultFail class final
The gift can't be sent now by the current user
- Inheritance
-
- Object
- TdObject
- CanSendGiftResult
- CanSendGiftResultFail
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanSendGiftResultFail({FormattedText? reason})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- reason → FormattedText?
-
reason Reason to be shown to the user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{FormattedText? reason}) → CanSendGiftResultFail -
Available on CanSendGiftResultFail, provided by the CanSendGiftResultFailExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fail(CanSendGiftResultFail value), required TResult ok(CanSendGiftResultOk value)}) → TResult -
Available on CanSendGiftResult, provided by the CanSendGiftResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fail(CanSendGiftResultFail value)?, TResult ok(CanSendGiftResultOk value)?, required TResult orElse()}) → TResult -
Available on CanSendGiftResult, provided by the CanSendGiftResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CanSendGiftResultFail? -
Inherited by:
CanSendGiftResultFail
CanSendGiftResultOk
override
Constants
- constructor → const String