CancelDownloadFile class final

Stops the downloading of a file. If a file has already been downloaded, does nothing Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CancelDownloadFile({required int fileId, required bool onlyIfPending})

Properties

fileId int
fileId Identifier of a file to stop downloading
final
hashCode int
The hash code for this object.
no setteroverride
onlyIfPending bool
onlyIfPending Pass true to stop downloading only if it hasn't been started, i.e. request hasn't been sent to server
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, bool? onlyIfPending}) CancelDownloadFile

Available on CancelDownloadFile, provided by the CancelDownloadFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String