ChangeImportedContacts class final

Changes imported contacts using the list of contacts saved on the device. Imports newly added contacts and, if at least the file database is enabled, deletes recently deleted contacts. Query result depends on the result of the previous query, so only one query is possible at the same time Returns ImportedContacts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChangeImportedContacts({required List<ImportedContact> contacts})

Properties

contacts List<ImportedContact>
contacts The new list of contacts to import
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ImportedContact>? contacts}) ChangeImportedContacts

Available on ChangeImportedContacts, provided by the ChangeImportedContactsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String