ChangeWebBrowserSettings class final
Changes web browser settings Returns Ok
- Inheritance
-
- Object
- TdFunction
- ChangeWebBrowserSettings
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChangeWebBrowserSettings({required bool openExternalBrowser, required bool displayCloseButton})
Properties
- displayCloseButton → bool
-
displayCloseButton Pass true if a close button must be shown in the
in-app browser; for Android app only
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- openExternalBrowser → bool
-
openExternalBrowser Pass true if links must be opened in an external
browser by default
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? openExternalBrowser, bool? displayCloseButton}) → ChangeWebBrowserSettings -
Available on ChangeWebBrowserSettings, provided by the ChangeWebBrowserSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String