displayCloseButton property
displayCloseButton Pass true if a close button must be shown in the in-app browser; for Android app only
Implementation
final bool displayCloseButton;
displayCloseButton Pass true if a close button must be shown in the in-app browser; for Android app only
final bool displayCloseButton;