accentColorId property
accentColorId Identifier of the accent color for message sender name, and backgrounds of chat photo, reply header, and link preview
Implementation
final int accentColorId;
accentColorId Identifier of the accent color for message sender name, and backgrounds of chat photo, reply header, and link preview
final int accentColorId;