backgroundCustomEmojiId property

int backgroundCustomEmojiId
final

backgroundCustomEmojiId Identifier of a custom emoji to be shown on the reply header and link preview background for messages sent by the chat; 0 if none

Implementation

final int backgroundCustomEmojiId;