chatLists property

List<ChatList> chatLists
final

chatLists Chat lists to which the chat belongs. A chat can have a non-zero position in a chat list even if it doesn't belong to the chat list and have no position in a chat list even if it belongs to the chat list

Implementation

final List<ChatList> chatLists;