profileBackgroundCustomEmojiId property
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown on the background of the chat's profile; 0 if none
Implementation
final int profileBackgroundCustomEmojiId;
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown on the background of the chat's profile; 0 if none
final int profileBackgroundCustomEmojiId;