replyMarkupMessageId property

int replyMarkupMessageId
final

replyMarkupMessageId Identifier of the message from which reply markup needs to be used; 0 if there is no reply markup in the chat

Implementation

final int replyMarkupMessageId;