unreadPollVoteCount property
unreadPollVoteCount Number of messages with unread poll votes in the chat
Implementation
final int unreadPollVoteCount;
unreadPollVoteCount Number of messages with unread poll votes in the chat
final int unreadPollVoteCount;