viewAsTopics property

bool viewAsTopics
final

viewAsTopics True, if the chat is a forum supergroup that must be shown in the "View as topics" mode, or Saved Messages chat that must be shown in the "View as chats"

Implementation

final bool viewAsTopics;