ChatActionBar class sealed

Describes actions which must be possible to do through a chat action bar

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult addContact(ChatActionBarAddContact value), required TResult inviteMembers(ChatActionBarInviteMembers value), required TResult joinRequest(ChatActionBarJoinRequest value), required TResult reportAddBlock(ChatActionBarReportAddBlock value), required TResult reportSpam(ChatActionBarReportSpam value), required TResult sharePhoneNumber(ChatActionBarSharePhoneNumber value)}) → TResult

Available on ChatActionBar, provided by the ChatActionBarExtensions extension

maybeMap<TResult extends Object?>({TResult addContact(ChatActionBarAddContact value)?, TResult inviteMembers(ChatActionBarInviteMembers value)?, TResult joinRequest(ChatActionBarJoinRequest value)?, TResult reportAddBlock(ChatActionBarReportAddBlock value)?, TResult reportSpam(ChatActionBarReportSpam value)?, TResult sharePhoneNumber(ChatActionBarSharePhoneNumber value)?, required TResult orElse()}) → TResult

Available on ChatActionBar, provided by the ChatActionBarExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String