ChatActionBarJoinRequest class final
The chat is a private chat with an administrator of a chat to which the user sent join request
- Inheritance
-
- Object
- TdObject
- ChatActionBar
- ChatActionBarJoinRequest
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatActionBarJoinRequest({required String title, required bool isChannel, required int requestDate})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isChannel → bool
-
isChannel True, if the join request was sent to a channel chat
final
- requestDate → int
-
requestDate Point in time (Unix timestamp) when the join request was
sent
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Title of the chat to which the join request was sent
final
Methods
-
copyWith(
{String? title, bool? isChannel, int? requestDate}) → ChatActionBarJoinRequest -
Available on ChatActionBarJoinRequest, provided by the ChatActionBarJoinRequestExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult addContact(ChatActionBarAddContact value), required TResult inviteMembers(ChatActionBarInviteMembers value), required TResult joinRequest(ChatActionBarJoinRequest value), required TResult reportAddBlock(ChatActionBarReportAddBlock value), required TResult reportSpam(ChatActionBarReportSpam value), }) → TResult -
Available on ChatActionBar, provided by the ChatActionBarExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult addContact(ChatActionBarAddContact value)?, TResult inviteMembers(ChatActionBarInviteMembers value)?, TResult joinRequest(ChatActionBarJoinRequest value)?, TResult reportAddBlock(ChatActionBarReportAddBlock value)?, TResult reportSpam(ChatActionBarReportSpam value)?, required TResult orElse()}) → TResult -
Available on ChatActionBar, provided by the ChatActionBarExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatActionBarJoinRequest? -
Inherited by:
ChatActionBarAddContact
ChatActionBarInviteMembers
ChatActionBarJoinRequest
ChatActionBarReportAddBlock
ChatActionBarReportSpam
ChatActionBarSharePhoneNumber
override
Constants
- constructor → const String