ChatActionBarReportAddBlock class final

The chat is a private or secret chat, which can be reported using the method reportChat, or the other user can be blocked using the method setMessageSenderBlockList, or the other user can be added to the contact list using the method addContact. If the chat is a private chat with a user with an emoji status, then a notice about emoji status usage must be shown

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatActionBarReportAddBlock({required bool canUnarchive, AccountInfo? accountInfo})

Properties

accountInfo AccountInfo?
accountInfo Basic information about the other user in the chat; may be null if unknown
final
canUnarchive bool
canUnarchive If true, the chat was automatically archived and can be moved back to the main chat list using addChatToList simultaneously with setting chat notification settings to default using setChatNotificationSettings
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canUnarchive, AccountInfo? accountInfo}) ChatActionBarReportAddBlock

Available on ChatActionBarReportAddBlock, provided by the ChatActionBarReportAddBlockExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult addContact(ChatActionBarAddContact value), required TResult inviteMembers(ChatActionBarInviteMembers value), required TResult joinRequest(ChatActionBarJoinRequest value), required TResult reportAddBlock(ChatActionBarReportAddBlock value), required TResult reportSpam(ChatActionBarReportSpam value), required TResult sharePhoneNumber(ChatActionBarSharePhoneNumber value)}) → TResult

Available on ChatActionBar, provided by the ChatActionBarExtensions extension

maybeMap<TResult extends Object?>({TResult addContact(ChatActionBarAddContact value)?, TResult inviteMembers(ChatActionBarInviteMembers value)?, TResult joinRequest(ChatActionBarJoinRequest value)?, TResult reportAddBlock(ChatActionBarReportAddBlock value)?, TResult reportSpam(ChatActionBarReportSpam value)?, TResult sharePhoneNumber(ChatActionBarSharePhoneNumber value)?, required TResult orElse()}) → TResult

Available on ChatActionBar, provided by the ChatActionBarExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String