accountInfo property
accountInfo Basic information about the other user in the chat; may be null if unknown
Implementation
final AccountInfo? accountInfo;
accountInfo Basic information about the other user in the chat; may be null if unknown
final AccountInfo? accountInfo;