ChatActionWatchingAnimations class final

The user is watching animations sent by the other party by clicking on an animated emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatActionWatchingAnimations({required String emoji})

Properties

emoji String
emoji The animated emoji
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) ChatActionWatchingAnimations

Available on ChatActionWatchingAnimations, provided by the ChatActionWatchingAnimationsExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult cancel(ChatActionCancel value), required TResult choosingContact(ChatActionChoosingContact value), required TResult choosingLocation(ChatActionChoosingLocation value), required TResult choosingSticker(ChatActionChoosingSticker value), required TResult recordingVideo(ChatActionRecordingVideo value), required TResult recordingVideoNote(ChatActionRecordingVideoNote value), required TResult recordingVoiceNote(ChatActionRecordingVoiceNote value), required TResult startPlayingGame(ChatActionStartPlayingGame value), required TResult typing(ChatActionTyping value), required TResult uploadingDocument(ChatActionUploadingDocument value), required TResult uploadingPhoto(ChatActionUploadingPhoto value), required TResult uploadingVideo(ChatActionUploadingVideo value), required TResult uploadingVideoNote(ChatActionUploadingVideoNote value), required TResult uploadingVoiceNote(ChatActionUploadingVoiceNote value), required TResult watchingAnimations(ChatActionWatchingAnimations value)}) → TResult

Available on ChatAction, provided by the ChatActionExtensions extension

maybeMap<TResult extends Object?>({TResult cancel(ChatActionCancel value)?, TResult choosingContact(ChatActionChoosingContact value)?, TResult choosingLocation(ChatActionChoosingLocation value)?, TResult choosingSticker(ChatActionChoosingSticker value)?, TResult recordingVideo(ChatActionRecordingVideo value)?, TResult recordingVideoNote(ChatActionRecordingVideoNote value)?, TResult recordingVoiceNote(ChatActionRecordingVoiceNote value)?, TResult startPlayingGame(ChatActionStartPlayingGame value)?, TResult typing(ChatActionTyping value)?, TResult uploadingDocument(ChatActionUploadingDocument value)?, TResult uploadingPhoto(ChatActionUploadingPhoto value)?, TResult uploadingVideo(ChatActionUploadingVideo value)?, TResult uploadingVideoNote(ChatActionUploadingVideoNote value)?, TResult uploadingVoiceNote(ChatActionUploadingVoiceNote value)?, TResult watchingAnimations(ChatActionWatchingAnimations value)?, required TResult orElse()}) → TResult

Available on ChatAction, provided by the ChatActionExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String