ChatActiveStories class final

Describes active stories posted by a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatActiveStories({required int chatId, StoryList? list, required int order, required bool canBeArchived, required int maxReadStoryId, required List<StoryInfo> stories})

Properties

canBeArchived bool
canBeArchived True, if the stories are shown in the main story list and can be archived; otherwise, the stories can be hidden from the main story list only by calling removeTopChat with topChatCategoryUsers and the chat_id. Stories of the current user can't be archived nor hidden using removeTopChat
final
chatId int
chatId Identifier of the chat that posted the stories
final
hashCode int
The hash code for this object.
no setteroverride
list StoryList?
list Identifier of the story list in which the stories are shown; may be null if the stories aren't shown in a story list
final
maxReadStoryId int
maxReadStoryId Identifier of the last read active story
final
order int
order A parameter used to determine order of the stories in the story list; 0 if the stories don't need to be shown in the story list. Stories must be sorted by the pair (order, story_poster_chat_id) in descending order
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stories List<StoryInfo>
stories Basic information about the stories; use getStory to get full information about the stories. The stories are in chronological order (i.e., in order of increasing story identifiers)
final

Methods

copyWith({int? chatId, StoryList? list, int? order, bool? canBeArchived, int? maxReadStoryId, List<StoryInfo>? stories}) ChatActiveStories

Available on ChatActiveStories, provided by the ChatActiveStoriesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatActiveStories?

Constants

constructor → const String