canBeEdited property
canBeEdited True, if the current user can edit the administrator privileges for the administrator
Implementation
final bool canBeEdited;
canBeEdited True, if the current user can edit the administrator privileges for the administrator
final bool canBeEdited;