canPostStories property
canPostStories True, if the administrator can create new chat stories, or edit and delete posted stories; applicable to supergroups and channels only
Implementation
final bool canPostStories;
canPostStories True, if the administrator can create new chat stories, or edit and delete posted stories; applicable to supergroups and channels only
final bool canPostStories;