canPromoteMembers property

bool canPromoteMembers
final

canPromoteMembers True, if the administrator can add new administrators with a subset of their own privileges or demote administrators that were directly or indirectly promoted by them; applicable to supergroups and channels only

Implementation

final bool canPromoteMembers;