canRestrictMembers property
canRestrictMembers True, if the administrator can restrict, ban, or unban chat members or view supergroup statistics
Implementation
final bool canRestrictMembers;
canRestrictMembers True, if the administrator can restrict, ban, or unban chat members or view supergroup statistics
final bool canRestrictMembers;