ChatAdministrators class final
Represents a list of chat administrators
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatAdministrators({required List<
ChatAdministrator> administrators})
Properties
-
administrators
→ List<
ChatAdministrator> -
administrators A list of chat administrators
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ChatAdministrator> ? administrators}) → ChatAdministrators -
Available on ChatAdministrators, provided by the ChatAdministratorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatAdministrators?
Constants
- constructor → const String