ChatAvailableReactions class sealed

Describes reactions available in the chat

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult all(ChatAvailableReactionsAll value), required TResult some(ChatAvailableReactionsSome value)}) → TResult

Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension

maybeMap<TResult extends Object?>({TResult all(ChatAvailableReactionsAll value)?, TResult some(ChatAvailableReactionsSome value)?, required TResult orElse()}) → TResult

Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String