ChatAvailableReactionsAll class final
All reactions are available in the chat, excluding the paid reaction and custom reactions in channel chats
- Inheritance
-
- Object
- TdObject
- ChatAvailableReactions
- ChatAvailableReactionsAll
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatAvailableReactionsAll({required int maxReactionCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxReactionCount → int
-
maxReactionCount The maximum allowed number of reactions per message;
1-11
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? maxReactionCount}) → ChatAvailableReactionsAll -
Available on ChatAvailableReactionsAll, provided by the ChatAvailableReactionsAllExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult all(ChatAvailableReactionsAll value), required TResult some(ChatAvailableReactionsSome value)}) → TResult -
Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult all(ChatAvailableReactionsAll value)?, TResult some(ChatAvailableReactionsSome value)?, required TResult orElse()}) → TResult -
Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatAvailableReactionsAll? -
Inherited by:
ChatAvailableReactionsAll
ChatAvailableReactionsSome
override
Constants
- constructor → const String