ChatBackground class final

Describes a background set for a specific chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBackground({Background? background, required int darkThemeDimming})

Properties

background Background?
background The background
final
darkThemeDimming int
darkThemeDimming Dimming of the background in dark themes, as a percentage; 0-100. Applied only to Wallpaper and Fill types of background
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Background? background, int? darkThemeDimming}) ChatBackground

Available on ChatBackground, provided by the ChatBackgroundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBackground?

Constants

constructor → const String