ChatBoostFeatures class final

Contains a list of features available on the first chat boost levels

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostFeatures({required List<ChatBoostLevelFeatures> features, required int minProfileBackgroundCustomEmojiBoostLevel, required int minBackgroundCustomEmojiBoostLevel, required int minEmojiStatusBoostLevel, required int minChatThemeBackgroundBoostLevel, required int minCustomBackgroundBoostLevel, required int minCustomEmojiStickerSetBoostLevel, required int minAutomaticTranslationBoostLevel, required int minSpeechRecognitionBoostLevel, required int minSponsoredMessageDisableBoostLevel})

Properties

features List<ChatBoostLevelFeatures>
features The list of features
final
hashCode int
The hash code for this object.
no setteroverride
minAutomaticTranslationBoostLevel int
minAutomaticTranslationBoostLevel The minimum boost level allowing to enable automatic translation of messages for non-Premium users; for channel chats only
final
minBackgroundCustomEmojiBoostLevel int
minBackgroundCustomEmojiBoostLevel The minimum boost level required to set custom emoji for reply header and link preview background; for channel chats only
final
minChatThemeBackgroundBoostLevel int
minChatThemeBackgroundBoostLevel The minimum boost level required to set a chat theme background as chat background
final
minCustomBackgroundBoostLevel int
minCustomBackgroundBoostLevel The minimum boost level required to set custom chat background
final
minCustomEmojiStickerSetBoostLevel int
minCustomEmojiStickerSetBoostLevel The minimum boost level required to set custom emoji sticker set for the chat; for supergroup chats only
final
minEmojiStatusBoostLevel int
minEmojiStatusBoostLevel The minimum boost level required to set emoji status
final
minProfileBackgroundCustomEmojiBoostLevel int
minProfileBackgroundCustomEmojiBoostLevel The minimum boost level required to set custom emoji for profile background
final
minSpeechRecognitionBoostLevel int
minSpeechRecognitionBoostLevel The minimum boost level allowing to recognize speech in video note and voice note messages for non-Premium users; for supergroup chats only
final
minSponsoredMessageDisableBoostLevel int
minSponsoredMessageDisableBoostLevel The minimum boost level allowing to disable sponsored messages in the chat; for channel chats only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatBoostLevelFeatures>? features, int? minProfileBackgroundCustomEmojiBoostLevel, int? minBackgroundCustomEmojiBoostLevel, int? minEmojiStatusBoostLevel, int? minChatThemeBackgroundBoostLevel, int? minCustomBackgroundBoostLevel, int? minCustomEmojiStickerSetBoostLevel, int? minAutomaticTranslationBoostLevel, int? minSpeechRecognitionBoostLevel, int? minSponsoredMessageDisableBoostLevel}) ChatBoostFeatures

Available on ChatBoostFeatures, provided by the ChatBoostFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoostFeatures?

Constants

constructor → const String