minBackgroundCustomEmojiBoostLevel property

int minBackgroundCustomEmojiBoostLevel
final

minBackgroundCustomEmojiBoostLevel The minimum boost level required to set custom emoji for reply header and link preview background; for channel chats only

Implementation

final int minBackgroundCustomEmojiBoostLevel;