minChatThemeBackgroundBoostLevel property
minChatThemeBackgroundBoostLevel The minimum boost level required to set a chat theme background as chat background
Implementation
final int minChatThemeBackgroundBoostLevel;
minChatThemeBackgroundBoostLevel The minimum boost level required to set a chat theme background as chat background
final int minChatThemeBackgroundBoostLevel;