minCustomBackgroundBoostLevel property
minCustomBackgroundBoostLevel The minimum boost level required to set custom chat background
Implementation
final int minCustomBackgroundBoostLevel;
minCustomBackgroundBoostLevel The minimum boost level required to set custom chat background
final int minCustomBackgroundBoostLevel;