minCustomEmojiStickerSetBoostLevel property
minCustomEmojiStickerSetBoostLevel The minimum boost level required to set custom emoji sticker set for the chat; for supergroup chats only
Implementation
final int minCustomEmojiStickerSetBoostLevel;
minCustomEmojiStickerSetBoostLevel The minimum boost level required to set custom emoji sticker set for the chat; for supergroup chats only
final int minCustomEmojiStickerSetBoostLevel;