minProfileBackgroundCustomEmojiBoostLevel property
minProfileBackgroundCustomEmojiBoostLevel The minimum boost level required to set custom emoji for profile background
Implementation
final int minProfileBackgroundCustomEmojiBoostLevel;
minProfileBackgroundCustomEmojiBoostLevel The minimum boost level required to set custom emoji for profile background
final int minProfileBackgroundCustomEmojiBoostLevel;