minSpeechRecognitionBoostLevel property
minSpeechRecognitionBoostLevel The minimum boost level allowing to recognize speech in video note and voice note messages for non-Premium users; for supergroup chats only
Implementation
final int minSpeechRecognitionBoostLevel;