minSponsoredMessageDisableBoostLevel property
minSponsoredMessageDisableBoostLevel The minimum boost level allowing to disable sponsored messages in the chat; for channel chats only
Implementation
final int minSponsoredMessageDisableBoostLevel;
minSponsoredMessageDisableBoostLevel The minimum boost level allowing to disable sponsored messages in the chat; for channel chats only
final int minSponsoredMessageDisableBoostLevel;