ChatBoostLevelFeatures class final

Contains a list of features available on a specific chat boost level

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostLevelFeatures({required int level, required int storyPerDayCount, required int customEmojiReactionCount, required int titleColorCount, required int profileAccentColorCount, required bool canSetProfileBackgroundCustomEmoji, required int accentColorCount, required bool canSetBackgroundCustomEmoji, required bool canSetEmojiStatus, required int chatThemeBackgroundCount, required bool canSetCustomBackground, required bool canSetCustomEmojiStickerSet, required bool canEnableAutomaticTranslation, required bool canRecognizeSpeech, required bool canDisableSponsoredMessages})

Properties

accentColorCount int
accentColorCount Number of custom colors for background of empty chat photo, replies to messages and link previews
final
canDisableSponsoredMessages bool
canDisableSponsoredMessages True, if sponsored messages can be disabled in the chat
final
canEnableAutomaticTranslation bool
canEnableAutomaticTranslation True, if automatic translation of messages can be enabled in the chat
final
canRecognizeSpeech bool
canRecognizeSpeech True, if speech recognition can be used for video note and voice note messages by all users
final
canSetBackgroundCustomEmoji bool
canSetBackgroundCustomEmoji True, if custom emoji for reply header and link preview background can be set
final
canSetCustomBackground bool
canSetCustomBackground True, if custom background can be set in the chat for all users
final
canSetCustomEmojiStickerSet bool
canSetCustomEmojiStickerSet True, if custom emoji sticker set can be set for the chat
final
canSetEmojiStatus bool
canSetEmojiStatus True, if emoji status can be set
final
canSetProfileBackgroundCustomEmoji bool
canSetProfileBackgroundCustomEmoji True, if custom emoji for profile background can be set
final
chatThemeBackgroundCount int
chatThemeBackgroundCount Number of chat theme backgrounds that can be set as chat background
final
customEmojiReactionCount int
customEmojiReactionCount Number of custom emoji reactions that can be added to the list of available reactions
final
hashCode int
The hash code for this object.
no setteroverride
level int
level Target chat boost level
final
profileAccentColorCount int
profileAccentColorCount Number of custom colors for profile photo background
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyPerDayCount int
storyPerDayCount Number of stories that the chat can publish daily
final
titleColorCount int
titleColorCount Number of custom colors for chat title
final

Methods

copyWith({int? level, int? storyPerDayCount, int? customEmojiReactionCount, int? titleColorCount, int? profileAccentColorCount, bool? canSetProfileBackgroundCustomEmoji, int? accentColorCount, bool? canSetBackgroundCustomEmoji, bool? canSetEmojiStatus, int? chatThemeBackgroundCount, bool? canSetCustomBackground, bool? canSetCustomEmojiStickerSet, bool? canEnableAutomaticTranslation, bool? canRecognizeSpeech, bool? canDisableSponsoredMessages}) ChatBoostLevelFeatures

Available on ChatBoostLevelFeatures, provided by the ChatBoostLevelFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoostLevelFeatures?

Constants

constructor → const String