canEnableAutomaticTranslation property
canEnableAutomaticTranslation True, if automatic translation of messages can be enabled in the chat
Implementation
final bool canEnableAutomaticTranslation;
canEnableAutomaticTranslation True, if automatic translation of messages can be enabled in the chat
final bool canEnableAutomaticTranslation;