canRecognizeSpeech property
canRecognizeSpeech True, if speech recognition can be used for video note and voice note messages by all users
Implementation
final bool canRecognizeSpeech;
canRecognizeSpeech True, if speech recognition can be used for video note and voice note messages by all users
final bool canRecognizeSpeech;