canSetBackgroundCustomEmoji property
canSetBackgroundCustomEmoji True, if custom emoji for reply header and link preview background can be set
Implementation
final bool canSetBackgroundCustomEmoji;
canSetBackgroundCustomEmoji True, if custom emoji for reply header and link preview background can be set
final bool canSetBackgroundCustomEmoji;