canSetCustomBackground property
canSetCustomBackground True, if custom background can be set in the chat for all users
Implementation
final bool canSetCustomBackground;
canSetCustomBackground True, if custom background can be set in the chat for all users
final bool canSetCustomBackground;