canSetCustomEmojiStickerSet property
canSetCustomEmojiStickerSet True, if custom emoji sticker set can be set for the chat
Implementation
final bool canSetCustomEmojiStickerSet;
canSetCustomEmojiStickerSet True, if custom emoji sticker set can be set for the chat
final bool canSetCustomEmojiStickerSet;