canSetProfileBackgroundCustomEmoji property
canSetProfileBackgroundCustomEmoji True, if custom emoji for profile background can be set
Implementation
final bool canSetProfileBackgroundCustomEmoji;
canSetProfileBackgroundCustomEmoji True, if custom emoji for profile background can be set
final bool canSetProfileBackgroundCustomEmoji;