chatThemeBackgroundCount property
chatThemeBackgroundCount Number of chat theme backgrounds that can be set as chat background
Implementation
final int chatThemeBackgroundCount;
chatThemeBackgroundCount Number of chat theme backgrounds that can be set as chat background
final int chatThemeBackgroundCount;