customEmojiReactionCount property
customEmojiReactionCount Number of custom emoji reactions that can be added to the list of available reactions
Implementation
final int customEmojiReactionCount;
customEmojiReactionCount Number of custom emoji reactions that can be added to the list of available reactions
final int customEmojiReactionCount;