profileAccentColorCount property
profileAccentColorCount Number of custom colors for profile photo background
Implementation
final int profileAccentColorCount;
profileAccentColorCount Number of custom colors for profile photo background
final int profileAccentColorCount;