ChatBoostLink class final

Contains an HTTPS link to boost a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostLink({required String link, required bool isPublic})

Properties

hashCode int
The hash code for this object.
no setteroverride
isPublic bool
isPublic True, if the link will work for non-members of the chat
final
link The link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link, bool? isPublic}) ChatBoostLink

Available on ChatBoostLink, provided by the ChatBoostLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoostLink?

Constants

constructor → const String