ChatBoostLinkInfo class final
Contains information about a link to boost a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatBoostLinkInfo({required bool isPublic, required int chatId})
Properties
- chatId → int
-
chatId Identifier of the chat to which the link points; 0 if the chat
isn't found
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPublic → bool
-
isPublic True, if the link will work for non-members of the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isPublic, int? chatId}) → ChatBoostLinkInfo -
Available on ChatBoostLinkInfo, provided by the ChatBoostLinkInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatBoostLinkInfo?
Constants
- constructor → const String