ChatBoostSlot class final

Describes a slot for chat boost

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostSlot({required int slotId, required int currentlyBoostedChatId, required int startDate, required int expirationDate, required int cooldownUntilDate})

Properties

cooldownUntilDate int
cooldownUntilDate Point in time (Unix timestamp) after which the boost can be used for another chat
final
currentlyBoostedChatId int
currentlyBoostedChatId Identifier of the currently boosted chat; 0 if none
final
expirationDate int
expirationDate Point in time (Unix timestamp) when the boost will expire
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slotId int
slotId Unique identifier of the slot
final
startDate int
startDate Point in time (Unix timestamp) when the chat was boosted; 0 if none
final

Methods

copyWith({int? slotId, int? currentlyBoostedChatId, int? startDate, int? expirationDate, int? cooldownUntilDate}) ChatBoostSlot

Available on ChatBoostSlot, provided by the ChatBoostSlotExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoostSlot?

Constants

constructor → const String