cooldownUntilDate property
cooldownUntilDate Point in time (Unix timestamp) after which the boost can be used for another chat
Implementation
final int cooldownUntilDate;
cooldownUntilDate Point in time (Unix timestamp) after which the boost can be used for another chat
final int cooldownUntilDate;