ChatBoostSlots class final

Contains a list of chat boost slots

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostSlots({required List<ChatBoostSlot> slots})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slots List<ChatBoostSlot>
slots List of boost slots
final

Methods

copyWith({List<ChatBoostSlot>? slots}) ChatBoostSlots

Available on ChatBoostSlots, provided by the ChatBoostSlotsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoostSlots?

Constants

constructor → const String