ChatBoostSource class sealed
Describes source of a chat boost
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftCode(ChatBoostSourceGiftCode value), required TResult giveaway(ChatBoostSourceGiveaway value), }) → TResult -
Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftCode(ChatBoostSourceGiftCode value)?, TResult giveaway(ChatBoostSourceGiveaway value)?, required TResult orElse()}) → TResult -
Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatBoostSource? - Inherited by: ChatBoostSourceGiftCode ChatBoostSourceGiveaway ChatBoostSourcePremium
Constants
- constructor → const String