ChatBoostSourceGiftCode class final

The chat created a Telegram Premium gift code for a user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostSourceGiftCode({required int userId, required String giftCode})

Properties

giftCode String
giftCode The created Telegram Premium gift code, which is known only if this is a gift code for the current user, or it has already been claimed
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of a user, for which the gift code was created
final

Methods

copyWith({int? userId, String? giftCode}) ChatBoostSourceGiftCode

Available on ChatBoostSourceGiftCode, provided by the ChatBoostSourceGiftCodeExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftCode(ChatBoostSourceGiftCode value), required TResult giveaway(ChatBoostSourceGiveaway value), required TResult premium(ChatBoostSourcePremium value)}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

maybeMap<TResult extends Object?>({TResult giftCode(ChatBoostSourceGiftCode value)?, TResult giveaway(ChatBoostSourceGiveaway value)?, TResult premium(ChatBoostSourcePremium value)?, required TResult orElse()}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String