giftCode property

String giftCode
final

giftCode The created Telegram Premium gift code, which is known only if this is a gift code for the current user, or it has already been claimed

Implementation

final String giftCode;