ChatBoostSourceGiveaway class final

The chat created a giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostSourceGiveaway({required int userId, required String giftCode, required int starCount, required int giveawayMessageId, required bool isUnclaimed})

Properties

giftCode String
giftCode The created Telegram Premium gift code if it was used by the user or can be claimed by the current user; an empty string otherwise; for Telegram Premium giveways only
final
giveawayMessageId int
giveawayMessageId Identifier of the corresponding giveaway message; can be an identifier of a deleted message
final
hashCode int
The hash code for this object.
no setteroverride
isUnclaimed bool
isUnclaimed True, if the winner for the corresponding giveaway prize wasn't chosen, because there were not enough participants
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Number of Telegram Stars distributed among winners of the giveaway
final
userId int
userId Identifier of a user who won in the giveaway; 0 if none
final

Methods

copyWith({int? userId, String? giftCode, int? starCount, int? giveawayMessageId, bool? isUnclaimed}) ChatBoostSourceGiveaway

Available on ChatBoostSourceGiveaway, provided by the ChatBoostSourceGiveawayExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftCode(ChatBoostSourceGiftCode value), required TResult giveaway(ChatBoostSourceGiveaway value), required TResult premium(ChatBoostSourcePremium value)}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

maybeMap<TResult extends Object?>({TResult giftCode(ChatBoostSourceGiftCode value)?, TResult giveaway(ChatBoostSourceGiveaway value)?, TResult premium(ChatBoostSourcePremium value)?, required TResult orElse()}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String