giftCode property

String giftCode
final

giftCode The created Telegram Premium gift code if it was used by the user or can be claimed by the current user; an empty string otherwise; for Telegram Premium giveways only

Implementation

final String giftCode;