isUnclaimed property
isUnclaimed True, if the winner for the corresponding giveaway prize wasn't chosen, because there were not enough participants
Implementation
final bool isUnclaimed;
isUnclaimed True, if the winner for the corresponding giveaway prize wasn't chosen, because there were not enough participants
final bool isUnclaimed;