ChatBoostSourcePremium class final

A user with Telegram Premium subscription or gifted Telegram Premium boosted the chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoostSourcePremium({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId}) ChatBoostSourcePremium

Available on ChatBoostSourcePremium, provided by the ChatBoostSourcePremiumExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftCode(ChatBoostSourceGiftCode value), required TResult giveaway(ChatBoostSourceGiveaway value), required TResult premium(ChatBoostSourcePremium value)}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

maybeMap<TResult extends Object?>({TResult giftCode(ChatBoostSourceGiftCode value)?, TResult giveaway(ChatBoostSourceGiveaway value)?, TResult premium(ChatBoostSourcePremium value)?, required TResult orElse()}) → TResult

Available on ChatBoostSource, provided by the ChatBoostSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String