appliedSlotIds property
appliedSlotIds Identifiers of boost slots of the current user applied to the chat
Implementation
final List<int> appliedSlotIds;
appliedSlotIds Identifiers of boost slots of the current user applied to the chat
final List<int> appliedSlotIds;