nextLevelBoostCount property
nextLevelBoostCount The number of boosts needed to reach the next level; 0 if the next level isn't available
Implementation
final int nextLevelBoostCount;
nextLevelBoostCount The number of boosts needed to reach the next level; 0 if the next level isn't available
final int nextLevelBoostCount;