premiumMemberPercentage property
premiumMemberPercentage A percentage of Telegram Premium subscribers joined the chat; always 0 if the current user isn't an administrator in the chat
Implementation
final double premiumMemberPercentage;
premiumMemberPercentage A percentage of Telegram Premium subscribers joined the chat; always 0 if the current user isn't an administrator in the chat
final double premiumMemberPercentage;