prepaidGiveaways property
prepaidGiveaways The list of prepaid giveaways available for the chat; only for chat administrators
Implementation
final List<PrepaidGiveaway> prepaidGiveaways;
prepaidGiveaways The list of prepaid giveaways available for the chat; only for chat administrators
final List<PrepaidGiveaway> prepaidGiveaways;