ChatEvent class final

Represents a chat event

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatEvent({required int id, required int date, MessageSender? memberId, ChatEventAction? action})

Properties

action ChatEventAction?
action The action
final
date int
date Point in time (Unix timestamp) when the event happened
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Chat event identifier
final
memberId MessageSender?
memberId Identifier of the user or chat who performed the action
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, int? date, MessageSender? memberId, ChatEventAction? action}) ChatEvent

Available on ChatEvent, provided by the ChatEventExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatEvent?

Constants

constructor → const String