ChatEventLogFilters class final
Represents a set of filters used to obtain a chat event log
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatEventLogFilters({required bool messageEdits, required bool messageDeletions, required bool messagePins, required bool memberJoins, required bool memberLeaves, required bool memberInvites, required bool memberPromotions, required bool memberRestrictions, required bool memberTagChanges, required bool infoChanges, required bool settingChanges, required bool inviteLinkChanges, required bool videoChatChanges, required bool forumChanges, required bool subscriptionExtensions})
Properties
- forumChanges → bool
-
forumChanges True, if forum-related actions need to be returned
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- infoChanges → bool
-
infoChanges True, if changes in chat information need to be returned
final
- inviteLinkChanges → bool
-
inviteLinkChanges True, if changes to invite links need to be returned
final
- memberInvites → bool
-
memberInvites True, if invited member events need to be returned
final
- memberJoins → bool
-
memberJoins True, if members joining events need to be returned
final
- memberLeaves → bool
-
memberLeaves True, if members leaving events need to be returned
final
- memberPromotions → bool
-
memberPromotions True, if member promotion/demotion events need to be
returned
final
- memberRestrictions → bool
-
memberRestrictions True, if member
restricted/unrestricted/banned/unbanned events need to be returned
final
- memberTagChanges → bool
-
memberTagChanges True, if member tag and custom title change events need
to be returned
final
- messageDeletions → bool
-
messageDeletions True, if message deletions need to be returned
final
- messageEdits → bool
-
messageEdits True, if message edits need to be returned
final
- messagePins → bool
-
messagePins True, if pin/unpin events need to be returned
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settingChanges → bool
-
settingChanges True, if changes in chat settings need to be returned
final
- subscriptionExtensions → bool
-
subscriptionExtensions True, if subscription extensions need to be
returned
final
- videoChatChanges → bool
-
videoChatChanges True, if video chat actions need to be returned
final
Methods
-
copyWith(
{bool? messageEdits, bool? messageDeletions, bool? messagePins, bool? memberJoins, bool? memberLeaves, bool? memberInvites, bool? memberPromotions, bool? memberRestrictions, bool? memberTagChanges, bool? infoChanges, bool? settingChanges, bool? inviteLinkChanges, bool? videoChatChanges, bool? forumChanges, bool? subscriptionExtensions}) → ChatEventLogFilters -
Available on ChatEventLogFilters, provided by the ChatEventLogFiltersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatEventLogFilters?
Constants
- constructor → const String