ChatEvents class final

Contains a list of chat events

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatEvents({required List<ChatEvent> events})

Properties

events List<ChatEvent>
events List of events
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatEvent>? events}) ChatEvents

Available on ChatEvents, provided by the ChatEventsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatEvents?

Constants

constructor → const String