ChatFolderInfo class final

Contains basic information about a chat folder

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatFolderInfo({required int id, ChatFolderName? name, ChatFolderIcon? icon, required int colorId, required bool isShareable, required bool hasMyInviteLinks})

Properties

colorId int
colorId The identifier of the chosen color for the chat folder icon; from -1 to 6. If -1, then color is disabled
final
hashCode int
The hash code for this object.
no setteroverride
hasMyInviteLinks True, if the chat folder has invite links created by the current user
final
icon ChatFolderIcon?
icon The chosen or default icon for the chat folder
final
id int
id Unique chat folder identifier
final
isShareable bool
isShareable True, if at least one link has been created for the folder
final
name ChatFolderName?
name The name of the folder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, ChatFolderName? name, ChatFolderIcon? icon, int? colorId, bool? isShareable, bool? hasMyInviteLinks}) ChatFolderInfo

Available on ChatFolderInfo, provided by the ChatFolderInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatFolderInfo?

Constants

constructor → const String