ChatFolderInviteLink class final

Contains a chat folder invite link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatFolderInviteLink({required String inviteLink, required String name, required List<int> chatIds})

Properties

chatIds List<int>
chatIds Identifiers of chats, included in the link
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink The chat folder invite link
final
name String
name Name of the link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink, String? name, List<int>? chatIds}) ChatFolderInviteLink

Available on ChatFolderInviteLink, provided by the ChatFolderInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatFolderInviteLink?

Constants

constructor → const String