ChatFolderInviteLinks class final

Represents a list of chat folder invite links

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatFolderInviteLinks({required List<ChatFolderInviteLink> inviteLinks})

Properties

hashCode int
The hash code for this object.
no setteroverride
inviteLinks List of the invite links
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatFolderInviteLink>? inviteLinks}) ChatFolderInviteLinks

Available on ChatFolderInviteLinks, provided by the ChatFolderInviteLinksExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatFolderInviteLinks?

Constants

constructor → const String