ChatFolderName class final

Describes name of a chat folder

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatFolderName({FormattedText? text, required bool animateCustomEmoji})

Properties

animateCustomEmoji bool
animateCustomEmoji True, if custom emoji in the name must be animated
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text The text of the chat folder name; 1-12 characters without line feeds. May contain only CustomEmoji entities
final

Methods

copyWith({FormattedText? text, bool? animateCustomEmoji}) ChatFolderName

Available on ChatFolderName, provided by the ChatFolderNameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatFolderName?

Constants

constructor → const String