ChatInviteLink class final
Contains a chat invite link
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatInviteLink({required String inviteLink, required String name, required int creatorUserId, required int date, required int editDate, required int expirationDate, StarSubscriptionPricing? subscriptionPricing, required int memberLimit, required int memberCount, required int expiredMemberCount, required int pendingJoinRequestCount, required bool createsJoinRequest, required bool isPrimary, required bool isRevoked})
Properties
- createsJoinRequest → bool
-
createsJoinRequest True, if the link only creates join request. If true,
total number of joining members will be unlimited
final
- creatorUserId → int
-
creatorUserId User identifier of an administrator created the link
final
- date → int
-
date Point in time (Unix timestamp) when the link was created
final
- editDate → int
-
editDate Point in time (Unix timestamp) when the link was last edited; 0
if never or unknown
final
- expirationDate → int
-
expirationDate Point in time (Unix timestamp) when the link will expire;
0 if never
final
- expiredMemberCount → int
-
expiredMemberCount Number of chat members, which joined the chat using
the link, but have already left because of expired subscription; for
subscription links only
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Chat invite link
final
- isPrimary → bool
-
isPrimary True, if the link is primary. Primary invite link can't have
name, expiration date, or usage limit. There is exactly one primary invite
link for each administrator with can_invite_users right at a given time
final
- isRevoked → bool
-
isRevoked True, if the link was revoked
final
- memberCount → int
-
memberCount Number of chat members, which joined the chat using the link
final
- memberLimit → int
-
memberLimit The maximum number of members, which can join the chat using
the link simultaneously; 0 if not limited. Always 0 if the link requires
approval
final
- name → String
-
name Name of the link
final
- pendingJoinRequestCount → int
-
pendingJoinRequestCount Number of pending join requests created using
this link
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionPricing → StarSubscriptionPricing?
-
subscriptionPricing Information about subscription plan that is applied
to the users joining the chat by the link; may be null if the link doesn't
require subscription
final
Methods
-
copyWith(
{String? inviteLink, String? name, int? creatorUserId, int? date, int? editDate, int? expirationDate, StarSubscriptionPricing? subscriptionPricing, int? memberLimit, int? memberCount, int? expiredMemberCount, int? pendingJoinRequestCount, bool? createsJoinRequest, bool? isPrimary, bool? isRevoked}) → ChatInviteLink -
Available on ChatInviteLink, provided by the ChatInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatInviteLink?
Constants
- constructor → const String