subscriptionPricing property
subscriptionPricing Information about subscription plan that is applied to the users joining the chat by the link; may be null if the link doesn't require subscription
Implementation
final StarSubscriptionPricing? subscriptionPricing;