ChatInviteLinkCounts class final

Contains a list of chat invite link counts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatInviteLinkCounts({required List<ChatInviteLinkCount> inviteLinkCounts})

Properties

hashCode int
The hash code for this object.
no setteroverride
inviteLinkCounts List<ChatInviteLinkCount>
inviteLinkCounts List of invite link counts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatInviteLinkCount>? inviteLinkCounts}) ChatInviteLinkCounts

Available on ChatInviteLinkCounts, provided by the ChatInviteLinkCountsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatInviteLinkCounts?

Constants

constructor → const String