ChatInviteLinkInfo class final

Contains information about a chat invite link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatInviteLinkInfo({required int chatId, required int accessibleFor, InviteLinkChatType? type, required String title, ChatPhotoInfo? photo, required int accentColorId, required String description, required int memberCount, required List<int> memberUserIds, ChatInviteLinkSubscriptionInfo? subscriptionInfo, required bool createsJoinRequest, required bool isPublic, VerificationStatus? verificationStatus})

Properties

accentColorId int
accentColorId Identifier of the accent color for chat title and background of chat photo
final
accessibleFor int
accessibleFor If non-zero, the amount of time for which read access to the chat will remain available, in seconds
final
chatId int
chatId Chat identifier of the invite link; 0 if the user has no access to the chat before joining
final
createsJoinRequest bool
createsJoinRequest True, if the link only creates join request
final
description String
param_description Chat description
final
hashCode int
The hash code for this object.
no setteroverride
isPublic bool
isPublic True, if the chat is a public supergroup or channel, i.e. it has a username or it is a location-based supergroup
final
memberCount int
memberCount Number of members in the chat
final
memberUserIds List<int>
memberUserIds User identifiers of some chat members that may be known to the current user
final
photo ChatPhotoInfo?
photo Chat photo; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionInfo ChatInviteLinkSubscriptionInfo?
subscriptionInfo Information about subscription plan that must be paid by the user to use the link; may be null if the link doesn't require subscription
final
title String
title Title of the chat
final
type InviteLinkChatType?
type Type of the chat
final
verificationStatus VerificationStatus?
verificationStatus Information about verification status of the chat; may be null if none
final

Methods

copyWith({int? chatId, int? accessibleFor, InviteLinkChatType? type, String? title, ChatPhotoInfo? photo, int? accentColorId, String? description, int? memberCount, List<int>? memberUserIds, ChatInviteLinkSubscriptionInfo? subscriptionInfo, bool? createsJoinRequest, bool? isPublic, VerificationStatus? verificationStatus}) ChatInviteLinkInfo

Available on ChatInviteLinkInfo, provided by the ChatInviteLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatInviteLinkInfo?

Constants

constructor → const String