subscriptionInfo property
subscriptionInfo Information about subscription plan that must be paid by the user to use the link; may be null if the link doesn't require subscription
Implementation
final ChatInviteLinkSubscriptionInfo? subscriptionInfo;
subscriptionInfo Information about subscription plan that must be paid by the user to use the link; may be null if the link doesn't require subscription
final ChatInviteLinkSubscriptionInfo? subscriptionInfo;