ChatInviteLinkMembers class final

Contains a list of chat members joined a chat via an invite link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatInviteLinkMembers({required int totalCount, required List<ChatInviteLinkMember> members})

Properties

hashCode int
The hash code for this object.
no setteroverride
members List<ChatInviteLinkMember>
members List of chat members, joined a chat via an invite link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of chat members found
final

Methods

copyWith({int? totalCount, List<ChatInviteLinkMember>? members}) ChatInviteLinkMembers

Available on ChatInviteLinkMembers, provided by the ChatInviteLinkMembersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatInviteLinkMembers?

Constants

constructor → const String