ChatInviteLinkSubscriptionInfo class final

Contains information about subscription plan that must be paid by the user to use a chat invite link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatInviteLinkSubscriptionInfo({StarSubscriptionPricing? pricing, required bool canReuse, required int formId})

Properties

canReuse bool
canReuse True, if the user has already paid for the subscription and can use joinChatByInviteLink to join the subscribed chat again
final
formId int
formId Identifier of the payment form to use for subscription payment; 0 if the subscription can't be paid
final
hashCode int
The hash code for this object.
no setteroverride
pricing StarSubscriptionPricing?
pricing Information about subscription plan that must be paid by the user to use the link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({StarSubscriptionPricing? pricing, bool? canReuse, int? formId}) ChatInviteLinkSubscriptionInfo

Available on ChatInviteLinkSubscriptionInfo, provided by the ChatInviteLinkSubscriptionInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatInviteLinkSubscriptionInfo?

Constants

constructor → const String