pricing property
pricing Information about subscription plan that must be paid by the user to use the link
Implementation
final StarSubscriptionPricing? pricing;
pricing Information about subscription plan that must be paid by the user to use the link
final StarSubscriptionPricing? pricing;