ChatInviteLinks class final

Contains a list of chat invite links

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatInviteLinks({required int totalCount, required List<ChatInviteLink> inviteLinks})

Properties

hashCode int
The hash code for this object.
no setteroverride
inviteLinks List of invite links
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of chat invite links found
final

Methods

copyWith({int? totalCount, List<ChatInviteLink>? inviteLinks}) ChatInviteLinks

Available on ChatInviteLinks, provided by the ChatInviteLinksExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatInviteLinks?

Constants

constructor → const String