ChatJoinRequest class final

Describes a user who sent a join request and waits for administrator approval

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatJoinRequest({required int userId, required int date, required String bio})

Properties

bio String
bio A short bio of the user
final
date int
date Point in time (Unix timestamp) when the user sent the join request
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, int? date, String? bio}) ChatJoinRequest

Available on ChatJoinRequest, provided by the ChatJoinRequestExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatJoinRequest?

Constants

constructor → const String