ChatJoinRequestResultDeclined class final
The request was declined
- Inheritance
-
- Object
- TdObject
- ChatJoinRequestResult
- ChatJoinRequestResultDeclined
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatJoinRequestResultDeclined()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult approved(ChatJoinRequestResultApproved value), required TResult declined(ChatJoinRequestResultDeclined value), required TResult queued(ChatJoinRequestResultQueued value)}) → TResult -
Available on ChatJoinRequestResult, provided by the ChatJoinRequestResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult approved(ChatJoinRequestResultApproved value)?, TResult declined(ChatJoinRequestResultDeclined value)?, TResult queued(ChatJoinRequestResultQueued value)?, required TResult orElse()}) → TResult -
Available on ChatJoinRequestResult, provided by the ChatJoinRequestResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatJoinRequestResultDeclined? -
Inherited by:
ChatJoinRequestResultApproved
ChatJoinRequestResultDeclined
ChatJoinRequestResultQueued
override
Constants
- constructor → const String