ChatJoinRequestsInfo class final

Contains information about pending join requests for a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatJoinRequestsInfo({required int totalCount, required List<int> userIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of pending join requests
final
userIds List<int>
userIds Identifiers of at most 3 users sent the newest pending join requests
final

Methods

copyWith({int? totalCount, List<int>? userIds}) ChatJoinRequestsInfo

Available on ChatJoinRequestsInfo, provided by the ChatJoinRequestsInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatJoinRequestsInfo?

Constants

constructor → const String