ChatJoinResultDeclined class final
The join was declined by the guard bot
- Inheritance
-
- Object
- TdObject
- ChatJoinResult
- ChatJoinResultDeclined
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatJoinResultDeclined()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult declined(ChatJoinResultDeclined value), required TResult guardBotApprovalRequired(ChatJoinResultGuardBotApprovalRequired value), required TResult requestSent(ChatJoinResultRequestSent value), required TResult success(ChatJoinResultSuccess value)}) → TResult -
Available on ChatJoinResult, provided by the ChatJoinResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult declined(ChatJoinResultDeclined value)?, TResult guardBotApprovalRequired(ChatJoinResultGuardBotApprovalRequired value)?, TResult requestSent(ChatJoinResultRequestSent value)?, TResult success(ChatJoinResultSuccess value)?, required TResult orElse()}) → TResult -
Available on ChatJoinResult, provided by the ChatJoinResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatJoinResultDeclined? -
Inherited by:
ChatJoinResultDeclined
ChatJoinResultGuardBotApprovalRequired
ChatJoinResultRequestSent
ChatJoinResultSuccess
override
Constants
- constructor → const String