ChatListArchive class final

A list of chats usually located at the top of the main chat list. Unmuted chats are automatically moved from the Archive to the Main chat list when a new message arrives

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatListArchive()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult archive(ChatListArchive value), required TResult folder(ChatListFolder value), required TResult main(ChatListMain value)}) → TResult

Available on ChatList, provided by the ChatListExtensions extension

maybeMap<TResult extends Object?>({TResult archive(ChatListArchive value)?, TResult folder(ChatListFolder value)?, TResult main(ChatListMain value)?, required TResult orElse()}) → TResult

Available on ChatList, provided by the ChatListExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatListArchive?
Inherited by: ChatListArchive ChatListFolder ChatListMain
override

Constants

constructor → const String