ChatLists class final

Contains a list of chat lists

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatLists({required List<ChatList> chatLists})

Properties

chatLists List<ChatList>
chatLists List of chat lists
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ChatList>? chatLists}) ChatLists

Available on ChatLists, provided by the ChatListsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatLists?

Constants

constructor → const String