ChatLocation class final

Represents a location to which a chat is connected

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatLocation({Location? location, required String address})

Properties

address → String
address Location address; 1-64 characters, as defined by the chat owner
final
hashCode → int
The hash code for this object.
no setteroverride
location → Location?
location The location
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, String? address}) → ChatLocation

Available on ChatLocation, provided by the ChatLocationExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → ChatLocation?

Constants

constructor → const String