ChatMember class final

Describes a user or a chat as a member of another chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatMember({MessageSender? memberId, required String tag, required int inviterUserId, required int joinedChatDate, ChatMemberStatus? status})

Properties

hashCode int
The hash code for this object.
no setteroverride
inviterUserId int
inviterUserId Identifier of a user who invited/promoted/banned this member in the chat; 0 if unknown
final
joinedChatDate int
joinedChatDate Point in time (Unix timestamp) when the user joined/was promoted/was banned in the chat
final
memberId MessageSender?
memberId Identifier of the chat member. Currently, other chats can be only Left or Banned. Only supergroups and channels can have other chats as Left or Banned members and these chats must be supergroups or channels
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ChatMemberStatus?
status Status of the member in the chat
final
tag String
tag Tag of the chat member or its custom title if the member is an administrator of the chat; 0-16 characters without emoji; applicable to basic groups and supergroups only
final

Methods

copyWith({MessageSender? memberId, String? tag, int? inviterUserId, int? joinedChatDate, ChatMemberStatus? status}) ChatMember

Available on ChatMember, provided by the ChatMemberExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatMember?

Constants

constructor → const String