ChatMemberStatusBanned class final

The user or the chat was banned (and hence is not a member of the chat). Implies the user can't return to the chat, view messages, or be used as a participant identifier to join a video chat of the chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatMemberStatusBanned({required int bannedUntilDate})

Properties

bannedUntilDate int
bannedUntilDate Point in time (Unix timestamp) when the user will be unbanned; 0 if never. If the user is banned for more than 366 days or for less than 30 seconds from the current time, the user is considered to be banned forever. Always 0 in basic groups
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? bannedUntilDate}) ChatMemberStatusBanned

Available on ChatMemberStatusBanned, provided by the ChatMemberStatusBannedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult administrator(ChatMemberStatusAdministrator value), required TResult banned(ChatMemberStatusBanned value), required TResult creator(ChatMemberStatusCreator value), required TResult left(ChatMemberStatusLeft value), required TResult member(ChatMemberStatusMember value), required TResult restricted(ChatMemberStatusRestricted value)}) → TResult

Available on ChatMemberStatus, provided by the ChatMemberStatusExtensions extension

maybeMap<TResult extends Object?>({TResult administrator(ChatMemberStatusAdministrator value)?, TResult banned(ChatMemberStatusBanned value)?, TResult creator(ChatMemberStatusCreator value)?, TResult left(ChatMemberStatusLeft value)?, TResult member(ChatMemberStatusMember value)?, TResult restricted(ChatMemberStatusRestricted value)?, required TResult orElse()}) → TResult

Available on ChatMemberStatus, provided by the ChatMemberStatusExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String