ChatMemberStatusRestricted class final

The user is under certain restrictions in the chat. Not supported in basic groups and channels

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatMemberStatusRestricted({required bool isMember, required int restrictedUntilDate, ChatPermissions? permissions})

Properties

hashCode int
The hash code for this object.
no setteroverride
isMember bool
isMember True, if the user is a member of the chat
final
permissions ChatPermissions?
permissions User permissions in the chat
final
restrictedUntilDate int
restrictedUntilDate Point in time (Unix timestamp) when restrictions will be lifted from the user; 0 if never. If the user is restricted for more than 366 days or for less than 30 seconds from the current time, the user is considered to be restricted forever
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isMember, int? restrictedUntilDate, ChatPermissions? permissions}) ChatMemberStatusRestricted

Available on ChatMemberStatusRestricted, provided by the ChatMemberStatusRestrictedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult administrator(ChatMemberStatusAdministrator value), required TResult banned(ChatMemberStatusBanned value), required TResult creator(ChatMemberStatusCreator value), required TResult left(ChatMemberStatusLeft value), required TResult member(ChatMemberStatusMember value), required TResult restricted(ChatMemberStatusRestricted value)}) → TResult

Available on ChatMemberStatus, provided by the ChatMemberStatusExtensions extension

maybeMap<TResult extends Object?>({TResult administrator(ChatMemberStatusAdministrator value)?, TResult banned(ChatMemberStatusBanned value)?, TResult creator(ChatMemberStatusCreator value)?, TResult left(ChatMemberStatusLeft value)?, TResult member(ChatMemberStatusMember value)?, TResult restricted(ChatMemberStatusRestricted value)?, required TResult orElse()}) → TResult

Available on ChatMemberStatus, provided by the ChatMemberStatusExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String