ChatMembers class final

Contains a list of chat members

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatMembers({required int totalCount, required List<ChatMember> members})

Properties

hashCode int
The hash code for this object.
no setteroverride
members List<ChatMember>
members A list of chat members
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of chat members found
final

Methods

copyWith({int? totalCount, List<ChatMember>? members}) ChatMembers

Available on ChatMembers, provided by the ChatMembersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatMembers?

Constants

constructor → const String