ChatMessageSenders class final

Represents a list of message senders, which can be used to send messages in a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatMessageSenders({required List<ChatMessageSender> senders})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senders List<ChatMessageSender>
senders List of available message senders
final

Methods

copyWith({List<ChatMessageSender>? senders}) ChatMessageSenders

Available on ChatMessageSenders, provided by the ChatMessageSendersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatMessageSenders?

Constants

constructor → const String