useDefaultDisableMentionNotifications property
useDefaultDisableMentionNotifications If true, the value for the relevant type of chat or the forum chat is used instead of disable_mention_notifications
Implementation
final bool useDefaultDisableMentionNotifications;