useDefaultMuteFor property
useDefaultMuteFor If true, the value for the relevant type of chat or the forum chat is used instead of mute_for
Implementation
final bool useDefaultMuteFor;
useDefaultMuteFor If true, the value for the relevant type of chat or the forum chat is used instead of mute_for
final bool useDefaultMuteFor;