useDefaultShowPreview property

bool useDefaultShowPreview
final

useDefaultShowPreview If true, the value for the relevant type of chat or the forum chat is used instead of show_preview

Implementation

final bool useDefaultShowPreview;