canAddLinkPreviews property
canAddLinkPreviews True, if the user may add a link preview to their messages
Implementation
final bool canAddLinkPreviews;
canAddLinkPreviews True, if the user may add a link preview to their messages
final bool canAddLinkPreviews;