ChatPhoto class final

Describes a chat or user profile photo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatPhoto({required int id, required int addedDate, Minithumbnail? minithumbnail, required List<PhotoSize> sizes, AnimatedChatPhoto? animation, AnimatedChatPhoto? smallAnimation, ChatPhotoSticker? sticker})

Properties

addedDate int
addedDate Point in time (Unix timestamp) when the photo has been added
final
animation AnimatedChatPhoto?
animation A big (up to 1280x1280) animated variant of the photo in MPEG4 format; may be null
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique photo identifier
final
minithumbnail Minithumbnail?
minithumbnail Photo minithumbnail; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizes List<PhotoSize>
sizes Available variants of the photo in JPEG format, in different size
final
smallAnimation AnimatedChatPhoto?
smallAnimation A small (160x160) animated variant of the photo in MPEG4 format; may be null even if the big animation is available
final
sticker ChatPhotoSticker?
sticker Sticker-based version of the chat photo; may be null
final

Methods

copyWith({int? id, int? addedDate, Minithumbnail? minithumbnail, List<PhotoSize>? sizes, AnimatedChatPhoto? animation, AnimatedChatPhoto? smallAnimation, ChatPhotoSticker? sticker}) ChatPhoto

Available on ChatPhoto, provided by the ChatPhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatPhoto?

Constants

constructor → const String