ChatPhotoInfo class final

Contains basic information about the photo of a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatPhotoInfo({File? small, File? big, Minithumbnail? minithumbnail, required bool hasAnimation, required bool isPersonal})

Properties

big File?
big A big (640x640) chat photo variant in JPEG format. The file can be downloaded only before the photo is changed
final
hasAnimation bool
hasAnimation True, if the photo has animated variant
final
hashCode int
The hash code for this object.
no setteroverride
isPersonal bool
isPersonal True, if the photo is visible only for the current user
final
minithumbnail Minithumbnail?
minithumbnail Chat photo minithumbnail; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
small File?
small A small (160x160) chat photo variant in JPEG format. The file can be downloaded only before the photo is changed
final

Methods

copyWith({File? small, File? big, Minithumbnail? minithumbnail, bool? hasAnimation, bool? isPersonal}) ChatPhotoInfo

Available on ChatPhotoInfo, provided by the ChatPhotoInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatPhotoInfo?

Constants

constructor → const String