ChatPhotos class final
Contains a list of chat or user profile photos
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatPhotos({required int totalCount, required List<
ChatPhoto> photos})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
photos
→ List<
ChatPhoto> -
photos List of photos
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Total number of photos
final
Methods
-
copyWith(
{int? totalCount, List< ChatPhoto> ? photos}) → ChatPhotos -
Available on ChatPhotos, provided by the ChatPhotosExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatPhotos?
Constants
- constructor → const String