ChatRevenueStatistics class final

A detailed statistics about revenue earned from sponsored messages in a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatRevenueStatistics({StatisticalGraph? revenueByHourGraph, StatisticalGraph? revenueGraph, ChatRevenueAmount? revenueAmount, required double usdRate})

Properties

hashCode int
The hash code for this object.
no setteroverride
revenueAmount ChatRevenueAmount?
revenueAmount Amount of earned revenue
final
revenueByHourGraph StatisticalGraph?
revenueByHourGraph A graph containing amount of revenue in a given hour
final
revenueGraph StatisticalGraph?
revenueGraph A graph containing amount of revenue
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usdRate double
usdRate Current conversion rate of the cryptocurrency in which revenue is calculated to USD
final

Methods

copyWith({StatisticalGraph? revenueByHourGraph, StatisticalGraph? revenueGraph, ChatRevenueAmount? revenueAmount, double? usdRate}) ChatRevenueStatistics

Available on ChatRevenueStatistics, provided by the ChatRevenueStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatRevenueStatistics?

Constants

constructor → const String