ChatRevenueTransactionTypeFragmentWithdrawal class final

Describes a withdrawal of earnings through Fragment

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatRevenueTransactionTypeFragmentWithdrawal({required int withdrawalDate, RevenueWithdrawalState? state})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state RevenueWithdrawalState?
state State of the withdrawal
final
withdrawalDate int
withdrawalDate Point in time (Unix timestamp) when the earnings withdrawal started
final

Methods

copyWith({int? withdrawalDate, RevenueWithdrawalState? state}) ChatRevenueTransactionTypeFragmentWithdrawal

Available on ChatRevenueTransactionTypeFragmentWithdrawal, provided by the ChatRevenueTransactionTypeFragmentWithdrawalExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult fragmentRefund(ChatRevenueTransactionTypeFragmentRefund value), required TResult fragmentWithdrawal(ChatRevenueTransactionTypeFragmentWithdrawal value), required TResult sponsoredMessageEarnings(ChatRevenueTransactionTypeSponsoredMessageEarnings value), required TResult suggestedPostEarnings(ChatRevenueTransactionTypeSuggestedPostEarnings value), required TResult unsupported(ChatRevenueTransactionTypeUnsupported value)}) → TResult

Available on ChatRevenueTransactionType, provided by the ChatRevenueTransactionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult fragmentRefund(ChatRevenueTransactionTypeFragmentRefund value)?, TResult fragmentWithdrawal(ChatRevenueTransactionTypeFragmentWithdrawal value)?, TResult sponsoredMessageEarnings(ChatRevenueTransactionTypeSponsoredMessageEarnings value)?, TResult suggestedPostEarnings(ChatRevenueTransactionTypeSuggestedPostEarnings value)?, TResult unsupported(ChatRevenueTransactionTypeUnsupported value)?, required TResult orElse()}) → TResult

Available on ChatRevenueTransactionType, provided by the ChatRevenueTransactionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String