ChatRevenueTransactions class final

Contains a list of chat revenue transactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatRevenueTransactions({required int gramAmount, required List<ChatRevenueTransaction> transactions, required String nextOffset})

Properties

gramAmount int
gramAmount The amount of owned TON Grams; in the smallest units of the cryptocurrency
final
hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactions List<ChatRevenueTransaction>
transactions List of transactions
final

Methods

copyWith({int? gramAmount, List<ChatRevenueTransaction>? transactions, String? nextOffset}) ChatRevenueTransactions

Available on ChatRevenueTransactions, provided by the ChatRevenueTransactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatRevenueTransactions?

Constants

constructor → const String