ChatSourcePublicServiceAnnouncement class final

The chat contains a public service announcement

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatSourcePublicServiceAnnouncement({required String type, required String text})

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
text The text of the announcement
final
type → String
type The type of the announcement
final

Methods

copyWith({String? type, String? text}) → ChatSourcePublicServiceAnnouncement

Available on ChatSourcePublicServiceAnnouncement, provided by the ChatSourcePublicServiceAnnouncementExtensions extension

getConstructor() → String
override
map<TResult extends Object?>({required TResult mtprotoProxy(ChatSourceMtprotoProxy value), required TResult publicServiceAnnouncement(ChatSourcePublicServiceAnnouncement value)}) → TResult

Available on ChatSource, provided by the ChatSourceExtensions extension

maybeMap<TResult extends Object?>({TResult mtprotoProxy(ChatSourceMtprotoProxy value)?, TResult publicServiceAnnouncement(ChatSourcePublicServiceAnnouncement value)?, required TResult orElse()}) → TResult

Available on ChatSource, provided by the ChatSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

constructor → const String