ChatStatistics class sealed

Contains a detailed statistics about a chat

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(ChatStatisticsChannel value), required TResult supergroup(ChatStatisticsSupergroup value)}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

maybeMap<TResult extends Object?>({TResult channel(ChatStatisticsChannel value)?, TResult supergroup(ChatStatisticsSupergroup value)?, required TResult orElse()}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatStatistics?
Inherited by: ChatStatisticsChannel ChatStatisticsSupergroup

Constants

constructor → const String