ChatStatisticsChannel class final

A detailed statistics about a channel chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatStatisticsChannel({DateRange? period, StatisticalValue? memberCount, StatisticalValue? meanMessageViewCount, StatisticalValue? meanMessageShareCount, StatisticalValue? meanMessageReactionCount, StatisticalValue? meanStoryViewCount, StatisticalValue? meanStoryShareCount, StatisticalValue? meanStoryReactionCount, required double enabledNotificationsPercentage, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? muteGraph, StatisticalGraph? viewCountByHourGraph, StatisticalGraph? viewCountBySourceGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageInteractionGraph, StatisticalGraph? messageReactionGraph, StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph, StatisticalGraph? instantViewInteractionGraph, required List<ChatStatisticsInteractionInfo> recentInteractions})

Properties

enabledNotificationsPercentage double
enabledNotificationsPercentage A percentage of users with enabled notifications for the chat; 0-100
final
hashCode int
The hash code for this object.
no setteroverride
instantViewInteractionGraph StatisticalGraph?
instantViewInteractionGraph A graph containing number of views of associated with the chat instant views
final
joinBySourceGraph StatisticalGraph?
joinBySourceGraph A graph containing number of new member joins per source
final
joinGraph StatisticalGraph?
joinGraph A graph containing number of members joined and left the chat
final
languageGraph StatisticalGraph?
languageGraph A graph containing number of users viewed chat messages per language
final
meanMessageReactionCount StatisticalValue?
meanMessageReactionCount Mean number of times reactions were added to the recently sent messages
final
meanMessageShareCount StatisticalValue?
meanMessageShareCount Mean number of times the recently sent messages were shared
final
meanMessageViewCount StatisticalValue?
meanMessageViewCount Mean number of times the recently sent messages were viewed
final
meanStoryReactionCount StatisticalValue?
meanStoryReactionCount Mean number of times reactions were added to the recently posted stories
final
meanStoryShareCount StatisticalValue?
meanStoryShareCount Mean number of times the recently posted stories were shared
final
meanStoryViewCount StatisticalValue?
meanStoryViewCount Mean number of times the recently posted stories were viewed
final
memberCount StatisticalValue?
memberCount Number of members in the chat
final
memberCountGraph StatisticalGraph?
memberCountGraph A graph containing number of members in the chat
final
messageInteractionGraph StatisticalGraph?
messageInteractionGraph A graph containing number of chat message views and shares
final
messageReactionGraph StatisticalGraph?
messageReactionGraph A graph containing number of reactions on messages
final
muteGraph StatisticalGraph?
muteGraph A graph containing number of members muted and unmuted the chat
final
period DateRange?
period A period to which the statistics applies
final
recentInteractions List<ChatStatisticsInteractionInfo>
recentInteractions Detailed statistics about number of views and shares of recently sent messages and posted stories
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyInteractionGraph StatisticalGraph?
storyInteractionGraph A graph containing number of story views and shares
final
storyReactionGraph StatisticalGraph?
storyReactionGraph A graph containing number of reactions on stories
final
viewCountByHourGraph StatisticalGraph?
viewCountByHourGraph A graph containing number of message views in a given hour in the last two weeks
final
viewCountBySourceGraph StatisticalGraph?
viewCountBySourceGraph A graph containing number of message views per source
final

Methods

copyWith({DateRange? period, StatisticalValue? memberCount, StatisticalValue? meanMessageViewCount, StatisticalValue? meanMessageShareCount, StatisticalValue? meanMessageReactionCount, StatisticalValue? meanStoryViewCount, StatisticalValue? meanStoryShareCount, StatisticalValue? meanStoryReactionCount, double? enabledNotificationsPercentage, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? muteGraph, StatisticalGraph? viewCountByHourGraph, StatisticalGraph? viewCountBySourceGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageInteractionGraph, StatisticalGraph? messageReactionGraph, StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph, StatisticalGraph? instantViewInteractionGraph, List<ChatStatisticsInteractionInfo>? recentInteractions}) ChatStatisticsChannel

Available on ChatStatisticsChannel, provided by the ChatStatisticsChannelExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(ChatStatisticsChannel value), required TResult supergroup(ChatStatisticsSupergroup value)}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

maybeMap<TResult extends Object?>({TResult channel(ChatStatisticsChannel value)?, TResult supergroup(ChatStatisticsSupergroup value)?, required TResult orElse()}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatStatisticsChannel?
Inherited by: ChatStatisticsChannel ChatStatisticsSupergroup
override

Constants

constructor → const String