meanStoryReactionCount property
meanStoryReactionCount Mean number of times reactions were added to the recently posted stories
Implementation
final StatisticalValue? meanStoryReactionCount;
meanStoryReactionCount Mean number of times reactions were added to the recently posted stories
final StatisticalValue? meanStoryReactionCount;