viewCountBySourceGraph property
viewCountBySourceGraph A graph containing number of message views per source
Implementation
final StatisticalGraph? viewCountBySourceGraph;
viewCountBySourceGraph A graph containing number of message views per source
final StatisticalGraph? viewCountBySourceGraph;