ChatStatisticsInteractionInfo class final

Contains statistics about interactions with a message sent in the chat or a story posted on behalf of the chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatStatisticsInteractionInfo({ChatStatisticsObjectType? objectType, required int viewCount, required int forwardCount, required int reactionCount})

Properties

forwardCount int
forwardCount Number of times the object was forwarded
final
hashCode int
The hash code for this object.
no setteroverride
objectType ChatStatisticsObjectType?
objectType Type of the object
final
reactionCount int
reactionCount Number of times reactions were added to the object
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewCount int
viewCount Number of times the object was viewed
final

Methods

copyWith({ChatStatisticsObjectType? objectType, int? viewCount, int? forwardCount, int? reactionCount}) ChatStatisticsInteractionInfo

Available on ChatStatisticsInteractionInfo, provided by the ChatStatisticsInteractionInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatStatisticsInteractionInfo?

Constants

constructor → const String