ChatStatisticsObjectType class sealed

Describes type of object, for which statistics are provided

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult message(ChatStatisticsObjectTypeMessage value), required TResult story(ChatStatisticsObjectTypeStory value)}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

maybeMap<TResult extends Object?>({TResult message(ChatStatisticsObjectTypeMessage value)?, TResult story(ChatStatisticsObjectTypeStory value)?, required TResult orElse()}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String