ChatStatisticsObjectTypeMessage class final

Describes a message sent in the chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatStatisticsObjectTypeMessage({required int messageId})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageId}) ChatStatisticsObjectTypeMessage

Available on ChatStatisticsObjectTypeMessage, provided by the ChatStatisticsObjectTypeMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(ChatStatisticsObjectTypeMessage value), required TResult story(ChatStatisticsObjectTypeStory value)}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

maybeMap<TResult extends Object?>({TResult message(ChatStatisticsObjectTypeMessage value)?, TResult story(ChatStatisticsObjectTypeStory value)?, required TResult orElse()}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String