ChatStatisticsObjectTypeStory class final

Describes a story posted on behalf of the chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatStatisticsObjectTypeStory({required int storyId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Story identifier
final

Methods

copyWith({int? storyId}) ChatStatisticsObjectTypeStory

Available on ChatStatisticsObjectTypeStory, provided by the ChatStatisticsObjectTypeStoryExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(ChatStatisticsObjectTypeMessage value), required TResult story(ChatStatisticsObjectTypeStory value)}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

maybeMap<TResult extends Object?>({TResult message(ChatStatisticsObjectTypeMessage value)?, TResult story(ChatStatisticsObjectTypeStory value)?, required TResult orElse()}) → TResult

Available on ChatStatisticsObjectType, provided by the ChatStatisticsObjectTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String