ChatStatisticsSupergroup class final

A detailed statistics about a supergroup chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatStatisticsSupergroup({DateRange? period, StatisticalValue? memberCount, StatisticalValue? messageCount, StatisticalValue? viewerCount, StatisticalValue? senderCount, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageContentGraph, StatisticalGraph? actionGraph, StatisticalGraph? dayGraph, StatisticalGraph? weekGraph, required List<ChatStatisticsMessageSenderInfo> topSenders, required List<ChatStatisticsAdministratorActionsInfo> topAdministrators, required List<ChatStatisticsInviterInfo> topInviters})

Properties

actionGraph StatisticalGraph?
actionGraph A graph containing number of different actions in the chat
final
dayGraph StatisticalGraph?
dayGraph A graph containing distribution of message views per hour
final
hashCode int
The hash code for this object.
no setteroverride
joinBySourceGraph StatisticalGraph?
joinBySourceGraph A graph containing number of new member joins per source
final
joinGraph StatisticalGraph?
joinGraph A graph containing number of members joined and left the chat
final
languageGraph StatisticalGraph?
languageGraph A graph containing distribution of active users per language
final
memberCount StatisticalValue?
memberCount Number of members in the chat
final
memberCountGraph StatisticalGraph?
memberCountGraph A graph containing number of members in the chat
final
messageContentGraph StatisticalGraph?
messageContentGraph A graph containing distribution of sent messages by content type
final
messageCount StatisticalValue?
messageCount Number of messages sent to the chat
final
period DateRange?
period A period to which the statistics applies
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderCount StatisticalValue?
senderCount Number of users who sent messages to the chat
final
topAdministrators List<ChatStatisticsAdministratorActionsInfo>
topAdministrators List of most active administrators in the last week
final
topInviters List<ChatStatisticsInviterInfo>
topInviters List of most active inviters of new members in the last week
final
topSenders List<ChatStatisticsMessageSenderInfo>
topSenders List of users sent most messages in the last week
final
viewerCount StatisticalValue?
viewerCount Number of users who viewed messages in the chat
final
weekGraph StatisticalGraph?
weekGraph A graph containing distribution of message views per day of week
final

Methods

copyWith({DateRange? period, StatisticalValue? memberCount, StatisticalValue? messageCount, StatisticalValue? viewerCount, StatisticalValue? senderCount, StatisticalGraph? memberCountGraph, StatisticalGraph? joinGraph, StatisticalGraph? joinBySourceGraph, StatisticalGraph? languageGraph, StatisticalGraph? messageContentGraph, StatisticalGraph? actionGraph, StatisticalGraph? dayGraph, StatisticalGraph? weekGraph, List<ChatStatisticsMessageSenderInfo>? topSenders, List<ChatStatisticsAdministratorActionsInfo>? topAdministrators, List<ChatStatisticsInviterInfo>? topInviters}) ChatStatisticsSupergroup

Available on ChatStatisticsSupergroup, provided by the ChatStatisticsSupergroupExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(ChatStatisticsChannel value), required TResult supergroup(ChatStatisticsSupergroup value)}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

maybeMap<TResult extends Object?>({TResult channel(ChatStatisticsChannel value)?, TResult supergroup(ChatStatisticsSupergroup value)?, required TResult orElse()}) → TResult

Available on ChatStatistics, provided by the ChatStatisticsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatStatisticsSupergroup?
Inherited by: ChatStatisticsChannel ChatStatisticsSupergroup
override

Constants

constructor → const String