ChatTheme class sealed

Describes a chat theme

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult emoji(ChatThemeEmoji value), required TResult gift(ChatThemeGift value)}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

maybeMap<TResult extends Object?>({TResult emoji(ChatThemeEmoji value)?, TResult gift(ChatThemeGift value)?, required TResult orElse()}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatTheme?
Inherited by: ChatThemeEmoji ChatThemeGift

Constants

constructor → const String