ChatThemeEmoji class final

A chat theme based on an emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatThemeEmoji({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the theme; full theme description is received through updateEmojiChatThemes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) ChatThemeEmoji

Available on ChatThemeEmoji, provided by the ChatThemeEmojiExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult emoji(ChatThemeEmoji value), required TResult gift(ChatThemeGift value)}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

maybeMap<TResult extends Object?>({TResult emoji(ChatThemeEmoji value)?, TResult gift(ChatThemeGift value)?, required TResult orElse()}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatThemeEmoji?
Inherited by: ChatThemeEmoji ChatThemeGift
override

Constants

constructor → const String