ChatThemeGift class final

A chat theme based on an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatThemeGift({GiftChatTheme? giftTheme})

Properties

giftTheme GiftChatTheme?
giftTheme The chat theme
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({GiftChatTheme? giftTheme}) ChatThemeGift

Available on ChatThemeGift, provided by the ChatThemeGiftExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult emoji(ChatThemeEmoji value), required TResult gift(ChatThemeGift value)}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

maybeMap<TResult extends Object?>({TResult emoji(ChatThemeEmoji value)?, TResult gift(ChatThemeGift value)?, required TResult orElse()}) → TResult

Available on ChatTheme, provided by the ChatThemeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatThemeGift?
Inherited by: ChatThemeEmoji ChatThemeGift
override

Constants

constructor → const String