ChatTypePrivate class final

An ordinary chat with a user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatTypePrivate({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId}) ChatTypePrivate

Available on ChatTypePrivate, provided by the ChatTypePrivateExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult basicGroup(ChatTypeBasicGroup value), required TResult private(ChatTypePrivate value), required TResult secret(ChatTypeSecret value), required TResult supergroup(ChatTypeSupergroup value)}) → TResult

Available on ChatType, provided by the ChatTypeExtensions extension

maybeMap<TResult extends Object?>({TResult basicGroup(ChatTypeBasicGroup value)?, TResult private(ChatTypePrivate value)?, TResult secret(ChatTypeSecret value)?, TResult supergroup(ChatTypeSupergroup value)?, required TResult orElse()}) → TResult

Available on ChatType, provided by the ChatTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatTypePrivate?
Inherited by: ChatTypeBasicGroup ChatTypePrivate ChatTypeSecret ChatTypeSupergroup
override

Constants

constructor → const String