ChatTypeSupergroup class final

A supergroup or channel (with unlimited members)

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatTypeSupergroup({required int supergroupId, required bool isChannel})

Properties

hashCode int
The hash code for this object.
no setteroverride
isChannel bool
isChannel True, if the supergroup is a channel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Supergroup or channel identifier
final

Methods

copyWith({int? supergroupId, bool? isChannel}) ChatTypeSupergroup

Available on ChatTypeSupergroup, provided by the ChatTypeSupergroupExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult basicGroup(ChatTypeBasicGroup value), required TResult private(ChatTypePrivate value), required TResult secret(ChatTypeSecret value), required TResult supergroup(ChatTypeSupergroup value)}) → TResult

Available on ChatType, provided by the ChatTypeExtensions extension

maybeMap<TResult extends Object?>({TResult basicGroup(ChatTypeBasicGroup value)?, TResult private(ChatTypePrivate value)?, TResult secret(ChatTypeSecret value)?, TResult supergroup(ChatTypeSupergroup value)?, required TResult orElse()}) → TResult

Available on ChatType, provided by the ChatTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatTypeSupergroup?
Inherited by: ChatTypeBasicGroup ChatTypePrivate ChatTypeSecret ChatTypeSupergroup
override

Constants

constructor → const String