Chats class final

Represents a list of chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Chats({required int totalCount, required List<int> chatIds})

Properties

chatIds List<int>
chatIds List of chat identifiers
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of chats found
final

Methods

copyWith({int? totalCount, List<int>? chatIds}) Chats

Available on Chats, provided by the ChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Chats?

Constants

constructor → const String