CheckAuthenticationBotToken class final
Checks the authentication token of a bot; to log in as a bot. Works only when the current authorization state is authorizationStateWaitPhoneNumber. Can be used instead of setAuthenticationPhoneNumber and checkAuthenticationCode to log in Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationBotToken
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckAuthenticationBotToken({required String token})
Properties
Methods
-
copyWith(
{String? token}) → CheckAuthenticationBotToken -
Available on CheckAuthenticationBotToken, provided by the CheckAuthenticationBotTokenExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String