CheckAuthenticationCode class final
Checks the authentication code. Works only when the current authorization state is authorizationStateWaitCode Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckAuthenticationCode({required String code})
Properties
Methods
-
copyWith(
{String? code}) → CheckAuthenticationCode -
Available on CheckAuthenticationCode, provided by the CheckAuthenticationCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String