authenticatorData property
authenticatorData Authenticator data of the application that created the credential
Implementation
final String authenticatorData;
authenticatorData Authenticator data of the application that created the credential
final String authenticatorData;