CheckAuthenticationPasswordRecoveryCode class final

Checks whether a 2-step verification password recovery code sent to an email address is valid. Works only when the current authorization state is authorizationStateWaitPassword Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CheckAuthenticationPasswordRecoveryCode({required String recoveryCode})

Properties

hashCode int
The hash code for this object.
no setteroverride
recoveryCode String
recoveryCode Recovery code to check
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? recoveryCode}) CheckAuthenticationPasswordRecoveryCode

Available on CheckAuthenticationPasswordRecoveryCode, provided by the CheckAuthenticationPasswordRecoveryCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String