CheckAuthenticationWebToken class final
Checks a web token to log in to the corresponding account; for official Telegram apps only. Works only when the current authorization state is authorizationStateWaitPhoneNumber or authorizationStateWaitOtherDeviceConfirmation Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationWebToken
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckAuthenticationWebToken({required String token, required int dcId})
Properties
Methods
-
copyWith(
{String? token, int? dcId}) → CheckAuthenticationWebToken -
Available on CheckAuthenticationWebToken, provided by the CheckAuthenticationWebTokenExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String