CheckBotUsername class final

Checks whether a username can be set for a new bot. Use checkChatUsername to check username for other chat types Returns CheckChatUsernameResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CheckBotUsername({required String username})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
username Username to be checked
final

Methods

copyWith({String? username}) CheckBotUsername

Available on CheckBotUsername, provided by the CheckBotUsernameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String