CheckChatFolderInviteLink class final

Checks the validity of an invite link for a chat folder and returns information about the corresponding chat folder Returns ChatFolderInviteLinkInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CheckChatFolderInviteLink({required String inviteLink})

Properties

hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link to be checked
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inviteLink}) CheckChatFolderInviteLink

Available on CheckChatFolderInviteLink, provided by the CheckChatFolderInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String