CheckChatInviteLink class final
Checks the validity of an invite link for a chat and returns information about the corresponding chat Returns ChatInviteLinkInfo
- Inheritance
-
- Object
- TdFunction
- CheckChatInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckChatInviteLink({required String inviteLink})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Invite link to be checked
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? inviteLink}) → CheckChatInviteLink -
Available on CheckChatInviteLink, provided by the CheckChatInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String