CheckChatUsernameResult class sealed

Represents result of checking whether a username can be set for a chat

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult ok(CheckChatUsernameResultOk value), required TResult publicChatsTooMany(CheckChatUsernameResultPublicChatsTooMany value), required TResult publicGroupsUnavailable(CheckChatUsernameResultPublicGroupsUnavailable value), required TResult usernameInvalid(CheckChatUsernameResultUsernameInvalid value), required TResult usernameOccupied(CheckChatUsernameResultUsernameOccupied value), required TResult usernamePurchasable(CheckChatUsernameResultUsernamePurchasable value)}) → TResult

Available on CheckChatUsernameResult, provided by the CheckChatUsernameResultExtensions extension

maybeMap<TResult extends Object?>({TResult ok(CheckChatUsernameResultOk value)?, TResult publicChatsTooMany(CheckChatUsernameResultPublicChatsTooMany value)?, TResult publicGroupsUnavailable(CheckChatUsernameResultPublicGroupsUnavailable value)?, TResult usernameInvalid(CheckChatUsernameResultUsernameInvalid value)?, TResult usernameOccupied(CheckChatUsernameResultUsernameOccupied value)?, TResult usernamePurchasable(CheckChatUsernameResultUsernamePurchasable value)?, required TResult orElse()}) → TResult

Available on CheckChatUsernameResult, provided by the CheckChatUsernameResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String