CheckEmailAddressVerificationCode class final
Checks the email address verification code for Telegram Passport Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckEmailAddressVerificationCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckEmailAddressVerificationCode({required String code})
Properties
Methods
-
copyWith(
{String? code}) → CheckEmailAddressVerificationCode -
Available on CheckEmailAddressVerificationCode, provided by the CheckEmailAddressVerificationCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String