CheckPhoneNumberCode class final
Checks the authentication code and completes the request for which the code was sent if appropriate Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckPhoneNumberCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckPhoneNumberCode({required String code})
Properties
Methods
-
copyWith(
{String? code}) → CheckPhoneNumberCode -
Available on CheckPhoneNumberCode, provided by the CheckPhoneNumberCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String