CheckPremiumGiftCode class final
Returns information about a Telegram Premium gift code Returns PremiumGiftCodeInfo
- Inheritance
-
- Object
- TdFunction
- CheckPremiumGiftCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckPremiumGiftCode({required String code})
Properties
Methods
-
copyWith(
{String? code}) → CheckPremiumGiftCode -
Available on CheckPremiumGiftCode, provided by the CheckPremiumGiftCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String