CheckQuickReplyShortcutName class final
Checks validness of a name for a quick reply shortcut. Can be called synchronously Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckQuickReplyShortcutName
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckQuickReplyShortcutName({required String name})
Properties
Methods
-
copyWith(
{String? name}) → CheckQuickReplyShortcutName -
Available on CheckQuickReplyShortcutName, provided by the CheckQuickReplyShortcutNameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String