CheckRecoveryEmailAddressCode class final
Checks the 2-step verification recovery email address verification code Returns PasswordState
- Inheritance
-
- Object
- TdFunction
- CheckRecoveryEmailAddressCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckRecoveryEmailAddressCode({required String code})
Properties
Methods
-
copyWith(
{String? code}) → CheckRecoveryEmailAddressCode -
Available on CheckRecoveryEmailAddressCode, provided by the CheckRecoveryEmailAddressCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String