CheckStickerSetName class final
Checks whether a name can be used for a new sticker set Returns CheckStickerSetNameResult
- Inheritance
-
- Object
- TdFunction
- CheckStickerSetName
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckStickerSetName({required String name})
Properties
Methods
-
copyWith(
{String? name}) → CheckStickerSetName -
Available on CheckStickerSetName, provided by the CheckStickerSetNameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String