CheckStickerSetNameResultNameInvalid class final
The name is invalid
- Inheritance
-
- Object
- TdObject
- CheckStickerSetNameResult
- CheckStickerSetNameResultNameInvalid
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult nameInvalid(CheckStickerSetNameResultNameInvalid value), required TResult nameOccupied(CheckStickerSetNameResultNameOccupied value), required TResult ok(CheckStickerSetNameResultOk value)}) → TResult -
Available on CheckStickerSetNameResult, provided by the CheckStickerSetNameResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult nameInvalid(CheckStickerSetNameResultNameInvalid value)?, TResult nameOccupied(CheckStickerSetNameResultNameOccupied value)?, TResult ok(CheckStickerSetNameResultOk value)?, required TResult orElse()}) → TResult -
Available on CheckStickerSetNameResult, provided by the CheckStickerSetNameResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CheckStickerSetNameResultNameInvalid? -
Inherited by:
CheckStickerSetNameResultNameInvalid
CheckStickerSetNameResultNameOccupied
CheckStickerSetNameResultOk
override
Constants
- constructor → const String