canAddTasks property
canAddTasks True, if the current user can add tasks to the list if they have Telegram Premium subscription
Implementation
final bool canAddTasks;
canAddTasks True, if the current user can add tasks to the list if they have Telegram Premium subscription
final bool canAddTasks;