canMarkTasksAsDone property
canMarkTasksAsDone True, if the current user can mark tasks as done or not done if they have Telegram Premium subscription
Implementation
final bool canMarkTasksAsDone;
canMarkTasksAsDone True, if the current user can mark tasks as done or not done if they have Telegram Premium subscription
final bool canMarkTasksAsDone;