othersCanAddTasks property
othersCanAddTasks True, if users other than creator of the list can add tasks to the list
Implementation
final bool othersCanAddTasks;
othersCanAddTasks True, if users other than creator of the list can add tasks to the list
final bool othersCanAddTasks;