ChecklistTask class final

Describes a task in a checklist

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChecklistTask({required int id, FormattedText? text, MessageSender? completedBy, required int completionDate})

Properties

completedBy MessageSender?
completedBy Identifier of the user or chat that completed the task; may be null if the task isn't completed yet
final
completionDate int
completionDate Point in time (Unix timestamp) when the task was completed; 0 if the task isn't completed
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the task
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text of the task; may contain only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, DateTime and automatically found entities
final

Methods

copyWith({int? id, FormattedText? text, MessageSender? completedBy, int? completionDate}) ChecklistTask

Available on ChecklistTask, provided by the ChecklistTaskExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChecklistTask?

Constants

constructor → const String