ClearRecentStickers class final
Clears the list of recently used stickers Returns Ok
- Inheritance
-
- Object
- TdFunction
- ClearRecentStickers
- Available extensions
- Annotations
-
- @immutable
Constructors
- ClearRecentStickers({required bool isAttached})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAttached → bool
-
isAttached Pass true to clear the list of stickers recently attached to
photo or video files; pass false to clear the list of recently sent
stickers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isAttached}) → ClearRecentStickers -
Available on ClearRecentStickers, provided by the ClearRecentStickersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String