fromFullscreen property

bool fromFullscreen
final

fromFullscreen Pass true if the user expanded the video from the sponsored message fullscreen before the click

Implementation

final bool fromFullscreen;