CloseSecretChat class final
Closes a secret chat, effectively transferring its state to secretChatStateClosed Returns Ok
- Inheritance
-
- Object
- TdFunction
- CloseSecretChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- CloseSecretChat({required int secretChatId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretChatId → int
-
secretChatId Secret chat identifier
final
Methods
-
copyWith(
{int? secretChatId}) → CloseSecretChat -
Available on CloseSecretChat, provided by the CloseSecretChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String