CloseStory class final

Informs TDLib that a story is closed by the user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CloseStory({required int storyPosterChatId, required int storyId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId The identifier of the story
final
storyPosterChatId int
storyPosterChatId The identifier of the poster of the story to close
final

Methods

copyWith({int? storyPosterChatId, int? storyId}) CloseStory

Available on CloseStory, provided by the CloseStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String