CloseWebApp class final

Informs TDLib that a previously opened Web App was closed Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CloseWebApp({required int webAppLaunchId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webAppLaunchId int
webAppLaunchId Identifier of Web App launch, received from openWebApp
final

Methods

copyWith({int? webAppLaunchId}) CloseWebApp

Available on CloseWebApp, provided by the CloseWebAppExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String