CollectibleItemInfo class final

Contains information about a collectible item and its last purchase

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CollectibleItemInfo({required int purchaseDate, required String currency, required int amount, required String cryptocurrency, required int cryptocurrencyAmount, required String url})

Properties

amount int
amount The paid amount, in the smallest units of the currency
final
cryptocurrency String
cryptocurrency Cryptocurrency used to pay for the item
final
cryptocurrencyAmount int
cryptocurrencyAmount The paid amount, in the smallest units of the cryptocurrency
final
currency String
currency Currency for the paid amount
final
hashCode int
The hash code for this object.
no setteroverride
purchaseDate int
purchaseDate Point in time (Unix timestamp) when the item was purchased
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url Individual URL for the item on https://fragment.com
final

Methods

copyWith({int? purchaseDate, String? currency, int? amount, String? cryptocurrency, int? cryptocurrencyAmount, String? url}) CollectibleItemInfo

Available on CollectibleItemInfo, provided by the CollectibleItemInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CollectibleItemInfo?

Constants

constructor → const String