CollectibleItemTypePhoneNumber class final

A phone number

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CollectibleItemTypePhoneNumber({required String phoneNumber})

Properties

hashCode int
The hash code for this object.
no setteroverride
phoneNumber String
phoneNumber The phone number
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? phoneNumber}) CollectibleItemTypePhoneNumber

Available on CollectibleItemTypePhoneNumber, provided by the CollectibleItemTypePhoneNumberExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult phoneNumber(CollectibleItemTypePhoneNumber value), required TResult username(CollectibleItemTypeUsername value)}) → TResult

Available on CollectibleItemType, provided by the CollectibleItemTypeExtensions extension

maybeMap<TResult extends Object?>({TResult phoneNumber(CollectibleItemTypePhoneNumber value)?, TResult username(CollectibleItemTypeUsername value)?, required TResult orElse()}) → TResult

Available on CollectibleItemType, provided by the CollectibleItemTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String