haveAccess property

bool haveAccess
final

haveAccess If false, the community is inaccessible, and the only information known about the community is inside this class. Identifier of the community can't be passed to any method

Implementation

final bool haveAccess;