canChangeInfo property
canChangeInfo True, if the administrator can change the community name, photo, and other settings
Implementation
final bool canChangeInfo;
canChangeInfo True, if the administrator can change the community name, photo, and other settings
final bool canChangeInfo;