canEditChatList property
canEditChatList True, if the user can change the chats added to the community
Implementation
final bool canEditChatList;
canEditChatList True, if the user can change the chats added to the community
final bool canEditChatList;