CommunityPermissions class final

Describes actions that a user is allowed to take in a community

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CommunityPermissions({required bool canEditChatList})

Properties

canEditChatList bool
canEditChatList True, if the user can change the chats added to the community
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canEditChatList}) CommunityPermissions

Available on CommunityPermissions, provided by the CommunityPermissionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CommunityPermissions?

Constants

constructor → const String