ComposeRichMessageWithAi class final

Changes a rich message using an AI model. May return an error with a message "AICOMPOSE_FLOOD_PREMIUM" if Telegram Premium is required to send further requests Returns RichMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ComposeRichMessageWithAi({InputRichMessage? message, required String translateToLanguageCode, required String styleName, required String customPrompt, required bool addEmojis})

Properties

addEmojis bool
addEmojis Pass true to add emoji to the text
final
customPrompt String
customPrompt Custom prompt that will be used instead of style_name; 0-getOption("text_composition_style_prompt_length_max") characters
final
hashCode int
The hash code for this object.
no setteroverride
message InputRichMessage?
message The original message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleName String
styleName Name of the style of the resulted text; handle updateTextCompositionStyles to get the list of supported styles; pass an empty string to keep the current style of the text or if a custom prompt is used
final
translateToLanguageCode String
translateToLanguageCode Pass a language code to which the text will be translated; pass an empty string if translation isn't needed. See translateText.to_language_code for the list of supported values
final

Methods

copyWith({InputRichMessage? message, String? translateToLanguageCode, String? styleName, String? customPrompt, bool? addEmojis}) ComposeRichMessageWithAi

Available on ComposeRichMessageWithAi, provided by the ComposeRichMessageWithAiExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String