customPrompt property
customPrompt Custom prompt that will be used instead of style_name; 0-getOption("text_composition_style_prompt_length_max") characters
Implementation
final String customPrompt;
customPrompt Custom prompt that will be used instead of style_name; 0-getOption("text_composition_style_prompt_length_max") characters
final String customPrompt;