styleName property

String styleName
final

styleName Name of the style of the resulted text; handle updateTextCompositionStyles to get the list of supported styles; pass an empty string to keep the current style of the text

Implementation

final String styleName;