ConfirmBusinessConnectedBot class final

Confirms an unconfirmed business connection of the current user from another device Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ConfirmBusinessConnectedBot({required int botUserId})

Properties

botUserId int
botUserId User identifier of the bot
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) ConfirmBusinessConnectedBot

Available on ConfirmBusinessConnectedBot, provided by the ConfirmBusinessConnectedBotExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String