ConfirmQrCodeAuthentication class final

Confirms QR code authentication on another device. Returns created session on success Returns Session

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ConfirmQrCodeAuthentication({required String link})

Properties

hashCode int
The hash code for this object.
no setteroverride
link A link from a QR code. The link must be scanned by the in-app camera
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link}) ConfirmQrCodeAuthentication

Available on ConfirmQrCodeAuthentication, provided by the ConfirmQrCodeAuthenticationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String