ConnectedAffiliateProgram class final

Describes an affiliate program that was connected to an affiliate

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ConnectedAffiliateProgram({required String url, required int botUserId, AffiliateProgramParameters? parameters, required int connectionDate, required bool isDisconnected, required int userCount, required int revenueStarCount})

Properties

botUserId int
botUserId User identifier of the bot created the program
final
connectionDate int
connectionDate Point in time (Unix timestamp) when the affiliate program was connected
final
hashCode int
The hash code for this object.
no setteroverride
isDisconnected bool
isDisconnected True, if the program was canceled by the bot, or disconnected by the chat owner and isn't available anymore
final
parameters AffiliateProgramParameters?
parameters The parameters of the affiliate program
final
revenueStarCount int
revenueStarCount The number of Telegram Stars that were earned by the affiliate program
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The link that can be used to refer users if the program is still active
final
userCount int
userCount The number of users that used the affiliate program
final

Methods

copyWith({String? url, int? botUserId, AffiliateProgramParameters? parameters, int? connectionDate, bool? isDisconnected, int? userCount, int? revenueStarCount}) ConnectedAffiliateProgram

Available on ConnectedAffiliateProgram, provided by the ConnectedAffiliateProgramExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ConnectedAffiliateProgram?

Constants

constructor → const String