isDisconnected property
isDisconnected True, if the program was canceled by the bot, or disconnected by the chat owner and isn't available anymore
Implementation
final bool isDisconnected;
isDisconnected True, if the program was canceled by the bot, or disconnected by the chat owner and isn't available anymore
final bool isDisconnected;