revenueStarCount property
revenueStarCount The number of Telegram Stars that were earned by the affiliate program
Implementation
final int revenueStarCount;
revenueStarCount The number of Telegram Stars that were earned by the affiliate program
final int revenueStarCount;