totalCount property
totalCount The total number of affiliate programs that were connected to the affiliate
Implementation
final int totalCount;
totalCount The total number of affiliate programs that were connected to the affiliate
final int totalCount;