ConnectionStateConnecting class final

Establishing a connection to the Telegram servers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ConnectionStateConnecting()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult connecting(ConnectionStateConnecting value), required TResult connectingToProxy(ConnectionStateConnectingToProxy value), required TResult ready(ConnectionStateReady value), required TResult updating(ConnectionStateUpdating value), required TResult waitingForNetwork(ConnectionStateWaitingForNetwork value)}) → TResult

Available on ConnectionState, provided by the ConnectionStateExtensions extension

maybeMap<TResult extends Object?>({TResult connecting(ConnectionStateConnecting value)?, TResult connectingToProxy(ConnectionStateConnectingToProxy value)?, TResult ready(ConnectionStateReady value)?, TResult updating(ConnectionStateUpdating value)?, TResult waitingForNetwork(ConnectionStateWaitingForNetwork value)?, required TResult orElse()}) → TResult

Available on ConnectionState, provided by the ConnectionStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String