Countries class final
Contains information about countries
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Countries({required List<
CountryInfo> countries})
Properties
-
countries
→ List<
CountryInfo> -
countries The list of countries
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< CountryInfo> ? countries}) → Countries -
Available on Countries, provided by the CountriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String