CountryInfo class final

Contains information about a country

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CountryInfo({required String countryCode, required String name, required String englishName, required String flagEmoji, required bool isHidden, required List<String> callingCodes})

Properties

callingCodes List<String>
callingCodes List of country calling codes
final
countryCode String
countryCode A two-letter ISO 3166-1 alpha-2 country code
final
englishName String
englishName English name of the country
final
flagEmoji String
flagEmoji An emoji for the flag of the country; may be empty if unknown
final
hashCode int
The hash code for this object.
no setteroverride
isHidden bool
isHidden True, if the country must be hidden from the list of all countries
final
name String
name Native name of the country
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? countryCode, String? name, String? englishName, String? flagEmoji, bool? isHidden, List<String>? callingCodes}) CountryInfo

Available on CountryInfo, provided by the CountryInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CountryInfo?

Constants

constructor → const String