CraftGift class final

Crafts a new gift from other gifts that will be permanently lost Returns CraftGiftResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CraftGift({required List<String> receivedGiftIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
receivedGiftIds List<String>
receivedGiftIds Identifier of the gifts to use for crafting. In the case of a successful craft, the resulting gift will have the number of the first gift. Consequently, the first gift must not have been withdrawn to the TON blockchain as an NFT and must have an empty gift_address
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? receivedGiftIds}) CraftGift

Available on CraftGift, provided by the CraftGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String