receivedGiftIds property

List<String> receivedGiftIds
final

receivedGiftIds Identifier of the gifts to use for crafting. In the case of a successful craft, the resulting gift will have the number of the first gift. Consequently, the first gift must not have been withdrawn to the TON blockchain as an NFT and must have an empty gift_address

Implementation

final List<String> receivedGiftIds;