CraftGiftResultInvalidGift class final

Crafting isn't possible because one of the gifts isn't suitable for crafting

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CraftGiftResultInvalidGift()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult fail(CraftGiftResultFail value), required TResult invalidGift(CraftGiftResultInvalidGift value), required TResult success(CraftGiftResultSuccess value), required TResult tooEarly(CraftGiftResultTooEarly value)}) → TResult

Available on CraftGiftResult, provided by the CraftGiftResultExtensions extension

maybeMap<TResult extends Object?>({TResult fail(CraftGiftResultFail value)?, TResult invalidGift(CraftGiftResultInvalidGift value)?, TResult success(CraftGiftResultSuccess value)?, TResult tooEarly(CraftGiftResultTooEarly value)?, required TResult orElse()}) → TResult

Available on CraftGiftResult, provided by the CraftGiftResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String