isNameImplicit property
isNameImplicit Pass true if the name of the topic wasn't entered explicitly; for chats with bots only
Implementation
final bool isNameImplicit;
isNameImplicit Pass true if the name of the topic wasn't entered explicitly; for chats with bots only
final bool isNameImplicit;