receivedGiftIds property
receivedGiftIds Identifier of the gifts to add to the collection; 0-getOption("gift_collection_size_max") identifiers
Implementation
final List<String> receivedGiftIds;
receivedGiftIds Identifier of the gifts to add to the collection; 0-getOption("gift_collection_size_max") identifiers
final List<String> receivedGiftIds;