CreateGroupCall class final

Creates a new group call that isn't bound to a chat Returns GroupCallInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateGroupCall({GroupCallJoinParameters? joinParameters})

Properties

hashCode int
The hash code for this object.
no setteroverride
joinParameters GroupCallJoinParameters?
joinParameters Parameters to join the call; pass null to only create call link without joining the call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({GroupCallJoinParameters? joinParameters}) CreateGroupCall

Available on CreateGroupCall, provided by the CreateGroupCallExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String