CreateInvoiceLink class final

Creates a link for the given invoice; for bots only Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateInvoiceLink({required String businessConnectionId, InputMessageContent? invoice})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which to send the request
final
hashCode int
The hash code for this object.
no setteroverride
invoice InputMessageContent?
invoice Information about the invoice of the type inputMessageInvoice
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, InputMessageContent? invoice}) CreateInvoiceLink

Available on CreateInvoiceLink, provided by the CreateInvoiceLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String