CreateNewBasicGroupChat class final
Creates a new basic group and sends a corresponding messageBasicGroupChatCreate. Returns information about the newly created chat Returns CreatedBasicGroupChat
- Inheritance
-
- Object
- TdFunction
- CreateNewBasicGroupChat
- Available extensions
- Annotations
-
- @immutable
Constructors
-
CreateNewBasicGroupChat({required List<
int> userIds, required String title, required int messageAutoDeleteTime})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageAutoDeleteTime → int
-
messageAutoDeleteTime Message auto-delete time value, in seconds; must
be from 0 up to 365 * 86400 and be divisible by 86400. If 0, then messages
aren't deleted automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Title of the new basic group; 1-128 characters
final
-
userIds
→ List<
int> -
userIds Identifiers of users to be added to the basic group; may be
empty to create a basic group without other members
final
Methods
-
copyWith(
{List< int> ? userIds, String? title, int? messageAutoDeleteTime}) → CreateNewBasicGroupChat -
Available on CreateNewBasicGroupChat, provided by the CreateNewBasicGroupChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String