CreateNewSecretChat class final

Creates a new secret chat. Returns the newly created chat Returns Chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateNewSecretChat({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the target user
final

Methods

copyWith({int? userId}) CreateNewSecretChat

Available on CreateNewSecretChat, provided by the CreateNewSecretChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String