CreateNewStickerSet class final

Creates a new sticker set. Returns the newly created sticker set Returns StickerSet

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateNewStickerSet({required int userId, required String title, required String name, StickerType? stickerType, required bool needsRepainting, required List<NewSticker> stickers, required String source})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Sticker set name. Can contain only English letters, digits and underscores. Must end with *"by If empty, then the name returned by getSuggestedStickerSetName will be used automatically
final
needsRepainting bool
needsRepainting Pass true if stickers in the sticker set must be repainted; for custom emoji sticker sets only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
source Source of the sticker set; may be empty if unknown
final
stickers List<NewSticker>
stickers List of stickers to be added to the set; 1-200 stickers for custom emoji sticker sets, and 1-120 stickers otherwise. For TGS stickers, uploadStickerFile must be used before the sticker is shown
final
stickerType StickerType?
stickerType Type of the stickers in the set
final
title String
title Sticker set title; 1-64 characters
final
userId int
userId Sticker set owner; ignored for regular users
final

Methods

copyWith({int? userId, String? title, String? name, StickerType? stickerType, bool? needsRepainting, List<NewSticker>? stickers, String? source}) CreateNewStickerSet

Available on CreateNewStickerSet, provided by the CreateNewStickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String