stickers property

List<NewSticker> stickers
final

stickers List of stickers to be added to the set; 1-200 stickers for custom emoji sticker sets, and 1-120 stickers otherwise. For TGS stickers, uploadStickerFile must be used before the sticker is shown

Implementation

final List<NewSticker> stickers;