CreateRichMessageWithAi class final

Creates a new rich message using an AI model. May return an error with a message "AICOMPOSE_FLOOD_PREMIUM" if Telegram Premium is required to send further requests Returns RichMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateRichMessageWithAi({required String prompt, required String languageCode, required bool addEmojis})

Properties

addEmojis bool
addEmojis Pass true to add emoji to the text
final
hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode Pass a language code in which the text will be created
final
prompt String
prompt Prompt that will be used to create the message; 0-getOption("text_composition_style_prompt_length_max") characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? prompt, String? languageCode, bool? addEmojis}) CreateRichMessageWithAi

Available on CreateRichMessageWithAi, provided by the CreateRichMessageWithAiExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String