CreateTemporaryPassword class final
Creates a new temporary password for processing payments Returns TemporaryPasswordState
- Inheritance
-
- Object
- TdFunction
- CreateTemporaryPassword
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreateTemporaryPassword({required String password, required int validFor})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- password → String
-
password The 2-step verification password of the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validFor → int
-
validFor Time during which the temporary password will be valid, in
seconds; must be between 60 and 86400
final
Methods
-
copyWith(
{String? password, int? validFor}) → CreateTemporaryPassword -
Available on CreateTemporaryPassword, provided by the CreateTemporaryPasswordExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String