CreateTextCompositionStyle class final

Creates a custom text composition style. May return an error with a message "TONES_SAVED_TOO_MANY" if the maximum number of added custom styles has been reached Returns TextCompositionStyle

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateTextCompositionStyle({required String title, required int customEmojiId, required String prompt, required bool showCreator})

Properties

customEmojiId int
customEmojiId Identifier of the custom emoji corresponding to the style
final
hashCode int
The hash code for this object.
no setteroverride
prompt String
prompt Prompt that will be used for text composition; 1-getOption("text_composition_style_prompt_length_max") characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCreator bool
showCreator Pass true if the current user must be shown as the creator of the style
final
title String
title Title of the style; 1-getOption("text_composition_style_title_length_max") characters
final

Methods

copyWith({String? title, int? customEmojiId, String? prompt, bool? showCreator}) CreateTextCompositionStyle

Available on CreateTextCompositionStyle, provided by the CreateTextCompositionStyleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String