showCreator property
showCreator Pass true if the current user must be shown as the creator of the style
Implementation
final bool showCreator;
showCreator Pass true if the current user must be shown as the creator of the style
final bool showCreator;