CreatedBasicGroupChat class final
Contains information about a newly created basic group chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreatedBasicGroupChat({required int chatId, FailedToAddMembers? failedToAddMembers})
Properties
- chatId → int
-
chatId Chat identifier
final
- failedToAddMembers → FailedToAddMembers?
-
failedToAddMembers Information about failed to add members
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, FailedToAddMembers? failedToAddMembers}) → CreatedBasicGroupChat -
Available on CreatedBasicGroupChat, provided by the CreatedBasicGroupChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CreatedBasicGroupChat?
Constants
- constructor → const String