CurrentWeather class final

Describes the current weather

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CurrentWeather({required double temperature, required String emoji})

Properties

emoji String
emoji Emoji representing the weather
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double
temperature Temperature, in degree Celsius
final

Methods

copyWith({double? temperature, String? emoji}) CurrentWeather

Available on CurrentWeather, provided by the CurrentWeatherExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) CurrentWeather?

Constants

constructor → const String