Data class final

Contains some binary data

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Data({required String data})

Properties

data String
data Data
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? data}) Data

Available on Data, provided by the DataExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Data?

Constants

constructor → const String