DatabaseStatistics class final

Contains database statistics

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DatabaseStatistics({required String statistics})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statistics String
statistics Database statistics in an unspecified human-readable format
final

Methods

copyWith({String? statistics}) DatabaseStatistics

Available on DatabaseStatistics, provided by the DatabaseStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DatabaseStatistics?

Constants

constructor → const String