Date class final

Represents a date according to the Gregorian calendar

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Date({required int day, required int month, required int year})

Properties

day int
day Day of the month; 1-31
final
hashCode int
The hash code for this object.
no setteroverride
month int
month Month; 1-12
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
year Year; 1-9999
final

Methods

copyWith({int? day, int? month, int? year}) Date

Available on Date, provided by the DateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Date?

Constants

constructor → const String