DateTimeFormattingType class sealed
Describes date and time formatting
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult absolute(DateTimeFormattingTypeAbsolute value), required TResult relative(DateTimeFormattingTypeRelative value)}) → TResult -
Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult absolute(DateTimeFormattingTypeAbsolute value)?, TResult relative(DateTimeFormattingTypeRelative value)?, required TResult orElse()}) → TResult -
Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DateTimeFormattingType? - Inherited by: DateTimeFormattingTypeAbsolute DateTimeFormattingTypeRelative
Constants
- constructor → const String