DateTimeFormattingTypeAbsolute class final

The date and time must be shown as absolute timestamps

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DateTimeFormattingTypeAbsolute({DateTimePartPrecision? timePrecision, DateTimePartPrecision? datePrecision, required bool showDayOfWeek})

Properties

datePrecision DateTimePartPrecision?
datePrecision The precision with which the date is shown
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDayOfWeek bool
showDayOfWeek True, if the day of week must be shown
final
timePrecision DateTimePartPrecision?
timePrecision The precision with which hours, minutes and seconds are shown
final

Methods

copyWith({DateTimePartPrecision? timePrecision, DateTimePartPrecision? datePrecision, bool? showDayOfWeek}) DateTimeFormattingTypeAbsolute

Available on DateTimeFormattingTypeAbsolute, provided by the DateTimeFormattingTypeAbsoluteExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult absolute(DateTimeFormattingTypeAbsolute value), required TResult relative(DateTimeFormattingTypeRelative value)}) → TResult

Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension

maybeMap<TResult extends Object?>({TResult absolute(DateTimeFormattingTypeAbsolute value)?, TResult relative(DateTimeFormattingTypeRelative value)?, required TResult orElse()}) → TResult

Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String