DateTimeFormattingTypeRelative class final

The time must be shown relative to the current time (in X seconds, minutes, hours, days, months, years ago)

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DateTimeFormattingTypeRelative()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult absolute(DateTimeFormattingTypeAbsolute value), required TResult relative(DateTimeFormattingTypeRelative value)}) → TResult

Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension

maybeMap<TResult extends Object?>({TResult absolute(DateTimeFormattingTypeAbsolute value)?, TResult relative(DateTimeFormattingTypeRelative value)?, required TResult orElse()}) → TResult

Available on DateTimeFormattingType, provided by the DateTimeFormattingTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String