DateTimePartPrecisionNone class final

Don't show the date or time

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DateTimePartPrecisionNone()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult long(DateTimePartPrecisionLong value), required TResult none(DateTimePartPrecisionNone value), required TResult short(DateTimePartPrecisionShort value)}) → TResult

Available on DateTimePartPrecision, provided by the DateTimePartPrecisionExtensions extension

maybeMap<TResult extends Object?>({TResult long(DateTimePartPrecisionLong value)?, TResult none(DateTimePartPrecisionNone value)?, TResult short(DateTimePartPrecisionShort value)?, required TResult orElse()}) → TResult

Available on DateTimePartPrecision, provided by the DateTimePartPrecisionExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String