DatedFile class final

File with the date it was uploaded

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DatedFile({File? file, required int date})

Properties

date int
date Point in time (Unix timestamp) when the file was uploaded
final
file File?
file The file
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({File? file, int? date}) DatedFile

Available on DatedFile, provided by the DatedFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DatedFile?

Constants

constructor → const String