DeclineGroupCallInvitation class final

Declines an invitation to an active group call via messageGroupCall. Can be called both by the sender and the receiver of the invitation Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeclineGroupCallInvitation({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message of the type messageGroupCall
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) DeclineGroupCallInvitation

Available on DeclineGroupCallInvitation, provided by the DeclineGroupCallInvitationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String