DeclineOauthRequest class final

Declines an OAuth authorization request Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeclineOauthRequest({required String url})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url URL of the OAuth deep link
final

Methods

copyWith({String? url}) DeclineOauthRequest

Available on DeclineOauthRequest, provided by the DeclineOauthRequestExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String