messageId property

int messageId
final

messageId Identifier of the message with the suggested post. Use messageProperties.can_be_declined to check whether the suggested post can be declined

Implementation

final int messageId;