DecryptGroupCallData class final

Decrypts group call data received by tgcalls Returns Data

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DecryptGroupCallData({required int groupCallId, MessageSender? participantId, GroupCallDataChannel? dataChannel, required String data})

Properties

data String
data Data to decrypt
final
dataChannel GroupCallDataChannel?
dataChannel Data channel for which data was encrypted; pass null if unknown
final
groupCallId int
groupCallId Group call identifier. The call must not be a video chat
final
hashCode int
The hash code for this object.
no setteroverride
participantId MessageSender?
participantId Identifier of the group call participant, which sent the data
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? participantId, GroupCallDataChannel? dataChannel, String? data}) DecryptGroupCallData

Available on DecryptGroupCallData, provided by the DecryptGroupCallDataExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String