participantId property
participantId Identifier of the group call participant, which sent the data
Implementation
final MessageSender? participantId;
participantId Identifier of the group call participant, which sent the data
final MessageSender? participantId;