DeepLinkInfo class final

Contains information about a tg: deep link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeepLinkInfo({FormattedText? text, required bool needUpdateApplication})

Properties

hashCode int
The hash code for this object.
no setteroverride
needUpdateApplication bool
needUpdateApplication True, if the user must be asked to update the application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text to be shown to the user
final

Methods

copyWith({FormattedText? text, bool? needUpdateApplication}) DeepLinkInfo

Available on DeepLinkInfo, provided by the DeepLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DeepLinkInfo?

Constants

constructor → const String