DeleteAccount class final

Deletes the account of the current user, deleting all information associated with the user from the server. The phone number of the account can be used to create a new account. Can be called before authorization when the current authorization state is authorizationStateWaitPassword Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteAccount({String? reason, required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password of the current user. If the current user isn't authorized, then an empty string can be passed and account deletion can be canceled within one week
final
reason String?
reason The reason why the account was deleted; optional
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? reason, String? password}) DeleteAccount

Available on DeleteAccount, provided by the DeleteAccountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String