DeleteAllRecentMessageReactionsFromSender class final

Deletes all recent reactions added by the specified sender in a chat. Supported only for basic groups and supergroups; requires can_delete_messages administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteAllRecentMessageReactionsFromSender({required int chatId, MessageSender? senderId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of reactions to delete
final

Methods

copyWith({int? chatId, MessageSender? senderId}) DeleteAllRecentMessageReactionsFromSender

Available on DeleteAllRecentMessageReactionsFromSender, provided by the DeleteAllRecentMessageReactionsFromSenderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String