DeleteBusinessChatLink class final

Deletes a business chat link of the current account Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteBusinessChatLink({required String link})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The link to delete
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link}) DeleteBusinessChatLink

Available on DeleteBusinessChatLink, provided by the DeleteBusinessChatLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String