DeleteBusinessConnectedBot class final

Deletes the business bot that is connected to the current user account Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteBusinessConnectedBot({required int botUserId})

Properties

botUserId int
botUserId Unique user identifier for the bot
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) DeleteBusinessConnectedBot

Available on DeleteBusinessConnectedBot, provided by the DeleteBusinessConnectedBotExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String