DeleteBusinessStory class final

Deletes a story posted by the bot on behalf of a business account; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteBusinessStory({required String businessConnectionId, required int storyId})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story to delete
final

Methods

copyWith({String? businessConnectionId, int? storyId}) DeleteBusinessStory

Available on DeleteBusinessStory, provided by the DeleteBusinessStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String