DeleteChatFolder class final

Deletes existing chat folder Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteChatFolder({required int chatFolderId, required List<int> leaveChatIds})

Properties

chatFolderId int
chatFolderId Chat folder identifier
final
hashCode int
The hash code for this object.
no setteroverride
leaveChatIds List<int>
leaveChatIds Identifiers of the chats to leave. The chats must be pinned or always included in the folder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, List<int>? leaveChatIds}) DeleteChatFolder

Available on DeleteChatFolder, provided by the DeleteChatFolderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String