DeleteChatMessagesBySender class final

Deletes all messages sent by the specified message sender in a chat. Supported only for supergroups; requires can_delete_messages administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteChatMessagesBySender({required int chatId, MessageSender? senderId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of messages to delete
final

Methods

copyWith({int? chatId, MessageSender? senderId}) DeleteChatMessagesBySender

Available on DeleteChatMessagesBySender, provided by the DeleteChatMessagesBySenderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String