DeleteDefaultBackground class final

Deletes default background for chats Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteDefaultBackground({required bool forDarkTheme})

Properties

forDarkTheme bool
forDarkTheme Pass true if the background is deleted for a dark theme
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? forDarkTheme}) DeleteDefaultBackground

Available on DeleteDefaultBackground, provided by the DeleteDefaultBackgroundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String