DeleteFile class final

Deletes a file from the TDLib file cache Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteFile({required int fileId})

Properties

fileId int
fileId Identifier of the file to delete
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId}) DeleteFile

Available on DeleteFile, provided by the DeleteFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String