DeleteForumTopic class final
Deletes all messages from a topic in a forum supergroup chat or a chat with a bot with topics; requires can_delete_messages administrator right in the supergroup unless the user is creator of the topic, the topic has no messages from other users and has at most 11 messages Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteForumTopic
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteForumTopic({required int chatId, required int forumTopicId})
Properties
- chatId → int
-
chatId Identifier of the chat
final
- forumTopicId → int
-
forumTopicId Forum topic identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId}) → DeleteForumTopic -
Available on DeleteForumTopic, provided by the DeleteForumTopicExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String