DeleteGroupCallMessagesBySender class final

Deletes all messages sent by the specified message sender in a group call; for live story calls only. Requires groupCall.can_delete_messages right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteGroupCallMessagesBySender({required int groupCallId, MessageSender? senderId, required bool reportSpam})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
reportSpam bool
reportSpam Pass true to report the messages as spam
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of messages to delete
final

Methods

copyWith({int? groupCallId, MessageSender? senderId, bool? reportSpam}) DeleteGroupCallMessagesBySender

Available on DeleteGroupCallMessagesBySender, provided by the DeleteGroupCallMessagesBySenderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String