DeleteMessages class final

Deletes messages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteMessages({required int chatId, required List<int> messageIds, required bool revoke})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Identifiers of the messages to be deleted. Use messageProperties.can_be_deleted_only_for_self and messageProperties.can_be_deleted_for_all_users to get suitable messages
final
revoke bool
revoke Pass true to delete messages for all chat members. Always true for supergroups, channels and secret chats
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? messageIds, bool? revoke}) DeleteMessages

Available on DeleteMessages, provided by the DeleteMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String