DeletePassportElement class final

Deletes a Telegram Passport element Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PassportElementType?
type Element type
final

Methods

copyWith({PassportElementType? type}) DeletePassportElement

Available on DeletePassportElement, provided by the DeletePassportElementExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String