DeleteQuickReplyShortcutMessages class final

Deletes specified quick reply messages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteQuickReplyShortcutMessages({required int shortcutId, required List<int> messageIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Unique identifiers of the messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutId int
shortcutId Unique identifier of the quick reply shortcut to which the messages belong
final

Methods

copyWith({int? shortcutId, List<int>? messageIds}) DeleteQuickReplyShortcutMessages

Available on DeleteQuickReplyShortcutMessages, provided by the DeleteQuickReplyShortcutMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String