shortcutId property
shortcutId Unique identifier of the quick reply shortcut to which the messages belong
Implementation
final int shortcutId;
shortcutId Unique identifier of the quick reply shortcut to which the messages belong
final int shortcutId;