DeleteRevokedChatInviteLink class final

Deletes revoked chat invite links. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteRevokedChatInviteLink({required int chatId, required String inviteLink})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link to revoke
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink}) DeleteRevokedChatInviteLink

Available on DeleteRevokedChatInviteLink, provided by the DeleteRevokedChatInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String