DeleteSavedMessagesTopicHistory class final

Deletes all messages in a Saved Messages topic Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteSavedMessagesTopicHistory({required int savedMessagesTopicId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Identifier of Saved Messages topic which messages will be deleted
final

Methods

copyWith({int? savedMessagesTopicId}) DeleteSavedMessagesTopicHistory

Available on DeleteSavedMessagesTopicHistory, provided by the DeleteSavedMessagesTopicHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String