DeleteSavedMessagesTopicMessagesByDate class final

Deletes all messages between the specified dates in a Saved Messages topic. Messages sent in the last 30 seconds will not be deleted Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteSavedMessagesTopicMessagesByDate({required int savedMessagesTopicId, required int minDate, required int maxDate})

Properties

hashCode int
The hash code for this object.
no setteroverride
maxDate int
maxDate The maximum date of the messages to delete
final
minDate int
minDate The minimum date of the messages to delete
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Identifier of Saved Messages topic which messages will be deleted
final

Methods

copyWith({int? savedMessagesTopicId, int? minDate, int? maxDate}) DeleteSavedMessagesTopicMessagesByDate

Available on DeleteSavedMessagesTopicMessagesByDate, provided by the DeleteSavedMessagesTopicMessagesByDateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String