DeleteStickerSet class final

Completely deletes a sticker set Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteStickerSet({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Sticker set name. The sticker set must be owned by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) DeleteStickerSet

Available on DeleteStickerSet, provided by the DeleteStickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String