DeleteStory class final

Deletes a previously posted story. Can be called only if story.can_be_deleted == true Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteStory({required int storyPosterChatId, required int storyId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story to delete
final
storyPosterChatId int
storyPosterChatId Identifier of the chat that posted the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId}) DeleteStory

Available on DeleteStory, provided by the DeleteStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String