DeviceToken class sealed
Represents a data needed to subscribe for push notifications through registerDevice method.
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult applePush(DeviceTokenApplePush value), required TResult applePushVoIP(DeviceTokenApplePushVoIP value), required TResult blackBerryPush(DeviceTokenBlackBerryPush value), required TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value), required TResult huaweiPush(DeviceTokenHuaweiPush value), required TResult microsoftPush(DeviceTokenMicrosoftPush value), required TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value), required TResult simplePush(DeviceTokenSimplePush value), required TResult tizenPush(DeviceTokenTizenPush value), required TResult ubuntuPush(DeviceTokenUbuntuPush value), required TResult webPush(DeviceTokenWebPush value), required TResult windowsPush(DeviceTokenWindowsPush value)}) → TResult -
Available on DeviceToken, provided by the DeviceTokenExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult applePush(DeviceTokenApplePush value)?, TResult applePushVoIP(DeviceTokenApplePushVoIP value)?, TResult blackBerryPush(DeviceTokenBlackBerryPush value)?, TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value)?, TResult huaweiPush(DeviceTokenHuaweiPush value)?, TResult microsoftPush(DeviceTokenMicrosoftPush value)?, TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value)?, TResult simplePush(DeviceTokenSimplePush value)?, TResult tizenPush(DeviceTokenTizenPush value)?, TResult ubuntuPush(DeviceTokenUbuntuPush value)?, TResult webPush(DeviceTokenWebPush value)?, TResult windowsPush(DeviceTokenWindowsPush value)?, required TResult orElse()}) → TResult -
Available on DeviceToken, provided by the DeviceTokenExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DeviceToken? - Inherited by: DeviceTokenApplePush DeviceTokenApplePushVoIP DeviceTokenBlackBerryPush DeviceTokenFirebaseCloudMessaging DeviceTokenHuaweiPush DeviceTokenMicrosoftPush DeviceTokenMicrosoftPushVoIP DeviceTokenSimplePush DeviceTokenTizenPush DeviceTokenUbuntuPush DeviceTokenWebPush DeviceTokenWindowsPush
Constants
- constructor → const String