DeviceTokenApplePushVoIP class final

A token for Apple Push Notification service VoIP notifications

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeviceTokenApplePushVoIP({required String deviceToken, required bool isAppSandbox, required bool encrypt})

Properties

deviceToken String
deviceToken Device token; may be empty to deregister a device
final
encrypt bool
encrypt True, if push notifications must be additionally encrypted
final
hashCode int
The hash code for this object.
no setteroverride
isAppSandbox bool
isAppSandbox True, if App Sandbox is enabled
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? deviceToken, bool? isAppSandbox, bool? encrypt}) DeviceTokenApplePushVoIP

Available on DeviceTokenApplePushVoIP, provided by the DeviceTokenApplePushVoIPExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult applePush(DeviceTokenApplePush value), required TResult applePushVoIP(DeviceTokenApplePushVoIP value), required TResult blackBerryPush(DeviceTokenBlackBerryPush value), required TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value), required TResult huaweiPush(DeviceTokenHuaweiPush value), required TResult microsoftPush(DeviceTokenMicrosoftPush value), required TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value), required TResult simplePush(DeviceTokenSimplePush value), required TResult tizenPush(DeviceTokenTizenPush value), required TResult ubuntuPush(DeviceTokenUbuntuPush value), required TResult webPush(DeviceTokenWebPush value), required TResult windowsPush(DeviceTokenWindowsPush value)}) → TResult

Available on DeviceToken, provided by the DeviceTokenExtensions extension

maybeMap<TResult extends Object?>({TResult applePush(DeviceTokenApplePush value)?, TResult applePushVoIP(DeviceTokenApplePushVoIP value)?, TResult blackBerryPush(DeviceTokenBlackBerryPush value)?, TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value)?, TResult huaweiPush(DeviceTokenHuaweiPush value)?, TResult microsoftPush(DeviceTokenMicrosoftPush value)?, TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value)?, TResult simplePush(DeviceTokenSimplePush value)?, TResult tizenPush(DeviceTokenTizenPush value)?, TResult ubuntuPush(DeviceTokenUbuntuPush value)?, TResult webPush(DeviceTokenWebPush value)?, TResult windowsPush(DeviceTokenWindowsPush value)?, required TResult orElse()}) → TResult

Available on DeviceToken, provided by the DeviceTokenExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String