DeviceTokenWebPush class final

A token for web Push API

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeviceTokenWebPush({required String endpoint, required String p256dhBase64url, required String authBase64url})

Properties

authBase64url String
authBase64url Base64url-encoded authentication secret
final
endpoint String
endpoint Absolute URL exposed by the push service where the application server can send push messages; may be empty to deregister a device
final
hashCode int
The hash code for this object.
no setteroverride
p256dhBase64url String
p256dhBase64url Base64url-encoded P-256 elliptic curve Diffie-Hellman public key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? endpoint, String? p256dhBase64url, String? authBase64url}) DeviceTokenWebPush

Available on DeviceTokenWebPush, provided by the DeviceTokenWebPushExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult applePush(DeviceTokenApplePush value), required TResult applePushVoIP(DeviceTokenApplePushVoIP value), required TResult blackBerryPush(DeviceTokenBlackBerryPush value), required TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value), required TResult huaweiPush(DeviceTokenHuaweiPush value), required TResult microsoftPush(DeviceTokenMicrosoftPush value), required TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value), required TResult simplePush(DeviceTokenSimplePush value), required TResult tizenPush(DeviceTokenTizenPush value), required TResult ubuntuPush(DeviceTokenUbuntuPush value), required TResult webPush(DeviceTokenWebPush value), required TResult windowsPush(DeviceTokenWindowsPush value)}) → TResult

Available on DeviceToken, provided by the DeviceTokenExtensions extension

maybeMap<TResult extends Object?>({TResult applePush(DeviceTokenApplePush value)?, TResult applePushVoIP(DeviceTokenApplePushVoIP value)?, TResult blackBerryPush(DeviceTokenBlackBerryPush value)?, TResult firebaseCloudMessaging(DeviceTokenFirebaseCloudMessaging value)?, TResult huaweiPush(DeviceTokenHuaweiPush value)?, TResult microsoftPush(DeviceTokenMicrosoftPush value)?, TResult microsoftPushVoIP(DeviceTokenMicrosoftPushVoIP value)?, TResult simplePush(DeviceTokenSimplePush value)?, TResult tizenPush(DeviceTokenTizenPush value)?, TResult ubuntuPush(DeviceTokenUbuntuPush value)?, TResult webPush(DeviceTokenWebPush value)?, TResult windowsPush(DeviceTokenWindowsPush value)?, required TResult orElse()}) → TResult

Available on DeviceToken, provided by the DeviceTokenExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String