DiceStickers class sealed

Contains animated stickers which must be used for dice animation rendering

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult regular(DiceStickersRegular value), required TResult slotMachine(DiceStickersSlotMachine value)}) → TResult

Available on DiceStickers, provided by the DiceStickersExtensions extension

maybeMap<TResult extends Object?>({TResult regular(DiceStickersRegular value)?, TResult slotMachine(DiceStickersSlotMachine value)?, required TResult orElse()}) → TResult

Available on DiceStickers, provided by the DiceStickersExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DiceStickers?
Inherited by: DiceStickersRegular DiceStickersSlotMachine

Constants

constructor → const String