DiceStickersSlotMachine class final

Animated stickers to be combined into a slot machine

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DiceStickersSlotMachine({Sticker? background, Sticker? lever, Sticker? leftReel, Sticker? centerReel, Sticker? rightReel})

Properties

background Sticker?
background The animated sticker with the slot machine background. The background animation must start playing after all reel animations finish
final
centerReel Sticker?
centerReel The animated sticker with the center reel
final
hashCode int
The hash code for this object.
no setteroverride
leftReel Sticker?
leftReel The animated sticker with the left reel
final
lever Sticker?
lever The animated sticker with the lever animation. The lever animation must play once in the initial dice state
final
rightReel Sticker?
rightReel The animated sticker with the right reel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Sticker? background, Sticker? lever, Sticker? leftReel, Sticker? centerReel, Sticker? rightReel}) DiceStickersSlotMachine

Available on DiceStickersSlotMachine, provided by the DiceStickersSlotMachineExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult regular(DiceStickersRegular value), required TResult slotMachine(DiceStickersSlotMachine value)}) → TResult

Available on DiceStickers, provided by the DiceStickersExtensions extension

maybeMap<TResult extends Object?>({TResult regular(DiceStickersRegular value)?, TResult slotMachine(DiceStickersSlotMachine value)?, required TResult orElse()}) → TResult

Available on DiceStickers, provided by the DiceStickersExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DiceStickersSlotMachine?
Inherited by: DiceStickersRegular DiceStickersSlotMachine
override

Constants

constructor → const String