DiffEntity class final

Represents a change of a text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DiffEntity({required int offset, required int length, DiffEntityType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
length int
length Length of the entity, in UTF-16 code units
final
offset int
offset Offset of the entity, in UTF-16 code units
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DiffEntityType?
type Type of the entity
final

Methods

copyWith({int? offset, int? length, DiffEntityType? type}) DiffEntity

Available on DiffEntity, provided by the DiffEntityExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DiffEntity?

Constants

constructor → const String