DiffEntityType class sealed
Represents a change of a text
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult delete(DiffEntityTypeDelete value), required TResult insert(DiffEntityTypeInsert value), required TResult replace(DiffEntityTypeReplace value)}) → TResult -
Available on DiffEntityType, provided by the DiffEntityTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult delete(DiffEntityTypeDelete value)?, TResult insert(DiffEntityTypeInsert value)?, TResult replace(DiffEntityTypeReplace value)?, required TResult orElse()}) → TResult -
Available on DiffEntityType, provided by the DiffEntityTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DiffEntityType? - Inherited by: DiffEntityTypeDelete DiffEntityTypeInsert DiffEntityTypeReplace
Constants
- constructor → const String