DiffEntityTypeInsert class final

Addition of some text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DiffEntityTypeInsert()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult delete(DiffEntityTypeDelete value), required TResult insert(DiffEntityTypeInsert value), required TResult replace(DiffEntityTypeReplace value)}) → TResult

Available on DiffEntityType, provided by the DiffEntityTypeExtensions extension

maybeMap<TResult extends Object?>({TResult delete(DiffEntityTypeDelete value)?, TResult insert(DiffEntityTypeInsert value)?, TResult replace(DiffEntityTypeReplace value)?, required TResult orElse()}) → TResult

Available on DiffEntityType, provided by the DiffEntityTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DiffEntityTypeInsert?
Inherited by: DiffEntityTypeDelete DiffEntityTypeInsert DiffEntityTypeReplace
override

Constants

constructor → const String