DiffText class final

A text with some changes highlighted

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DiffText({required String text, required List<DiffEntity> entities})

Properties

entities List<DiffEntity>
entities Entities describing changes in the text. Entities don't mutually intersect with each other
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text The text
final

Methods

copyWith({String? text, List<DiffEntity>? entities}) DiffText

Available on DiffText, provided by the DiffTextExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DiffText?

Constants

constructor → const String