canSendUnpaidMessages property
canSendUnpaidMessages True, if the other party can send unpaid messages even if the chat has paid messages enabled
Implementation
final bool canSendUnpaidMessages;
canSendUnpaidMessages True, if the other party can send unpaid messages even if the chat has paid messages enabled
final bool canSendUnpaidMessages;