senderId property
senderId Identifier of the user or chat that sends the messages to the topic
Implementation
final MessageSender? senderId;
senderId Identifier of the user or chat that sends the messages to the topic
final MessageSender? senderId;