DiscardCall class final

Discards a call Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DiscardCall({required int callId, required bool isDisconnected, required String inviteLink, required int duration, required bool isVideo, required int connectionId})

Properties

callId int
callId Call identifier
final
connectionId int
connectionId Identifier of the connection used during the call
final
duration int
duration The call duration, in seconds
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink If the call was upgraded to a group call, pass invite link to the group call
final
isDisconnected bool
isDisconnected Pass true if the user was disconnected
final
isVideo bool
isVideo Pass true if the call was a video call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, bool? isDisconnected, String? inviteLink, int? duration, bool? isVideo, int? connectionId}) DiscardCall

Available on DiscardCall, provided by the DiscardCallExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String