inviteLink property
inviteLink If the call was upgraded to a group call, pass invite link to the group call
Implementation
final String inviteLink;
inviteLink If the call was upgraded to a group call, pass invite link to the group call
final String inviteLink;