DisconnectAffiliateProgram class final

Disconnects an affiliate program from the given affiliate and immediately deactivates its referral link. Returns updated information about the disconnected affiliate program Returns ConnectedAffiliateProgram

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DisconnectAffiliateProgram({AffiliateType? affiliate, required String url})

Properties

affiliate AffiliateType?
affiliate The affiliate to which the affiliate program is connected
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The referral link of the affiliate program
final

Methods

copyWith({AffiliateType? affiliate, String? url}) DisconnectAffiliateProgram

Available on DisconnectAffiliateProgram, provided by the DisconnectAffiliateProgramExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String