DownloadFile class final
Downloads a file from the cloud. Download progress and completion of the download will be notified through updateFile updates Returns File
- Inheritance
-
- Object
- TdFunction
- DownloadFile
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- fileId → int
-
fileId Identifier of the file to download
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit Number of bytes which need to be downloaded starting from the
"offset" position before the download will automatically be canceled; use
0 to download without a limit
final
- offset → int
-
offset The starting position from which the file needs to be downloaded
final
- priority → int
-
priority Priority of the download (1-32). The higher the priority, the
earlier the file will be downloaded. If the priorities of two files are
equal, then the last one for which downloadFile/addFileToDownloads was
called will be downloaded first
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- synchronous → bool
-
synchronous Pass true to return response only after the file download
has succeeded, has failed, has been canceled, or a new downloadFile
request with different offset/limit parameters was sent; pass false to
return file state immediately, just after the download has been started
final
Methods
-
copyWith(
{int? fileId, int? priority, int? offset, int? limit, bool? synchronous}) → DownloadFile -
Available on DownloadFile, provided by the DownloadFileExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String