DownloadedFileCounts class final

Contains number of being downloaded and recently downloaded files found

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DownloadedFileCounts({required int activeCount, required int pausedCount, required int completedCount})

Properties

activeCount int
activeCount Number of active file downloads found, including paused
final
completedCount int
completedCount Number of completed file downloads found
final
hashCode int
The hash code for this object.
no setteroverride
pausedCount int
pausedCount Number of paused file downloads found
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? activeCount, int? pausedCount, int? completedCount}) DownloadedFileCounts

Available on DownloadedFileCounts, provided by the DownloadedFileCountsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) DownloadedFileCounts?

Constants

constructor → const String