DraftMessageContent class sealed

Content of the message draft

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult richMessage(DraftMessageContentRichMessage value), required TResult text(DraftMessageContentText value), required TResult videoNote(DraftMessageContentVideoNote value), required TResult voiceNote(DraftMessageContentVoiceNote value)}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

maybeMap<TResult extends Object?>({TResult richMessage(DraftMessageContentRichMessage value)?, TResult text(DraftMessageContentText value)?, TResult videoNote(DraftMessageContentVideoNote value)?, TResult voiceNote(DraftMessageContentVoiceNote value)?, required TResult orElse()}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String