DraftMessageContentRichMessage class final

A rich message draft; not supported in setChatDraftMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DraftMessageContentRichMessage({RichMessage? message})

Properties

hashCode int
The hash code for this object.
no setteroverride
message RichMessage?
message The rich message; the message must not have not yet uploaded media
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({RichMessage? message}) DraftMessageContentRichMessage

Available on DraftMessageContentRichMessage, provided by the DraftMessageContentRichMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult richMessage(DraftMessageContentRichMessage value), required TResult text(DraftMessageContentText value), required TResult videoNote(DraftMessageContentVideoNote value), required TResult voiceNote(DraftMessageContentVoiceNote value)}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

maybeMap<TResult extends Object?>({TResult richMessage(DraftMessageContentRichMessage value)?, TResult text(DraftMessageContentText value)?, TResult videoNote(DraftMessageContentVideoNote value)?, TResult voiceNote(DraftMessageContentVoiceNote value)?, required TResult orElse()}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String