text property
text Formatted text to be saved as a draft; 0-getOption("message_text_length_max") characters
Implementation
final FormattedText? text;
text Formatted text to be saved as a draft; 0-getOption("message_text_length_max") characters
final FormattedText? text;