DraftMessageContentVoiceNote class final

A voice note message draft

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DraftMessageContentVoiceNote({required String filePath, required int duration, required String waveform, MessageSelfDestructType? selfDestructType})

Properties

duration int
duration Duration of the voice note, in seconds
final
filePath String
filePath Path to the file with the voice note
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfDestructType MessageSelfDestructType?
selfDestructType Voice note self-destruct type; may be null if none; pass null if none; private chats only
final
waveform String
waveform Waveform representation of the voice note in 5-bit format
final

Methods

copyWith({String? filePath, int? duration, String? waveform, MessageSelfDestructType? selfDestructType}) DraftMessageContentVoiceNote

Available on DraftMessageContentVoiceNote, provided by the DraftMessageContentVoiceNoteExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult richMessage(DraftMessageContentRichMessage value), required TResult text(DraftMessageContentText value), required TResult videoNote(DraftMessageContentVideoNote value), required TResult voiceNote(DraftMessageContentVoiceNote value)}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

maybeMap<TResult extends Object?>({TResult richMessage(DraftMessageContentRichMessage value)?, TResult text(DraftMessageContentText value)?, TResult videoNote(DraftMessageContentVideoNote value)?, TResult voiceNote(DraftMessageContentVoiceNote value)?, required TResult orElse()}) → TResult

Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String