DropGiftOriginalDetails class final
Drops original details for an upgraded gift Returns Ok
- Inheritance
-
- Object
- TdFunction
- DropGiftOriginalDetails
- Available extensions
- Annotations
-
- @immutable
Constructors
- DropGiftOriginalDetails({required String receivedGiftId, required int starCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- receivedGiftId → String
-
receivedGiftId Identifier of the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount The Telegram Star amount required to pay for the operation
final
Methods
-
copyWith(
{String? receivedGiftId, int? starCount}) → DropGiftOriginalDetails -
Available on DropGiftOriginalDetails, provided by the DropGiftOriginalDetailsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String