EditBotMediaPreview class final

Replaces media preview in the list of media previews of a bot. Returns the new preview after edit is completed server-side Returns BotMediaPreview

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBotMediaPreview({required int botUserId, required String languageCode, required int fileId, InputStoryContent? content})

Properties

botUserId int
botUserId Identifier of the target bot. The bot must be owned and must have the main Web App
final
content InputStoryContent?
content Content of the new preview
final
fileId int
fileId File identifier of the media to replace
final
hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode Language code of the media preview to edit
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? languageCode, int? fileId, InputStoryContent? content}) EditBotMediaPreview

Available on EditBotMediaPreview, provided by the EditBotMediaPreviewExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String