EditBusinessChatLink class final

Edits a business chat link of the current account. Requires Telegram Business subscription. Returns the edited link Returns BusinessChatLink

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBusinessChatLink({required String link, InputBusinessChatLink? linkInfo})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The link to edit
final
linkInfo InputBusinessChatLink?
linkInfo New description of the link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link, InputBusinessChatLink? linkInfo}) EditBusinessChatLink

Available on EditBusinessChatLink, provided by the EditBusinessChatLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String