EditBusinessMessageCaption class final

Edits the caption of a message sent on behalf of a business account; for bots only Returns BusinessMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBusinessMessageCaption({required String businessConnectionId, required int chatId, required int messageId, ReplyMarkup? replyMarkup, FormattedText? caption, required bool showCaptionAboveMedia})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which the message was sent
final
caption FormattedText?
caption New message content caption; pass null to remove caption; 0-getOption("message_caption_length_max") characters
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCaptionAboveMedia bool
showCaptionAboveMedia Pass true to show the caption above the media; otherwise, the caption will be shown below the media. May be true only for animation, photo, and video messages
final

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, ReplyMarkup? replyMarkup, FormattedText? caption, bool? showCaptionAboveMedia}) EditBusinessMessageCaption

Available on EditBusinessMessageCaption, provided by the EditBusinessMessageCaptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String