EditBusinessMessageLiveLocation class final

Edits the content of a live location in a message sent on behalf of a business account; for bots only Returns BusinessMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBusinessMessageLiveLocation({required String businessConnectionId, required int chatId, required int messageId, ReplyMarkup? replyMarkup, LiveLocation? location})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which the message was sent
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
location LiveLocation?
location New live location of the message; pass null to stop sharing the live location. If the new live_period isn't set to 0x7FFFFFFF, then it must not exceed the current live_period by more than a day, and the live location expiration date must remain in the next 90 days
final
messageId int
messageId Identifier of the message
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, ReplyMarkup? replyMarkup, LiveLocation? location}) EditBusinessMessageLiveLocation

Available on EditBusinessMessageLiveLocation, provided by the EditBusinessMessageLiveLocationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String