EditBusinessMessageMedia class final

Edits the media content of a message with a text, an animation, an audio, a document, a photo or a video in a message sent on behalf of a business account; for bots only Returns BusinessMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBusinessMessageMedia({required String businessConnectionId, required int chatId, required int messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which the message was sent
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
messageId int
messageId Identifier of the message
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) EditBusinessMessageMedia

Available on EditBusinessMessageMedia, provided by the EditBusinessMessageMediaExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String