EditChatFolderInviteLink class final

Edits an invite link for a chat folder Returns ChatFolderInviteLink

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditChatFolderInviteLink({required int chatFolderId, required String inviteLink, required String name, required List<int> chatIds})

Properties

chatFolderId int
chatFolderId Chat folder identifier
final
chatIds List<int>
chatIds New identifiers of chats to be accessible by the invite link. Use getChatsForChatFolderInviteLink to get suitable chats. Basic groups will be automatically converted to supergroups before link editing
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link to be edited
final
name String
name New name of the link; 0-32 characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, String? inviteLink, String? name, List<int>? chatIds}) EditChatFolderInviteLink

Available on EditChatFolderInviteLink, provided by the EditChatFolderInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String