EditCustomLanguagePackInfo class final

Edits information about a custom local language pack in the current localization target. Can be called before authorization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
info LanguagePackInfo?
info New information about the custom local language pack
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({LanguagePackInfo? info}) EditCustomLanguagePackInfo

Available on EditCustomLanguagePackInfo, provided by the EditCustomLanguagePackInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String