EditForumTopic class final

Edits title and icon of a topic in a forum supergroup chat or a chat with a bot with topics; for supergroup chats requires can_manage_topics administrator right unless the user is creator of the topic Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditForumTopic({required int chatId, required int forumTopicId, required String name, required bool editIconCustomEmoji, required int iconCustomEmojiId})

Properties

chatId int
chatId Identifier of the chat
final
editIconCustomEmoji bool
editIconCustomEmoji Pass true to edit the icon of the topic. Icon of the General topic can't be edited
final
forumTopicId int
forumTopicId Forum topic identifier
final
hashCode int
The hash code for this object.
no setteroverride
iconCustomEmojiId int
iconCustomEmojiId Identifier of the new custom emoji for topic icon; pass 0 to remove the custom emoji. Ignored if edit_icon_custom_emoji is false. Telegram Premium users can use any custom emoji, other users can use only a custom emoji returned by getForumTopicDefaultIcons
final
name String
name New name of the topic; 0-128 characters. If empty, the previous topic name is kept
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId, String? name, bool? editIconCustomEmoji, int? iconCustomEmojiId}) EditForumTopic

Available on EditForumTopic, provided by the EditForumTopicExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String