EditInlineMessageCaption class final
Edits the caption of an inline message sent via a bot; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- EditInlineMessageCaption
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditInlineMessageCaption({required String inlineMessageId, ReplyMarkup? replyMarkup, FormattedText? caption, required bool showCaptionAboveMedia})
Properties
- caption → FormattedText?
-
caption New message content caption; pass null to remove caption;
0-getOption("message_caption_length_max") characters
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inlineMessageId → String
-
inlineMessageId Inline message identifier
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCaptionAboveMedia → bool
-
showCaptionAboveMedia Pass true to show the caption above the media;
otherwise, the caption will be shown below the media. May be true only for
animation, photo, and video messages
final
Methods
-
copyWith(
{String? inlineMessageId, ReplyMarkup? replyMarkup, FormattedText? caption, bool? showCaptionAboveMedia}) → EditInlineMessageCaption -
Available on EditInlineMessageCaption, provided by the EditInlineMessageCaptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String