EditInlineMessageText class final

Edits the text of an inline text or game message sent via the bot; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditInlineMessageText({required String inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

hashCode int
The hash code for this object.
no setteroverride
inlineMessageId String
inlineMessageId Inline message identifier
final
inputMessageContent InputMessageContent?
inputMessageContent New text content of the message. Must be of type inputMessageText or inputMessageRichMessage; file upload isn't supported
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? inlineMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) EditInlineMessageText

Available on EditInlineMessageText, provided by the EditInlineMessageTextExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String