EditMessageCaption class final

Edits the message content caption. Returns the edited message after the edit is completed on the server side Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditMessageCaption({required int chatId, required int messageId, ReplyMarkup? replyMarkup, FormattedText? caption, required bool showCaptionAboveMedia})

Properties

caption FormattedText?
caption New message content caption; 0-getOption("message_caption_length_max") characters; pass null to remove caption
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCaptionAboveMedia bool
showCaptionAboveMedia Pass true to show the caption above the media; otherwise, the caption will be shown below the media. May be true only for animation, photo, and video messages
final

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, FormattedText? caption, bool? showCaptionAboveMedia}) EditMessageCaption

Available on EditMessageCaption, provided by the EditMessageCaptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String