EditMessageChecklist class final

Edits the message content of a checklist. Returns the edited message after the edit is completed on the server side Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditMessageChecklist({required int chatId, required int messageId, ReplyMarkup? replyMarkup, InputChecklist? checklist})

Properties

chatId int
chatId The chat the message belongs to
final
checklist InputChecklist?
checklist The new checklist. If some tasks were completed, this information will be kept
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message. Use messageProperties.can_be_edited to check whether the message can be edited
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none; for bots only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputChecklist? checklist}) EditMessageChecklist

Available on EditMessageChecklist, provided by the EditMessageChecklistExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String