checklist property
checklist The new checklist. If some tasks were completed, this information will be kept
Implementation
final InputChecklist? checklist;
checklist The new checklist. If some tasks were completed, this information will be kept
final InputChecklist? checklist;