EditMessageMedia class final
Edits the media content of a message, including message caption. If only the caption needs to be edited, use editMessageCaption instead. The type of message content in an album can't be changed with exception of replacing a photo with a video or vice versa. Returns the edited message after the edit is completed on the server side Returns Message
- Inheritance
-
- Object
- TdFunction
- EditMessageMedia
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditMessageMedia({required int chatId, required int messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- chatId → int
-
chatId The chat the message belongs to
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inputMessageContent → InputMessageContent?
-
inputMessageContent New content of the message. Must be one of the
following types: inputMessageAnimation, inputMessageAudio,
inputMessageDocument, inputMessagePhoto or inputMessageVideo
final
- messageId → int
-
messageId Identifier of the message. Use
messageProperties.can_edit_media to check whether the message can be
edited
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none; for bots
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditMessageMedia -
Available on EditMessageMedia, provided by the EditMessageMediaExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String