EditMessageSchedulingState class final

Edits the time when a scheduled message will be sent. Scheduling state of all messages in the same album or forwarded together with the message will be also changed Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditMessageSchedulingState({required int chatId, required int messageId, MessageSchedulingState? schedulingState})

Properties

chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message. Use messageProperties.can_edit_scheduling_state to check whether the message is suitable
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedulingState MessageSchedulingState?
schedulingState The new message scheduling state; pass null to send the message immediately. Must be null for messages in the state messageSchedulingStateSendWhenVideoProcessed
final

Methods

copyWith({int? chatId, int? messageId, MessageSchedulingState? schedulingState}) EditMessageSchedulingState

Available on EditMessageSchedulingState, provided by the EditMessageSchedulingStateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String