EditQuickReplyMessage class final

Asynchronously edits the text, media or caption of a quick reply message. Use quickReplyMessage.can_be_edited to check whether a message can be edited. Media message can be edited only to a media message. Checklist messages can be edited only to a checklist message. The type of message content in an album can't be changed with exception of replacing a photo with a video or vice versa Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditQuickReplyMessage({required int shortcutId, required int messageId, InputMessageContent? inputMessageContent})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent New content of the message. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessageChecklist, inputMessageDocument, inputMessagePhoto, inputMessageRichMessage, inputMessageText, or inputMessageVideo
final
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutId int
shortcutId Unique identifier of the quick reply shortcut with the message
final

Methods

copyWith({int? shortcutId, int? messageId, InputMessageContent? inputMessageContent}) EditQuickReplyMessage

Available on EditQuickReplyMessage, provided by the EditQuickReplyMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String