EditStarSubscription class final

Cancels or re-enables Telegram Star subscription Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditStarSubscription({required String subscriptionId, required bool isCanceled})

Properties

hashCode int
The hash code for this object.
no setteroverride
isCanceled bool
isCanceled New value of is_canceled
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId String
subscriptionId Identifier of the subscription to change
final

Methods

copyWith({String? subscriptionId, bool? isCanceled}) EditStarSubscription

Available on EditStarSubscription, provided by the EditStarSubscriptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String