isCanceled property
isCanceled Pass true to cancel the subscription; pass false to allow the user to enable it
Implementation
final bool isCanceled;
isCanceled Pass true to cancel the subscription; pass false to allow the user to enable it
final bool isCanceled;