EmailAddressAuthenticationCodeInfo class final

Information about the email address authentication code that was sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmailAddressAuthenticationCodeInfo({required String emailAddressPattern, required int length})

Properties

emailAddressPattern String
emailAddressPattern Pattern of the email address to which an authentication code was sent
final
hashCode int
The hash code for this object.
no setteroverride
length int
length Length of the code; 0 if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddressPattern, int? length}) EmailAddressAuthenticationCodeInfo

Available on EmailAddressAuthenticationCodeInfo, provided by the EmailAddressAuthenticationCodeInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmailAddressAuthenticationCodeInfo?

Constants

constructor → const String