EmailAddressAuthenticationGoogleId class final

An authentication token received through Google ID

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmailAddressAuthenticationGoogleId({required String token})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
token The token
final

Methods

copyWith({String? token}) EmailAddressAuthenticationGoogleId

Available on EmailAddressAuthenticationGoogleId, provided by the EmailAddressAuthenticationGoogleIdExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult appleId(EmailAddressAuthenticationAppleId value), required TResult code(EmailAddressAuthenticationCode value), required TResult googleId(EmailAddressAuthenticationGoogleId value)}) → TResult

Available on EmailAddressAuthentication, provided by the EmailAddressAuthenticationExtensions extension

maybeMap<TResult extends Object?>({TResult appleId(EmailAddressAuthenticationAppleId value)?, TResult code(EmailAddressAuthenticationCode value)?, TResult googleId(EmailAddressAuthenticationGoogleId value)?, required TResult orElse()}) → TResult

Available on EmailAddressAuthentication, provided by the EmailAddressAuthenticationExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String