EmailAddressResetStateAvailable class final

Email address can be reset after the given period. Call resetAuthenticationEmailAddress to reset it and allow the user to authorize with a code sent to the user's phone number

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmailAddressResetStateAvailable({required int waitPeriod})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waitPeriod int
waitPeriod Time required to wait before the email address can be reset; 0 if the user is subscribed to Telegram Premium
final

Methods

copyWith({int? waitPeriod}) EmailAddressResetStateAvailable

Available on EmailAddressResetStateAvailable, provided by the EmailAddressResetStateAvailableExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult available(EmailAddressResetStateAvailable value), required TResult pending(EmailAddressResetStatePending value)}) → TResult

Available on EmailAddressResetState, provided by the EmailAddressResetStateExtensions extension

maybeMap<TResult extends Object?>({TResult available(EmailAddressResetStateAvailable value)?, TResult pending(EmailAddressResetStatePending value)?, required TResult orElse()}) → TResult

Available on EmailAddressResetState, provided by the EmailAddressResetStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String