EmailAddressResetStatePending class final

Email address reset has already been requested. Call resetAuthenticationEmailAddress to check whether immediate reset is possible

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmailAddressResetStatePending({required int resetIn})

Properties

hashCode int
The hash code for this object.
no setteroverride
resetIn int
resetIn Left time before the email address will be reset, in seconds. updateAuthorizationState is not sent when this field changes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? resetIn}) EmailAddressResetStatePending

Available on EmailAddressResetStatePending, provided by the EmailAddressResetStatePendingExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult available(EmailAddressResetStateAvailable value), required TResult pending(EmailAddressResetStatePending value)}) → TResult

Available on EmailAddressResetState, provided by the EmailAddressResetStateExtensions extension

maybeMap<TResult extends Object?>({TResult available(EmailAddressResetStateAvailable value)?, TResult pending(EmailAddressResetStatePending value)?, required TResult orElse()}) → TResult

Available on EmailAddressResetState, provided by the EmailAddressResetStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String