isGreeting property
isGreeting True, if the category must be shown first when choosing a sticker for the start page
Implementation
final bool isGreeting;
isGreeting True, if the category must be shown first when choosing a sticker for the start page
final bool isGreeting;