EmojiCategorySource class sealed

Describes source of stickers for an emoji category

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult premium(EmojiCategorySourcePremium value), required TResult search(EmojiCategorySourceSearch value)}) → TResult

Available on EmojiCategorySource, provided by the EmojiCategorySourceExtensions extension

maybeMap<TResult extends Object?>({TResult premium(EmojiCategorySourcePremium value)?, TResult search(EmojiCategorySourceSearch value)?, required TResult orElse()}) → TResult

Available on EmojiCategorySource, provided by the EmojiCategorySourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiCategorySource?
Inherited by: EmojiCategorySourcePremium EmojiCategorySourceSearch

Constants

constructor → const String