EmojiCategorySourceSearch class final

The category contains a list of similar emoji to search for in getStickers and searchStickers for stickers, or getInlineQueryResults with the bot getOption("animation_search_bot_username") for animations

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiCategorySourceSearch({required List<String> emojis})

Properties

emojis List<String>
emojis List of emojis to search for
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? emojis}) EmojiCategorySourceSearch

Available on EmojiCategorySourceSearch, provided by the EmojiCategorySourceSearchExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult premium(EmojiCategorySourcePremium value), required TResult search(EmojiCategorySourceSearch value)}) → TResult

Available on EmojiCategorySource, provided by the EmojiCategorySourceExtensions extension

maybeMap<TResult extends Object?>({TResult premium(EmojiCategorySourcePremium value)?, TResult search(EmojiCategorySourceSearch value)?, required TResult orElse()}) → TResult

Available on EmojiCategorySource, provided by the EmojiCategorySourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiCategorySourceSearch?
Inherited by: EmojiCategorySourcePremium EmojiCategorySourceSearch
override

Constants

constructor → const String