EmojiChatTheme class final

Describes a chat theme based on an emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiChatTheme({required String name, ThemeSettings? lightSettings, ThemeSettings? darkSettings})

Properties

darkSettings ThemeSettings?
darkSettings Theme settings for a dark chat theme
final
hashCode int
The hash code for this object.
no setteroverride
lightSettings ThemeSettings?
lightSettings Theme settings for a light chat theme
final
name String
name Theme name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, ThemeSettings? lightSettings, ThemeSettings? darkSettings}) EmojiChatTheme

Available on EmojiChatTheme, provided by the EmojiChatThemeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiChatTheme?

Constants

constructor → const String