EmojiKeyword class final

Represents an emoji with its keyword

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiKeyword({required String emoji, required String keyword})

Properties

emoji String
emoji The emoji
final
hashCode int
The hash code for this object.
no setteroverride
keyword String
keyword The keyword
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji, String? keyword}) EmojiKeyword

Available on EmojiKeyword, provided by the EmojiKeywordExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiKeyword?

Constants

constructor → const String