EmojiReaction class final
Contains information about an emoji reaction
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- activateAnimation → Sticker?
-
activateAnimation Activate animation for the reaction
final
- appearAnimation → Sticker?
-
appearAnimation Appear animation for the reaction
final
- aroundAnimation → Sticker?
-
aroundAnimation Around animation for the reaction; may be null
final
- centerAnimation → Sticker?
-
centerAnimation Center animation for the reaction; may be null
final
- effectAnimation → Sticker?
-
effectAnimation Effect animation for the reaction
final
- emoji → String
-
emoji Text representation of the reaction
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isActive → bool
-
isActive True, if the reaction can be added to new messages and enabled
in chats
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectAnimation → Sticker?
-
selectAnimation Select animation for the reaction
final
- staticIcon → Sticker?
-
staticIcon Static icon for the reaction
final
- title → String
-
title Reaction title
final
Methods
-
copyWith(
{String? emoji, String? title, bool? isActive, Sticker? staticIcon, Sticker? appearAnimation, Sticker? selectAnimation, Sticker? activateAnimation, Sticker? effectAnimation, Sticker? aroundAnimation, Sticker? centerAnimation}) → EmojiReaction -
Available on EmojiReaction, provided by the EmojiReactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiReaction?
Constants
- constructor → const String