EmojiStatusType class sealed
Describes type of emoji status
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult customEmoji(EmojiStatusTypeCustomEmoji value), required TResult upgradedGift(EmojiStatusTypeUpgradedGift value)}) → TResult -
Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult customEmoji(EmojiStatusTypeCustomEmoji value)?, TResult upgradedGift(EmojiStatusTypeUpgradedGift value)?, required TResult orElse()}) → TResult -
Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiStatusType? - Inherited by: EmojiStatusTypeCustomEmoji EmojiStatusTypeUpgradedGift
Constants
- constructor → const String