EmojiStatusTypeUpgradedGift class final

An upgraded gift set as emoji status

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiStatusTypeUpgradedGift({required int upgradedGiftId, required String giftTitle, required String giftName, required int modelCustomEmojiId, required int symbolCustomEmojiId, UpgradedGiftBackdropColors? backdropColors})

Properties

backdropColors UpgradedGiftBackdropColors?
backdropColors Colors of the backdrop of the upgraded gift
final
giftName String
giftName Unique name of the upgraded gift that can be used with internalLinkTypeUpgradedGift
final
giftTitle String
giftTitle The title of the upgraded gift
final
hashCode int
The hash code for this object.
no setteroverride
modelCustomEmojiId int
modelCustomEmojiId Custom emoji identifier of the model of the upgraded gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbolCustomEmojiId int
symbolCustomEmojiId Custom emoji identifier of the symbol of the upgraded gift
final
upgradedGiftId int
upgradedGiftId Identifier of the upgraded gift
final

Methods

copyWith({int? upgradedGiftId, String? giftTitle, String? giftName, int? modelCustomEmojiId, int? symbolCustomEmojiId, UpgradedGiftBackdropColors? backdropColors}) EmojiStatusTypeUpgradedGift

Available on EmojiStatusTypeUpgradedGift, provided by the EmojiStatusTypeUpgradedGiftExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(EmojiStatusTypeCustomEmoji value), required TResult upgradedGift(EmojiStatusTypeUpgradedGift value)}) → TResult

Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(EmojiStatusTypeCustomEmoji value)?, TResult upgradedGift(EmojiStatusTypeUpgradedGift value)?, required TResult orElse()}) → TResult

Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiStatusTypeUpgradedGift?
Inherited by: EmojiStatusTypeCustomEmoji EmojiStatusTypeUpgradedGift
override

Constants

constructor → const String