EnableProxy class final
Enables a proxy. Only one proxy can be enabled at a time. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- EnableProxy
- Available extensions
- Annotations
-
- @immutable
Constructors
- EnableProxy({required int proxyId})
Properties
Methods
-
copyWith(
{int? proxyId}) → EnableProxy -
Available on EnableProxy, provided by the EnableProxyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String