EncryptGroupCallData class final
Encrypts group call data before sending them over network using tgcalls Returns Data
- Inheritance
-
- Object
- TdFunction
- EncryptGroupCallData
- Available extensions
- Annotations
-
- @immutable
Constructors
- EncryptGroupCallData({required int groupCallId, GroupCallDataChannel? dataChannel, required String data, required int unencryptedPrefixSize})
Properties
- data → String
-
data Data to encrypt
final
- dataChannel → GroupCallDataChannel?
-
dataChannel Data channel for which data is encrypted
final
- groupCallId → int
-
groupCallId Group call identifier. The call must not be a video chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unencryptedPrefixSize → int
-
unencryptedPrefixSize Size of data prefix that must be kept unencrypted
final
Methods
-
copyWith(
{int? groupCallId, GroupCallDataChannel? dataChannel, String? data, int? unencryptedPrefixSize}) → EncryptGroupCallData -
Available on EncryptGroupCallData, provided by the EncryptGroupCallDataExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String