EncryptedCredentials class final
Contains encrypted Telegram Passport data credentials
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- EncryptedCredentials({required String data, required String hash, required String secret})
Properties
- data → String
-
data The encrypted credentials
final
- hash → String
-
hash The decrypted data hash
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secret → String
-
secret Secret for data decryption, encrypted with the service's public
key
final
Methods
-
copyWith(
{String? data, String? hash, String? secret}) → EncryptedCredentials -
Available on EncryptedCredentials, provided by the EncryptedCredentialsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EncryptedCredentials?
Constants
- constructor → const String