EndGroupCallRecording class final

Ends recording of an active group call; for video chats only. Requires groupCall.can_be_managed right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EndGroupCallRecording({required int groupCallId})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId}) EndGroupCallRecording

Available on EndGroupCallRecording, provided by the EndGroupCallRecordingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String