countryCode property
countryCode A two-letter ISO 3166-1 alpha-2 country code of the country for which the fact-check is shown
Implementation
final String countryCode;
countryCode A two-letter ISO 3166-1 alpha-2 country code of the country for which the fact-check is shown
final String countryCode;