premiumWouldAllowInvite property

bool premiumWouldAllowInvite
final

premiumWouldAllowInvite True, if subscription to Telegram Premium would have allowed to add the user to the chat

Implementation

final bool premiumWouldAllowInvite;