FileDownload class final

Describes a file added to file download list

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FileDownload({required int fileId, Message? message, required int addDate, required int completeDate, required bool isPaused})

Properties

addDate int
addDate Point in time (Unix timestamp) when the file was added to the download list
final
completeDate int
completeDate Point in time (Unix timestamp) when the file downloading was completed; 0 if the file downloading isn't completed
final
fileId int
fileId File identifier
final
hashCode int
The hash code for this object.
no setteroverride
isPaused bool
isPaused True, if downloading of the file is paused
final
message Message?
message The message with the file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, Message? message, int? addDate, int? completeDate, bool? isPaused}) FileDownload

Available on FileDownload, provided by the FileDownloadExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FileDownload?

Constants

constructor → const String