FileDownloadedPrefixSize class final

Contains size of downloaded prefix of a file

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FileDownloadedPrefixSize({required int size})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
size The prefix size, in bytes
final

Methods

copyWith({int? size}) FileDownloadedPrefixSize

Available on FileDownloadedPrefixSize, provided by the FileDownloadedPrefixSizeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FileDownloadedPrefixSize?

Constants

constructor → const String