FileTypeLivePhotoVideo class final
The file is a video for a live photo
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- FileTypeLivePhotoVideo()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(FileTypeAnimation value), required TResult audio(FileTypeAudio value), required TResult document(FileTypeDocument value), required TResult livePhotoVideo(FileTypeLivePhotoVideo value), required TResult none(FileTypeNone value), required TResult notificationSound(FileTypeNotificationSound value), required TResult photo(FileTypePhoto value), required TResult photoStory(FileTypePhotoStory value), required TResult profilePhoto(FileTypeProfilePhoto value), required TResult secret(FileTypeSecret value), required TResult secretThumbnail(FileTypeSecretThumbnail value), required TResult secure(FileTypeSecure value), required TResult selfDestructingLivePhotoVideo(FileTypeSelfDestructingLivePhotoVideo value), required TResult selfDestructingPhoto(FileTypeSelfDestructingPhoto value), required TResult selfDestructingVideo(FileTypeSelfDestructingVideo value), required TResult selfDestructingVideoNote(FileTypeSelfDestructingVideoNote value), required TResult selfDestructingVoiceNote(FileTypeSelfDestructingVoiceNote value), required TResult sticker(FileTypeSticker value), required TResult thumbnail(FileTypeThumbnail value), required TResult unknown(FileTypeUnknown value), required TResult video(FileTypeVideo value), required TResult videoNote(FileTypeVideoNote value), required TResult videoStory(FileTypeVideoStory value), required TResult voiceNote(FileTypeVoiceNote value), required TResult wallpaper(FileTypeWallpaper value)}) → TResult -
Available on FileType, provided by the FileTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(FileTypeAnimation value)?, TResult audio(FileTypeAudio value)?, TResult document(FileTypeDocument value)?, TResult livePhotoVideo(FileTypeLivePhotoVideo value)?, TResult none(FileTypeNone value)?, TResult notificationSound(FileTypeNotificationSound value)?, TResult photo(FileTypePhoto value)?, TResult photoStory(FileTypePhotoStory value)?, TResult profilePhoto(FileTypeProfilePhoto value)?, TResult secret(FileTypeSecret value)?, TResult secretThumbnail(FileTypeSecretThumbnail value)?, TResult secure(FileTypeSecure value)?, TResult selfDestructingLivePhotoVideo(FileTypeSelfDestructingLivePhotoVideo value)?, TResult selfDestructingPhoto(FileTypeSelfDestructingPhoto value)?, TResult selfDestructingVideo(FileTypeSelfDestructingVideo value)?, TResult selfDestructingVideoNote(FileTypeSelfDestructingVideoNote value)?, TResult selfDestructingVoiceNote(FileTypeSelfDestructingVoiceNote value)?, TResult sticker(FileTypeSticker value)?, TResult thumbnail(FileTypeThumbnail value)?, TResult unknown(FileTypeUnknown value)?, TResult video(FileTypeVideo value)?, TResult videoNote(FileTypeVideoNote value)?, TResult videoStory(FileTypeVideoStory value)?, TResult voiceNote(FileTypeVoiceNote value)?, TResult wallpaper(FileTypeWallpaper value)?, required TResult orElse()}) → TResult -
Available on FileType, provided by the FileTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FileTypeLivePhotoVideo? -
Inherited by:
FileTypeAnimation
FileTypeAudio
FileTypeDocument
FileTypeLivePhotoVideo
FileTypeNone
FileTypeNotificationSound
FileTypePhoto
FileTypePhotoStory
FileTypeProfilePhoto
FileTypeSecret
FileTypeSecretThumbnail
FileTypeSecure
FileTypeSelfDestructingLivePhotoVideo
FileTypeSelfDestructingPhoto
FileTypeSelfDestructingVideo
FileTypeSelfDestructingVideoNote
FileTypeSelfDestructingVoiceNote
FileTypeSticker
FileTypeThumbnail
FileTypeUnknown
FileTypeVideo
FileTypeVideoNote
FileTypeVideoStory
FileTypeVoiceNote
FileTypeWallpaper
override
Constants
- constructor → const String