FinishFileGeneration class final

Finishes the file generation Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FinishFileGeneration({required int generationId, TdError? error})

Properties

error TdError?
error If passed, the file generation has failed and must be terminated; pass null if the file generation succeeded
final
generationId int
generationId The identifier of the generation process
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, TdError? error}) FinishFileGeneration

Available on FinishFileGeneration, provided by the FinishFileGenerationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String