FirebaseAuthenticationSettingsAndroid class final

Settings for Firebase Authentication in the official Android application

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult android(FirebaseAuthenticationSettingsAndroid value), required TResult ios(FirebaseAuthenticationSettingsIos value)}) → TResult

Available on FirebaseAuthenticationSettings, provided by the FirebaseAuthenticationSettingsExtensions extension

maybeMap<TResult extends Object?>({TResult android(FirebaseAuthenticationSettingsAndroid value)?, TResult ios(FirebaseAuthenticationSettingsIos value)?, required TResult orElse()}) → TResult

Available on FirebaseAuthenticationSettings, provided by the FirebaseAuthenticationSettingsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String