FirebaseDeviceVerificationParametersPlayIntegrity class final

Device verification must be performed with the classic Play Integrity verification (https://developer.android.com/google/play/integrity/classic)

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FirebaseDeviceVerificationParametersPlayIntegrity({required String nonce, required int cloudProjectNumber})

Properties

cloudProjectNumber int
cloudProjectNumber Cloud project number to pass to the Play Integrity API
final
hashCode int
The hash code for this object.
no setteroverride
nonce String
nonce Base64url-encoded nonce to pass to the Play Integrity API
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? nonce, int? cloudProjectNumber}) FirebaseDeviceVerificationParametersPlayIntegrity

Available on FirebaseDeviceVerificationParametersPlayIntegrity, provided by the FirebaseDeviceVerificationParametersPlayIntegrityExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult playIntegrity(FirebaseDeviceVerificationParametersPlayIntegrity value), required TResult safetyNet(FirebaseDeviceVerificationParametersSafetyNet value)}) → TResult

Available on FirebaseDeviceVerificationParameters, provided by the FirebaseDeviceVerificationParametersExtensions extension

maybeMap<TResult extends Object?>({TResult playIntegrity(FirebaseDeviceVerificationParametersPlayIntegrity value)?, TResult safetyNet(FirebaseDeviceVerificationParametersSafetyNet value)?, required TResult orElse()}) → TResult

Available on FirebaseDeviceVerificationParameters, provided by the FirebaseDeviceVerificationParametersExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String