ForumTopic class final

Describes a forum topic

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ForumTopic({ForumTopicInfo? info, Message? lastMessage, required int order, required bool isPinned, required int unreadCount, required int lastReadInboxMessageId, required int lastReadOutboxMessageId, required int unreadMentionCount, required int unreadReactionCount, required int unreadPollVoteCount, ChatNotificationSettings? notificationSettings, DraftMessage? draftMessage})

Properties

draftMessage DraftMessage?
draftMessage A draft of a message in the topic; may be null if none
final
hashCode int
The hash code for this object.
no setteroverride
info ForumTopicInfo?
info Basic information about the topic
final
isPinned bool
isPinned True, if the topic is pinned in the topic list
final
lastMessage Message?
lastMessage Last message in the topic; may be null if unknown
final
lastReadInboxMessageId int
lastReadInboxMessageId Identifier of the last read incoming message
final
lastReadOutboxMessageId int
lastReadOutboxMessageId Identifier of the last read outgoing message
final
notificationSettings ChatNotificationSettings?
notificationSettings Notification settings for the topic
final
order int
order A parameter used to determine order of the topic in the topic list. Topics must be sorted by the order in descending order
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreadCount int
unreadCount Number of unread messages in the topic
final
unreadMentionCount int
unreadMentionCount Number of unread messages with a mention/reply in the topic
final
unreadPollVoteCount int
unreadPollVoteCount Number of messages with unread poll votes in the topic
final
unreadReactionCount int
unreadReactionCount Number of messages with unread reactions in the topic
final

Methods

copyWith({ForumTopicInfo? info, Message? lastMessage, int? order, bool? isPinned, int? unreadCount, int? lastReadInboxMessageId, int? lastReadOutboxMessageId, int? unreadMentionCount, int? unreadReactionCount, int? unreadPollVoteCount, ChatNotificationSettings? notificationSettings, DraftMessage? draftMessage}) ForumTopic

Available on ForumTopic, provided by the ForumTopicExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ForumTopic?

Constants

constructor → const String