ForumTopicIcon class final

Describes a forum topic icon

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ForumTopicIcon({required int color, required int customEmojiId})

Properties

color int
color Color of the topic icon in RGB format
final
customEmojiId int
customEmojiId Unique identifier of the custom emoji shown on the topic icon; 0 if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? color, int? customEmojiId}) ForumTopicIcon

Available on ForumTopicIcon, provided by the ForumTopicIconExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ForumTopicIcon?

Constants

constructor → const String