ForumTopicInfo class final
Contains basic information about a forum topic
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ForumTopicInfo({required int chatId, required int forumTopicId, required String name, ForumTopicIcon? icon, required int creationDate, MessageSender? creatorId, required bool isGeneral, required bool isOutgoing, required bool isClosed, required bool isHidden, required bool isNameImplicit})
Properties
- chatId → int
-
chatId Identifier of a forum supergroup chat or a chat with a bot to
which the topic belongs
final
- creationDate → int
-
creationDate Point in time (Unix timestamp) when the topic was created
final
- creatorId → MessageSender?
-
creatorId Identifier of the creator of the topic
final
- forumTopicId → int
-
forumTopicId Forum topic identifier of the topic
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → ForumTopicIcon?
-
icon Icon of the topic
final
- isClosed → bool
-
isClosed True, if the topic is closed. If the topic is closed, then the
user must have can_manage_topics administrator right in the supergroup or
must be the creator of the topic to send messages there
final
- isGeneral → bool
-
isGeneral True, if the topic is the General topic
final
- isHidden → bool
-
isHidden True, if the topic is hidden above the topic list and closed;
for General topic only
final
- isNameImplicit → bool
-
isNameImplicit True, if the name of the topic wasn't added explicitly
final
- isOutgoing → bool
-
isOutgoing True, if the topic was created by the current user
final
- name → String
-
name Name of the topic
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId, String? name, ForumTopicIcon? icon, int? creationDate, MessageSender? creatorId, bool? isGeneral, bool? isOutgoing, bool? isClosed, bool? isHidden, bool? isNameImplicit}) → ForumTopicInfo -
Available on ForumTopicInfo, provided by the ForumTopicInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ForumTopicInfo?
Constants
- constructor → const String