isClosed property

bool isClosed
final

isClosed True, if the topic is closed. If the topic is closed, then the user must have can_manage_topics administrator right in the supergroup or must be the creator of the topic to send messages there

Implementation

final bool isClosed;