nextOffsetForumTopicId property
nextOffsetForumTopicId Offset forum topic identifier for the next getForumTopics request
Implementation
final int nextOffsetForumTopicId;
nextOffsetForumTopicId Offset forum topic identifier for the next getForumTopics request
final int nextOffsetForumTopicId;