topicId property
topicId Topic in which the messages will be forwarded; message threads aren't supported; pass null if none
Implementation
final MessageTopic? topicId;
topicId Topic in which the messages will be forwarded; message threads aren't supported; pass null if none
final MessageTopic? topicId;