ForwardSource class final

Contains information about the last message from which a new message was forwarded last time

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ForwardSource({required int chatId, required int messageId, MessageSender? senderId, required String senderName, required int date, required bool isOutgoing})

Properties

chatId int
chatId Identifier of the chat to which the message that was forwarded belonged; may be 0 if unknown
final
date int
date Point in time (Unix timestamp) when the message is sent; 0 if unknown
final
hashCode int
The hash code for this object.
no setteroverride
isOutgoing bool
isOutgoing True, if the message that was forwarded is outgoing; always false if sender is unknown
final
messageId int
messageId Identifier of the message; may be 0 if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of the message; may be null if unknown or the new message was forwarded not to Saved Messages
final
senderName String
senderName Name of the sender of the message if the sender is hidden by their privacy settings
final

Methods

copyWith({int? chatId, int? messageId, MessageSender? senderId, String? senderName, int? date, bool? isOutgoing}) ForwardSource

Available on ForwardSource, provided by the ForwardSourceExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ForwardSource?

Constants

constructor → const String