isOutgoing property
isOutgoing True, if the message that was forwarded is outgoing; always false if sender is unknown
Implementation
final bool isOutgoing;
isOutgoing True, if the message that was forwarded is outgoing; always false if sender is unknown
final bool isOutgoing;