senderName property
senderName Name of the sender of the message if the sender is hidden by their privacy settings
Implementation
final String senderName;
senderName Name of the sender of the message if the sender is hidden by their privacy settings
final String senderName;