FoundAffiliateProgram class final

Describes a found affiliate program

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundAffiliateProgram({required int botUserId, AffiliateProgramInfo? info})

Properties

botUserId int
botUserId User identifier of the bot created the program
final
hashCode int
The hash code for this object.
no setteroverride
info AffiliateProgramInfo?
info Information about the affiliate program
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, AffiliateProgramInfo? info}) FoundAffiliateProgram

Available on FoundAffiliateProgram, provided by the FoundAffiliateProgramExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundAffiliateProgram?

Constants

constructor → const String