FoundChatMessages class final

Contains a list of messages found by a search in a given chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundChatMessages({required int totalCount, required List<Message> messages, required int nextFromMessageId})

Properties

hashCode int
The hash code for this object.
no setteroverride
messages List<Message>
messages List of messages
final
nextFromMessageId int
nextFromMessageId The offset for the next request. If 0, there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of messages found; -1 if unknown
final

Methods

copyWith({int? totalCount, List<Message>? messages, int? nextFromMessageId}) FoundChatMessages

Available on FoundChatMessages, provided by the FoundChatMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundChatMessages?

Constants

constructor → const String