FoundFileDownloads class final

Contains a list of downloaded files, found by a search

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundFileDownloads({DownloadedFileCounts? totalCounts, required List<FileDownload> files, required String nextOffset})

Properties

files List<FileDownload>
files The list of files
final
hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCounts DownloadedFileCounts?
totalCounts Total number of suitable files, ignoring offset
final

Methods

copyWith({DownloadedFileCounts? totalCounts, List<FileDownload>? files, String? nextOffset}) FoundFileDownloads

Available on FoundFileDownloads, provided by the FoundFileDownloadsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundFileDownloads?

Constants

constructor → const String