FoundPosition class final

Contains 0-based match position

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundPosition({required int position})

Properties

hashCode int
The hash code for this object.
no setteroverride
position int
position The position of the match
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? position}) FoundPosition

Available on FoundPosition, provided by the FoundPositionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundPosition?

Constants

constructor → const String