FoundPositions class final

Contains 0-based positions of matched objects

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundPositions({required int totalCount, required List<int> positions})

Properties

hashCode int
The hash code for this object.
no setteroverride
positions List<int>
positions The positions of the matched objects
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of matched objects
final

Methods

copyWith({int? totalCount, List<int>? positions}) FoundPositions

Available on FoundPositions, provided by the FoundPositionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundPositions?

Constants

constructor → const String