areLimitsExceeded property
areLimitsExceeded True, if the query has failed because search limits are exceeded. In this case search_limits.daily_free_query_count will be equal to 0
Implementation
final bool areLimitsExceeded;
areLimitsExceeded True, if the query has failed because search limits are exceeded. In this case search_limits.daily_free_query_count will be equal to 0
final bool areLimitsExceeded;