searchLimits property

PublicPostSearchLimits? searchLimits
final

searchLimits Updated public post search limits after the query; repeated requests with the same query will be free; may be null if they didn't change

Implementation

final PublicPostSearchLimits? searchLimits;