FoundWebApp class final

Contains information about a Web App found by its short name

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundWebApp({WebApp? webApp, required bool requestWriteAccess, required bool skipConfirmation})

Properties

hashCode int
The hash code for this object.
no setteroverride
requestWriteAccess bool
requestWriteAccess True, if the user must be asked for the permission to the bot to send them messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipConfirmation bool
skipConfirmation True, if there is no need to show an ordinary open URL confirmation before opening the Web App. The field must be ignored and confirmation must be shown anyway if the Web App link was hidden
final
webApp WebApp?
webApp The Web App
final

Methods

copyWith({WebApp? webApp, bool? requestWriteAccess, bool? skipConfirmation}) FoundWebApp

Available on FoundWebApp, provided by the FoundWebAppExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundWebApp?

Constants

constructor → const String