GetActiveSessions class final

Returns all active sessions of the current user. Additionally, getBusinessConnectedBot must be used to show the bot on top of active sessions Returns Sessions

Inheritance
Annotations
  • @immutable

Constructors

GetActiveSessions()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String