GetAllPassportElements class final

Returns all available Telegram Passport elements Returns PassportElements

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetAllPassportElements({required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password of the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? password}) GetAllPassportElements

Available on GetAllPassportElements, provided by the GetAllPassportElementsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String