returnOnlyMainEmoji property

bool returnOnlyMainEmoji
final

returnOnlyMainEmoji Pass true if only main emoji for each found sticker must be included in the result

Implementation

final bool returnOnlyMainEmoji;