GetAnimatedEmoji class final

Returns an animated emoji corresponding to a given emoji. Returns a 404 error if the emoji has no animated emoji Returns AnimatedEmoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetAnimatedEmoji({required String emoji})

Properties

emoji String
emoji The emoji
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) GetAnimatedEmoji

Available on GetAnimatedEmoji, provided by the GetAnimatedEmojiExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String