offsetStickerSetId property
offsetStickerSetId Identifier of the sticker set from which to return the result; use 0 to get results from the beginning
Implementation
final int offsetStickerSetId;
offsetStickerSetId Identifier of the sticker set from which to return the result; use 0 to get results from the beginning
final int offsetStickerSetId;