GetAttachmentMenuBot class final

Returns information about a bot that can be added to attachment or side menu Returns AttachmentMenuBot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetAttachmentMenuBot({required int botUserId})

Properties

botUserId int
botUserId Bot's user identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) GetAttachmentMenuBot

Available on GetAttachmentMenuBot, provided by the GetAttachmentMenuBotExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String