GetBackgroundUrl class final

Constructs a persistent HTTP URL for a background Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBackgroundUrl({required String name, BackgroundType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Background name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type BackgroundType?
type Background type; backgroundTypeChatTheme isn't supported
final

Methods

copyWith({String? name, BackgroundType? type}) GetBackgroundUrl

Available on GetBackgroundUrl, provided by the GetBackgroundUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String