GetBankCardInfo class final

Returns information about a bank card Returns BankCardInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBankCardInfo({required String bankCardNumber})

Properties

bankCardNumber String
bankCardNumber The bank card number
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? bankCardNumber}) GetBankCardInfo

Available on GetBankCardInfo, provided by the GetBankCardInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String