GetBlockedMessageSenders class final

Returns users and chats that were blocked by the current user Returns MessageSenders

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBlockedMessageSenders({BlockList? blockList, required int offset, required int limit})

Properties

blockList BlockList?
blockList Block list from which to return users
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of users and chats to return; up to 100
final
offset int
offset Number of users and chats to skip in the result; must be non-negative
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BlockList? blockList, int? offset, int? limit}) GetBlockedMessageSenders

Available on GetBlockedMessageSenders, provided by the GetBlockedMessageSendersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String