GetBotMediaPreviewInfo class final

Returns the list of media previews for the given language and the list of languages for which the bot has dedicated previews Returns BotMediaPreviewInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBotMediaPreviewInfo({required int botUserId, required String languageCode})

Properties

botUserId int
botUserId Identifier of the target bot. The bot must be owned and must have the main Web App
final
hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode A two-letter ISO 639-1 language code for which to get previews. If empty, then default previews are returned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? languageCode}) GetBotMediaPreviewInfo

Available on GetBotMediaPreviewInfo, provided by the GetBotMediaPreviewInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String