GetBotMediaPreviews class final
Returns the list of media previews of a bot Returns BotMediaPreviews
- Inheritance
-
- Object
- TdFunction
- GetBotMediaPreviews
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetBotMediaPreviews({required int botUserId})
Properties
Methods
-
copyWith(
{int? botUserId}) → GetBotMediaPreviews -
Available on GetBotMediaPreviews, provided by the GetBotMediaPreviewsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String