GetBotSimilarBots class final

Returns a list of bots similar to the given bot Returns Users

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBotSimilarBots({required int botUserId})

Properties

botUserId int
botUserId User identifier of the target bot
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) GetBotSimilarBots

Available on GetBotSimilarBots, provided by the GetBotSimilarBotsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String