GetBusinessAccountStarAmount class final
Returns the Telegram Star amount owned by a business account; for bots only Returns StarAmount
- Inheritance
-
- Object
- TdFunction
- GetBusinessAccountStarAmount
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetBusinessAccountStarAmount({required String businessConnectionId})
Properties
- businessConnectionId → String
-
businessConnectionId Unique identifier of business connection
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId}) → GetBusinessAccountStarAmount -
Available on GetBusinessAccountStarAmount, provided by the GetBusinessAccountStarAmountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String