GetBusinessChatLinkInfo class final

Returns information about a business chat link Returns BusinessChatLinkInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBusinessChatLinkInfo({required String linkName})

Properties

hashCode int
The hash code for this object.
no setteroverride
linkName String
linkName Name of the link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? linkName}) GetBusinessChatLinkInfo

Available on GetBusinessChatLinkInfo, provided by the GetBusinessChatLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String