GetBusinessConnection class final

Returns information about a business connection by its identifier; for bots only Returns BusinessConnection

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBusinessConnection({required String connectionId})

Properties

connectionId String
connectionId Identifier of the business connection to return
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? connectionId}) GetBusinessConnection

Available on GetBusinessConnection, provided by the GetBusinessConnectionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String