GetBusinessFeatures class final

Returns information about features, available to Business users Returns BusinessFeatures

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBusinessFeatures({BusinessFeature? source})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source BusinessFeature?
source Source of the request; pass null if the method is called from settings or some non-standard source
final

Methods

copyWith({BusinessFeature? source}) GetBusinessFeatures

Available on GetBusinessFeatures, provided by the GetBusinessFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String