source property
source Source of the request; pass null if the method is called from settings or some non-standard source
Implementation
final BusinessFeature? source;
source Source of the request; pass null if the method is called from settings or some non-standard source
final BusinessFeature? source;