GetCallbackQueryAnswer class final

Sends a callback query to a bot and returns an answer. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires Returns CallbackQueryAnswer

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCallbackQueryAnswer({required int chatId, required int messageId, CallbackQueryPayload? payload})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message from which the query originated. The message must not be scheduled
final
payload CallbackQueryPayload?
payload Query payload
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, CallbackQueryPayload? payload}) GetCallbackQueryAnswer

Available on GetCallbackQueryAnswer, provided by the GetCallbackQueryAnswerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String