GetCallbackQueryMessage class final

Returns information about a message with the callback button that originated a callback query; for bots only Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCallbackQueryMessage({required int chatId, required int messageId, required int callbackQueryId})

Properties

callbackQueryId int
callbackQueryId Identifier of the callback query
final
chatId int
chatId Identifier of the chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? callbackQueryId}) GetCallbackQueryMessage

Available on GetCallbackQueryMessage, provided by the GetCallbackQueryMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String