GetChat class final
Returns information about a chat by its identifier. This is an offline method if the current user is not a bot Returns Chat
- Inheritance
-
- Object
- TdFunction
- GetChat
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{int? chatId}) → GetChat -
Available on GetChat, provided by the GetChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String