GetChatActiveStories class final
Returns the list of active stories posted by the given chat Returns ChatActiveStories
- Inheritance
-
- Object
- TdFunction
- GetChatActiveStories
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatActiveStories({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetChatActiveStories -
Available on GetChatActiveStories, provided by the GetChatActiveStoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String