GetChatAdministrators class final
Returns a list of administrators of the chat with their custom titles Returns ChatAdministrators
- Inheritance
-
- Object
- TdFunction
- GetChatAdministrators
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatAdministrators({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetChatAdministrators -
Available on GetChatAdministrators, provided by the GetChatAdministratorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String