GetChatAvailablePaidMessageReactionSenders class final

Returns the list of message sender identifiers, which can be used to send a paid reaction in a chat Returns MessageSenders

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatAvailablePaidMessageReactionSenders({required int chatId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatAvailablePaidMessageReactionSenders

Available on GetChatAvailablePaidMessageReactionSenders, provided by the GetChatAvailablePaidMessageReactionSendersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String