GetChatBoostFeatures class final
Returns the list of features available for different chat boost levels. This is an offline method Returns ChatBoostFeatures
- Inheritance
-
- Object
- TdFunction
- GetChatBoostFeatures
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatBoostFeatures({required bool isChannel})
Properties
Methods
-
copyWith(
{bool? isChannel}) → GetChatBoostFeatures -
Available on GetChatBoostFeatures, provided by the GetChatBoostFeaturesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String