GetChatBoostLevelFeatures class final
Returns the list of features available on the specific chat boost level. This is an offline method Returns ChatBoostLevelFeatures
- Inheritance
-
- Object
- TdFunction
- GetChatBoostLevelFeatures
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatBoostLevelFeatures({required bool isChannel, required int level})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isChannel → bool
-
isChannel Pass true to get the list of features for channels; pass false
to get the list of features for supergroups
final
- level → int
-
level Chat boost level
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isChannel, int? level}) → GetChatBoostLevelFeatures -
Available on GetChatBoostLevelFeatures, provided by the GetChatBoostLevelFeaturesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String