GetChatBoostLink class final

Returns an HTTPS link to boost the specified supergroup or channel chat Returns ChatBoostLink

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatBoostLink({required int chatId})

Properties

chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatBoostLink

Available on GetChatBoostLink, provided by the GetChatBoostLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String