GetChatBoostLinkInfo class final

Returns information about a link to boost a chat. Can be called for any internal link of the type internalLinkTypeChatBoost Returns ChatBoostLinkInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatBoostLinkInfo({required String url})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The link to boost a chat
final

Methods

copyWith({String? url}) GetChatBoostLinkInfo

Available on GetChatBoostLinkInfo, provided by the GetChatBoostLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String