GetChatBoostStatus class final

Returns the current boost status for a supergroup or a channel chat Returns ChatBoostStatus

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatBoostStatus({required int chatId})

Properties

chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatBoostStatus

Available on GetChatBoostStatus, provided by the GetChatBoostStatusExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String