GetChatBoosts class final
Returns the list of boosts applied to a chat; requires administrator rights in the chat Returns FoundChatBoosts
- Inheritance
-
- Object
- TdFunction
- GetChatBoosts
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatBoosts({required int chatId, required bool onlyGiftCodes, required String offset, required int limit})
Properties
- chatId → int
-
chatId Identifier of the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of boosts to be returned; up to 100. For
optimal performance, the number of returned boosts can be smaller than the
specified limit
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- onlyGiftCodes → bool
-
onlyGiftCodes Pass true to receive only boosts received from gift codes
and giveaways created by the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? onlyGiftCodes, String? offset, int? limit}) → GetChatBoosts -
Available on GetChatBoosts, provided by the GetChatBoostsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String