limit property

int limit
final

limit The maximum number of boosts to be returned; up to 100. For optimal performance, the number of returned boosts can be smaller than the specified limit

Implementation

final int limit;