onlyGiftCodes property
onlyGiftCodes Pass true to receive only boosts received from gift codes and giveaways created by the chat
Implementation
final bool onlyGiftCodes;
onlyGiftCodes Pass true to receive only boosts received from gift codes and giveaways created by the chat
final bool onlyGiftCodes;