GetChatEventLog class final
Returns a list of service actions taken by chat members and administrators in the last 48 hours. Available only in supergroups and channels. Requires administrator rights. Returns results in reverse chronological order (i.e., in order of decreasing event_id) Returns ChatEvents
- Inheritance
-
- Object
- TdFunction
- GetChatEventLog
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GetChatEventLog({required int chatId, required String query, required int fromEventId, required int limit, ChatEventLogFilters? filters, required List<
int> userIds})
Properties
- chatId → int
-
chatId Chat identifier
final
- filters → ChatEventLogFilters?
-
filters The types of events to return; pass null to get chat events of
all types
final
- fromEventId → int
-
fromEventId Identifier of an event from which to return results. Use 0
to get results from the latest events
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of events to return; up to 100
final
- query → String
-
query Search query by which to filter events
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
int> -
userIds User identifiers by which to filter events. By default, events
relating to all users will be returned
final
Methods
-
copyWith(
{int? chatId, String? query, int? fromEventId, int? limit, ChatEventLogFilters? filters, List< int> ? userIds}) → GetChatEventLog -
Available on GetChatEventLog, provided by the GetChatEventLogExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String