GetChatFolderDefaultIconName class final

Returns default icon name for a folder. Can be called synchronously Returns ChatFolderIcon

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatFolderDefaultIconName({ChatFolder? folder})

Properties

folder ChatFolder?
folder Chat folder
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatFolder? folder}) GetChatFolderDefaultIconName

Available on GetChatFolderDefaultIconName, provided by the GetChatFolderDefaultIconNameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String