GetChatFolderInviteLinks class final

Returns invite links created by the current user for a shareable chat folder Returns ChatFolderInviteLinks

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatFolderInviteLinks({required int chatFolderId})

Properties

chatFolderId int
chatFolderId Chat folder identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId}) GetChatFolderInviteLinks

Available on GetChatFolderInviteLinks, provided by the GetChatFolderInviteLinksExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String