GetChatHistory class final

Returns messages in a chat. The messages are returned in reverse chronological order (i.e., in order of decreasing message_id). For optimal performance, the number of returned messages is chosen by TDLib. This is an offline method if only_local is true Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatHistory({required int chatId, required int fromMessageId, required int offset, required int limit, required bool onlyLocal})

Properties

chatId int
chatId Chat identifier
final
fromMessageId int
fromMessageId Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, then the limit must be greater than or equal to -offset. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset int
offset Specify 0 to get results from exactly the message from_message_id or a negative number from -99 to -1 to get additionally -offset newer messages
final
onlyLocal bool
onlyLocal Pass true to get only messages that are available without sending network requests
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? fromMessageId, int? offset, int? limit, bool? onlyLocal}) GetChatHistory

Available on GetChatHistory, provided by the GetChatHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String