GetChatInviteLink class final

Returns information about an invite link. Requires administrator privileges and can_invite_users right in the chat to get own links and owner privileges to get other links Returns ChatInviteLink

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatInviteLink({required int chatId, required String inviteLink})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link to get
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink}) GetChatInviteLink

Available on GetChatInviteLink, provided by the GetChatInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String