GetChatInviteLinkCounts class final

Returns the list of chat administrators with number of their invite links. Requires owner privileges in the chat Returns ChatInviteLinkCounts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatInviteLinkCounts({required int chatId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatInviteLinkCounts

Available on GetChatInviteLinkCounts, provided by the GetChatInviteLinkCountsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String