GetChatInviteLinkMembers class final

Returns chat members joined a chat via an invite link. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links Returns ChatInviteLinkMembers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatInviteLinkMembers({required int chatId, required String inviteLink, required bool onlyWithExpiredSubscription, ChatInviteLinkMember? offsetMember, required int limit})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link for which to return chat members
final
limit int
limit The maximum number of chat members to return; up to 100
final
offsetMember ChatInviteLinkMember?
offsetMember A chat member from which to return next chat members; pass null to get results from the beginning
final
onlyWithExpiredSubscription bool
onlyWithExpiredSubscription Pass true if the link is a subscription link and only members with expired subscription must be returned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink, bool? onlyWithExpiredSubscription, ChatInviteLinkMember? offsetMember, int? limit}) GetChatInviteLinkMembers

Available on GetChatInviteLinkMembers, provided by the GetChatInviteLinkMembersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String