GetChatInviteLinks class final

Returns invite links for a chat created by specified administrator. Requires administrator privileges and can_invite_users right in the chat to get own links and owner privileges to get other links Returns ChatInviteLinks

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatInviteLinks({required int chatId, required int creatorUserId, required bool isRevoked, required int offsetDate, required String offsetInviteLink, required int limit})

Properties

chatId int
chatId Chat identifier
final
creatorUserId int
creatorUserId User identifier of a chat administrator. Must be an identifier of the current user for non-owner
final
hashCode int
The hash code for this object.
no setteroverride
isRevoked bool
isRevoked Pass true if revoked links need to be returned instead of active or expired
final
limit int
limit The maximum number of invite links to return; up to 100
final
offsetDate int
offsetDate Creation date of an invite link starting after which to return invite links; use 0 to get results from the beginning
final
offsetInviteLink Invite link starting after which to return invite links; use empty string to get results from the beginning
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? creatorUserId, bool? isRevoked, int? offsetDate, String? offsetInviteLink, int? limit}) GetChatInviteLinks

Available on GetChatInviteLinks, provided by the GetChatInviteLinksExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String