GetChatMember class final

Returns information about a single member of a chat Returns ChatMember

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatMember({required int chatId, MessageSender? memberId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
memberId MessageSender?
memberId Member identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, MessageSender? memberId}) GetChatMember

Available on GetChatMember, provided by the GetChatMemberExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String