GetChatMessageByDate class final

Returns the last message sent in a chat no later than the specified date. Returns a 404 error if such message doesn't exist Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatMessageByDate({required int chatId, required int date})

Properties

chatId int
chatId Chat identifier
final
date int
date Point in time (Unix timestamp) relative to which to search for messages
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? date}) GetChatMessageByDate

Available on GetChatMessageByDate, provided by the GetChatMessageByDateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String