GetChatMessageCalendar class final

Returns information about the next messages of the specified type in the chat split by days. Returns the results in reverse chronological order. Can return partial result for the last returned day. Behavior of this method depends on the value of the option "utc_time_offset" Returns MessageCalendar

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatMessageCalendar({required int chatId, MessageTopic? topicId, SearchMessagesFilter? filter, required int fromMessageId})

Properties

chatId int
chatId Identifier of the chat in which to return information about messages
final
filter SearchMessagesFilter?
filter Filter for message content. Filters searchMessagesFilterEmpty, searchMessagesFilterMention, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterUnreadPollVote are unsupported in this function
final
fromMessageId int
fromMessageId The message identifier from which to return information about messages; use 0 to get results from the last message
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId MessageTopic?
topicId Pass topic identifier to get the result only in specific topic; pass null to get the result in all topics; forum topics and message threads aren't supported
final

Methods

copyWith({int? chatId, MessageTopic? topicId, SearchMessagesFilter? filter, int? fromMessageId}) GetChatMessageCalendar

Available on GetChatMessageCalendar, provided by the GetChatMessageCalendarExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String