topicId property

MessageTopic? topicId
final

topicId Pass topic identifier to get the result only in specific topic; pass null to get the result in all topics; forum topics and message threads aren't supported

Implementation

final MessageTopic? topicId;