topicId property
topicId Pass topic identifier to get number of messages only in specific topic; pass null to get number of messages in all topics; message threads aren't supported
Implementation
final MessageTopic? topicId;
topicId Pass topic identifier to get number of messages only in specific topic; pass null to get number of messages in all topics; message threads aren't supported
final MessageTopic? topicId;