GetChatMessagePosition class final
Returns approximate 1-based position of a message among messages, which can be found by the specified filter in the chat and topic. Cannot be used in secret chats Returns Count
- Inheritance
-
- Object
- TdFunction
- GetChatMessagePosition
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatMessagePosition({required int chatId, MessageTopic? topicId, SearchMessagesFilter? filter, required int messageId})
Properties
- chatId → int
-
chatId Identifier of the chat in which to find message position
final
- filter → SearchMessagesFilter?
-
filter Filter for message content; searchMessagesFilterEmpty,
searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction,
searchMessagesFilterUnreadPollVote, and searchMessagesFilterFailedToSend
are unsupported in this function
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Message identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Pass topic identifier to get position among messages only in
specific topic; pass null to get position among all chat messages; message
threads aren't supported
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, SearchMessagesFilter? filter, int? messageId}) → GetChatMessagePosition -
Available on GetChatMessagePosition, provided by the GetChatMessagePositionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String