topicId property

MessageTopic? topicId
final

topicId Pass topic identifier to get position among messages only in specific topic; pass null to get position among all chat messages; message threads aren't supported

Implementation

final MessageTopic? topicId;