GetChatNotificationSettingsExceptions class final

Returns the list of chats with non-default notification settings for new messages Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatNotificationSettingsExceptions({NotificationSettingsScope? scope, required bool compareSound})

Properties

compareSound bool
compareSound Pass true to include in the response chats with only non-default sound
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope NotificationSettingsScope?
scope If specified, only chats from the scope will be returned; pass null to return chats from all scopes
final

Methods

copyWith({NotificationSettingsScope? scope, bool? compareSound}) GetChatNotificationSettingsExceptions

Available on GetChatNotificationSettingsExceptions, provided by the GetChatNotificationSettingsExceptionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String