GetChatPinnedMessage class final

Returns information about a newest pinned message in the chat. Returns a 404 error if the message doesn't exist Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatPinnedMessage({required int chatId})

Properties

chatId int
chatId Identifier of the chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatPinnedMessage

Available on GetChatPinnedMessage, provided by the GetChatPinnedMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String