GetChatPostedToChatPageStories class final

Returns the list of stories that posted by the given chat to its chat page. If from_story_id == 0, then pinned stories are returned first. Then, stories are returned in reverse chronological order (i.e., in order of decreasing story_id). For optimal performance, the number of returned stories is chosen by TDLib Returns Stories

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatPostedToChatPageStories({required int chatId, required int fromStoryId, required int limit})

Properties

chatId int
chatId Chat identifier
final
fromStoryId int
fromStoryId Identifier of the story starting from which stories must be returned; use 0 to get results from pinned and the newest story
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of stories to be returned. For optimal performance, the number of returned stories is chosen by TDLib and can be smaller than the specified limit
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? fromStoryId, int? limit}) GetChatPostedToChatPageStories

Available on GetChatPostedToChatPageStories, provided by the GetChatPostedToChatPageStoriesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String