GetChatRevenueStatistics class final
Returns detailed revenue statistics about a chat. Currently, this method can be used only for channels if supergroupFullInfo.can_get_revenue_statistics == true or bots if userFullInfo.bot_info.can_get_revenue_statistics == true Returns ChatRevenueStatistics
- Inheritance
-
- Object
- TdFunction
- GetChatRevenueStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatRevenueStatistics({required int chatId, required bool isDark})
Properties
Methods
-
copyWith(
{int? chatId, bool? isDark}) → GetChatRevenueStatistics -
Available on GetChatRevenueStatistics, provided by the GetChatRevenueStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String