returnLocal property
returnLocal Pass true to get the number of chats without sending network requests, or -1 if the number of chats is unknown locally
Implementation
final bool returnLocal;
returnLocal Pass true to get the number of chats without sending network requests, or -1 if the number of chats is unknown locally
final bool returnLocal;