GetChatSimilarChats class final

Returns a list of chats similar to the given chat Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatSimilarChats({required int chatId})

Properties

chatId int
chatId Identifier of the target chat; must be an identifier of a channel chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetChatSimilarChats

Available on GetChatSimilarChats, provided by the GetChatSimilarChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String