GetChatSparseMessagePositions class final

Returns sparse positions of messages of the specified type in the chat to be used for Shared Media scroll implementation. Returns the results in reverse chronological order (i.e., in order of decreasing message_id). Cannot be used in secret chats or with searchMessagesFilterFailedToSend filter without an enabled message database Returns MessagePositions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatSparseMessagePositions({required int chatId, SearchMessagesFilter? filter, required int fromMessageId, required int limit, required int savedMessagesTopicId})

Properties

chatId int
chatId Identifier of the chat in which to return information about message positions
final
filter SearchMessagesFilter?
filter Filter for message content. Filters searchMessagesFilterEmpty, searchMessagesFilterMention, searchMessagesFilterUnreadMention, searchMessagesFilterUnreadReaction, and searchMessagesFilterUnreadPollVote are unsupported in this function
final
fromMessageId int
fromMessageId The message identifier from which to return information about message positions
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The expected number of message positions to be returned; 50-2000. A smaller number of positions can be returned, if there are not enough appropriate messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all messages, or for chats other than Saved Messages
final

Methods

copyWith({int? chatId, SearchMessagesFilter? filter, int? fromMessageId, int? limit, int? savedMessagesTopicId}) GetChatSparseMessagePositions

Available on GetChatSparseMessagePositions, provided by the GetChatSparseMessagePositionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String