GetChatStatistics class final

Returns detailed statistics about a chat. Currently, this method can be used only for supergroups and channels. Can be used only if supergroupFullInfo.can_get_statistics == true Returns ChatStatistics

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatStatistics({required int chatId, required bool isDark})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
isDark bool
isDark Pass true if a dark theme is used by the application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isDark}) GetChatStatistics

Available on GetChatStatistics, provided by the GetChatStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String