GetChatStoryAlbums class final
Returns the list of story albums owned by the given chat Returns StoryAlbums
- Inheritance
-
- Object
- TdFunction
- GetChatStoryAlbums
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatStoryAlbums({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetChatStoryAlbums -
Available on GetChatStoryAlbums, provided by the GetChatStoryAlbumsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String