GetChatStoryInteractions class final

Returns interactions with a story posted in a chat. Can be used only if story is posted on behalf of a chat and the user is an administrator in the chat Returns StoryInteractions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatStoryInteractions({required int storyPosterChatId, required int storyId, ReactionType? reactionType, required bool preferForwards, required String offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of story interactions to return
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
preferForwards bool
preferForwards Pass true to get forwards and reposts first, then reactions, then other views; pass false to get interactions sorted just by interaction date
final
reactionType ReactionType?
reactionType Pass the default heart reaction or a suggested reaction type to receive only interactions with the specified reaction type; pass null to receive all interactions; reactionTypePaid isn't supported
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Story identifier
final
storyPosterChatId int
storyPosterChatId The identifier of the poster of the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId, ReactionType? reactionType, bool? preferForwards, String? offset, int? limit}) GetChatStoryInteractions

Available on GetChatStoryInteractions, provided by the GetChatStoryInteractionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String