reactionType property

ReactionType? reactionType
final

reactionType Pass the default heart reaction or a suggested reaction type to receive only interactions with the specified reaction type; pass null to receive all interactions; reactionTypePaid isn't supported

Implementation

final ReactionType? reactionType;