GetChats class final

Returns an ordered list of chats from the beginning of a chat list. For informational purposes only. Use loadChats and updates processing instead to maintain chat lists in a consistent state Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChats({ChatList? chatList, required int limit})

Properties

chatList ChatList?
chatList The chat list in which to return chats; pass null to get chats from the main chat list
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of chats to be returned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList, int? limit}) GetChats

Available on GetChats, provided by the GetChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String