GetCollectibleItemInfo class final

Returns information about a given collectible item that was purchased at https://fragment.com Returns CollectibleItemInfo

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type CollectibleItemType?
type Type of the collectible item. The item must be used by a user and must be visible to the current user
final

Methods

copyWith({CollectibleItemType? type}) GetCollectibleItemInfo

Available on GetCollectibleItemInfo, provided by the GetCollectibleItemInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String