type property
type Type of the collectible item. The item must be used by a user and must be visible to the current user
Implementation
final CollectibleItemType? type;
type Type of the collectible item. The item must be used by a user and must be visible to the current user
final CollectibleItemType? type;