GetCommands class final

Returns the list of commands supported by the bot for the given user scope and language; for bots only Returns BotCommands

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCommands({BotCommandScope? scope, required String languageCode})

Properties

hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode A two-letter ISO 639-1 language code or an empty string
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope BotCommandScope?
scope The scope to which the commands are relevant; pass null to get commands in the default bot command scope
final

Methods

copyWith({BotCommandScope? scope, String? languageCode}) GetCommands

Available on GetCommands, provided by the GetCommandsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String