GetConnectedAffiliateProgram class final

Returns an affiliate program that was connected to the given affiliate by identifier of the bot that created the program Returns ConnectedAffiliateProgram

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetConnectedAffiliateProgram({AffiliateType? affiliate, required int botUserId})

Properties

affiliate AffiliateType?
affiliate The affiliate to which the affiliate program will be connected
final
botUserId int
botUserId Identifier of the bot that created the program
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AffiliateType? affiliate, int? botUserId}) GetConnectedAffiliateProgram

Available on GetConnectedAffiliateProgram, provided by the GetConnectedAffiliateProgramExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String