GetConnectedAffiliatePrograms class final

Returns affiliate programs that were connected to the given affiliate Returns ConnectedAffiliatePrograms

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetConnectedAffiliatePrograms({AffiliateType? affiliate, required String offset, required int limit})

Properties

affiliate AffiliateType?
affiliate The affiliate to which the affiliate programs were connected
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of affiliate programs to return
final
offset String
offset Offset of the first affiliate program to return as received from the previous request; use empty string to get the first chunk of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({AffiliateType? affiliate, String? offset, int? limit}) GetConnectedAffiliatePrograms

Available on GetConnectedAffiliatePrograms, provided by the GetConnectedAffiliateProgramsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String