GetCountryFlagEmoji class final

Returns an emoji for the flag of the given country. Returns an empty string on failure. Can be called synchronously Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCountryFlagEmoji({required String countryCode})

Properties

countryCode String
countryCode A two-letter ISO 3166-1 alpha-2 country code as received from getCountries
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? countryCode}) GetCountryFlagEmoji

Available on GetCountryFlagEmoji, provided by the GetCountryFlagEmojiExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String