GetCurrentWeather class final

Returns the current weather in the given location Returns CurrentWeather

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCurrentWeather({Location? location})

Properties

hashCode int
The hash code for this object.
no setteroverride
location Location?
location The location
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location}) GetCurrentWeather

Available on GetCurrentWeather, provided by the GetCurrentWeatherExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String