GetCustomEmojiStickers class final
Returns the list of custom emoji stickers by their identifiers. Stickers are returned in arbitrary order. Only found stickers are returned Returns Stickers
- Inheritance
-
- Object
- TdFunction
- GetCustomEmojiStickers
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GetCustomEmojiStickers({required List<
int> customEmojiIds})
Properties
-
customEmojiIds
→ List<
int> -
customEmojiIds Identifiers of custom emoji stickers. At most 200 custom
emoji stickers can be received simultaneously
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< int> ? customEmojiIds}) → GetCustomEmojiStickers -
Available on GetCustomEmojiStickers, provided by the GetCustomEmojiStickersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String