GetDeepLinkInfo class final

Returns information about a tg:// deep link. Use "tg://need_update_for_some_feature" or "tg:some_unsupported_feature" for testing. Returns a 404 error for unknown links. Can be called before authorization Returns DeepLinkInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetDeepLinkInfo({required String link})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link}) GetDeepLinkInfo

Available on GetDeepLinkInfo, provided by the GetDeepLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String