GetDirectMessagesChatTopicMessageByDate class final

Returns the last message sent in the topic in a channel direct messages chat administered by the current user no later than the specified date Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetDirectMessagesChatTopicMessageByDate({required int chatId, required int topicId, required int date})

Properties

chatId int
chatId Chat identifier of the channel direct messages chat
final
date int
date Point in time (Unix timestamp) relative to which to search for messages
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId int
topicId Identifier of the topic which messages will be fetched
final

Methods

copyWith({int? chatId, int? topicId, int? date}) GetDirectMessagesChatTopicMessageByDate

Available on GetDirectMessagesChatTopicMessageByDate, provided by the GetDirectMessagesChatTopicMessageByDateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String