GetEmojiReaction class final

Returns information about an emoji reaction. Returns a 404 error if the reaction is not found Returns EmojiReaction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetEmojiReaction({required String emoji})

Properties

emoji String
emoji Text representation of the reaction
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) GetEmojiReaction

Available on GetEmojiReaction, provided by the GetEmojiReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String