allowWriteAccess property
allowWriteAccess Pass true if the current user allowed the bot that was returned in getExternalLinkInfo, to send them messages
Implementation
final bool allowWriteAccess;
allowWriteAccess Pass true if the current user allowed the bot that was returned in getExternalLinkInfo, to send them messages
final bool allowWriteAccess;