GetFile class final

Returns information about a file. This is an offline method Returns File

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetFile({required int fileId})

Properties

fileId int
fileId Identifier of the file to get
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId}) GetFile

Available on GetFile, provided by the GetFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String