GetFileDownloadedPrefixSize class final
Returns file downloaded prefix size from a given offset, in bytes Returns FileDownloadedPrefixSize
- Inheritance
-
- Object
- TdFunction
- GetFileDownloadedPrefixSize
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetFileDownloadedPrefixSize({required int fileId, required int offset})
Properties
Methods
-
copyWith(
{int? fileId, int? offset}) → GetFileDownloadedPrefixSize -
Available on GetFileDownloadedPrefixSize, provided by the GetFileDownloadedPrefixSizeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String