GetFileExtension class final

Returns the extension of a file, guessed by its MIME type. Returns an empty string on failure. Can be called synchronously Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetFileExtension({required String mimeType})

Properties

hashCode int
The hash code for this object.
no setteroverride
mimeType String
mimeType The MIME type of the file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? mimeType}) GetFileExtension

Available on GetFileExtension, provided by the GetFileExtensionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String