GetFileMimeType class final

Returns the MIME type of a file, guessed by its extension. Returns an empty string on failure. Can be called synchronously Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetFileMimeType({required String fileName})

Properties

fileName String
fileName The name of the file or path to the file
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? fileName}) GetFileMimeType

Available on GetFileMimeType, provided by the GetFileMimeTypeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String