GetForumTopicHistory class final

Returns messages in a topic in a forum supergroup chat or a chat with a bot with topics. The messages are returned in reverse chronological order (i.e., in order of decreasing message_id). For optimal performance, the number of returned messages is chosen by TDLib Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetForumTopicHistory({required int chatId, required int forumTopicId, required int fromMessageId, required int offset, required int limit})

Properties

chatId int
chatId Chat identifier
final
forumTopicId int
forumTopicId Forum topic identifier
final
fromMessageId int
fromMessageId Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, then the limit must be greater than or equal to -offset. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset int
offset Specify 0 to get results from exactly the message from_message_id or a negative number from -99 to -1 to get additionally -offset newer messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId, int? fromMessageId, int? offset, int? limit}) GetForumTopicHistory

Available on GetForumTopicHistory, provided by the GetForumTopicHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String