GetForumTopicLink class final

Returns an HTTPS link to a topic in a forum supergroup chat. This is an offline method Returns MessageLink

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetForumTopicLink({required int chatId, required int forumTopicId})

Properties

chatId int
chatId Identifier of the chat
final
forumTopicId int
forumTopicId Forum topic identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId}) GetForumTopicLink

Available on GetForumTopicLink, provided by the GetForumTopicLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String