offsetForumTopicId property
offsetForumTopicId The forum topic identifier of the last found topic, or 0 for the first request
Implementation
final int offsetForumTopicId;
offsetForumTopicId The forum topic identifier of the last found topic, or 0 for the first request
final int offsetForumTopicId;