GetGameHighScores class final

Returns the high scores for a game and some part of the high score table in the range of the specified user; for bots only Returns GameHighScores

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGameHighScores({required int chatId, required int messageId, required int userId})

Properties

chatId int
chatId The chat that contains the message with the game
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? chatId, int? messageId, int? userId}) GetGameHighScores

Available on GetGameHighScores, provided by the GetGameHighScoresExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String