GetGiftAuctionAcquiredGifts class final

Returns the gifts that were acquired by the current user on a gift auction Returns GiftAuctionAcquiredGifts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGiftAuctionAcquiredGifts({required int giftId})

Properties

giftId int
giftId Identifier of the auctioned gift
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? giftId}) GetGiftAuctionAcquiredGifts

Available on GetGiftAuctionAcquiredGifts, provided by the GetGiftAuctionAcquiredGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String