GetGiftAuctionState class final

Returns auction state for a gift Returns GiftAuctionState

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGiftAuctionState({required String auctionId})

Properties

auctionId String
auctionId Unique identifier of the auction
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? auctionId}) GetGiftAuctionState

Available on GetGiftAuctionState, provided by the GetGiftAuctionStateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String