GetGiftsForCrafting class final

Returns upgraded gifts of the current user who can be used to craft another gifts Returns GiftsForCrafting

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGiftsForCrafting({required int regularGiftId, required String offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of gifts to be returned; must be positive and can't be greater than 100. For optimal performance, the number of returned objects is chosen by TDLib and can be smaller than the specified limit
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
regularGiftId int
regularGiftId Identifier of the regular gift that will be used for crafting
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? regularGiftId, String? offset, int? limit}) GetGiftsForCrafting

Available on GetGiftsForCrafting, provided by the GetGiftsForCraftingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String