GetGiveawayInfo class final

Returns information about a giveaway Returns GiveawayInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGiveawayInfo({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the channel chat which started the giveaway
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the giveaway or a giveaway winners message in the chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) GetGiveawayInfo

Available on GetGiveawayInfo, provided by the GetGiveawayInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String