GetGramWithdrawalUrl class final

Returns a URL for TON Gram withdrawal from the current user's account. The user must have at least 10 Grams to withdraw and can withdraw up to 100000 Grams in one transaction Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGramWithdrawalUrl({required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password of the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? password}) GetGramWithdrawalUrl

Available on GetGramWithdrawalUrl, provided by the GetGramWithdrawalUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String