GetInlineQueryResults class final

Sends an inline query to a bot and returns its results. Returns an error with code 502 if the bot fails to answer the query before the query timeout expires Returns InlineQueryResults

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetInlineQueryResults({required int botUserId, required int chatId, Location? userLocation, required String query, required String offset})

Properties

botUserId int
botUserId Identifier of the target bot
final
chatId int
chatId Identifier of the chat where the query was sent
final
hashCode int
The hash code for this object.
no setteroverride
offset String
offset Offset of the first entry to return; use empty string to get the first chunk of results
final
query String
query Text of the query
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userLocation Location?
userLocation Location of the user; pass null if unknown or the bot doesn't need user's location
final

Methods

copyWith({int? botUserId, int? chatId, Location? userLocation, String? query, String? offset}) GetInlineQueryResults

Available on GetInlineQueryResults, provided by the GetInlineQueryResultsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String