GetInstalledStickerSets class final
Returns a list of installed sticker sets Returns StickerSets
- Inheritance
-
- Object
- TdFunction
- GetInstalledStickerSets
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetInstalledStickerSets({StickerType? stickerType})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the sticker sets to return
final
Methods
-
copyWith(
{StickerType? stickerType}) → GetInstalledStickerSets -
Available on GetInstalledStickerSets, provided by the GetInstalledStickerSetsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String