GetInternalLink class final
Returns an HTTPS or a tg: link with the given type. Can be called before authorization Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetInternalLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetInternalLink({InternalLinkType? type, required bool isHttp})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isHttp → bool
-
isHttp Pass true to create an HTTPS link (only available for some link
types); pass false to create a tg: link
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → InternalLinkType?
-
type Expected type of the link
final
Methods
-
copyWith(
{InternalLinkType? type, bool? isHttp}) → GetInternalLink -
Available on GetInternalLink, provided by the GetInternalLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String