GetInternalLinkType class final

Returns information about the type of internal link. Returns a 404 error if the link is not internal. Can be called before authorization Returns InternalLinkType

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetInternalLinkType({required String link})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link}) GetInternalLinkType

Available on GetInternalLinkType, provided by the GetInternalLinkTypeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String