GetJsonString class final

Converts a JsonValue object to corresponding JSON-serialized string. Can be called synchronously Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetJsonString({JsonValue? jsonValue})

Properties

hashCode int
The hash code for this object.
no setteroverride
jsonValue JsonValue?
jsonValue The JsonValue object
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({JsonValue? jsonValue}) GetJsonString

Available on GetJsonString, provided by the GetJsonStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String