GetJsonValue class final

Converts a JSON-serialized string to corresponding JsonValue object. Can be called synchronously Returns JsonValue

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetJsonValue({required String json})

Properties

hashCode int
The hash code for this object.
no setteroverride
json String
json The JSON-serialized string
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? json}) GetJsonValue

Available on GetJsonValue, provided by the GetJsonValueExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String