GetKeywordEmojis class final

Returns emojis matching the keyword. Supported only if the file database is enabled. Order of results is unspecified Returns Emojis

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetKeywordEmojis({required String text, required List<String> inputLanguageCodes})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputLanguageCodes List<String>
inputLanguageCodes List of possible IETF language tags of the user's input language; may be empty if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text Text to search for
final

Methods

copyWith({String? text, List<String>? inputLanguageCodes}) GetKeywordEmojis

Available on GetKeywordEmojis, provided by the GetKeywordEmojisExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String