GetLanguagePackString class final

Returns a string stored in the local database from the specified localization target and language pack by its key. Returns a 404 error if the string is not found. Can be called synchronously Returns LanguagePackStringValue

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetLanguagePackString({required String languagePackDatabasePath, required String localizationTarget, required String languagePackId, required String key})

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
key Language pack key of the string to be returned
final
languagePackDatabasePath String
languagePackDatabasePath Path to the language pack database in which strings are stored
final
languagePackId String
languagePackId Language pack identifier
final
localizationTarget String
localizationTarget Localization target to which the language pack belongs
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackDatabasePath, String? localizationTarget, String? languagePackId, String? key}) GetLanguagePackString

Available on GetLanguagePackString, provided by the GetLanguagePackStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String