GetLinkWebBrowserType class final
Returns a type of the web browser which must be used to open the link Returns WebBrowserType
- Inheritance
-
- Object
- TdFunction
- GetLinkWebBrowserType
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetLinkWebBrowserType({required String link})
Properties
Methods
-
copyWith(
{String? link}) → GetLinkWebBrowserType -
Available on GetLinkWebBrowserType, provided by the GetLinkWebBrowserTypeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String