GetLiveStoryTopDonors class final

Returns the list of top live story donors Returns LiveStoryDonors

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetLiveStoryTopDonors({required int groupCallId})

Properties

groupCallId int
groupCallId Group call identifier of the live story
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId}) GetLiveStoryTopDonors

Available on GetLiveStoryTopDonors, provided by the GetLiveStoryTopDonorsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String