GetLoginUrl class final

Returns an HTTP URL which can be used to automatically authorize the user on a website after clicking an inline button of type inlineKeyboardButtonTypeLoginUrl. Use the method getLoginUrlInfo to find whether a prior user confirmation is needed. If an error is returned, then the button must be handled as an ordinary URL button Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetLoginUrl({required int chatId, required int messageId, required int buttonId, required bool allowWriteAccess})

Properties

allowWriteAccess bool
allowWriteAccess Pass true to allow the bot to send messages to the current user. Phone number access can't be requested using the button
final
buttonId int
buttonId Button identifier
final
chatId int
chatId Chat identifier of the message with the button
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier of the message with the button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? buttonId, bool? allowWriteAccess}) GetLoginUrl

Available on GetLoginUrl, provided by the GetLoginUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String