allowWriteAccess property
allowWriteAccess Pass true to allow the bot to send messages to the current user. Phone number access can't be requested using the button
Implementation
final bool allowWriteAccess;
allowWriteAccess Pass true to allow the bot to send messages to the current user. Phone number access can't be requested using the button
final bool allowWriteAccess;