GetLoginUrlInfo class final

Returns information about a button of type inlineKeyboardButtonTypeLoginUrl. The method needs to be called when the user presses the button Returns LoginUrlInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetLoginUrlInfo({required int chatId, required int messageId, required int buttonId})

Properties

buttonId int
buttonId Button identifier
final
chatId int
chatId Chat identifier of the message with the button
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier of the message with the button. The message must not be scheduled
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? buttonId}) GetLoginUrlInfo

Available on GetLoginUrlInfo, provided by the GetLoginUrlInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String