GetMainWebApp class final

Returns information needed to open the main Web App of a bot Returns MainWebApp

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMainWebApp({required int chatId, required int botUserId, required String startParameter, WebAppOpenParameters? parameters})

Properties

botUserId int
botUserId Identifier of the target bot. If the bot is restricted for the current user, then show an error instead of calling the method
final
chatId int
chatId Identifier of the chat in which the Web App is opened; pass 0 if none
final
hashCode int
The hash code for this object.
no setteroverride
parameters WebAppOpenParameters?
parameters Parameters to use to open the Web App
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startParameter String
startParameter Start parameter from internalLinkTypeMainWebApp
final

Methods

copyWith({int? chatId, int? botUserId, String? startParameter, WebAppOpenParameters? parameters}) GetMainWebApp

Available on GetMainWebApp, provided by the GetMainWebAppExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String