GetManagedBotToken class final

Returns token of a managed bot; for bots only Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetManagedBotToken({required int botUserId, required bool revoke})

Properties

botUserId int
botUserId Identifier of the managed bot
final
hashCode int
The hash code for this object.
no setteroverride
revoke bool
revoke Pass true to revoke the current token and create a new one
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, bool? revoke}) GetManagedBotToken

Available on GetManagedBotToken, provided by the GetManagedBotTokenExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String