GetMapThumbnailFile class final
Returns information about a file with a map thumbnail in PNG format. Only map thumbnail files with size less than 1MB can be downloaded Returns File
- Inheritance
-
- Object
- TdFunction
- GetMapThumbnailFile
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Identifier of a chat in which the thumbnail will be shown. Use 0
if unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Map height in pixels before applying scale; 16-1024
final
- location → Location?
-
location Location of the map center
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → int
-
scale Map scale; 1-3
final
- width → int
-
width Map width in pixels before applying scale; 16-1024
final
- zoom → int
-
zoom Map zoom level; 13-20
final
Methods
-
copyWith(
{Location? location, int? zoom, int? width, int? height, int? scale, int? chatId}) → GetMapThumbnailFile -
Available on GetMapThumbnailFile, provided by the GetMapThumbnailFileExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String