GetMarkdownText class final

Replaces text entities with Markdown formatting in a human-friendly format. Entities that can't be represented in Markdown unambiguously are kept as is. Can be called synchronously Returns FormattedText

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMarkdownText({FormattedText? text})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text The text
final

Methods

copyWith({FormattedText? text}) GetMarkdownText

Available on GetMarkdownText, provided by the GetMarkdownTextExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String