GetMenuButton class final

Returns menu button set by the bot for the given user; for bots only Returns BotMenuButton

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMenuButton({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user or 0 to get the default menu button
final

Methods

copyWith({int? userId}) GetMenuButton

Available on GetMenuButton, provided by the GetMenuButtonExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String