GetMessageAddedReactions class final

Returns reactions added for a message, along with their sender Returns AddedReactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageAddedReactions({required int chatId, required int messageId, ReactionType? reactionType, required String offset, required int limit})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of reactions to be returned; must be positive and can't be greater than 100
final
messageId int
messageId Identifier of the message. Use message.interaction_info.reactions.can_get_added_reactions to check whether added reactions can be received for the message
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
reactionType ReactionType?
reactionType Type of the reactions to return; pass null to return all added reactions; reactionTypePaid isn't supported
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReactionType? reactionType, String? offset, int? limit}) GetMessageAddedReactions

Available on GetMessageAddedReactions, provided by the GetMessageAddedReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String