GetMessageEffect class final
Returns information about a message effect. Returns a 404 error if the effect is not found Returns MessageEffect
- Inheritance
-
- Object
- TdFunction
- GetMessageEffect
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMessageEffect({required int effectId})
Properties
Methods
-
copyWith(
{int? effectId}) → GetMessageEffect -
Available on GetMessageEffect, provided by the GetMessageEffectExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String