GetMessageImportConfirmationText class final

Returns a confirmation text to be shown to the user before starting message import Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageImportConfirmationText({required int chatId})

Properties

chatId int
chatId Identifier of a chat to which the messages will be imported. It must be an identifier of a private chat with a mutual contact or an identifier of a supergroup chat with can_change_info member right
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) GetMessageImportConfirmationText

Available on GetMessageImportConfirmationText, provided by the GetMessageImportConfirmationTextExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String