checklistTaskId property
checklistTaskId If not 0, identifier of the checklist task in the message to be linked
Implementation
final int checklistTaskId;
checklistTaskId If not 0, identifier of the checklist task in the message to be linked
final int checklistTaskId;