pollOptionId property
pollOptionId If not empty, identifier of the poll option in the message to be linked
Implementation
final String pollOptionId;
pollOptionId If not empty, identifier of the poll option in the message to be linked
final String pollOptionId;