GetMessageLocally class final
Returns information about a message, if it is available without sending network request. Returns a 404 error if message isn't available locally. This is an offline method Returns Message
- Inheritance
-
- Object
- TdFunction
- GetMessageLocally
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMessageLocally({required int chatId, required int messageId})
Properties
Methods
-
copyWith(
{int? chatId, int? messageId}) → GetMessageLocally -
Available on GetMessageLocally, provided by the GetMessageLocallyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String