GetMessagePublicForwards class final
Returns forwarded copies of a channel message to different public channels and public reposts as a story. Can be used only if messageProperties.can_get_statistics == true. For optimal performance, the number of returned messages and stories is chosen by TDLib Returns PublicForwards
- Inheritance
-
- Object
- TdFunction
- GetMessagePublicForwards
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMessagePublicForwards({required int chatId, required int messageId, required String offset, required int limit})
Properties
- chatId → int
-
chatId Chat identifier of the message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of messages and stories to be returned; must be
positive and can't be greater than 100. For optimal performance, the
number of returned objects is chosen by TDLib and can be smaller than the
specified limit
final
- messageId → int
-
messageId Message identifier
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, String? offset, int? limit}) → GetMessagePublicForwards -
Available on GetMessagePublicForwards, provided by the GetMessagePublicForwardsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String