GetMessageReadDate class final

Returns read date of a recent outgoing message in a private chat. The method can be called if messageProperties.can_get_read_date == true Returns MessageReadDate

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageReadDate({required int chatId, required int messageId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) GetMessageReadDate

Available on GetMessageReadDate, provided by the GetMessageReadDateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String