GetMessageStatistics class final

Returns detailed statistics about a message. Can be used only if messageProperties.can_get_statistics == true Returns MessageStatistics

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageStatistics({required int chatId, required int messageId, required bool isDark})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
isDark bool
isDark Pass true if a dark theme is used by the application
final
messageId int
messageId Message identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, bool? isDark}) GetMessageStatistics

Available on GetMessageStatistics, provided by the GetMessageStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String