GetMessages class final

Returns information about messages. If a message is not found, returns null on the corresponding position of the result Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessages({required int chatId, required List<int> messageIds})

Properties

chatId int
chatId Identifier of the chat the messages belong to
final
hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Identifiers of the messages to get
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? messageIds}) GetMessages

Available on GetMessages, provided by the GetMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String