inAppOrigin property
inAppOrigin Origin of the OAuth request if the request was received from the in-app browser; pass an empty string otherwise
Implementation
final String inAppOrigin;
inAppOrigin Origin of the OAuth request if the request was received from the in-app browser; pass an empty string otherwise
final String inAppOrigin;