GetOption class final
Returns the value of an option by its name. (Check the list of available options on https://core.telegram.org/tdlib/options.) Can be called before authorization. Can be called synchronously for options "version" and "commit_hash" Returns OptionValue
- Inheritance
-
- Object
- TdFunction
- GetOption
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{String? name}) → GetOption -
Available on GetOption, provided by the GetOptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String