GetPaidMessageRevenue class final

Returns the total number of Telegram Stars received by the current user for paid messages from the given user Returns StarCount

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPaidMessageRevenue({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId}) GetPaidMessageRevenue

Available on GetPaidMessageRevenue, provided by the GetPaidMessageRevenueExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String