GetPassportAuthorizationForm class final

Returns a Telegram Passport authorization form for sharing data with a service Returns PassportAuthorizationForm

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPassportAuthorizationForm({required int botUserId, required String scope, required String publicKey, required String nonce})

Properties

botUserId int
botUserId User identifier of the service's bot
final
hashCode int
The hash code for this object.
no setteroverride
nonce String
nonce Unique request identifier provided by the service
final
publicKey String
publicKey Service's public key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
scope Telegram Passport element types requested by the service
final

Methods

copyWith({int? botUserId, String? scope, String? publicKey, String? nonce}) GetPassportAuthorizationForm

Available on GetPassportAuthorizationForm, provided by the GetPassportAuthorizationFormExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String