GetPassportAuthorizationFormAvailableElements class final

Returns already available Telegram Passport elements suitable for completing a Telegram Passport authorization form. Result can be received only once for each authorization form Returns PassportElementsWithErrors

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPassportAuthorizationFormAvailableElements({required int authorizationFormId, required String password})

Properties

authorizationFormId int
authorizationFormId Authorization form identifier
final
hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password of the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? authorizationFormId, String? password}) GetPassportAuthorizationFormAvailableElements

Available on GetPassportAuthorizationFormAvailableElements, provided by the GetPassportAuthorizationFormAvailableElementsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String