GetPassportElement class final

Returns one of the available Telegram Passport elements Returns PassportElement

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPassportElement({PassportElementType? type, required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password The 2-step verification password of the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PassportElementType?
type Telegram Passport element type
final

Methods

copyWith({PassportElementType? type, String? password}) GetPassportElement

Available on GetPassportElement, provided by the GetPassportElementExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String