GetPaymentForm class final

Returns an invoice payment form. This method must be called when the user presses inline button of the type inlineKeyboardButtonTypeBuy, or wants to buy access to media in a messagePaidMedia message Returns PaymentForm

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPaymentForm({InputInvoice? inputInvoice, ThemeParameters? theme})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputInvoice InputInvoice?
inputInvoice The invoice
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme ThemeParameters?
theme Preferred payment form theme; pass null to use the default theme
final

Methods

copyWith({InputInvoice? inputInvoice, ThemeParameters? theme}) GetPaymentForm

Available on GetPaymentForm, provided by the GetPaymentFormExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String