GetPaymentReceipt class final

Returns information about a successful payment Returns PaymentReceipt

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPaymentReceipt({required int chatId, required int messageId})

Properties

chatId → int
chatId Chat identifier of the messagePaymentSuccessful message
final
hashCode → int
The hash code for this object.
no setteroverride
messageId → int
messageId Message identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) → GetPaymentReceipt

Available on GetPaymentReceipt, provided by the GetPaymentReceiptExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

constructor → const String