GetPersonalChatHistory class final

Returns messages in the personal chat of a given user; for bots only Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPersonalChatHistory({required int userId, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; 1-20
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, int? limit}) GetPersonalChatHistory

Available on GetPersonalChatHistory, provided by the GetPersonalChatHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String