GetPhoneNumberInfo class final

Returns information about a phone number by its prefix. Can be called before authorization Returns PhoneNumberInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPhoneNumberInfo({required String phoneNumberPrefix})

Properties

hashCode int
The hash code for this object.
no setteroverride
phoneNumberPrefix String
phoneNumberPrefix The phone number prefix
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? phoneNumberPrefix}) GetPhoneNumberInfo

Available on GetPhoneNumberInfo, provided by the GetPhoneNumberInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String