GetPollVoters class final
Returns message senders voted for the specified option in a poll; use poll.can_get_voters to check whether the method can be used. For optimal performance, the number of returned users is chosen by TDLib Returns PollVoters
- Inheritance
-
- Object
- TdFunction
- GetPollVoters
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Identifier of the chat to which the poll belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of voters to be returned; must be positive and
can't be greater than 50. For optimal performance, the number of returned
voters is chosen by TDLib and can be smaller than the specified limit,
even if the end of the voter list has not been reached
final
- messageId → int
-
messageId Identifier of the message containing the poll
final
- offset → int
-
offset Number of voters to skip in the result; must be non-negative
final
- optionId → int
-
optionId 0-based identifier of the answer option
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, int? optionId, int? offset, int? limit}) → GetPollVoters -
Available on GetPollVoters, provided by the GetPollVotersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String