GetPremiumFeatures class final

Returns information about features, available to Premium users Returns PremiumFeatures

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPremiumFeatures({PremiumSource? source})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source PremiumSource?
source Source of the request; pass null if the method is called from some non-standard source
final

Methods

copyWith({PremiumSource? source}) GetPremiumFeatures

Available on GetPremiumFeatures, provided by the GetPremiumFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String