GetPremiumGiveawayPaymentOptions class final

Returns available options for creating of Telegram Premium giveaway or manual distribution of Telegram Premium among chat members Returns PremiumGiveawayPaymentOptions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPremiumGiveawayPaymentOptions({required int boostedChatId})

Properties

boostedChatId int
boostedChatId Identifier of the supergroup or channel chat, which will be automatically boosted by receivers of the gift codes and which is administered by the user
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? boostedChatId}) GetPremiumGiveawayPaymentOptions

Available on GetPremiumGiveawayPaymentOptions, provided by the GetPremiumGiveawayPaymentOptionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String