boostedChatId property

int boostedChatId
final

boostedChatId Identifier of the supergroup or channel chat, which will be automatically boosted by receivers of the gift codes and which is administered by the user

Implementation

final int boostedChatId;