GetPremiumInfoSticker class final

Returns the sticker to be used as representation of the Telegram Premium subscription Returns Sticker

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPremiumInfoSticker({required int monthCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? monthCount}) GetPremiumInfoSticker

Available on GetPremiumInfoSticker, provided by the GetPremiumInfoStickerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String