GetPremiumLimit class final
Returns information about a limit, increased for Premium users. Returns a 404 error if the limit is unknown Returns PremiumLimit
- Inheritance
-
- Object
- TdFunction
- GetPremiumLimit
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetPremiumLimit({PremiumLimitType? limitType})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limitType → PremiumLimitType?
-
limitType Type of the limit
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PremiumLimitType? limitType}) → GetPremiumLimit -
Available on GetPremiumLimit, provided by the GetPremiumLimitExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String