GetPremiumStickers class final

Returns premium stickers from regular sticker sets Returns Stickers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPremiumStickers({required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of stickers to be returned; 0-100
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? limit}) GetPremiumStickers

Available on GetPremiumStickers, provided by the GetPremiumStickersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String