GetPreparedInlineMessage class final

Saves an inline message to be sent by the given user Returns PreparedInlineMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPreparedInlineMessage({required int botUserId, required String preparedMessageId})

Properties

botUserId int
botUserId Identifier of the bot that created the message
final
hashCode int
The hash code for this object.
no setteroverride
preparedMessageId String
preparedMessageId Identifier of the prepared message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? preparedMessageId}) GetPreparedInlineMessage

Available on GetPreparedInlineMessage, provided by the GetPreparedInlineMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String