GetPreparedKeyboardButton class final

Returns a keyboard button prepared by the bot for the user. The button will be of the type keyboardButtonTypeRequestUsers, keyboardButtonTypeRequestChat, or keyboardButtonTypeRequestManagedBot Returns KeyboardButton

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPreparedKeyboardButton({required int botUserId, required String preparedButtonId})

Properties

botUserId int
botUserId Identifier of the bot that created the button
final
hashCode int
The hash code for this object.
no setteroverride
preparedButtonId String
preparedButtonId Identifier of the prepared button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, String? preparedButtonId}) GetPreparedKeyboardButton

Available on GetPreparedKeyboardButton, provided by the GetPreparedKeyboardButtonExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String