GetPublicPostSearchLimits class final

Checks public post search limits without actually performing the search Returns PublicPostSearchLimits

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetPublicPostSearchLimits({required String query})

Properties

hashCode int
The hash code for this object.
no setteroverride
query String
query Query that will be searched for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query}) GetPublicPostSearchLimits

Available on GetPublicPostSearchLimits, provided by the GetPublicPostSearchLimitsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String