GetReceivedGift class final
Returns information about a received gift Returns ReceivedGift
- Inheritance
-
- Object
- TdFunction
- GetReceivedGift
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetReceivedGift({required String receivedGiftId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- receivedGiftId → String
-
receivedGiftId Identifier of the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? receivedGiftId}) → GetReceivedGift -
Available on GetReceivedGift, provided by the GetReceivedGiftExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String