collectionId property
collectionId Pass collection identifier to get gifts only from the specified collection; pass 0 to get gifts regardless of collections
Implementation
final int collectionId;
collectionId Pass collection identifier to get gifts only from the specified collection; pass 0 to get gifts regardless of collections
final int collectionId;