excludeNonUpgradable property
excludeNonUpgradable Pass true to exclude gifts that can be purchased limited number of times and can't be upgraded
Implementation
final bool excludeNonUpgradable;
excludeNonUpgradable Pass true to exclude gifts that can be purchased limited number of times and can't be upgraded
final bool excludeNonUpgradable;