excludeUnlimited property
excludeUnlimited Pass true to exclude gifts that can be purchased unlimited number of times
Implementation
final bool excludeUnlimited;
excludeUnlimited Pass true to exclude gifts that can be purchased unlimited number of times
final bool excludeUnlimited;