excludeUpgradable property

bool excludeUpgradable
final

excludeUpgradable Pass true to exclude gifts that can be purchased limited number of times and can be upgraded

Implementation

final bool excludeUpgradable;