GetRecentStickers class final
Returns a list of recently used stickers Returns Stickers
- Inheritance
-
- Object
- TdFunction
- GetRecentStickers
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetRecentStickers({required bool isAttached})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAttached → bool
-
isAttached Pass true to return stickers and masks that were recently
attached to photos or video files; pass false to return recently sent
stickers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isAttached}) → GetRecentStickers -
Available on GetRecentStickers, provided by the GetRecentStickersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String