GetRecentlyOpenedChats class final

Returns recently opened chats. This is an offline method. Returns chats in the order of last opening Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetRecentlyOpenedChats({required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of chats to be returned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? limit}) GetRecentlyOpenedChats

Available on GetRecentlyOpenedChats, provided by the GetRecentlyOpenedChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String