GetRecentlyVisitedTMeUrls class final
Returns t.me URLs recently visited by a newly registered user Returns TMeUrls
- Inheritance
-
- Object
- TdFunction
- GetRecentlyVisitedTMeUrls
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetRecentlyVisitedTMeUrls({required String referrer})
Properties
Methods
-
copyWith(
{String? referrer}) → GetRecentlyVisitedTMeUrls -
Available on GetRecentlyVisitedTMeUrls, provided by the GetRecentlyVisitedTMeUrlsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String