GetRecoveryEmailAddress class final
Returns a 2-step verification recovery email address that was previously set up. This method can be used to verify a password provided by the user Returns RecoveryEmailAddress
- Inheritance
-
- Object
- TdFunction
- GetRecoveryEmailAddress
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetRecoveryEmailAddress({required String password})
Properties
Methods
-
copyWith(
{String? password}) → GetRecoveryEmailAddress -
Available on GetRecoveryEmailAddress, provided by the GetRecoveryEmailAddressExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String