GetSavedMessagesTags class final

Returns tags used in Saved Messages or a Saved Messages topic Returns SavedMessagesTags

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSavedMessagesTags({required int savedMessagesTopicId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Identifier of Saved Messages topic which tags will be returned; pass 0 to get all Saved Messages tags
final

Methods

copyWith({int? savedMessagesTopicId}) GetSavedMessagesTags

Available on GetSavedMessagesTags, provided by the GetSavedMessagesTagsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String