GetSavedMessagesTopicMessageByDate class final

Returns the last message sent in a Saved Messages topic no later than the specified date Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSavedMessagesTopicMessageByDate({required int savedMessagesTopicId, required int date})

Properties

date int
date Point in time (Unix timestamp) relative to which to search for messages
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Identifier of Saved Messages topic which message will be returned
final

Methods

copyWith({int? savedMessagesTopicId, int? date}) GetSavedMessagesTopicMessageByDate

Available on GetSavedMessagesTopicMessageByDate, provided by the GetSavedMessagesTopicMessageByDateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String