GetScopeNotificationSettings class final
Returns the notification settings for chats of a given type Returns ScopeNotificationSettings
- Inheritance
-
- Object
- TdFunction
- GetScopeNotificationSettings
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → NotificationSettingsScope?
-
scope Types of chats for which to return the notification settings
information
final
Methods
-
copyWith(
{NotificationSettingsScope? scope}) → GetScopeNotificationSettings -
Available on GetScopeNotificationSettings, provided by the GetScopeNotificationSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String