GetStarGiftPaymentOptions class final
Returns available options for Telegram Stars gifting Returns StarPaymentOptions
- Inheritance
-
- Object
- TdFunction
- GetStarGiftPaymentOptions
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStarGiftPaymentOptions({required int userId})
Properties
Methods
-
copyWith(
{int? userId}) → GetStarGiftPaymentOptions -
Available on GetStarGiftPaymentOptions, provided by the GetStarGiftPaymentOptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String