GetStarRevenueStatistics class final

Returns detailed Telegram Star revenue statistics Returns StarRevenueStatistics

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStarRevenueStatistics({MessageSender? ownerId, required bool isDark})

Properties

hashCode int
The hash code for this object.
no setteroverride
isDark bool
isDark Pass true if a dark theme is used by the application
final
ownerId MessageSender?
ownerId Identifier of the owner of the Telegram Stars; can be identifier of the current user, an owned bot, or a supergroup or a channel chat with supergroupFullInfo.can_get_star_revenue_statistics == true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, bool? isDark}) GetStarRevenueStatistics

Available on GetStarRevenueStatistics, provided by the GetStarRevenueStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String