ownerId property

MessageSender? ownerId
final

ownerId Identifier of the owner of the Telegram Stars; can be identifier of the current user, an owned bot, or a supergroup or a channel chat with supergroupFullInfo.can_get_star_revenue_statistics == true

Implementation

final MessageSender? ownerId;