onlyExpiring property
onlyExpiring Pass true to receive only expiring subscriptions for which there aren't enough Telegram Stars to extend
Implementation
final bool onlyExpiring;
onlyExpiring Pass true to receive only expiring subscriptions for which there aren't enough Telegram Stars to extend
final bool onlyExpiring;