GetStarTransactions class final

Returns the list of Telegram Star transactions for the specified owner Returns StarTransactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStarTransactions({MessageSender? ownerId, required String subscriptionId, TransactionDirection? direction, required String offset, required int limit})

Properties

direction TransactionDirection?
direction Direction of the transactions to receive; pass null to get all transactions
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of transactions to return
final
offset String
offset Offset of the first transaction to return as received from the previous request; use empty string to get the first chunk of results
final
ownerId MessageSender?
ownerId Identifier of the owner of the Telegram Stars; can be the identifier of the current user, identifier of an owned bot, or identifier of a supergroup or a channel chat with supergroupFullInfo.can_get_star_revenue_statistics == true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId String
subscriptionId If non-empty, only transactions related to the Star Subscription will be returned
final

Methods

copyWith({MessageSender? ownerId, String? subscriptionId, TransactionDirection? direction, String? offset, int? limit}) GetStarTransactions

Available on GetStarTransactions, provided by the GetStarTransactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String