subscriptionId property
subscriptionId If non-empty, only transactions related to the Star Subscription will be returned
Implementation
final String subscriptionId;
subscriptionId If non-empty, only transactions related to the Star Subscription will be returned
final String subscriptionId;