GetStarWithdrawalUrl class final

Returns a URL for Telegram Star withdrawal Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStarWithdrawalUrl({MessageSender? ownerId, required int starCount, required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the owner of the Telegram Stars; can be identifier of the current user, an owned bot, or an owned supergroup or channel chat
final
password String
password The 2-step verification password of the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars to withdraw; must be between getOption("star_withdrawal_count_min") and getOption("star_withdrawal_count_max")
final

Methods

copyWith({MessageSender? ownerId, int? starCount, String? password}) GetStarWithdrawalUrl

Available on GetStarWithdrawalUrl, provided by the GetStarWithdrawalUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String