GetStickerOutline class final

Returns outline of a sticker. This is an offline method. Returns a 404 error if the outline isn't known Returns Outline

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStickerOutline({required int stickerFileId, required bool forAnimatedEmoji, required bool forClickedAnimatedEmojiMessage})

Properties

forAnimatedEmoji bool
forAnimatedEmoji Pass true to get the outline scaled for animated emoji
final
forClickedAnimatedEmojiMessage bool
forClickedAnimatedEmojiMessage Pass true to get the outline scaled for clicked animated emoji message
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerFileId int
stickerFileId File identifier of the sticker
final

Methods

copyWith({int? stickerFileId, bool? forAnimatedEmoji, bool? forClickedAnimatedEmojiMessage}) GetStickerOutline

Available on GetStickerOutline, provided by the GetStickerOutlineExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String