forClickedAnimatedEmojiMessage property
forClickedAnimatedEmojiMessage Pass true to get the outline scaled for clicked animated emoji message
Implementation
final bool forClickedAnimatedEmojiMessage;
forClickedAnimatedEmojiMessage Pass true to get the outline scaled for clicked animated emoji message
final bool forClickedAnimatedEmojiMessage;