GetStickerSet class final

Returns information about a sticker set by its identifier Returns StickerSet

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStickerSet({required int setId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setId int
setId Identifier of the sticker set
final

Methods

copyWith({int? setId}) GetStickerSet

Available on GetStickerSet, provided by the GetStickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String