GetStickers class final
Returns stickers from the installed sticker sets that correspond to any of the given emoji or can be found by sticker-specific keywords. If the query is non-empty, then favorite, recently used or trending stickers may also be returned Returns Stickers
- Inheritance
-
- Object
- TdFunction
- GetStickers
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStickers({StickerType? stickerType, required String query, required int limit, required int chatId})
Properties
- chatId → int
-
chatId Chat identifier for which to return stickers. Available custom
emoji stickers may be different for different chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of stickers to be returned
final
- query → String
-
query Search query; a space-separated list of emojis or a keyword
prefix. If empty, returns all known installed stickers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the stickers to return
final
Methods
-
copyWith(
{StickerType? stickerType, String? query, int? limit, int? chatId}) → GetStickers -
Available on GetStickers, provided by the GetStickersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String