GetStoryAvailableReactions class final

Returns reactions, which can be chosen for a story Returns AvailableReactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStoryAvailableReactions({required int rowSize})

Properties

hashCode int
The hash code for this object.
no setteroverride
rowSize int
rowSize Number of reaction per row, 5-25
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? rowSize}) GetStoryAvailableReactions

Available on GetStoryAvailableReactions, provided by the GetStoryAvailableReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String