GetStoryInteractions class final

Returns interactions with a story. The method can be called only for stories posted on behalf of the current user Returns StoryInteractions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetStoryInteractions({required int storyId, required String query, required bool onlyContacts, required bool preferForwards, required bool preferWithReaction, required String offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of story interactions to return
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
onlyContacts bool
onlyContacts Pass true to get only interactions by contacts; pass false to get all relevant interactions
final
preferForwards bool
preferForwards Pass true to get forwards and reposts first, then reactions, then other views; pass false to get interactions sorted just by interaction date
final
preferWithReaction bool
preferWithReaction Pass true to get interactions with reaction first; pass false to get interactions sorted just by interaction date. Ignored if prefer_forwards == true
final
query String
query Query to search for in names, usernames and titles; may be empty to get all relevant interactions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Story identifier
final

Methods

copyWith({int? storyId, String? query, bool? onlyContacts, bool? preferForwards, bool? preferWithReaction, String? offset, int? limit}) GetStoryInteractions

Available on GetStoryInteractions, provided by the GetStoryInteractionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String