onlyContacts property
onlyContacts Pass true to get only interactions by contacts; pass false to get all relevant interactions
Implementation
final bool onlyContacts;
onlyContacts Pass true to get only interactions by contacts; pass false to get all relevant interactions
final bool onlyContacts;