GetSuggestedFileName class final

Returns suggested name for saving a file in a given directory Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSuggestedFileName({required int fileId, required String directory})

Properties

directory String
directory Directory in which the file is expected to be saved
final
fileId int
fileId Identifier of the file
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, String? directory}) GetSuggestedFileName

Available on GetSuggestedFileName, provided by the GetSuggestedFileNameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String