GetSupergroup class final

Returns information about a supergroup or a channel by its identifier. This is an offline method if the current user is not a bot Returns Supergroup

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSupergroup({required int supergroupId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Supergroup or channel identifier
final

Methods

copyWith({int? supergroupId}) GetSupergroup

Available on GetSupergroup, provided by the GetSupergroupExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String