GetSupergroupFullInfo class final

Returns full information about a supergroup or a channel by its identifier, cached for up to 1 minute Returns SupergroupFullInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSupergroupFullInfo({required int supergroupId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Supergroup or channel identifier
final

Methods

copyWith({int? supergroupId}) GetSupergroupFullInfo

Available on GetSupergroupFullInfo, provided by the GetSupergroupFullInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String