GetTextCompositionStyleExample class final
Returns an example of usage of a custom text composition style Returns TextCompositionStyleExample
- Inheritance
-
- Object
- TdFunction
- GetTextCompositionStyleExample
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetTextCompositionStyleExample({required String name, required int exampleNumber})
Properties
- exampleNumber → int
-
exampleNumber 0-based unique number of the requested example; must be
non-negative and less than
getOption("text_composition_style_example_count")
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the style
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? name, int? exampleNumber}) → GetTextCompositionStyleExample -
Available on GetTextCompositionStyleExample, provided by the GetTextCompositionStyleExampleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String