GetThemeParametersJsonString class final
Converts a themeParameters object to corresponding JSON-serialized string. Can be called synchronously Returns Text
- Inheritance
-
- Object
- TdFunction
- GetThemeParametersJsonString
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetThemeParametersJsonString({ThemeParameters? theme})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeParameters?
-
theme Theme parameters to convert to JSON
final
Methods
-
copyWith(
{ThemeParameters? theme}) → GetThemeParametersJsonString -
Available on GetThemeParametersJsonString, provided by the GetThemeParametersJsonStringExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String