GetThemedChatEmojiStatuses class final

Returns up to 8 emoji statuses, which must be shown in the emoji status list for chats Returns EmojiStatusCustomEmojis

Inheritance
Annotations
  • @immutable

Constructors

GetThemedChatEmojiStatuses()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String