GetTonTransactions class final

Returns the list of TON blockchain transactions of the current user Returns TonTransactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetTonTransactions({TransactionDirection? direction, required String offset, required int limit})

Properties

direction TransactionDirection?
direction Direction of the transactions to receive; pass null to get all transactions
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of transactions to return
final
offset String
offset Offset of the first transaction to return as received from the previous request; use empty string to get the first chunk of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TransactionDirection? direction, String? offset, int? limit}) GetTonTransactions

Available on GetTonTransactions, provided by the GetTonTransactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String