GetTrendingStickerSets class final
Returns a list of trending sticker sets. For optimal performance, the number of returned sticker sets is chosen by TDLib Returns TrendingStickerSets
- Inheritance
-
- Object
- TdFunction
- GetTrendingStickerSets
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetTrendingStickerSets({StickerType? stickerType, required int offset, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of sticker sets to be returned; up to 100. For
optimal performance, the number of returned sticker sets is chosen by
TDLib and can be smaller than the specified limit, even if the end of the
list has not been reached
final
- offset → int
-
offset The offset from which to return the sticker sets; must be
non-negative
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the sticker sets to return
final
Methods
-
copyWith(
{StickerType? stickerType, int? offset, int? limit}) → GetTrendingStickerSets -
Available on GetTrendingStickerSets, provided by the GetTrendingStickerSetsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String