GetUpgradedGift class final

Returns information about an upgraded gift by its name Returns UpgradedGift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetUpgradedGift({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Unique name of the upgraded gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) GetUpgradedGift

Available on GetUpgradedGift, provided by the GetUpgradedGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String