GetUpgradedGiftValueInfo class final

Returns information about value of an upgraded gift by its name Returns UpgradedGiftValueInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetUpgradedGiftValueInfo({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Unique name of the upgraded gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) GetUpgradedGiftValueInfo

Available on GetUpgradedGiftValueInfo, provided by the GetUpgradedGiftValueInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String