GetUpgradedGiftVariants class final

Returns all possible variants of upgraded gifts for a regular gift Returns GiftUpgradeVariants

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetUpgradedGiftVariants({required int regularGiftId, required bool returnUpgradeModels, required bool returnCraftModels})

Properties

hashCode int
The hash code for this object.
no setteroverride
regularGiftId int
regularGiftId Identifier of the regular gift
final
returnCraftModels bool
returnCraftModels Pass true to get models that can be obtained by crafting a gift from upgraded gifts
final
returnUpgradeModels bool
returnUpgradeModels Pass true to get models that can be obtained by upgrading a regular gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? regularGiftId, bool? returnUpgradeModels, bool? returnCraftModels}) GetUpgradedGiftVariants

Available on GetUpgradedGiftVariants, provided by the GetUpgradedGiftVariantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String