GetUser class final
Returns information about a user by their identifier. This is an offline method if the current user is not a bot Returns User
- Inheritance
-
- Object
- TdFunction
- GetUser
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{int? userId}) → GetUser -
Available on GetUser, provided by the GetUserExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String