GetUserChatBoosts class final
Returns the list of boosts applied to a chat by a given user; requires administrator rights in the chat; for bots only Returns FoundChatBoosts
- Inheritance
-
- Object
- TdFunction
- GetUserChatBoosts
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetUserChatBoosts({required int chatId, required int userId})
Properties
Methods
-
copyWith(
{int? chatId, int? userId}) → GetUserChatBoosts -
Available on GetUserChatBoosts, provided by the GetUserChatBoostsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String