GetUserFullInfo class final
Returns full information about a user by their identifier Returns UserFullInfo
- Inheritance
-
- Object
- TdFunction
- GetUserFullInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetUserFullInfo({required int userId})
Properties
Methods
-
copyWith(
{int? userId}) → GetUserFullInfo -
Available on GetUserFullInfo, provided by the GetUserFullInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String