GetUserProfileAudios class final

Returns the list of profile audio files of a user Returns Audios

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetUserProfileAudios({required int userId, required int offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of audio files to be returned; up to 100
final
offset int
offset The number of audio files to skip; must be non-negative
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, int? offset, int? limit}) GetUserProfileAudios

Available on GetUserProfileAudios, provided by the GetUserProfileAudiosExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String