GetVideoChatInviteLink class final

Returns invite link to a video chat in a public chat Returns HttpUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetVideoChatInviteLink({required int groupCallId, required bool canSelfUnmute})

Properties

canSelfUnmute bool
canSelfUnmute Pass true if the invite link needs to contain an invite hash, passing which to joinVideoChat would allow the invited user to unmute themselves. Requires groupCall.can_be_managed right
final
groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? canSelfUnmute}) GetVideoChatInviteLink

Available on GetVideoChatInviteLink, provided by the GetVideoChatInviteLinkExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String