canSelfUnmute property

bool canSelfUnmute
final

canSelfUnmute Pass true if the invite link needs to contain an invite hash, passing which to joinVideoChat would allow the invited user to unmute themselves. Requires groupCall.can_be_managed right

Implementation

final bool canSelfUnmute;