GetVideoChatRtmpUrl class final
Returns RTMP URL for streaming to the video chat of a chat; requires can_manage_video_chats administrator right Returns RtmpUrl
- Inheritance
-
- Object
- TdFunction
- GetVideoChatRtmpUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetVideoChatRtmpUrl({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetVideoChatRtmpUrl -
Available on GetVideoChatRtmpUrl, provided by the GetVideoChatRtmpUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String