GetVideoMessageAdvertisements class final

Returns advertisements to be shown while a video from a message is watched. Available only if messageProperties.can_get_video_advertisements Returns VideoMessageAdvertisements

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetVideoMessageAdvertisements({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) GetVideoMessageAdvertisements

Available on GetVideoMessageAdvertisements, provided by the GetVideoMessageAdvertisementsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String