auctionInfo property

GiftAuction? auctionInfo
final

auctionInfo Information about the auction on which the gift can be purchased; may be null if the gift can be purchased directly

Implementation

final GiftAuction? auctionInfo;