defaultSellStarCount property

int defaultSellStarCount
final

defaultSellStarCount Number of Telegram Stars that can be claimed by the receiver instead of the regular gift by default. If the gift was paid with just bought Telegram Stars, then full value can be claimed

Implementation

final int defaultSellStarCount;