firstSendDate property
firstSendDate Point in time (Unix timestamp) when the gift was sent for the first time; for sold out gifts only
Implementation
final int firstSendDate;
firstSendDate Point in time (Unix timestamp) when the gift was sent for the first time; for sold out gifts only
final int firstSendDate;