hasColors property

bool hasColors
final

hasColors True, if the gift can be used to customize the user's name, and backgrounds of profile photo, reply header, and link preview

Implementation

final bool hasColors;