lastSendDate property
lastSendDate Point in time (Unix timestamp) when the gift was sent for the last time; for sold out gifts only
Implementation
final int lastSendDate;
lastSendDate Point in time (Unix timestamp) when the gift was sent for the last time; for sold out gifts only
final int lastSendDate;