nextSendDate property

int nextSendDate
final

nextSendDate Point in time (Unix timestamp) when the gift can be sent next time by the current user; may be 0 or a date in the past. If the date is in the future, then call canSendGift to get the reason, why the gift can't be sent now

Implementation

final int nextSendDate;