userLimits property
userLimits Number of times the gift can be purchased by the current user; may be null if not limited
Implementation
final GiftPurchaseLimits? userLimits;
userLimits Number of times the gift can be purchased by the current user; may be null if not limited
final GiftPurchaseLimits? userLimits;