GiftAuction class final

Describes an auction on which a gift can be purchased

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftAuction({required String id, required int giftsPerRound, required int startDate})

Properties

giftsPerRound int
giftsPerRound Number of gifts distributed in each round
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Identifier of the auction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate int
startDate Point in time (Unix timestamp) when the auction will start
final

Methods

copyWith({String? id, int? giftsPerRound, int? startDate}) GiftAuction

Available on GiftAuction, provided by the GiftAuctionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftAuction?

Constants

constructor → const String