auctionRoundPosition property
auctionRoundPosition Position of the user in the round among all auction participants
Implementation
final int auctionRoundPosition;
auctionRoundPosition Position of the user in the round among all auction participants
final int auctionRoundPosition;