GiftAuctionAcquiredGifts class final

Represents a list of gifts that were acquired by the current user on an auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftAuctionAcquiredGifts({required List<GiftAuctionAcquiredGift> gifts})

Properties

gifts List<GiftAuctionAcquiredGift>
gifts The list of acquired gifts
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<GiftAuctionAcquiredGift>? gifts}) GiftAuctionAcquiredGifts

Available on GiftAuctionAcquiredGifts, provided by the GiftAuctionAcquiredGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftAuctionAcquiredGifts?

Constants

constructor → const String