GiftAuctionState class final

Represent auction state of a gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftAuctionState({Gift? gift, AuctionState? state})

Properties

gift Gift?
gift The gift
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AuctionState?
state Auction state of the gift
final

Methods

copyWith({Gift? gift, AuctionState? state}) GiftAuctionState

Available on GiftAuctionState, provided by the GiftAuctionStateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftAuctionState?

Constants

constructor → const String