GiftBackground class final

Describes background of a gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftBackground({required int centerColor, required int edgeColor, required int textColor})

Properties

centerColor int
centerColor Center color in RGB format
final
edgeColor int
edgeColor Edge color in RGB format
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor int
textColor Text color in RGB format
final

Methods

copyWith({int? centerColor, int? edgeColor, int? textColor}) GiftBackground

Available on GiftBackground, provided by the GiftBackgroundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftBackground?

Constants

constructor → const String