GiftChatTheme class final

Describes a chat theme based on an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftChatTheme({UpgradedGift? gift, ThemeSettings? lightSettings, ThemeSettings? darkSettings})

Properties

darkSettings ThemeSettings?
darkSettings Theme settings for a dark chat theme
final
gift UpgradedGift?
gift The gift
final
hashCode int
The hash code for this object.
no setteroverride
lightSettings ThemeSettings?
lightSettings Theme settings for a light chat theme
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({UpgradedGift? gift, ThemeSettings? lightSettings, ThemeSettings? darkSettings}) GiftChatTheme

Available on GiftChatTheme, provided by the GiftChatThemeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftChatTheme?

Constants

constructor → const String