GiftChatThemes class final

Contains a list of chat themes based on upgraded gifts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftChatThemes({required List<GiftChatTheme> themes, required String nextOffset})

Properties

hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
themes List<GiftChatTheme>
themes A list of chat themes
final

Methods

copyWith({List<GiftChatTheme>? themes, String? nextOffset}) GiftChatThemes

Available on GiftChatThemes, provided by the GiftChatThemesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftChatThemes?

Constants

constructor → const String