GiftCollection class final

Describes collection of gifts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftCollection({required int id, required String name, Sticker? icon, required int giftCount})

Properties

giftCount int
giftCount Total number of gifts in the collection
final
hashCode int
The hash code for this object.
no setteroverride
icon Sticker?
icon Icon of the collection; may be null if none
final
id int
id Unique identifier of the collection
final
name String
name Name of the collection
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name, Sticker? icon, int? giftCount}) GiftCollection

Available on GiftCollection, provided by the GiftCollectionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftCollection?

Constants

constructor → const String