GiftForResaleOrder class sealed
Describes order in which upgraded gifts for resale will be sorted
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult number(GiftForResaleOrderNumber value), required TResult price(GiftForResaleOrderPrice value), required TResult priceChangeDate(GiftForResaleOrderPriceChangeDate value)}) → TResult -
Available on GiftForResaleOrder, provided by the GiftForResaleOrderExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult number(GiftForResaleOrderNumber value)?, TResult price(GiftForResaleOrderPrice value)?, TResult priceChangeDate(GiftForResaleOrderPriceChangeDate value)?, required TResult orElse()}) → TResult -
Available on GiftForResaleOrder, provided by the GiftForResaleOrderExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftForResaleOrder? - Inherited by: GiftForResaleOrderNumber GiftForResaleOrderPrice GiftForResaleOrderPriceChangeDate
Constants
- constructor → const String