GiftPremiumWithStars class final

Allows to buy a Telegram Premium subscription for another user with payment in Telegram Stars; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftPremiumWithStars({required int userId, required int starCount, required int monthCount, FormattedText? text})

Properties

hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active for the user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars to pay for subscription
final
text FormattedText?
text Text to show to the user receiving Telegram Premium; 0-getOption("gift_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed
final
userId int
userId Identifier of the user which will receive Telegram Premium
final

Methods

copyWith({int? userId, int? starCount, int? monthCount, FormattedText? text}) GiftPremiumWithStars

Available on GiftPremiumWithStars, provided by the GiftPremiumWithStarsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String