monthCount property
monthCount Number of months the Telegram Premium subscription will be active for the user
Implementation
final int monthCount;
monthCount Number of months the Telegram Premium subscription will be active for the user
final int monthCount;