GiftPurchaseOfferState class sealed
Describes state of a gift purchase offer
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult accepted(GiftPurchaseOfferStateAccepted value), required TResult pending(GiftPurchaseOfferStatePending value), required TResult rejected(GiftPurchaseOfferStateRejected value)}) → TResult -
Available on GiftPurchaseOfferState, provided by the GiftPurchaseOfferStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult accepted(GiftPurchaseOfferStateAccepted value)?, TResult pending(GiftPurchaseOfferStatePending value)?, TResult rejected(GiftPurchaseOfferStateRejected value)?, required TResult orElse()}) → TResult -
Available on GiftPurchaseOfferState, provided by the GiftPurchaseOfferStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftPurchaseOfferState? - Inherited by: GiftPurchaseOfferStateAccepted GiftPurchaseOfferStatePending GiftPurchaseOfferStateRejected
Constants
- constructor → const String