GiftResaleParameters class final

Describes parameters of a unique gift available for resale

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftResaleParameters({required int starCount, required int gramCentCount, required bool gramOnly})

Properties

gramCentCount int
gramCentCount Resale price of the gift in 1/100 of TON Gram
final
gramOnly bool
gramOnly True, if the gift can be bought only using Grams
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Resale price of the gift in Telegram Stars
final

Methods

copyWith({int? starCount, int? gramCentCount, bool? gramOnly}) GiftResaleParameters

Available on GiftResaleParameters, provided by the GiftResaleParametersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftResaleParameters?

Constants

constructor → const String