GiftResalePrice class sealed

Describes price of a resold gift

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult gram(GiftResalePriceGram value), required TResult star(GiftResalePriceStar value)}) → TResult

Available on GiftResalePrice, provided by the GiftResalePriceExtensions extension

maybeMap<TResult extends Object?>({TResult gram(GiftResalePriceGram value)?, TResult star(GiftResalePriceStar value)?, required TResult orElse()}) → TResult

Available on GiftResalePrice, provided by the GiftResalePriceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftResalePrice?
Inherited by: GiftResalePriceGram GiftResalePriceStar

Constants

constructor → const String