GiftResalePriceStar class final

Describes price of a resold gift in Telegram Stars

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftResalePriceStar({required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount expected to be paid for the gift. Must be in the range getOption("gift_resale_star_count_min")-getOption("gift_resale_star_count_max") for gifts put for resale
final

Methods

copyWith({int? starCount}) GiftResalePriceStar

Available on GiftResalePriceStar, provided by the GiftResalePriceStarExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult gram(GiftResalePriceGram value), required TResult star(GiftResalePriceStar value)}) → TResult

Available on GiftResalePrice, provided by the GiftResalePriceExtensions extension

maybeMap<TResult extends Object?>({TResult gram(GiftResalePriceGram value)?, TResult star(GiftResalePriceStar value)?, required TResult orElse()}) → TResult

Available on GiftResalePrice, provided by the GiftResalePriceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftResalePriceStar?
Inherited by: GiftResalePriceGram GiftResalePriceStar
override

Constants

constructor → const String