GiftResaleResultOk class final
Operation was successfully completed
- Inheritance
-
- Object
- TdObject
- GiftResaleResult
- GiftResaleResultOk
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiftResaleResultOk({required String receivedGiftId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- receivedGiftId → String
-
receivedGiftId Unique identifier of the received gift; only for the
gifts sent to the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? receivedGiftId}) → GiftResaleResultOk -
Available on GiftResaleResultOk, provided by the GiftResaleResultOkExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ok(GiftResaleResultOk value), required TResult priceIncreased(GiftResaleResultPriceIncreased value)}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ok(GiftResaleResultOk value)?, TResult priceIncreased(GiftResaleResultPriceIncreased value)?, required TResult orElse()}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftResaleResultOk? -
Inherited by:
GiftResaleResultOk
GiftResaleResultPriceIncreased
override
Constants
- constructor → const String