receivedGiftId property
receivedGiftId Unique identifier of the received gift; only for the gifts sent to the current user
Implementation
final String receivedGiftId;
receivedGiftId Unique identifier of the received gift; only for the gifts sent to the current user
final String receivedGiftId;