showGiftButton property
showGiftButton True, if a button for sending a gift to the user or by the user must always be shown in the input field
Implementation
final bool showGiftButton;
showGiftButton True, if a button for sending a gift to the user or by the user must always be shown in the input field
final bool showGiftButton;