GiftUpgradePreview class final

Contains examples of possible upgraded gifts for the given regular gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftUpgradePreview({required List<UpgradedGiftModel> models, required List<UpgradedGiftSymbol> symbols, required List<UpgradedGiftBackdrop> backdrops, required List<GiftUpgradePrice> prices, required List<GiftUpgradePrice> nextPrices})

Properties

backdrops List<UpgradedGiftBackdrop>
backdrops Examples of possible backdrops that can be chosen for the gift after upgrade
final
hashCode int
The hash code for this object.
no setteroverride
models List<UpgradedGiftModel>
models Examples of possible models that can be chosen for the gift after upgrade
final
nextPrices List<GiftUpgradePrice>
nextPrices Next changes for the price for gift upgrade with more granularity than in prices
final
prices List<GiftUpgradePrice>
prices Examples of price for gift upgrade from the maximum price to the minimum price
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<UpgradedGiftSymbol>
symbols Examples of possible symbols that can be chosen for the gift after upgrade
final

Methods

copyWith({List<UpgradedGiftModel>? models, List<UpgradedGiftSymbol>? symbols, List<UpgradedGiftBackdrop>? backdrops, List<GiftUpgradePrice>? prices, List<GiftUpgradePrice>? nextPrices}) GiftUpgradePreview

Available on GiftUpgradePreview, provided by the GiftUpgradePreviewExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftUpgradePreview?

Constants

constructor → const String