backdrops property
backdrops Examples of possible backdrops that can be chosen for the gift after upgrade
Implementation
final List<UpgradedGiftBackdrop> backdrops;
backdrops Examples of possible backdrops that can be chosen for the gift after upgrade
final List<UpgradedGiftBackdrop> backdrops;