models property
models Examples of possible models that can be chosen for the gift after upgrade
Implementation
final List<UpgradedGiftModel> models;
models Examples of possible models that can be chosen for the gift after upgrade
final List<UpgradedGiftModel> models;