nextPrices property
nextPrices Next changes for the price for gift upgrade with more granularity than in prices
Implementation
final List<GiftUpgradePrice> nextPrices;
nextPrices Next changes for the price for gift upgrade with more granularity than in prices
final List<GiftUpgradePrice> nextPrices;