symbols property
symbols Examples of possible symbols that can be chosen for the gift after upgrade
Implementation
final List<UpgradedGiftSymbol> symbols;
symbols Examples of possible symbols that can be chosen for the gift after upgrade
final List<UpgradedGiftSymbol> symbols;