backdrops property
backdrops Backdrops that can be chosen for the gift after upgrade
Implementation
final List<UpgradedGiftBackdrop> backdrops;
backdrops Backdrops that can be chosen for the gift after upgrade
final List<UpgradedGiftBackdrop> backdrops;