attributePersistenceProbabilities property
attributePersistenceProbabilities The 4 objects that describe probabilities of the crafted gift to have the backdrop or symbol of one of the original gifts for the cases when 1, 2, 3 or 4 gifts are used in the craft correspondingly
Implementation
final List<AttributeCraftPersistenceProbability>
attributePersistenceProbabilities;