giftCode property

String giftCode
final

giftCode Telegram Premium gift code that was received by the current user; empty if the user isn't a winner in the giveaway or the giveaway isn't a Telegram Premium giveaway

Implementation

final String giftCode;