GiveawayParameters class final

Describes parameters of a giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiveawayParameters({required int boostedChatId, required List<int> additionalChatIds, required int winnersSelectionDate, required bool onlyNewMembers, required bool hasPublicWinners, required List<String> countryCodes, required String prizeDescription})

Properties

additionalChatIds List<int>
additionalChatIds Identifiers of other supergroup or channel chats that must be subscribed by the users to be eligible for the giveaway. There can be up to getOption("giveaway_additional_chat_count_max") additional chats
final
boostedChatId int
boostedChatId Identifier of the supergroup or channel chat, which will be automatically boosted by the winners of the giveaway for duration of the Telegram Premium subscription, or for the specified time. If the chat is a channel, then can_post_messages administrator right is required in the channel, otherwise, the user must be an administrator in the supergroup
final
countryCodes List<String>
countryCodes The list of two-letter ISO 3166-1 alpha-2 codes of countries, users from which will be eligible for the giveaway. If empty, then all users can participate in the giveaway. There can be up to getOption("giveaway_country_count_max") chosen countries. Users with phone number that was bought at https://fragment.com can participate in any giveaway and the country code "FT" must not be specified in the list
final
hashCode int
The hash code for this object.
no setteroverride
hasPublicWinners bool
hasPublicWinners True, if the list of winners of the giveaway will be available to everyone
final
onlyNewMembers bool
onlyNewMembers True, if only new members of the chats will be eligible for the giveaway
final
prizeDescription String
prizeDescription Additional description of the giveaway prize; 0-128 characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winnersSelectionDate int
winnersSelectionDate Point in time (Unix timestamp) when the giveaway is expected to be performed; must be 60-getOption("giveaway_duration_max") seconds in the future in scheduled giveaways
final

Methods

copyWith({int? boostedChatId, List<int>? additionalChatIds, int? winnersSelectionDate, bool? onlyNewMembers, bool? hasPublicWinners, List<String>? countryCodes, String? prizeDescription}) GiveawayParameters

Available on GiveawayParameters, provided by the GiveawayParametersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiveawayParameters?

Constants

constructor → const String