GiveawayParticipantStatus class sealed
Contains information about status of a user in a giveaway
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult administrator(GiveawayParticipantStatusAdministrator value), required TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value), required TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value), required TResult eligible(GiveawayParticipantStatusEligible value), required TResult participating(GiveawayParticipantStatusParticipating value)}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult administrator(GiveawayParticipantStatusAdministrator value)?, TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value)?, TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value)?, TResult eligible(GiveawayParticipantStatusEligible value)?, TResult participating(GiveawayParticipantStatusParticipating value)?, required TResult orElse()}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String