GiveawayPrize class sealed

Contains information about a giveaway prize

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() → String
override
map<TResult extends Object?>({required TResult premium(GiveawayPrizePremium value), required TResult stars(GiveawayPrizeStars value)}) → TResult

Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension

maybeMap<TResult extends Object?>({TResult premium(GiveawayPrizePremium value)?, TResult stars(GiveawayPrizeStars value)?, required TResult orElse()}) → TResult

Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → GiveawayPrize?
Inherited by: GiveawayPrizePremium GiveawayPrizeStars

Constants

constructor → const String