GiveawayPrizePremium class final
The giveaway sends Telegram Premium subscriptions to the winners
- Inheritance
-
- Object
- TdObject
- GiveawayPrize
- GiveawayPrizePremium
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiveawayPrizePremium({required int monthCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- monthCount → int
-
monthCount Number of months the Telegram Premium subscription will be
active after code activation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? monthCount}) → GiveawayPrizePremium -
Available on GiveawayPrizePremium, provided by the GiveawayPrizePremiumExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult stars(GiveawayPrizeStars value)}) → TResult -
Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult stars(GiveawayPrizeStars value)?, required TResult orElse()}) → TResult -
Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiveawayPrizePremium? -
Inherited by:
GiveawayPrizePremium
GiveawayPrizeStars
override
Constants
- constructor → const String