GramRevenueStatistics class final

A detailed statistics about TON Grams earned by the current user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GramRevenueStatistics({StatisticalGraph? revenueByDayGraph, GramRevenueStatus? status, required double usdRate})

Properties

hashCode int
The hash code for this object.
no setteroverride
revenueByDayGraph StatisticalGraph?
revenueByDayGraph A graph containing amount of revenue in a given day
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GramRevenueStatus?
status Amount of earned revenue
final
usdRate double
usdRate Current conversion rate of nanogram to USD cents
final

Methods

copyWith({StatisticalGraph? revenueByDayGraph, GramRevenueStatus? status, double? usdRate}) GramRevenueStatistics

Available on GramRevenueStatistics, provided by the GramRevenueStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GramRevenueStatistics?

Constants

constructor → const String