GroupCall class final

Describes a group call

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCall({required int id, required int uniqueId, required String title, required String inviteLink, required int paidMessageStarCount, required int scheduledStartDate, required bool enabledStartNotification, required bool isActive, required bool isVideoChat, required bool isLiveStory, required bool isRtmpStream, required bool isJoined, required bool needRejoin, required bool isOwned, required bool canBeManaged, required int participantCount, required bool hasHiddenListeners, required bool loadedAllParticipants, MessageSender? messageSenderId, required List<GroupCallRecentSpeaker> recentSpeakers, required bool isMyVideoEnabled, required bool isMyVideoPaused, required bool canEnableVideo, required bool muteNewParticipants, required bool canToggleMuteNewParticipants, required bool canSendMessages, required bool areMessagesAllowed, required bool canToggleAreMessagesAllowed, required bool canDeleteMessages, required int recordDuration, required bool isVideoRecorded, required int duration})

Properties

areMessagesAllowed bool
areMessagesAllowed True, if sending of messages is allowed in the group call
final
canBeManaged bool
canBeManaged True, if the current user can manage the group call; for video chats and live stories only
final
canDeleteMessages bool
canDeleteMessages True, if the user can delete messages in the group call
final
canEnableVideo bool
canEnableVideo True, if the current user can broadcast video or share screen
final
canSendMessages bool
canSendMessages True, if the current user can send messages to the group call
final
canToggleAreMessagesAllowed bool
canToggleAreMessagesAllowed True, if the current user can enable or disable sending of messages in the group call
final
canToggleMuteNewParticipants bool
canToggleMuteNewParticipants True, if the current user can enable or disable mute_new_participants setting; for video chats only
final
duration int
duration Call duration, in seconds; for ended calls only
final
enabledStartNotification bool
enabledStartNotification True, if the group call is scheduled and the current user will receive a notification when the group call starts; for video chats only
final
hashCode int
The hash code for this object.
no setteroverride
hasHiddenListeners bool
hasHiddenListeners True, if group call participants, which are muted, aren't returned in participant list; for video chats only
final
id int
id Group call identifier
final
inviteLink Invite link for the group call; for group calls that aren't bound to a chat. For video chats call getVideoChatInviteLink to get the link. For live stories in chats with username call getInternalLink with internalLinkTypeLiveStory
final
isActive bool
isActive True, if the call is active
final
isJoined bool
isJoined True, if the call is joined
final
isLiveStory bool
isLiveStory True, if the call is a live story of a chat
final
isMyVideoEnabled bool
isMyVideoEnabled True, if the current user's video is enabled
final
isMyVideoPaused bool
isMyVideoPaused True, if the current user's video is paused
final
isOwned bool
isOwned True, if the user is the owner of the call and can end the call, change volume level of other users, or ban users there; for group calls that aren't bound to a chat
final
isRtmpStream bool
isRtmpStream True, if the call is an RTMP stream instead of an ordinary video chat; for video chats and live stories only
final
isVideoChat bool
isVideoChat True, if the call is bound to a chat
final
isVideoRecorded bool
isVideoRecorded True, if a video file is being recorded for the call
final
loadedAllParticipants bool
loadedAllParticipants True, if all group call participants are loaded
final
messageSenderId MessageSender?
messageSenderId Message sender chosen to send messages to the group call; for live stories only; may be null if the call isn't a live story
final
muteNewParticipants bool
muteNewParticipants True, if only group call administrators can unmute new participants; for video chats only
final
needRejoin bool
needRejoin True, if user was kicked from the call because of network loss and the call needs to be rejoined
final
paidMessageStarCount int
paidMessageStarCount The minimum number of Telegram Stars that must be paid by general participant for each sent message to the call; for live stories only
final
participantCount int
participantCount Number of participants in the group call
final
recentSpeakers List<GroupCallRecentSpeaker>
recentSpeakers At most 3 recently speaking users in the group call
final
recordDuration int
recordDuration Duration of the ongoing group call recording, in seconds; 0 if none. An updateGroupCall update is not triggered when value of this field changes, but the same recording goes on
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduledStartDate int
scheduledStartDate Point in time (Unix timestamp) when the group call is expected to be started by an administrator; 0 if it is already active or was ended; for video chats only
final
title String
title Group call title; for video chats only
final
uniqueId int
uniqueId Persistent unique group call identifier
final

Methods

copyWith({int? id, int? uniqueId, String? title, String? inviteLink, int? paidMessageStarCount, int? scheduledStartDate, bool? enabledStartNotification, bool? isActive, bool? isVideoChat, bool? isLiveStory, bool? isRtmpStream, bool? isJoined, bool? needRejoin, bool? isOwned, bool? canBeManaged, int? participantCount, bool? hasHiddenListeners, bool? loadedAllParticipants, MessageSender? messageSenderId, List<GroupCallRecentSpeaker>? recentSpeakers, bool? isMyVideoEnabled, bool? isMyVideoPaused, bool? canEnableVideo, bool? muteNewParticipants, bool? canToggleMuteNewParticipants, bool? canSendMessages, bool? areMessagesAllowed, bool? canToggleAreMessagesAllowed, bool? canDeleteMessages, int? recordDuration, bool? isVideoRecorded, int? duration}) GroupCall

Available on GroupCall, provided by the GroupCallExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCall?

Constants

constructor → const String