canBeManaged property
canBeManaged True, if the current user can manage the group call; for video chats and live stories only
Implementation
final bool canBeManaged;
canBeManaged True, if the current user can manage the group call; for video chats and live stories only
final bool canBeManaged;