canSendMessages property
canSendMessages True, if the current user can send messages to the group call
Implementation
final bool canSendMessages;
canSendMessages True, if the current user can send messages to the group call
final bool canSendMessages;