canToggleAreMessagesAllowed property
canToggleAreMessagesAllowed True, if the current user can enable or disable sending of messages in the group call
Implementation
final bool canToggleAreMessagesAllowed;
canToggleAreMessagesAllowed True, if the current user can enable or disable sending of messages in the group call
final bool canToggleAreMessagesAllowed;