canToggleMuteNewParticipants property
canToggleMuteNewParticipants True, if the current user can enable or disable mute_new_participants setting; for video chats only
Implementation
final bool canToggleMuteNewParticipants;
canToggleMuteNewParticipants True, if the current user can enable or disable mute_new_participants setting; for video chats only
final bool canToggleMuteNewParticipants;