enabledStartNotification property
enabledStartNotification True, if the group call is scheduled and the current user will receive a notification when the group call starts; for video chats only
Implementation
final bool enabledStartNotification;
enabledStartNotification True, if the group call is scheduled and the current user will receive a notification when the group call starts; for video chats only
final bool enabledStartNotification;