isOwned property

bool isOwned
final

isOwned True, if the user is the owner of the call and can end the call, change volume level of other users, or ban users there; for group calls that aren't bound to a chat

Implementation

final bool isOwned;