muteNewParticipants property
muteNewParticipants True, if only group call administrators can unmute new participants; for video chats only
Implementation
final bool muteNewParticipants;
muteNewParticipants True, if only group call administrators can unmute new participants; for video chats only
final bool muteNewParticipants;