paidMessageStarCount property

int paidMessageStarCount
final

paidMessageStarCount The minimum number of Telegram Stars that must be paid by general participant for each sent message to the call; for live stories only

Implementation

final int paidMessageStarCount;