GroupCallDataChannelScreenSharing class final
The data channel for screen sharing
- Inheritance
-
- Object
- TdObject
- GroupCallDataChannel
- GroupCallDataChannelScreenSharing
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult main(GroupCallDataChannelMain value), required TResult screenSharing(GroupCallDataChannelScreenSharing value)}) → TResult -
Available on GroupCallDataChannel, provided by the GroupCallDataChannelExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult main(GroupCallDataChannelMain value)?, TResult screenSharing(GroupCallDataChannelScreenSharing value)?, required TResult orElse()}) → TResult -
Available on GroupCallDataChannel, provided by the GroupCallDataChannelExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallDataChannelScreenSharing? -
Inherited by:
GroupCallDataChannelMain
GroupCallDataChannelScreenSharing
override
Constants
- constructor → const String