GroupCallId class final

Contains the group call identifier

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallId({required int id})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Group call identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id}) GroupCallId

Available on GroupCallId, provided by the GroupCallIdExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallId?

Constants

constructor → const String