GroupCallJoinParameters class final

Describes parameters used to join a group call

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallJoinParameters({required int audioSourceId, required String payload, required bool isMuted, required bool isMyVideoEnabled})

Properties

audioSourceId int
audioSourceId Audio channel synchronization source identifier; received from tgcalls
final
hashCode int
The hash code for this object.
no setteroverride
isMuted bool
isMuted Pass true to join the call with muted microphone
final
isMyVideoEnabled bool
isMyVideoEnabled Pass true if the user's video is enabled
final
payload String
payload Group call join payload; received from tgcalls
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? audioSourceId, String? payload, bool? isMuted, bool? isMyVideoEnabled}) GroupCallJoinParameters

Available on GroupCallJoinParameters, provided by the GroupCallJoinParametersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallJoinParameters?

Constants

constructor → const String