canBeDeleted property
canBeDeleted True, if the message can be deleted by the current user; for live stories only
Implementation
final bool canBeDeleted;
canBeDeleted True, if the message can be deleted by the current user; for live stories only
final bool canBeDeleted;