paidMessageStarCount property
paidMessageStarCount The number of Telegram Stars that were paid to send the message; for live stories only
Implementation
final int paidMessageStarCount;
paidMessageStarCount The number of Telegram Stars that were paid to send the message; for live stories only
final int paidMessageStarCount;