text property
text Text of the message. If empty, then the message is a paid reaction in a live story
Implementation
final FormattedText? text;
text Text of the message. If empty, then the message is a paid reaction in a live story
final FormattedText? text;