GroupCallMessageLevel class final

Represents a level of features for a message sent in a live story group call

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallMessageLevel({required int minStarCount, required int pinDuration, required int maxTextLength, required int maxCustomEmojiCount, required int firstColor, required int secondColor, required int backgroundColor})

Properties

backgroundColor int
backgroundColor Background color for the message the RGB format
final
firstColor int
firstColor The first color used to show the message text in the RGB format
final
hashCode int
The hash code for this object.
no setteroverride
maxCustomEmojiCount int
maxCustomEmojiCount The maximum allowed number of custom emoji in the message text
final
maxTextLength int
maxTextLength The maximum allowed length of the message text
final
minStarCount int
minStarCount The minimum number of Telegram Stars required to get features of the level
final
pinDuration int
pinDuration The amount of time the message of this level will be pinned, in seconds
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondColor int
secondColor The second color used to show the message text in the RGB format
final

Methods

copyWith({int? minStarCount, int? pinDuration, int? maxTextLength, int? maxCustomEmojiCount, int? firstColor, int? secondColor, int? backgroundColor}) GroupCallMessageLevel

Available on GroupCallMessageLevel, provided by the GroupCallMessageLevelExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallMessageLevel?

Constants

constructor → const String