maxCustomEmojiCount property
maxCustomEmojiCount The maximum allowed number of custom emoji in the message text
Implementation
final int maxCustomEmojiCount;
maxCustomEmojiCount The maximum allowed number of custom emoji in the message text
final int maxCustomEmojiCount;