pinDuration property
pinDuration The amount of time the message of this level will be pinned, in seconds
Implementation
final int pinDuration;
pinDuration The amount of time the message of this level will be pinned, in seconds
final int pinDuration;