GroupCallParticipant class final
Represents a group call participant
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GroupCallParticipant({MessageSender? participantId, required int audioSourceId, required int screenSharingAudioSourceId, GroupCallParticipantVideoInfo? videoInfo, GroupCallParticipantVideoInfo? screenSharingVideoInfo, required String bio, required bool isCurrentUser, required bool isSpeaking, required bool isHandRaised, required bool canBeMutedForAllUsers, required bool canBeUnmutedForAllUsers, required bool canBeMutedForCurrentUser, required bool canBeUnmutedForCurrentUser, required bool isMutedForAllUsers, required bool isMutedForCurrentUser, required bool canUnmuteSelf, required int volumeLevel, required String order})
Properties
- audioSourceId → int
-
audioSourceId User's audio channel synchronization source identifier
final
- bio → String
-
bio The participant user's bio or the participant chat's description
final
- canBeMutedForAllUsers → bool
-
canBeMutedForAllUsers True, if the current user can mute the participant
for all other group call participants
final
- canBeMutedForCurrentUser → bool
-
canBeMutedForCurrentUser True, if the current user can mute the
participant only for self
final
- canBeUnmutedForAllUsers → bool
-
canBeUnmutedForAllUsers True, if the current user can allow the
participant to unmute themselves or unmute the participant (if the
participant is the current user)
final
- canBeUnmutedForCurrentUser → bool
-
canBeUnmutedForCurrentUser True, if the current user can unmute the
participant for self
final
- canUnmuteSelf → bool
-
canUnmuteSelf True, if the participant is muted for all users, but can
unmute themselves
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCurrentUser → bool
-
isCurrentUser True, if the participant is the current user
final
- isHandRaised → bool
-
isHandRaised True, if the participant hand is raised
final
- isMutedForAllUsers → bool
-
isMutedForAllUsers True, if the participant is muted for all users
final
- isMutedForCurrentUser → bool
-
isMutedForCurrentUser True, if the participant is muted for the current
user
final
- isSpeaking → bool
-
isSpeaking True, if the participant is speaking as set by
setGroupCallParticipantIsSpeaking
final
- order → String
-
order User's order in the group call participant list. Orders must be
compared lexicographically. The bigger is order, the higher is user in the
list. If order is empty, the user must be removed from the participant
list
final
- participantId → MessageSender?
-
participantId Identifier of the group call participant
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSharingAudioSourceId → int
-
screenSharingAudioSourceId User's screen sharing audio channel
synchronization source identifier
final
- screenSharingVideoInfo → GroupCallParticipantVideoInfo?
-
screenSharingVideoInfo Information about user's screen sharing video
channel; may be null if there is no active screen sharing video
final
- videoInfo → GroupCallParticipantVideoInfo?
-
videoInfo Information about user's video channel; may be null if there
is no active video
final
- volumeLevel → int
-
volumeLevel Participant's volume level; 1-20000 in hundreds of percents
final
Methods
-
copyWith(
{MessageSender? participantId, int? audioSourceId, int? screenSharingAudioSourceId, GroupCallParticipantVideoInfo? videoInfo, GroupCallParticipantVideoInfo? screenSharingVideoInfo, String? bio, bool? isCurrentUser, bool? isSpeaking, bool? isHandRaised, bool? canBeMutedForAllUsers, bool? canBeUnmutedForAllUsers, bool? canBeMutedForCurrentUser, bool? canBeUnmutedForCurrentUser, bool? isMutedForAllUsers, bool? isMutedForCurrentUser, bool? canUnmuteSelf, int? volumeLevel, String? order}) → GroupCallParticipant -
Available on GroupCallParticipant, provided by the GroupCallParticipantExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallParticipant?
Constants
- constructor → const String