GroupCallParticipantVideoInfo class final

Contains information about a group call participant's video channel

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallParticipantVideoInfo({required List<GroupCallVideoSourceGroup> sourceGroups, required String endpointId, required bool isPaused})

Properties

endpointId String
endpointId Video channel endpoint identifier
final
hashCode int
The hash code for this object.
no setteroverride
isPaused bool
isPaused True, if the video is paused. This flag needs to be ignored, if new video frames are received
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceGroups List<GroupCallVideoSourceGroup>
sourceGroups List of synchronization source groups of the video
final

Methods

copyWith({List<GroupCallVideoSourceGroup>? sourceGroups, String? endpointId, bool? isPaused}) GroupCallParticipantVideoInfo

Available on GroupCallParticipantVideoInfo, provided by the GroupCallParticipantVideoInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallParticipantVideoInfo?

Constants

constructor → const String