GroupCallRecentSpeaker class final

Describes a recently speaking participant in a group call

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallRecentSpeaker({MessageSender? participantId, required bool isSpeaking})

Properties

hashCode int
The hash code for this object.
no setteroverride
isSpeaking bool
isSpeaking True, is the user has spoken recently
final
participantId MessageSender?
participantId Group call participant identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? participantId, bool? isSpeaking}) GroupCallRecentSpeaker

Available on GroupCallRecentSpeaker, provided by the GroupCallRecentSpeakerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallRecentSpeaker?

Constants

constructor → const String