GroupCallStream class final

Describes an available stream in a video chat or a live story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallStream({required int channelId, required int scale, required int timeOffset})

Properties

channelId int
channelId Identifier of an audio/video channel
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale int
scale Scale of segment durations in the stream. The duration is 1000/(2**scale) milliseconds
final
timeOffset int
timeOffset Point in time when the stream currently ends; Unix timestamp in milliseconds
final

Methods

copyWith({int? channelId, int? scale, int? timeOffset}) GroupCallStream

Available on GroupCallStream, provided by the GroupCallStreamExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallStream?

Constants

constructor → const String