GroupCallStreams class final

Represents a list of group call streams

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallStreams({required List<GroupCallStream> streams})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streams List<GroupCallStream>
streams A list of group call streams
final

Methods

copyWith({List<GroupCallStream>? streams}) GroupCallStreams

Available on GroupCallStreams, provided by the GroupCallStreamsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallStreams?

Constants

constructor → const String