GroupCallVideoQualityFull class final
The best available video quality
- Inheritance
-
- Object
- TdObject
- GroupCallVideoQuality
- GroupCallVideoQualityFull
- Available extensions
- Annotations
-
- @immutable
Constructors
- GroupCallVideoQualityFull()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult full(GroupCallVideoQualityFull value), required TResult medium(GroupCallVideoQualityMedium value), required TResult thumbnail(GroupCallVideoQualityThumbnail value)}) → TResult -
Available on GroupCallVideoQuality, provided by the GroupCallVideoQualityExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult full(GroupCallVideoQualityFull value)?, TResult medium(GroupCallVideoQualityMedium value)?, TResult thumbnail(GroupCallVideoQualityThumbnail value)?, required TResult orElse()}) → TResult -
Available on GroupCallVideoQuality, provided by the GroupCallVideoQualityExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallVideoQualityFull? -
Inherited by:
GroupCallVideoQualityFull
GroupCallVideoQualityMedium
GroupCallVideoQualityThumbnail
override
Constants
- constructor → const String