Hashtags class final

Contains a list of hashtags

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Hashtags({required List<String> hashtags})

Properties

hashCode int
The hash code for this object.
no setteroverride
hashtags List<String>
hashtags A list of hashtags
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? hashtags}) Hashtags

Available on Hashtags, provided by the HashtagsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Hashtags?

Constants

constructor → const String