HttpUrl class final

Contains an HTTP URL

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

HttpUrl({required String url})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The URL
final

Methods

copyWith({String? url}) HttpUrl

Available on HttpUrl, provided by the HttpUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) HttpUrl?

Constants

constructor → const String