IdentityDocument class final

An identity document

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

IdentityDocument({required String number, Date? expirationDate, DatedFile? frontSide, DatedFile? reverseSide, DatedFile? selfie, required List<DatedFile> translation})

Properties

expirationDate Date?
expirationDate Document expiration date; may be null if not applicable
final
frontSide DatedFile?
frontSide Front side of the document
final
hashCode int
The hash code for this object.
no setteroverride
number String
number Document number; 1-24 characters
final
reverseSide DatedFile?
reverseSide Reverse side of the document; only for driver license and identity card; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfie DatedFile?
selfie Selfie with the document; may be null
final
translation List<DatedFile>
translation List of files containing a certified English translation of the document
final

Methods

copyWith({String? number, Date? expirationDate, DatedFile? frontSide, DatedFile? reverseSide, DatedFile? selfie, List<DatedFile>? translation}) IdentityDocument

Available on IdentityDocument, provided by the IdentityDocumentExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) IdentityDocument?

Constants

constructor → const String