ImportContacts class final

Adds new contacts or edits existing contacts by their phone numbers; contacts' user identifiers are ignored Returns ImportedContacts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ImportContacts({required List<ImportedContact> contacts})

Properties

contacts List<ImportedContact>
contacts The list of contacts to import or edit
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<ImportedContact>? contacts}) ImportContacts

Available on ImportContacts, provided by the ImportContactsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String