ImportedContact class final

Describes a contact to import

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ImportedContact({required String phoneNumber, required String firstName, required String lastName, FormattedText? note})

Properties

firstName String
firstName First name of the user; 1-64 characters
final
hashCode int
The hash code for this object.
no setteroverride
lastName String
lastName Last name of the user; 0-64 characters
final
note FormattedText?
note Note to add about the user; 0-getOption("user_note_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed; pass null to keep the current user's note
final
phoneNumber String
phoneNumber Phone number of the user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? phoneNumber, String? firstName, String? lastName, FormattedText? note}) ImportedContact

Available on ImportedContact, provided by the ImportedContactExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ImportedContact?

Constants

constructor → const String