IncreaseGiftAuctionBid class final
Increases a bid for an auction gift without changing gift text and receiver Returns Ok
- Inheritance
-
- Object
- TdFunction
- IncreaseGiftAuctionBid
- Available extensions
- Annotations
-
- @immutable
Constructors
- IncreaseGiftAuctionBid({required int giftId, required int starCount})
Properties
Methods
-
copyWith(
{int? giftId, int? starCount}) → IncreaseGiftAuctionBid -
Available on IncreaseGiftAuctionBid, provided by the IncreaseGiftAuctionBidExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String