InlineKeyboardButtonType class sealed
Describes the type of inline keyboard button
- Inheritance
- Implementers
- InlineKeyboardButtonTypeBuy
- InlineKeyboardButtonTypeCallback
- InlineKeyboardButtonTypeCallbackGame
- InlineKeyboardButtonTypeCallbackWithPassword
- InlineKeyboardButtonTypeCopyText
- InlineKeyboardButtonTypeLoginUrl
- InlineKeyboardButtonTypeSwitchInline
- InlineKeyboardButtonTypeUrl
- InlineKeyboardButtonTypeUser
- InlineKeyboardButtonTypeWebApp
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult buy(InlineKeyboardButtonTypeBuy value), required TResult callback(InlineKeyboardButtonTypeCallback value), required TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value), required TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value), required TResult copyText(InlineKeyboardButtonTypeCopyText value), required TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value), required TResult switchInline(InlineKeyboardButtonTypeSwitchInline value), required TResult url(InlineKeyboardButtonTypeUrl value), required TResult user(InlineKeyboardButtonTypeUser value), required TResult webApp(InlineKeyboardButtonTypeWebApp value)}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult buy(InlineKeyboardButtonTypeBuy value)?, TResult callback(InlineKeyboardButtonTypeCallback value)?, TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value)?, TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value)?, TResult copyText(InlineKeyboardButtonTypeCopyText value)?, TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value)?, TResult switchInline(InlineKeyboardButtonTypeSwitchInline value)?, TResult url(InlineKeyboardButtonTypeUrl value)?, TResult user(InlineKeyboardButtonTypeUser value)?, TResult webApp(InlineKeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineKeyboardButtonType? - Inherited by: InlineKeyboardButtonTypeBuy InlineKeyboardButtonTypeCallback InlineKeyboardButtonTypeCallbackGame InlineKeyboardButtonTypeCallbackWithPassword InlineKeyboardButtonTypeCopyText InlineKeyboardButtonTypeLoginUrl InlineKeyboardButtonTypeSwitchInline InlineKeyboardButtonTypeUrl InlineKeyboardButtonTypeUser InlineKeyboardButtonTypeWebApp
Constants
- constructor → const String