InlineKeyboardButtonTypeSwitchInline class final
A button that forces an inline query to the bot to be inserted in the input field
- Inheritance
-
- Object
- TdObject
- InlineKeyboardButtonType
- InlineKeyboardButtonTypeSwitchInline
- Available extensions
- Annotations
-
- @immutable
Constructors
- InlineKeyboardButtonTypeSwitchInline({required String query, TargetChat? targetChat})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- query → String
-
query Inline query to be sent to the bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetChat → TargetChat?
-
targetChat Target chat from which to send the inline query
final
Methods
-
copyWith(
{String? query, TargetChat? targetChat}) → InlineKeyboardButtonTypeSwitchInline -
Available on InlineKeyboardButtonTypeSwitchInline, provided by the InlineKeyboardButtonTypeSwitchInlineExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult buy(InlineKeyboardButtonTypeBuy value), required TResult callback(InlineKeyboardButtonTypeCallback value), required TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value), required TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value), required TResult copyText(InlineKeyboardButtonTypeCopyText value), required TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value), required TResult switchInline(InlineKeyboardButtonTypeSwitchInline value), required TResult url(InlineKeyboardButtonTypeUrl value), required TResult user(InlineKeyboardButtonTypeUser value), required TResult webApp(InlineKeyboardButtonTypeWebApp value)}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult buy(InlineKeyboardButtonTypeBuy value)?, TResult callback(InlineKeyboardButtonTypeCallback value)?, TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value)?, TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value)?, TResult copyText(InlineKeyboardButtonTypeCopyText value)?, TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value)?, TResult switchInline(InlineKeyboardButtonTypeSwitchInline value)?, TResult url(InlineKeyboardButtonTypeUrl value)?, TResult user(InlineKeyboardButtonTypeUser value)?, TResult webApp(InlineKeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineKeyboardButtonTypeSwitchInline? -
Inherited by:
InlineKeyboardButtonTypeBuy
InlineKeyboardButtonTypeCallback
InlineKeyboardButtonTypeCallbackGame
InlineKeyboardButtonTypeCallbackWithPassword
InlineKeyboardButtonTypeCopyText
InlineKeyboardButtonTypeLoginUrl
InlineKeyboardButtonTypeSwitchInline
InlineKeyboardButtonTypeUrl
InlineKeyboardButtonTypeUser
InlineKeyboardButtonTypeWebApp
override
Constants
- constructor → const String