InlineKeyboardButtonTypeUser class final
A button with a user reference to be handled in the same way as textEntityTypeMentionName entities
- Inheritance
-
- Object
- TdObject
- InlineKeyboardButtonType
- InlineKeyboardButtonTypeUser
- Available extensions
- Annotations
-
- @immutable
Constructors
- InlineKeyboardButtonTypeUser({required int userId})
Properties
Methods
-
copyWith(
{int? userId}) → InlineKeyboardButtonTypeUser -
Available on InlineKeyboardButtonTypeUser, provided by the InlineKeyboardButtonTypeUserExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult buy(InlineKeyboardButtonTypeBuy value), required TResult callback(InlineKeyboardButtonTypeCallback value), required TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value), required TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value), required TResult copyText(InlineKeyboardButtonTypeCopyText value), required TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value), required TResult switchInline(InlineKeyboardButtonTypeSwitchInline value), required TResult url(InlineKeyboardButtonTypeUrl value), required TResult user(InlineKeyboardButtonTypeUser value), required TResult webApp(InlineKeyboardButtonTypeWebApp value)}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult buy(InlineKeyboardButtonTypeBuy value)?, TResult callback(InlineKeyboardButtonTypeCallback value)?, TResult callbackGame(InlineKeyboardButtonTypeCallbackGame value)?, TResult callbackWithPassword(InlineKeyboardButtonTypeCallbackWithPassword value)?, TResult copyText(InlineKeyboardButtonTypeCopyText value)?, TResult loginUrl(InlineKeyboardButtonTypeLoginUrl value)?, TResult switchInline(InlineKeyboardButtonTypeSwitchInline value)?, TResult url(InlineKeyboardButtonTypeUrl value)?, TResult user(InlineKeyboardButtonTypeUser value)?, TResult webApp(InlineKeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult -
Available on InlineKeyboardButtonType, provided by the InlineKeyboardButtonTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineKeyboardButtonTypeUser? -
Inherited by:
InlineKeyboardButtonTypeBuy
InlineKeyboardButtonTypeCallback
InlineKeyboardButtonTypeCallbackGame
InlineKeyboardButtonTypeCallbackWithPassword
InlineKeyboardButtonTypeCopyText
InlineKeyboardButtonTypeLoginUrl
InlineKeyboardButtonTypeSwitchInline
InlineKeyboardButtonTypeUrl
InlineKeyboardButtonTypeUser
InlineKeyboardButtonTypeWebApp
override
Constants
- constructor → const String