InlineQueryResult class sealed
Represents a single result of an inline query
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InlineQueryResultAnimation value), required TResult article(InlineQueryResultArticle value), required TResult audio(InlineQueryResultAudio value), required TResult contact(InlineQueryResultContact value), required TResult document(InlineQueryResultDocument value), required TResult game(InlineQueryResultGame value), required TResult location(InlineQueryResultLocation value), required TResult photo(InlineQueryResultPhoto value), required TResult sticker(InlineQueryResultSticker value), required TResult venue(InlineQueryResultVenue value), required TResult video(InlineQueryResultVideo value), required TResult voiceNote(InlineQueryResultVoiceNote value)}) → TResult -
Available on InlineQueryResult, provided by the InlineQueryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InlineQueryResultAnimation value)?, TResult article(InlineQueryResultArticle value)?, TResult audio(InlineQueryResultAudio value)?, TResult contact(InlineQueryResultContact value)?, TResult document(InlineQueryResultDocument value)?, TResult game(InlineQueryResultGame value)?, TResult location(InlineQueryResultLocation value)?, TResult photo(InlineQueryResultPhoto value)?, TResult sticker(InlineQueryResultSticker value)?, TResult venue(InlineQueryResultVenue value)?, TResult video(InlineQueryResultVideo value)?, TResult voiceNote(InlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult -
Available on InlineQueryResult, provided by the InlineQueryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineQueryResult? - Inherited by: InlineQueryResultAnimation InlineQueryResultArticle InlineQueryResultAudio InlineQueryResultContact InlineQueryResultDocument InlineQueryResultGame InlineQueryResultLocation InlineQueryResultPhoto InlineQueryResultSticker InlineQueryResultVenue InlineQueryResultVideo InlineQueryResultVoiceNote
Constants
- constructor → const String