InlineQueryResultLocation class final

Represents a point on the map

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InlineQueryResultLocation({required String id, Location? location, required String title, Thumbnail? thumbnail})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the query result
final
location Location?
location Location result
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail Thumbnail?
thumbnail Result thumbnail in JPEG format; may be null
final
title String
title Title of the result
final

Methods

copyWith({String? id, Location? location, String? title, Thumbnail? thumbnail}) InlineQueryResultLocation

Available on InlineQueryResultLocation, provided by the InlineQueryResultLocationExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(InlineQueryResultAnimation value), required TResult article(InlineQueryResultArticle value), required TResult audio(InlineQueryResultAudio value), required TResult contact(InlineQueryResultContact value), required TResult document(InlineQueryResultDocument value), required TResult game(InlineQueryResultGame value), required TResult location(InlineQueryResultLocation value), required TResult photo(InlineQueryResultPhoto value), required TResult sticker(InlineQueryResultSticker value), required TResult venue(InlineQueryResultVenue value), required TResult video(InlineQueryResultVideo value), required TResult voiceNote(InlineQueryResultVoiceNote value)}) → TResult

Available on InlineQueryResult, provided by the InlineQueryResultExtensions extension

maybeMap<TResult extends Object?>({TResult animation(InlineQueryResultAnimation value)?, TResult article(InlineQueryResultArticle value)?, TResult audio(InlineQueryResultAudio value)?, TResult contact(InlineQueryResultContact value)?, TResult document(InlineQueryResultDocument value)?, TResult game(InlineQueryResultGame value)?, TResult location(InlineQueryResultLocation value)?, TResult photo(InlineQueryResultPhoto value)?, TResult sticker(InlineQueryResultSticker value)?, TResult venue(InlineQueryResultVenue value)?, TResult video(InlineQueryResultVideo value)?, TResult voiceNote(InlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult

Available on InlineQueryResult, provided by the InlineQueryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String