InlineQueryResultsButton class final
Represents a button to be shown above inline query results
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InlineQueryResultsButton({required String text, InlineQueryResultsButtonType? type})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
text The text of the button
final
- type → InlineQueryResultsButtonType?
-
type Type of the button
final
Methods
-
copyWith(
{String? text, InlineQueryResultsButtonType? type}) → InlineQueryResultsButton -
Available on InlineQueryResultsButton, provided by the InlineQueryResultsButtonExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineQueryResultsButton?
Constants
- constructor → const String