InlineQueryResultsButtonTypeStartBot class final

Describes the button that opens a private chat with the bot and sends a start message to the bot with the given parameter

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InlineQueryResultsButtonTypeStartBot({required String parameter})

Properties

hashCode int
The hash code for this object.
no setteroverride
parameter String
parameter The parameter for the bot start message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? parameter}) InlineQueryResultsButtonTypeStartBot

Available on InlineQueryResultsButtonTypeStartBot, provided by the InlineQueryResultsButtonTypeStartBotExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult startBot(InlineQueryResultsButtonTypeStartBot value), required TResult webApp(InlineQueryResultsButtonTypeWebApp value)}) → TResult

Available on InlineQueryResultsButtonType, provided by the InlineQueryResultsButtonTypeExtensions extension

maybeMap<TResult extends Object?>({TResult startBot(InlineQueryResultsButtonTypeStartBot value)?, TResult webApp(InlineQueryResultsButtonTypeWebApp value)?, required TResult orElse()}) → TResult

Available on InlineQueryResultsButtonType, provided by the InlineQueryResultsButtonTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String