InputBackgroundPrevious class final

A background previously set in the chat; for chat backgrounds only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputBackgroundPrevious({required int messageId})

Properties

hashCode → int
The hash code for this object.
no setteroverride
messageId → int
messageId Identifier of the message with the background
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? messageId}) → InputBackgroundPrevious

Available on InputBackgroundPrevious, provided by the InputBackgroundPreviousExtensions extension

getConstructor() → String
override
map<TResult extends Object?>({required TResult local(InputBackgroundLocal value), required TResult previous(InputBackgroundPrevious value), required TResult remote(InputBackgroundRemote value)}) → TResult

Available on InputBackground, provided by the InputBackgroundExtensions extension

maybeMap<TResult extends Object?>({TResult local(InputBackgroundLocal value)?, TResult previous(InputBackgroundPrevious value)?, TResult remote(InputBackgroundRemote value)?, required TResult orElse()}) → TResult

Available on InputBackground, provided by the InputBackgroundExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

constructor → const String