InputBackgroundRemote class final

A background from the server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputBackgroundRemote({required int backgroundId})

Properties

backgroundId int
backgroundId The background identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? backgroundId}) InputBackgroundRemote

Available on InputBackgroundRemote, provided by the InputBackgroundRemoteExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult local(InputBackgroundLocal value), required TResult previous(InputBackgroundPrevious value), required TResult remote(InputBackgroundRemote value)}) → TResult

Available on InputBackground, provided by the InputBackgroundExtensions extension

maybeMap<TResult extends Object?>({TResult local(InputBackgroundLocal value)?, TResult previous(InputBackgroundPrevious value)?, TResult remote(InputBackgroundRemote value)?, required TResult orElse()}) → TResult

Available on InputBackground, provided by the InputBackgroundExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputBackgroundRemote?
Inherited by: InputBackgroundLocal InputBackgroundPrevious InputBackgroundRemote
override

Constants

constructor → const String