InputBusinessStartPage class final

Describes settings for a business account start page to set

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputBusinessStartPage({required String title, required String message, InputFile? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
message String
message Message text of the start page; 0-getOption("business_start_page_message_length_max") characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker Greeting sticker of the start page; pass null if none. The sticker must belong to a sticker set and must not be a custom emoji
final
title String
title Title text of the start page; 0-getOption("business_start_page_title_length_max") characters
final

Methods

copyWith({String? title, String? message, InputFile? sticker}) InputBusinessStartPage

Available on InputBusinessStartPage, provided by the InputBusinessStartPageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputBusinessStartPage?

Constants

constructor → const String