InputCallDiscarded class final

A just ended call

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputCallDiscarded({required int callId})

Properties

callId int
callId Identifier of the call
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId}) InputCallDiscarded

Available on InputCallDiscarded, provided by the InputCallDiscardedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult discarded(InputCallDiscarded value), required TResult fromMessage(InputCallFromMessage value)}) → TResult

Available on InputCall, provided by the InputCallExtensions extension

maybeMap<TResult extends Object?>({TResult discarded(InputCallDiscarded value)?, TResult fromMessage(InputCallFromMessage value)?, required TResult orElse()}) → TResult

Available on InputCall, provided by the InputCallExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputCallDiscarded?
Inherited by: InputCallDiscarded InputCallFromMessage
override

Constants

constructor → const String