InputCallFromMessage class final

A call from a message of the type messageCall with non-zero messageCall.unique_id

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputCallFromMessage({required int chatId, required int messageId})

Properties

chatId int
chatId Chat identifier of the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) InputCallFromMessage

Available on InputCallFromMessage, provided by the InputCallFromMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult discarded(InputCallDiscarded value), required TResult fromMessage(InputCallFromMessage value)}) → TResult

Available on InputCall, provided by the InputCallExtensions extension

maybeMap<TResult extends Object?>({TResult discarded(InputCallDiscarded value)?, TResult fromMessage(InputCallFromMessage value)?, required TResult orElse()}) → TResult

Available on InputCall, provided by the InputCallExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputCallFromMessage?
Inherited by: InputCallDiscarded InputCallFromMessage
override

Constants

constructor → const String