InputChatPhoto class sealed

Describes a photo to be set as a user profile or chat photo

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(InputChatPhotoAnimation value), required TResult previous(InputChatPhotoPrevious value), required TResult static(InputChatPhotoStatic value), required TResult sticker(InputChatPhotoSticker value)}) → TResult

Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension

maybeMap<TResult extends Object?>({TResult animation(InputChatPhotoAnimation value)?, TResult previous(InputChatPhotoPrevious value)?, TResult static(InputChatPhotoStatic value)?, TResult sticker(InputChatPhotoSticker value)?, required TResult orElse()}) → TResult

Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String