InputChatPhotoSticker class final
A sticker on a custom background
- Inheritance
-
- Object
- TdObject
- InputChatPhoto
- InputChatPhotoSticker
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputChatPhotoSticker({ChatPhotoSticker? sticker})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → ChatPhotoSticker?
-
sticker Information about the sticker
final
Methods
-
copyWith(
{ChatPhotoSticker? sticker}) → InputChatPhotoSticker -
Available on InputChatPhotoSticker, provided by the InputChatPhotoStickerExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InputChatPhotoAnimation value), required TResult previous(InputChatPhotoPrevious value), required TResult static(InputChatPhotoStatic value), required TResult sticker(InputChatPhotoSticker value)}) → TResult -
Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InputChatPhotoAnimation value)?, TResult previous(InputChatPhotoPrevious value)?, TResult static(InputChatPhotoStatic value)?, TResult sticker(InputChatPhotoSticker value)?, required TResult orElse()}) → TResult -
Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputChatPhotoSticker? -
Inherited by:
InputChatPhotoAnimation
InputChatPhotoPrevious
InputChatPhotoStatic
InputChatPhotoSticker
override
Constants
- constructor → const String