InputChatThemeEmoji class final

A theme based on an emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputChatThemeEmoji({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the theme
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) InputChatThemeEmoji

Available on InputChatThemeEmoji, provided by the InputChatThemeEmojiExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult emoji(InputChatThemeEmoji value), required TResult gift(InputChatThemeGift value)}) → TResult

Available on InputChatTheme, provided by the InputChatThemeExtensions extension

maybeMap<TResult extends Object?>({TResult emoji(InputChatThemeEmoji value)?, TResult gift(InputChatThemeGift value)?, required TResult orElse()}) → TResult

Available on InputChatTheme, provided by the InputChatThemeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputChatThemeEmoji?
Inherited by: InputChatThemeEmoji InputChatThemeGift
override

Constants

constructor → const String