InputChatThemeGift class final
A theme based on an upgraded gift
- Inheritance
-
- Object
- TdObject
- InputChatTheme
- InputChatThemeGift
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputChatThemeGift({required String name})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the upgraded gift. A gift can be used only in one chat in a
time. When the same gift is used in another chat, theme in the previous
chat is reset to default
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? name}) → InputChatThemeGift -
Available on InputChatThemeGift, provided by the InputChatThemeGiftExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult emoji(InputChatThemeEmoji value), required TResult gift(InputChatThemeGift value)}) → TResult -
Available on InputChatTheme, provided by the InputChatThemeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult emoji(InputChatThemeEmoji value)?, TResult gift(InputChatThemeGift value)?, required TResult orElse()}) → TResult -
Available on InputChatTheme, provided by the InputChatThemeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputChatThemeGift? -
Inherited by:
InputChatThemeEmoji
InputChatThemeGift
override
Constants
- constructor → const String