InputChecklist class final

Describes a checklist to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputChecklist({FormattedText? title, required List<InputChecklistTask> tasks, required bool othersCanAddTasks, required bool othersCanMarkTasksAsDone})

Properties

hashCode int
The hash code for this object.
no setteroverride
othersCanAddTasks bool
othersCanAddTasks True, if other users can add tasks to the list
final
othersCanMarkTasksAsDone bool
othersCanMarkTasksAsDone True, if other users can mark tasks as done or not done
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks List<InputChecklistTask>
tasks List of tasks in the checklist; 1-getOption("checklist_task_count_max") tasks
final
title FormattedText?
title Title of the checklist; 1-getOption("checklist_title_length_max") characters. May contain only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities
final

Methods

copyWith({FormattedText? title, List<InputChecklistTask>? tasks, bool? othersCanAddTasks, bool? othersCanMarkTasksAsDone}) InputChecklist

Available on InputChecklist, provided by the InputChecklistExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputChecklist?

Constants

constructor → const String