othersCanMarkTasksAsDone property
othersCanMarkTasksAsDone True, if other users can mark tasks as done or not done
Implementation
final bool othersCanMarkTasksAsDone;
othersCanMarkTasksAsDone True, if other users can mark tasks as done or not done
final bool othersCanMarkTasksAsDone;