InputChecklistTask class final

Describes a task in a checklist to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputChecklistTask({required int id, FormattedText? text})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the task; must be positive
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text of the task; 1-getOption("checklist_task_text_length_max") characters without line feeds. May contain only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities
final

Methods

copyWith({int? id, FormattedText? text}) InputChecklistTask

Available on InputChecklistTask, provided by the InputChecklistTaskExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputChecklistTask?

Constants

constructor → const String