InputCredentialsSaved class final

Applies if a user chooses some previously saved payment credentials. To use their previously saved credentials, the user must have a valid temporary password

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputCredentialsSaved({required String savedCredentialsId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedCredentialsId String
savedCredentialsId Identifier of the saved credentials
final

Methods

copyWith({String? savedCredentialsId}) InputCredentialsSaved

Available on InputCredentialsSaved, provided by the InputCredentialsSavedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult applePay(InputCredentialsApplePay value), required TResult googlePay(InputCredentialsGooglePay value), required TResult $new(InputCredentialsNew value), required TResult saved(InputCredentialsSaved value)}) → TResult

Available on InputCredentials, provided by the InputCredentialsExtensions extension

maybeMap<TResult extends Object?>({TResult applePay(InputCredentialsApplePay value)?, TResult googlePay(InputCredentialsGooglePay value)?, TResult $new(InputCredentialsNew value)?, TResult saved(InputCredentialsSaved value)?, required TResult orElse()}) → TResult

Available on InputCredentials, provided by the InputCredentialsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String