disableContentTypeDetection property
disableContentTypeDetection Pass true to disable automatic file type detection and send the document as a file. Always true for files sent to secret chats
Implementation
final bool disableContentTypeDetection;
disableContentTypeDetection Pass true to disable automatic file type detection and send the document as a file. Always true for files sent to secret chats
final bool disableContentTypeDetection;