originalPath property

String originalPath
final

originalPath Local path to a file from which the file is generated. The path doesn't have to be a valid path and is used by TDLib only to detect name and MIME type of the generated file

Implementation

final String originalPath;