InputFileRemote class final

A file defined by its remote identifier. The remote identifier is guaranteed to be usable only if the corresponding file is still accessible to the user and known to TDLib. For example, if the file is from a message, then the message must be not deleted and accessible to the user. If the file database is disabled, then the corresponding object with the file must be preloaded by the application

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputFileRemote({required String id})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Remote file identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id}) InputFileRemote

Available on InputFileRemote, provided by the InputFileRemoteExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult generated(InputFileGenerated value), required TResult id(InputFileId value), required TResult local(InputFileLocal value), required TResult remote(InputFileRemote value)}) → TResult

Available on InputFile, provided by the InputFileExtensions extension

maybeMap<TResult extends Object?>({TResult generated(InputFileGenerated value)?, TResult id(InputFileId value)?, TResult local(InputFileLocal value)?, TResult remote(InputFileRemote value)?, required TResult orElse()}) → TResult

Available on InputFile, provided by the InputFileExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputFileRemote?
Inherited by: InputFileGenerated InputFileId InputFileLocal InputFileRemote
override

Constants

constructor → const String