InputGroupCall class sealed
Describes a non-joined group call that isn't bound to a chat
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult link(InputGroupCallLink value), required TResult message(InputGroupCallMessage value)}) → TResult -
Available on InputGroupCall, provided by the InputGroupCallExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult link(InputGroupCallLink value)?, TResult message(InputGroupCallMessage value)?, required TResult orElse()}) → TResult -
Available on InputGroupCall, provided by the InputGroupCallExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputGroupCall? - Inherited by: InputGroupCallLink InputGroupCallMessage
Constants
- constructor → const String