InputGroupCallLink class final

The group call is accessible through a link

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputGroupCallLink({required String link})

Properties

hashCode int
The hash code for this object.
no setteroverride
link The link for the group call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? link}) InputGroupCallLink

Available on InputGroupCallLink, provided by the InputGroupCallLinkExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult link(InputGroupCallLink value), required TResult message(InputGroupCallMessage value)}) → TResult

Available on InputGroupCall, provided by the InputGroupCallExtensions extension

maybeMap<TResult extends Object?>({TResult link(InputGroupCallLink value)?, TResult message(InputGroupCallMessage value)?, required TResult orElse()}) → TResult

Available on InputGroupCall, provided by the InputGroupCallExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputGroupCallLink?
Inherited by: InputGroupCallLink InputGroupCallMessage
override

Constants

constructor → const String