InputGroupCallMessage class final

The group call is accessible through a message of the type messageGroupCall

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputGroupCallMessage({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message of the type messageGroupCall
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) InputGroupCallMessage

Available on InputGroupCallMessage, provided by the InputGroupCallMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult link(InputGroupCallLink value), required TResult message(InputGroupCallMessage value)}) → TResult

Available on InputGroupCall, provided by the InputGroupCallExtensions extension

maybeMap<TResult extends Object?>({TResult link(InputGroupCallLink value)?, TResult message(InputGroupCallMessage value)?, required TResult orElse()}) → TResult

Available on InputGroupCall, provided by the InputGroupCallExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputGroupCallMessage?
Inherited by: InputGroupCallLink InputGroupCallMessage
override

Constants

constructor → const String