InputInlineQueryResult class sealed
Represents a single result of an inline query; for bots only
- Inheritance
- Implementers
- InputInlineQueryResultAnimation
- InputInlineQueryResultArticle
- InputInlineQueryResultAudio
- InputInlineQueryResultContact
- InputInlineQueryResultDocument
- InputInlineQueryResultGame
- InputInlineQueryResultLocation
- InputInlineQueryResultPhoto
- InputInlineQueryResultSticker
- InputInlineQueryResultVenue
- InputInlineQueryResultVideo
- InputInlineQueryResultVoiceNote
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InputInlineQueryResultAnimation value), required TResult article(InputInlineQueryResultArticle value), required TResult audio(InputInlineQueryResultAudio value), required TResult contact(InputInlineQueryResultContact value), required TResult document(InputInlineQueryResultDocument value), required TResult game(InputInlineQueryResultGame value), required TResult location(InputInlineQueryResultLocation value), required TResult photo(InputInlineQueryResultPhoto value), required TResult sticker(InputInlineQueryResultSticker value), required TResult venue(InputInlineQueryResultVenue value), required TResult video(InputInlineQueryResultVideo value), required TResult voiceNote(InputInlineQueryResultVoiceNote value)}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InputInlineQueryResultAnimation value)?, TResult article(InputInlineQueryResultArticle value)?, TResult audio(InputInlineQueryResultAudio value)?, TResult contact(InputInlineQueryResultContact value)?, TResult document(InputInlineQueryResultDocument value)?, TResult game(InputInlineQueryResultGame value)?, TResult location(InputInlineQueryResultLocation value)?, TResult photo(InputInlineQueryResultPhoto value)?, TResult sticker(InputInlineQueryResultSticker value)?, TResult venue(InputInlineQueryResultVenue value)?, TResult video(InputInlineQueryResultVideo value)?, TResult voiceNote(InputInlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputInlineQueryResult? - Inherited by: InputInlineQueryResultAnimation InputInlineQueryResultArticle InputInlineQueryResultAudio InputInlineQueryResultContact InputInlineQueryResultDocument InputInlineQueryResultGame InputInlineQueryResultLocation InputInlineQueryResultPhoto InputInlineQueryResultSticker InputInlineQueryResultVenue InputInlineQueryResultVideo InputInlineQueryResultVoiceNote
Constants
- constructor → const String