InputInlineQueryResultAnimation class final
Represents a link to an animated GIF or an animated (i.e., without sound) H.264/MPEG-4 AVC video
- Inheritance
-
- Object
- TdObject
- InputInlineQueryResult
- InputInlineQueryResultAnimation
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputInlineQueryResultAnimation({required String id, required String title, required String thumbnailUrl, required String thumbnailMimeType, required String videoUrl, required String videoMimeType, required int videoDuration, required int videoWidth, required int videoHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique identifier of the query result
final
- inputMessageContent → InputMessageContent?
-
inputMessageContent The content of the message to be sent. Must be one
of the following types: inputMessageText, inputMessageRichMessage,
inputMessageAnimation, inputMessageInvoice, inputMessageLiveLocation,
inputMessageLocation, inputMessageVenue or inputMessageContact
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The message reply markup; pass null if none. Must be of type
replyMarkupInlineKeyboard or null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnailMimeType → String
-
thumbnailMimeType MIME type of the video thumbnail. If non-empty, must
be one of "image/jpeg", "image/gif" and "video/mp4"
final
- thumbnailUrl → String
-
thumbnailUrl URL of the result thumbnail (JPEG, GIF, or MPEG4), if it
exists
final
- title → String
-
title Title of the query result
final
- videoDuration → int
-
videoDuration Duration of the video, in seconds
final
- videoHeight → int
-
videoHeight Height of the video
final
- videoMimeType → String
-
videoMimeType MIME type of the video file. Must be one of "image/gif"
and "video/mp4"
final
- videoUrl → String
-
videoUrl The URL of the video file (file size must not exceed 1MB)
final
- videoWidth → int
-
videoWidth Width of the video
final
Methods
-
copyWith(
{String? id, String? title, String? thumbnailUrl, String? thumbnailMimeType, String? videoUrl, String? videoMimeType, int? videoDuration, int? videoWidth, int? videoHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultAnimation -
Available on InputInlineQueryResultAnimation, provided by the InputInlineQueryResultAnimationExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InputInlineQueryResultAnimation value), required TResult article(InputInlineQueryResultArticle value), required TResult audio(InputInlineQueryResultAudio value), required TResult contact(InputInlineQueryResultContact value), required TResult document(InputInlineQueryResultDocument value), required TResult game(InputInlineQueryResultGame value), required TResult location(InputInlineQueryResultLocation value), required TResult photo(InputInlineQueryResultPhoto value), required TResult sticker(InputInlineQueryResultSticker value), required TResult venue(InputInlineQueryResultVenue value), required TResult video(InputInlineQueryResultVideo value), required TResult voiceNote(InputInlineQueryResultVoiceNote value)}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InputInlineQueryResultAnimation value)?, TResult article(InputInlineQueryResultArticle value)?, TResult audio(InputInlineQueryResultAudio value)?, TResult contact(InputInlineQueryResultContact value)?, TResult document(InputInlineQueryResultDocument value)?, TResult game(InputInlineQueryResultGame value)?, TResult location(InputInlineQueryResultLocation value)?, TResult photo(InputInlineQueryResultPhoto value)?, TResult sticker(InputInlineQueryResultSticker value)?, TResult venue(InputInlineQueryResultVenue value)?, TResult video(InputInlineQueryResultVideo value)?, TResult voiceNote(InputInlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputInlineQueryResultAnimation? -
Inherited by:
InputInlineQueryResultAnimation
InputInlineQueryResultArticle
InputInlineQueryResultAudio
InputInlineQueryResultContact
InputInlineQueryResultDocument
InputInlineQueryResultGame
InputInlineQueryResultLocation
InputInlineQueryResultPhoto
InputInlineQueryResultSticker
InputInlineQueryResultVenue
InputInlineQueryResultVideo
InputInlineQueryResultVoiceNote
override
Constants
- constructor → const String