InputInlineQueryResultAudio class final

Represents a link to an MP3 audio file

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputInlineQueryResultAudio({required String id, required String title, required String performer, required String audioUrl, required int audioDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

audioDuration int
audioDuration Audio file duration, in seconds
final
audioUrl String
audioUrl The URL of the audio file
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the query result
final
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageRichMessage, inputMessageAudio, inputMessageInvoice, inputMessageLiveLocation, inputMessageLocation, inputMessageVenue or inputMessageContact
final
performer String
performer Performer of the audio file
final
replyMarkup ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Title of the audio file
final

Methods

copyWith({String? id, String? title, String? performer, String? audioUrl, int? audioDuration, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) InputInlineQueryResultAudio

Available on InputInlineQueryResultAudio, provided by the InputInlineQueryResultAudioExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(InputInlineQueryResultAnimation value), required TResult article(InputInlineQueryResultArticle value), required TResult audio(InputInlineQueryResultAudio value), required TResult contact(InputInlineQueryResultContact value), required TResult document(InputInlineQueryResultDocument value), required TResult game(InputInlineQueryResultGame value), required TResult location(InputInlineQueryResultLocation value), required TResult photo(InputInlineQueryResultPhoto value), required TResult sticker(InputInlineQueryResultSticker value), required TResult venue(InputInlineQueryResultVenue value), required TResult video(InputInlineQueryResultVideo value), required TResult voiceNote(InputInlineQueryResultVoiceNote value)}) → TResult

Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension

maybeMap<TResult extends Object?>({TResult animation(InputInlineQueryResultAnimation value)?, TResult article(InputInlineQueryResultArticle value)?, TResult audio(InputInlineQueryResultAudio value)?, TResult contact(InputInlineQueryResultContact value)?, TResult document(InputInlineQueryResultDocument value)?, TResult game(InputInlineQueryResultGame value)?, TResult location(InputInlineQueryResultLocation value)?, TResult photo(InputInlineQueryResultPhoto value)?, TResult sticker(InputInlineQueryResultSticker value)?, TResult venue(InputInlineQueryResultVenue value)?, TResult video(InputInlineQueryResultVideo value)?, TResult voiceNote(InputInlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult

Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String