InputInlineQueryResultPhoto class final

Represents link to a JPEG image

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputInlineQueryResultPhoto({required String id, required String title, required String description, required String thumbnailUrl, required String photoUrl, required int photoWidth, required int photoHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

description String
param_description A short description of the result, if known
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the query result
final
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageRichMessage, inputMessagePhoto, inputMessageInvoice, inputMessageLiveLocation, inputMessageLocation, inputMessageVenue or inputMessageContact
final
photoHeight int
photoHeight Height of the photo
final
photoUrl String
photoUrl The URL of the JPEG photo (photo size must not exceed 5MB)
final
photoWidth int
photoWidth Width of the photo
final
replyMarkup ReplyMarkup?
replyMarkup The message reply markup; pass null if none. Must be of type replyMarkupInlineKeyboard or null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl String
thumbnailUrl URL of the photo thumbnail, if it exists
final
title String
title Title of the result, if known
final

Methods

copyWith({String? id, String? title, String? description, String? thumbnailUrl, String? photoUrl, int? photoWidth, int? photoHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) InputInlineQueryResultPhoto

Available on InputInlineQueryResultPhoto, provided by the InputInlineQueryResultPhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(InputInlineQueryResultAnimation value), required TResult article(InputInlineQueryResultArticle value), required TResult audio(InputInlineQueryResultAudio value), required TResult contact(InputInlineQueryResultContact value), required TResult document(InputInlineQueryResultDocument value), required TResult game(InputInlineQueryResultGame value), required TResult location(InputInlineQueryResultLocation value), required TResult photo(InputInlineQueryResultPhoto value), required TResult sticker(InputInlineQueryResultSticker value), required TResult venue(InputInlineQueryResultVenue value), required TResult video(InputInlineQueryResultVideo value), required TResult voiceNote(InputInlineQueryResultVoiceNote value)}) → TResult

Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension

maybeMap<TResult extends Object?>({TResult animation(InputInlineQueryResultAnimation value)?, TResult article(InputInlineQueryResultArticle value)?, TResult audio(InputInlineQueryResultAudio value)?, TResult contact(InputInlineQueryResultContact value)?, TResult document(InputInlineQueryResultDocument value)?, TResult game(InputInlineQueryResultGame value)?, TResult location(InputInlineQueryResultLocation value)?, TResult photo(InputInlineQueryResultPhoto value)?, TResult sticker(InputInlineQueryResultSticker value)?, TResult venue(InputInlineQueryResultVenue value)?, TResult video(InputInlineQueryResultVideo value)?, TResult voiceNote(InputInlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult

Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String