InputInlineQueryResultSticker class final
Represents a link to a WEBP, TGS, or WEBM sticker
- Inheritance
-
- Object
- TdObject
- InputInlineQueryResult
- InputInlineQueryResultSticker
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputInlineQueryResultSticker({required String id, required String thumbnailUrl, required String stickerUrl, required int stickerWidth, required int stickerHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique identifier of the query result
final
- inputMessageContent → InputMessageContent?
-
inputMessageContent The content of the message to be sent. Must be one
of the following types: inputMessageText, inputMessageRichMessage,
inputMessageSticker, inputMessageInvoice, inputMessageLiveLocation,
inputMessageLocation, inputMessageVenue or inputMessageContact
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The message reply markup; pass null if none. Must be of type
replyMarkupInlineKeyboard or null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerHeight → int
-
stickerHeight Height of the sticker
final
- stickerUrl → String
-
stickerUrl The URL of the WEBP, TGS, or WEBM sticker (sticker file size
must not exceed 5MB)
final
- stickerWidth → int
-
stickerWidth Width of the sticker
final
- thumbnailUrl → String
-
thumbnailUrl URL of the sticker thumbnail, if it exists
final
Methods
-
copyWith(
{String? id, String? thumbnailUrl, String? stickerUrl, int? stickerWidth, int? stickerHeight, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → InputInlineQueryResultSticker -
Available on InputInlineQueryResultSticker, provided by the InputInlineQueryResultStickerExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InputInlineQueryResultAnimation value), required TResult article(InputInlineQueryResultArticle value), required TResult audio(InputInlineQueryResultAudio value), required TResult contact(InputInlineQueryResultContact value), required TResult document(InputInlineQueryResultDocument value), required TResult game(InputInlineQueryResultGame value), required TResult location(InputInlineQueryResultLocation value), required TResult photo(InputInlineQueryResultPhoto value), required TResult sticker(InputInlineQueryResultSticker value), required TResult venue(InputInlineQueryResultVenue value), required TResult video(InputInlineQueryResultVideo value), required TResult voiceNote(InputInlineQueryResultVoiceNote value)}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InputInlineQueryResultAnimation value)?, TResult article(InputInlineQueryResultArticle value)?, TResult audio(InputInlineQueryResultAudio value)?, TResult contact(InputInlineQueryResultContact value)?, TResult document(InputInlineQueryResultDocument value)?, TResult game(InputInlineQueryResultGame value)?, TResult location(InputInlineQueryResultLocation value)?, TResult photo(InputInlineQueryResultPhoto value)?, TResult sticker(InputInlineQueryResultSticker value)?, TResult venue(InputInlineQueryResultVenue value)?, TResult video(InputInlineQueryResultVideo value)?, TResult voiceNote(InputInlineQueryResultVoiceNote value)?, required TResult orElse()}) → TResult -
Available on InputInlineQueryResult, provided by the InputInlineQueryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputInlineQueryResultSticker? -
Inherited by:
InputInlineQueryResultAnimation
InputInlineQueryResultArticle
InputInlineQueryResultAudio
InputInlineQueryResultContact
InputInlineQueryResultDocument
InputInlineQueryResultGame
InputInlineQueryResultLocation
InputInlineQueryResultPhoto
InputInlineQueryResultSticker
InputInlineQueryResultVenue
InputInlineQueryResultVideo
InputInlineQueryResultVoiceNote
override
Constants
- constructor → const String