InputInvoiceMessage class final

An invoice from a message of the type messageInvoice or paid media purchase from messagePaidMedia

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputInvoiceMessage({required int chatId, required int messageId})

Properties

chatId int
chatId Chat identifier of the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier. Use messageProperties.can_be_paid to check whether the message can be used in the method
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) InputInvoiceMessage

Available on InputInvoiceMessage, provided by the InputInvoiceMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(InputInvoiceMessage value), required TResult name(InputInvoiceName value), required TResult telegram(InputInvoiceTelegram value)}) → TResult

Available on InputInvoice, provided by the InputInvoiceExtensions extension

maybeMap<TResult extends Object?>({TResult message(InputInvoiceMessage value)?, TResult name(InputInvoiceName value)?, TResult telegram(InputInvoiceTelegram value)?, required TResult orElse()}) → TResult

Available on InputInvoice, provided by the InputInvoiceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputInvoiceMessage?
Inherited by: InputInvoiceMessage InputInvoiceName InputInvoiceTelegram
override

Constants

constructor → const String