InputInvoiceName class final

An invoice from a link of the type internalLinkTypeInvoice

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputInvoiceName({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the invoice
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) InputInvoiceName

Available on InputInvoiceName, provided by the InputInvoiceNameExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(InputInvoiceMessage value), required TResult name(InputInvoiceName value), required TResult telegram(InputInvoiceTelegram value)}) → TResult

Available on InputInvoice, provided by the InputInvoiceExtensions extension

maybeMap<TResult extends Object?>({TResult message(InputInvoiceMessage value)?, TResult name(InputInvoiceName value)?, TResult telegram(InputInvoiceTelegram value)?, required TResult orElse()}) → TResult

Available on InputInvoice, provided by the InputInvoiceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputInvoiceName?
Inherited by: InputInvoiceMessage InputInvoiceName InputInvoiceTelegram
override

Constants

constructor → const String