InputInvoiceTelegram class final
An invoice for a payment toward Telegram; must not be used in the in-store apps
- Inheritance
-
- Object
- TdObject
- InputInvoice
- InputInvoiceTelegram
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputInvoiceTelegram({TelegramPaymentPurpose? purpose})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- purpose → TelegramPaymentPurpose?
-
purpose Transaction purpose
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{TelegramPaymentPurpose? purpose}) → InputInvoiceTelegram -
Available on InputInvoiceTelegram, provided by the InputInvoiceTelegramExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult message(InputInvoiceMessage value), required TResult name(InputInvoiceName value), required TResult telegram(InputInvoiceTelegram value)}) → TResult -
Available on InputInvoice, provided by the InputInvoiceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult message(InputInvoiceMessage value)?, TResult name(InputInvoiceName value)?, TResult telegram(InputInvoiceTelegram value)?, required TResult orElse()}) → TResult -
Available on InputInvoice, provided by the InputInvoiceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputInvoiceTelegram? -
Inherited by:
InputInvoiceMessage
InputInvoiceName
InputInvoiceTelegram
override
Constants
- constructor → const String