showCaptionAboveMedia property

bool showCaptionAboveMedia
final

showCaptionAboveMedia True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats

Implementation

final bool showCaptionAboveMedia;