replaceVideoStartTimestamp property
replaceVideoStartTimestamp Pass true to replace video start timestamp in the forwarded message
Implementation
final bool replaceVideoStartTimestamp;
replaceVideoStartTimestamp Pass true to replace video start timestamp in the forwarded message
final bool replaceVideoStartTimestamp;