InputMessageInvoice class final

A message with an invoice; can be used only by bots

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputMessageInvoice({Invoice? invoice, required String title, required String description, String? photoUrl, required int photoSize, required int photoWidth, required int photoHeight, required String payload, required String providerToken, required String providerData, required String startParameter, InputPaidMedia? paidMedia, FormattedText? paidMediaCaption})

Properties

description String
param_description Product description; 0-255 characters
final
hashCode int
The hash code for this object.
no setteroverride
invoice Invoice?
invoice Invoice
final
paidMedia InputPaidMedia?
paidMedia The content of paid media attached to the invoice; pass null if none
final
paidMediaCaption FormattedText?
paidMediaCaption Paid media caption; pass null to use an empty caption; 0-getOption("message_caption_length_max") characters
final
payload String
payload The invoice payload
final
photoHeight int
photoHeight Product photo height
final
photoSize int
photoSize Product photo size
final
photoUrl String?
photoUrl Product photo URL; optional
final
photoWidth int
photoWidth Product photo width
final
providerData String
providerData JSON-encoded data about the invoice, which will be shared with the payment provider
final
providerToken String
providerToken Payment provider token; may be empty for payments in Telegram Stars
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startParameter String
startParameter Unique invoice bot deep link parameter for the generation of this invoice. If empty, it would be possible to pay directly from forwards of the invoice message
final
title String
title Product title; 1-32 characters
final

Methods

copyWith({Invoice? invoice, String? title, String? description, String? photoUrl, int? photoSize, int? photoWidth, int? photoHeight, String? payload, String? providerToken, String? providerData, String? startParameter, InputPaidMedia? paidMedia, FormattedText? paidMediaCaption}) InputMessageInvoice

Available on InputMessageInvoice, provided by the InputMessageInvoiceExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult inputMessageAnimation(InputMessageAnimation value), required TResult inputMessageAudio(InputMessageAudio value), required TResult inputMessageChecklist(InputMessageChecklist value), required TResult inputMessageContact(InputMessageContact value), required TResult inputMessageDice(InputMessageDice value), required TResult inputMessageDocument(InputMessageDocument value), required TResult inputMessageForwarded(InputMessageForwarded value), required TResult inputMessageGame(InputMessageGame value), required TResult inputMessageInvoice(InputMessageInvoice value), required TResult inputMessageLiveLocation(InputMessageLiveLocation value), required TResult inputMessageLocation(InputMessageLocation value), required TResult inputMessagePaidMedia(InputMessagePaidMedia value), required TResult inputMessagePhoto(InputMessagePhoto value), required TResult inputMessagePoll(InputMessagePoll value), required TResult inputMessageRichMessage(InputMessageRichMessage value), required TResult inputMessageStakeDice(InputMessageStakeDice value), required TResult inputMessageSticker(InputMessageSticker value), required TResult inputMessageStory(InputMessageStory value), required TResult inputMessageText(InputMessageText value), required TResult inputMessageVenue(InputMessageVenue value), required TResult inputMessageVideo(InputMessageVideo value), required TResult inputMessageVideoNote(InputMessageVideoNote value), required TResult inputMessageVoiceNote(InputMessageVoiceNote value)}) → TResult

Available on InputMessageContent, provided by the InputMessageContentExtensions extension

maybeMap<TResult extends Object?>({TResult inputMessageAnimation(InputMessageAnimation value)?, TResult inputMessageAudio(InputMessageAudio value)?, TResult inputMessageChecklist(InputMessageChecklist value)?, TResult inputMessageContact(InputMessageContact value)?, TResult inputMessageDice(InputMessageDice value)?, TResult inputMessageDocument(InputMessageDocument value)?, TResult inputMessageForwarded(InputMessageForwarded value)?, TResult inputMessageGame(InputMessageGame value)?, TResult inputMessageInvoice(InputMessageInvoice value)?, TResult inputMessageLiveLocation(InputMessageLiveLocation value)?, TResult inputMessageLocation(InputMessageLocation value)?, TResult inputMessagePaidMedia(InputMessagePaidMedia value)?, TResult inputMessagePhoto(InputMessagePhoto value)?, TResult inputMessagePoll(InputMessagePoll value)?, TResult inputMessageRichMessage(InputMessageRichMessage value)?, TResult inputMessageStakeDice(InputMessageStakeDice value)?, TResult inputMessageSticker(InputMessageSticker value)?, TResult inputMessageStory(InputMessageStory value)?, TResult inputMessageText(InputMessageText value)?, TResult inputMessageVenue(InputMessageVenue value)?, TResult inputMessageVideo(InputMessageVideo value)?, TResult inputMessageVideoNote(InputMessageVideoNote value)?, TResult inputMessageVoiceNote(InputMessageVoiceNote value)?, required TResult orElse()}) → TResult

Available on InputMessageContent, provided by the InputMessageContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String