showCaptionAboveMedia property

bool showCaptionAboveMedia
final

showCaptionAboveMedia True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo; not supported in secret chats

Implementation

final bool showCaptionAboveMedia;