membersOnly property
membersOnly True, if only the users that are members of the chat for more than a day will be able to vote; for channel chats only
Implementation
final bool membersOnly;
membersOnly True, if only the users that are members of the chat for more than a day will be able to vote; for channel chats only
final bool membersOnly;