InputMessageReplyTo class sealed

Contains information about the message or the story to be replied

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value), required TResult externalMessage(InputMessageReplyToExternalMessage value), required TResult message(InputMessageReplyToMessage value), required TResult story(InputMessageReplyToStory value)}) → TResult

Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension

maybeMap<TResult extends Object?>({TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value)?, TResult externalMessage(InputMessageReplyToExternalMessage value)?, TResult message(InputMessageReplyToMessage value)?, TResult story(InputMessageReplyToStory value)?, required TResult orElse()}) → TResult

Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String