checklistTaskId property
checklistTaskId Identifier of the checklist task in the message to be replied; pass 0 to reply to the whole message
Implementation
final int checklistTaskId;
checklistTaskId Identifier of the checklist task in the message to be replied; pass 0 to reply to the whole message
final int checklistTaskId;