messageId property

int messageId
final

messageId The identifier of the message to be replied in the same chat and forum topic. A message can be replied in the same chat and forum topic only if messageProperties.can_be_replied

Implementation

final int messageId;