pollOptionId property
pollOptionId Identifier of the poll option in the message to be replied; pass an empty string if none
Implementation
final String pollOptionId;
pollOptionId Identifier of the poll option in the message to be replied; pass an empty string if none
final String pollOptionId;