quote property
quote Quote from the message to be replied; pass null if none. Must always be null for replies in secret chats
Implementation
final InputTextQuote? quote;
quote Quote from the message to be replied; pass null if none. Must always be null for replies in secret chats
final InputTextQuote? quote;