InputMessageReplyToStory class final
Describes a story to be replied
- Inheritance
-
- Object
- TdObject
- InputMessageReplyTo
- InputMessageReplyToStory
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputMessageReplyToStory({required int storyPosterChatId, required int storyId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId The identifier of the story
final
- storyPosterChatId → int
-
storyPosterChatId The identifier of the poster of the story. Currently,
stories can be replied only in the chat that posted the story; channel
stories can't be replied
final
Methods
-
copyWith(
{int? storyPosterChatId, int? storyId}) → InputMessageReplyToStory -
Available on InputMessageReplyToStory, provided by the InputMessageReplyToStoryExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value), required TResult externalMessage(InputMessageReplyToExternalMessage value), required TResult message(InputMessageReplyToMessage value), required TResult story(InputMessageReplyToStory value)}) → TResult -
Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value)?, TResult externalMessage(InputMessageReplyToExternalMessage value)?, TResult message(InputMessageReplyToMessage value)?, TResult story(InputMessageReplyToStory value)?, required TResult orElse()}) → TResult -
Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputMessageReplyToStory? -
Inherited by:
InputMessageReplyToEphemeralMessage
InputMessageReplyToExternalMessage
InputMessageReplyToMessage
InputMessageReplyToStory
override
Constants
- constructor → const String