storyPosterChatId property

int storyPosterChatId
final

storyPosterChatId The identifier of the poster of the story. Currently, stories can be replied only in the chat that posted the story; channel stories can't be replied

Implementation

final int storyPosterChatId;