showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the video; otherwise, the caption must be shown below the video; not supported in secret chats
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the video; otherwise, the caption must be shown below the video; not supported in secret chats
final bool showCaptionAboveMedia;