InputPageBlockMap class final
A map. The map's width and height must not exceed 10000 in total. Width and height ratio must be at most 20
- Inheritance
-
- Object
- TdObject
- InputPageBlock
- InputPageBlockMap
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputPageBlockMap({Location? location, required int zoom, required int width, required int height, PageBlockCaption? caption})
Properties
- caption → PageBlockCaption?
-
caption Block caption; pass null if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Map height; 0-10000
final
- location → Location?
-
location Location of the map center
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
width Map width; 0-10000
final
- zoom → int
-
zoom Map zoom level; 0-24
final
Methods
-
copyWith(
{Location? location, int? zoom, int? width, int? height, PageBlockCaption? caption}) → InputPageBlockMap -
Available on InputPageBlockMap, provided by the InputPageBlockMapExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult anchor(InputPageBlockAnchor value), required TResult animation(InputPageBlockAnimation value), required TResult audio(InputPageBlockAudio value), required TResult blockQuote(InputPageBlockBlockQuote value), required TResult collage(InputPageBlockCollage value), required TResult details(InputPageBlockDetails value), required TResult divider(InputPageBlockDivider value), required TResult list(InputPageBlockList value), required TResult map(InputPageBlockMap value), required TResult mathematicalExpression(InputPageBlockMathematicalExpression value), required TResult paragraph(InputPageBlockParagraph value), required TResult photo(InputPageBlockPhoto value), required TResult preformatted(InputPageBlockPreformatted value), required TResult pullQuote(InputPageBlockPullQuote value), required TResult sectionHeading(InputPageBlockSectionHeading value), required TResult slideshow(InputPageBlockSlideshow value), required TResult table(InputPageBlockTable value), required TResult thinking(InputPageBlockThinking value), required TResult video(InputPageBlockVideo value), required TResult voiceNote(InputPageBlockVoiceNote value)}) → TResult -
Available on InputPageBlock, provided by the InputPageBlockExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult anchor(InputPageBlockAnchor value)?, TResult animation(InputPageBlockAnimation value)?, TResult audio(InputPageBlockAudio value)?, TResult blockQuote(InputPageBlockBlockQuote value)?, TResult collage(InputPageBlockCollage value)?, TResult details(InputPageBlockDetails value)?, TResult divider(InputPageBlockDivider value)?, TResult list(InputPageBlockList value)?, TResult map(InputPageBlockMap value)?, TResult mathematicalExpression(InputPageBlockMathematicalExpression value)?, TResult paragraph(InputPageBlockParagraph value)?, TResult photo(InputPageBlockPhoto value)?, TResult preformatted(InputPageBlockPreformatted value)?, TResult pullQuote(InputPageBlockPullQuote value)?, TResult sectionHeading(InputPageBlockSectionHeading value)?, TResult slideshow(InputPageBlockSlideshow value)?, TResult table(InputPageBlockTable value)?, TResult thinking(InputPageBlockThinking value)?, TResult video(InputPageBlockVideo value)?, TResult voiceNote(InputPageBlockVoiceNote value)?, required TResult orElse()}) → TResult -
Available on InputPageBlock, provided by the InputPageBlockExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputPageBlockMap? -
Inherited by:
InputPageBlockAnchor
InputPageBlockAnimation
InputPageBlockAudio
InputPageBlockBlockQuote
InputPageBlockCollage
InputPageBlockDetails
InputPageBlockDivider
InputPageBlockFooter
InputPageBlockList
InputPageBlockMap
InputPageBlockMathematicalExpression
InputPageBlockParagraph
InputPageBlockPhoto
InputPageBlockPreformatted
InputPageBlockPullQuote
InputPageBlockSectionHeading
InputPageBlockSlideshow
InputPageBlockTable
InputPageBlockThinking
InputPageBlockVideo
InputPageBlockVoiceNote
override
Constants
- constructor → const String