InputPageBlockSlideshow class final

A slideshow

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPageBlockSlideshow({required List<InputPageBlock> blocks, PageBlockCaption? caption})

Properties

blocks List<InputPageBlock>
blocks Slideshow item contents
final
caption PageBlockCaption?
caption Block caption; pass null if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<InputPageBlock>? blocks, PageBlockCaption? caption}) InputPageBlockSlideshow

Available on InputPageBlockSlideshow, provided by the InputPageBlockSlideshowExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult anchor(InputPageBlockAnchor value), required TResult animation(InputPageBlockAnimation value), required TResult audio(InputPageBlockAudio value), required TResult blockQuote(InputPageBlockBlockQuote value), required TResult collage(InputPageBlockCollage value), required TResult details(InputPageBlockDetails value), required TResult divider(InputPageBlockDivider value), required TResult footer(InputPageBlockFooter value), required TResult list(InputPageBlockList value), required TResult map(InputPageBlockMap value), required TResult mathematicalExpression(InputPageBlockMathematicalExpression value), required TResult paragraph(InputPageBlockParagraph value), required TResult photo(InputPageBlockPhoto value), required TResult preformatted(InputPageBlockPreformatted value), required TResult pullQuote(InputPageBlockPullQuote value), required TResult sectionHeading(InputPageBlockSectionHeading value), required TResult slideshow(InputPageBlockSlideshow value), required TResult table(InputPageBlockTable value), required TResult thinking(InputPageBlockThinking value), required TResult video(InputPageBlockVideo value), required TResult voiceNote(InputPageBlockVoiceNote value)}) → TResult

Available on InputPageBlock, provided by the InputPageBlockExtensions extension

maybeMap<TResult extends Object?>({TResult anchor(InputPageBlockAnchor value)?, TResult animation(InputPageBlockAnimation value)?, TResult audio(InputPageBlockAudio value)?, TResult blockQuote(InputPageBlockBlockQuote value)?, TResult collage(InputPageBlockCollage value)?, TResult details(InputPageBlockDetails value)?, TResult divider(InputPageBlockDivider value)?, TResult footer(InputPageBlockFooter value)?, TResult list(InputPageBlockList value)?, TResult map(InputPageBlockMap value)?, TResult mathematicalExpression(InputPageBlockMathematicalExpression value)?, TResult paragraph(InputPageBlockParagraph value)?, TResult photo(InputPageBlockPhoto value)?, TResult preformatted(InputPageBlockPreformatted value)?, TResult pullQuote(InputPageBlockPullQuote value)?, TResult sectionHeading(InputPageBlockSectionHeading value)?, TResult slideshow(InputPageBlockSlideshow value)?, TResult table(InputPageBlockTable value)?, TResult thinking(InputPageBlockThinking value)?, TResult video(InputPageBlockVideo value)?, TResult voiceNote(InputPageBlockVoiceNote value)?, required TResult orElse()}) → TResult

Available on InputPageBlock, provided by the InputPageBlockExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String