InputPaidMediaType class sealed

Describes type of paid media to send

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(InputPaidMediaTypePhoto value), required TResult video(InputPaidMediaTypeVideo value)}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult photo(InputPaidMediaTypePhoto value)?, TResult video(InputPaidMediaTypeVideo value)?, required TResult orElse()}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPaidMediaType?
Inherited by: InputPaidMediaTypePhoto InputPaidMediaTypeVideo

Constants

constructor → const String