InputPaidMediaTypePhoto class final

The media is a photo. The photo must be at most 10 MB in size. The photo's width and height must not exceed 10000 in total. Width and height ratio must be at most 20

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPaidMediaTypePhoto({InputFile? video})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video InputFile?
video Video of the live photo; pass null if the photo isn't a live photo
final

Methods

copyWith({InputFile? video}) InputPaidMediaTypePhoto

Available on InputPaidMediaTypePhoto, provided by the InputPaidMediaTypePhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(InputPaidMediaTypePhoto value), required TResult video(InputPaidMediaTypeVideo value)}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult photo(InputPaidMediaTypePhoto value)?, TResult video(InputPaidMediaTypeVideo value)?, required TResult orElse()}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPaidMediaTypePhoto?
Inherited by: InputPaidMediaTypePhoto InputPaidMediaTypeVideo
override

Constants

constructor → const String