InputPaidMediaTypeVideo class final

The media is a video

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPaidMediaTypeVideo({InputFile? cover, required int startTimestamp, required int duration, required bool supportsStreaming})

Properties

cover InputFile?
cover Cover of the video; pass null to skip cover uploading
final
duration int
duration Duration of the video, in seconds
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp int
startTimestamp Timestamp from which the video playing must start, in seconds
final
supportsStreaming bool
supportsStreaming True, if the video is expected to be streamed
final

Methods

copyWith({InputFile? cover, int? startTimestamp, int? duration, bool? supportsStreaming}) InputPaidMediaTypeVideo

Available on InputPaidMediaTypeVideo, provided by the InputPaidMediaTypeVideoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(InputPaidMediaTypePhoto value), required TResult video(InputPaidMediaTypeVideo value)}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult photo(InputPaidMediaTypePhoto value)?, TResult video(InputPaidMediaTypeVideo value)?, required TResult orElse()}) → TResult

Available on InputPaidMediaType, provided by the InputPaidMediaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPaidMediaTypeVideo?
Inherited by: InputPaidMediaTypePhoto InputPaidMediaTypeVideo
override

Constants

constructor → const String