InputPassportElementError class final

Contains the description of an error in a Telegram Passport element; for bots only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPassportElementError({PassportElementType? type, required String message, InputPassportElementErrorSource? source})

Properties

hashCode → int
The hash code for this object.
no setteroverride
message → String
message Error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → InputPassportElementErrorSource?
source Error source
final
type → PassportElementType?
type Type of Telegram Passport element that has the error
final

Methods

copyWith({PassportElementType? type, String? message, InputPassportElementErrorSource? source}) → InputPassportElementError

Available on InputPassportElementError, provided by the InputPassportElementErrorExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → InputPassportElementError?

Constants

constructor → const String