InputPhoto class final

A photo to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPhoto({InputFile? photo, InputThumbnail? thumbnail, InputFile? video, required List<int> addedStickerFileIds, required int width, required int height})

Properties

addedStickerFileIds List<int>
addedStickerFileIds File identifiers of the stickers added to the photo, if applicable
final
hashCode int
The hash code for this object.
no setteroverride
height int
height Photo height; may be replaced by the server
final
photo InputFile?
photo Photo to be sent. The photo must be at most 10 MB in size. The photo's width and height must not exceed 10000 in total. Width and height ratio must be at most 20
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail InputThumbnail?
thumbnail Photo thumbnail; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
final
video InputFile?
video Video of the live photo; not supported in secret chats; pass null if the photo isn't a live photo
final
width int
width Photo width; may be replaced by the server
final

Methods

copyWith({InputFile? photo, InputThumbnail? thumbnail, InputFile? video, List<int>? addedStickerFileIds, int? width, int? height}) InputPhoto

Available on InputPhoto, provided by the InputPhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPhoto?

Constants

constructor → const String