thumbnail property
thumbnail Photo thumbnail; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
Implementation
final InputThumbnail? thumbnail;
thumbnail Photo thumbnail; pass null to skip thumbnail uploading. The thumbnail is sent to the other party only in secret chats
final InputThumbnail? thumbnail;