InputPollMediaPhoto class final

A photo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPollMediaPhoto({InputPhoto? photo})

Properties

hashCode int
The hash code for this object.
no setteroverride
photo InputPhoto?
photo Photo to be sent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputPhoto? photo}) InputPollMediaPhoto

Available on InputPollMediaPhoto, provided by the InputPollMediaPhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(InputPollMediaAnimation value), required TResult audio(InputPollMediaAudio value), required TResult document(InputPollMediaDocument value), required TResult link(InputPollMediaLink value), required TResult location(InputPollMediaLocation value), required TResult photo(InputPollMediaPhoto value), required TResult sticker(InputPollMediaSticker value), required TResult venue(InputPollMediaVenue value), required TResult video(InputPollMediaVideo value)}) → TResult

Available on InputPollMedia, provided by the InputPollMediaExtensions extension

maybeMap<TResult extends Object?>({TResult animation(InputPollMediaAnimation value)?, TResult audio(InputPollMediaAudio value)?, TResult document(InputPollMediaDocument value)?, TResult link(InputPollMediaLink value)?, TResult location(InputPollMediaLocation value)?, TResult photo(InputPollMediaPhoto value)?, TResult sticker(InputPollMediaSticker value)?, TResult venue(InputPollMediaVenue value)?, TResult video(InputPollMediaVideo value)?, required TResult orElse()}) → TResult

Available on InputPollMedia, provided by the InputPollMediaExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String