InputPollOption class final

Describes one answer option of a poll to be created

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPollOption({FormattedText? text, InputPollMedia? media})

Properties

hashCode int
The hash code for this object.
no setteroverride
media InputPollMedia?
media Option media; pass null if none; ignored in addPollOption. Must be one of the following types: inputPollMediaAnimation, inputPollMediaLink, inputPollMediaLocation, inputPollMediaPhoto, inputPollMediaSticker, inputPollMediaVenue, or inputPollMediaVideo without caption
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Option text; 1-100 characters. Only custom emoji entities are allowed to be added and only by Premium users
final

Methods

copyWith({FormattedText? text, InputPollMedia? media}) InputPollOption

Available on InputPollOption, provided by the InputPollOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPollOption?

Constants

constructor → const String