text property
text Option text; 1-100 characters. Only custom emoji entities are allowed to be added and only by Premium users
Implementation
final FormattedText? text;
text Option text; 1-100 characters. Only custom emoji entities are allowed to be added and only by Premium users
final FormattedText? text;