InputPollType class sealed

Describes the type of poll to send

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult quiz(InputPollTypeQuiz value), required TResult regular(InputPollTypeRegular value)}) → TResult

Available on InputPollType, provided by the InputPollTypeExtensions extension

maybeMap<TResult extends Object?>({TResult quiz(InputPollTypeQuiz value)?, TResult regular(InputPollTypeRegular value)?, required TResult orElse()}) → TResult

Available on InputPollType, provided by the InputPollTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPollType?
Inherited by: InputPollTypeQuiz InputPollTypeRegular

Constants

constructor → const String