InputPollTypeQuiz class final

A poll in quiz mode, which has predefined correct answers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPollTypeQuiz({required List<int> correctOptionIds, FormattedText? explanation, InputPollMedia? explanationMedia})

Properties

correctOptionIds List<int>
correctOptionIds Increasing list of 0-based identifiers of the correct answer options; must be non-empty
final
explanation FormattedText?
explanation Text that is shown when the user chooses an incorrect answer or taps on the lamp icon; 0-200 characters with at most 2 line feeds
final
explanationMedia InputPollMedia?
explanationMedia Media that is shown when the user chooses an incorrect answer or taps on the lamp icon; pass null if none. Must be one of the following types: inputPollMediaAnimation, inputPollMediaAudio, inputPollMediaDocument, inputPollMediaLocation, inputPollMediaPhoto, inputPollMediaVenue, or inputPollMediaVideo without caption
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? correctOptionIds, FormattedText? explanation, InputPollMedia? explanationMedia}) InputPollTypeQuiz

Available on InputPollTypeQuiz, provided by the InputPollTypeQuizExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult quiz(InputPollTypeQuiz value), required TResult regular(InputPollTypeRegular value)}) → TResult

Available on InputPollType, provided by the InputPollTypeExtensions extension

maybeMap<TResult extends Object?>({TResult quiz(InputPollTypeQuiz value)?, TResult regular(InputPollTypeRegular value)?, required TResult orElse()}) → TResult

Available on InputPollType, provided by the InputPollTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPollTypeQuiz?
Inherited by: InputPollTypeQuiz InputPollTypeRegular
override

Constants

constructor → const String