explanation property

FormattedText? explanation
final

explanation Text that is shown when the user chooses an incorrect answer or taps on the lamp icon; 0-200 characters with at most 2 line feeds

Implementation

final FormattedText? explanation;