InputPollTypeRegular class final
A regular poll
- Inheritance
-
- Object
- TdObject
- InputPollType
- InputPollTypeRegular
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputPollTypeRegular({required bool allowAddingOptions})
Properties
- allowAddingOptions → bool
-
allowAddingOptions True, if answer options can be added to the poll
after creation; not supported in channel chats and for anonymous polls
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? allowAddingOptions}) → InputPollTypeRegular -
Available on InputPollTypeRegular, provided by the InputPollTypeRegularExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult quiz(InputPollTypeQuiz value), required TResult regular(InputPollTypeRegular value)}) → TResult -
Available on InputPollType, provided by the InputPollTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult quiz(InputPollTypeQuiz value)?, TResult regular(InputPollTypeRegular value)?, required TResult orElse()}) → TResult -
Available on InputPollType, provided by the InputPollTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputPollTypeRegular? -
Inherited by:
InputPollTypeQuiz
InputPollTypeRegular
override
Constants
- constructor → const String