allowAddingOptions property
allowAddingOptions True, if answer options can be added to the poll after creation; not supported in channel chats and for anonymous polls
Implementation
final bool allowAddingOptions;
allowAddingOptions True, if answer options can be added to the poll after creation; not supported in channel chats and for anonymous polls
final bool allowAddingOptions;