InputRichMessage class final

A rich message to send. Total length of all texts, including custom emoji alternative text and formula source, must not exceed getOption("rich_message_text_length_max"). The total number of all blocks, list items and table rows must not exceed getOption("rich_message_block_count_max"). The maximum allowed depth of nested blocks and rich texts is getOption("rich_message_depth_max"). The total number of media in all blocks must not exceed getOption("rich_message_media_count_max"). The maximum allowed number of table columns is getOption("rich_message_table_column_count_max")

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputRichMessage({RichMessageSource? source, required bool isRtl, required bool detectAutomaticBlocks})

Properties

detectAutomaticBlocks bool
detectAutomaticBlocks Pass true to enable detection of URLs, email addresses and other automatic blocks
final
hashCode int
The hash code for this object.
no setteroverride
isRtl bool
isRtl Pass true if the message must be shown from right to left
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source RichMessageSource?
source Source of the rich message
final

Methods

copyWith({RichMessageSource? source, bool? isRtl, bool? detectAutomaticBlocks}) InputRichMessage

Available on InputRichMessage, provided by the InputRichMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputRichMessage?

Constants

constructor → const String