InputRichMessageMedia class final

Describes a media to be used in a sent rich message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputRichMessageMedia({required String id, InputMessageContent? media})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the media; 1-64 base64url characters
final
media InputMessageContent?
media The media to send. Must be one of the following types: inputMessageAnimation, inputMessageAudio, inputMessagePhoto, inputMessageVideo, or inputMessageVoiceNote
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? id, InputMessageContent? media}) InputRichMessageMedia

Available on InputRichMessageMedia, provided by the InputRichMessageMediaExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputRichMessageMedia?

Constants

constructor → const String