InputSticker class final
A sticker to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputSticker({InputFile? sticker, InputThumbnail? thumbnail, required int width, required int height})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Sticker height
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputFile?
-
sticker Sticker to be sent
final
- thumbnail → InputThumbnail?
-
thumbnail Sticker thumbnail; pass null to skip thumbnail uploading
final
- width → int
-
width Sticker width
final
Methods
-
copyWith(
{InputFile? sticker, InputThumbnail? thumbnail, int? width, int? height}) → InputSticker -
Available on InputSticker, provided by the InputStickerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputSticker?
Constants
- constructor → const String