InputStoryAreaTypeFoundVenue class final

An area pointing to a venue found by the bot getOption("venue_search_bot_username")

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputStoryAreaTypeFoundVenue({required int queryId, required String resultId})

Properties

hashCode int
The hash code for this object.
no setteroverride
queryId int
queryId Identifier of the inline query, used to found the venue
final
resultId String
resultId Identifier of the inline query result
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? queryId, String? resultId}) InputStoryAreaTypeFoundVenue

Available on InputStoryAreaTypeFoundVenue, provided by the InputStoryAreaTypeFoundVenueExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult foundVenue(InputStoryAreaTypeFoundVenue value), required TResult link(InputStoryAreaTypeLink value), required TResult location(InputStoryAreaTypeLocation value), required TResult message(InputStoryAreaTypeMessage value), required TResult previousVenue(InputStoryAreaTypePreviousVenue value), required TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value), required TResult upgradedGift(InputStoryAreaTypeUpgradedGift value), required TResult weather(InputStoryAreaTypeWeather value)}) → TResult

Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult foundVenue(InputStoryAreaTypeFoundVenue value)?, TResult link(InputStoryAreaTypeLink value)?, TResult location(InputStoryAreaTypeLocation value)?, TResult message(InputStoryAreaTypeMessage value)?, TResult previousVenue(InputStoryAreaTypePreviousVenue value)?, TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value)?, TResult upgradedGift(InputStoryAreaTypeUpgradedGift value)?, TResult weather(InputStoryAreaTypeWeather value)?, required TResult orElse()}) → TResult

Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String