InputStoryAreaTypeLocation class final

An area pointing to a location

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputStoryAreaTypeLocation({Location? location, LocationAddress? address})

Properties

address LocationAddress?
address Address of the location; pass null if unknown
final
hashCode int
The hash code for this object.
no setteroverride
location Location?
location The location
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, LocationAddress? address}) InputStoryAreaTypeLocation

Available on InputStoryAreaTypeLocation, provided by the InputStoryAreaTypeLocationExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult foundVenue(InputStoryAreaTypeFoundVenue value), required TResult link(InputStoryAreaTypeLink value), required TResult location(InputStoryAreaTypeLocation value), required TResult message(InputStoryAreaTypeMessage value), required TResult previousVenue(InputStoryAreaTypePreviousVenue value), required TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value), required TResult upgradedGift(InputStoryAreaTypeUpgradedGift value), required TResult weather(InputStoryAreaTypeWeather value)}) → TResult

Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult foundVenue(InputStoryAreaTypeFoundVenue value)?, TResult link(InputStoryAreaTypeLink value)?, TResult location(InputStoryAreaTypeLocation value)?, TResult message(InputStoryAreaTypeMessage value)?, TResult previousVenue(InputStoryAreaTypePreviousVenue value)?, TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value)?, TResult upgradedGift(InputStoryAreaTypeUpgradedGift value)?, TResult weather(InputStoryAreaTypeWeather value)?, required TResult orElse()}) → TResult

Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String