InputStoryAreaTypeMessage class final
An area pointing to a message
- Inheritance
-
- Object
- TdObject
- InputStoryAreaType
- InputStoryAreaTypeMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputStoryAreaTypeMessage({required int chatId, required int messageId})
Properties
- chatId → int
-
chatId Identifier of the chat with the message. Currently, the chat must
be a supergroup or a channel chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message. Use
messageProperties.can_be_shared_in_story to check whether the message is
suitable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId}) → InputStoryAreaTypeMessage -
Available on InputStoryAreaTypeMessage, provided by the InputStoryAreaTypeMessageExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult foundVenue(InputStoryAreaTypeFoundVenue value), required TResult link(InputStoryAreaTypeLink value), required TResult location(InputStoryAreaTypeLocation value), required TResult message(InputStoryAreaTypeMessage value), required TResult previousVenue(InputStoryAreaTypePreviousVenue value), required TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value), required TResult upgradedGift(InputStoryAreaTypeUpgradedGift value), required TResult weather(InputStoryAreaTypeWeather value)}) → TResult -
Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult foundVenue(InputStoryAreaTypeFoundVenue value)?, TResult link(InputStoryAreaTypeLink value)?, TResult location(InputStoryAreaTypeLocation value)?, TResult message(InputStoryAreaTypeMessage value)?, TResult previousVenue(InputStoryAreaTypePreviousVenue value)?, TResult suggestedReaction(InputStoryAreaTypeSuggestedReaction value)?, TResult upgradedGift(InputStoryAreaTypeUpgradedGift value)?, TResult weather(InputStoryAreaTypeWeather value)?, required TResult orElse()}) → TResult -
Available on InputStoryAreaType, provided by the InputStoryAreaTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputStoryAreaTypeMessage? -
Inherited by:
InputStoryAreaTypeFoundVenue
InputStoryAreaTypeLink
InputStoryAreaTypeLocation
InputStoryAreaTypeMessage
InputStoryAreaTypePreviousVenue
InputStoryAreaTypeSuggestedReaction
InputStoryAreaTypeUpgradedGift
InputStoryAreaTypeWeather
override
Constants
- constructor → const String