InputStoryContent class sealed

The content of a story to post

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(InputStoryContentPhoto value), required TResult video(InputStoryContentVideo value)}) → TResult

Available on InputStoryContent, provided by the InputStoryContentExtensions extension

maybeMap<TResult extends Object?>({TResult photo(InputStoryContentPhoto value)?, TResult video(InputStoryContentVideo value)?, required TResult orElse()}) → TResult

Available on InputStoryContent, provided by the InputStoryContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputStoryContent?
Inherited by: InputStoryContentPhoto InputStoryContentVideo

Constants

constructor → const String