InputStoryContentVideo class final

A video story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputStoryContentVideo({InputFile? video, required List<int> addedStickerFileIds, required double duration, required double coverFrameTimestamp, required bool isAnimation})

Properties

addedStickerFileIds List<int>
addedStickerFileIds File identifiers of the stickers added to the video, if applicable
final
coverFrameTimestamp double
coverFrameTimestamp Timestamp of the frame, which will be used as video thumbnail
final
duration double
duration Precise duration of the video, in seconds; 0-60
final
hashCode int
The hash code for this object.
no setteroverride
isAnimation bool
isAnimation True, if the video has no sound
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video InputFile?
video Video to be sent. The video size must be 720x1280. The video must be streamable and stored in MPEG4 format, after encoding with H.265 codec and key frames added each second
final

Methods

copyWith({InputFile? video, List<int>? addedStickerFileIds, double? duration, double? coverFrameTimestamp, bool? isAnimation}) InputStoryContentVideo

Available on InputStoryContentVideo, provided by the InputStoryContentVideoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(InputStoryContentPhoto value), required TResult video(InputStoryContentVideo value)}) → TResult

Available on InputStoryContent, provided by the InputStoryContentExtensions extension

maybeMap<TResult extends Object?>({TResult photo(InputStoryContentPhoto value)?, TResult video(InputStoryContentVideo value)?, required TResult orElse()}) → TResult

Available on InputStoryContent, provided by the InputStoryContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputStoryContentVideo?
Inherited by: InputStoryContentPhoto InputStoryContentVideo
override

Constants

constructor → const String