InputThumbnail class final

A thumbnail to be sent along with a file; must be in JPEG or WEBP format for stickers, and less than 200 KB in size

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputThumbnail({InputFile? thumbnail, required int width, required int height})

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
height Thumbnail height, usually shouldn't exceed 320. Use 0 if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail InputFile?
thumbnail Thumbnail file to send. Sending thumbnails by file_id is currently not supported
final
width int
width Thumbnail width, usually shouldn't exceed 320. Use 0 if unknown
final

Methods

copyWith({InputFile? thumbnail, int? width, int? height}) InputThumbnail

Available on InputThumbnail, provided by the InputThumbnailExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputThumbnail?

Constants

constructor → const String