InternalLinkTypePremiumGiftPurchase class final

The link is a link to the screen for gifting Telegram Premium subscriptions to friends via inputInvoiceTelegram with telegramPaymentPurposePremiumGift payments or in-store purchases

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InternalLinkTypePremiumGiftPurchase({required String referrer})

Properties

hashCode int
The hash code for this object.
no setteroverride
referrer String
referrer Referrer specified in the link
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? referrer}) InternalLinkTypePremiumGiftPurchase

Available on InternalLinkTypePremiumGiftPurchase, provided by the InternalLinkTypePremiumGiftPurchaseExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult attachmentMenuBot(InternalLinkTypeAttachmentMenuBot value), required TResult authenticationCode(InternalLinkTypeAuthenticationCode value), required TResult background(InternalLinkTypeBackground value), required TResult botAddToChannel(InternalLinkTypeBotAddToChannel value), required TResult botStart(InternalLinkTypeBotStart value), required TResult botStartInGroup(InternalLinkTypeBotStartInGroup value), required TResult businessChat(InternalLinkTypeBusinessChat value), required TResult callsPage(InternalLinkTypeCallsPage value), required TResult chatAffiliateProgram(InternalLinkTypeChatAffiliateProgram value), required TResult chatBoost(InternalLinkTypeChatBoost value), required TResult chatFolderInvite(InternalLinkTypeChatFolderInvite value), required TResult chatInvite(InternalLinkTypeChatInvite value), required TResult chatSelection(InternalLinkTypeChatSelection value), required TResult contactsPage(InternalLinkTypeContactsPage value), required TResult directMessagesChat(InternalLinkTypeDirectMessagesChat value), required TResult game(InternalLinkTypeGame value), required TResult giftAuction(InternalLinkTypeGiftAuction value), required TResult giftCollection(InternalLinkTypeGiftCollection value), required TResult groupCall(InternalLinkTypeGroupCall value), required TResult instantView(InternalLinkTypeInstantView value), required TResult invoice(InternalLinkTypeInvoice value), required TResult languagePack(InternalLinkTypeLanguagePack value), required TResult liveStory(InternalLinkTypeLiveStory value), required TResult mainWebApp(InternalLinkTypeMainWebApp value), required TResult message(InternalLinkTypeMessage value), required TResult messageDraft(InternalLinkTypeMessageDraft value), required TResult myProfilePage(InternalLinkTypeMyProfilePage value), required TResult newChannelChat(InternalLinkTypeNewChannelChat value), required TResult newGroupChat(InternalLinkTypeNewGroupChat value), required TResult newPrivateChat(InternalLinkTypeNewPrivateChat value), required TResult newStory(InternalLinkTypeNewStory value), required TResult oauth(InternalLinkTypeOauth value), required TResult passportDataRequest(InternalLinkTypePassportDataRequest value), required TResult phoneNumberConfirmation(InternalLinkTypePhoneNumberConfirmation value), required TResult premiumFeaturesPage(InternalLinkTypePremiumFeaturesPage value), required TResult premiumGiftCode(InternalLinkTypePremiumGiftCode value), required TResult premiumGiftPurchase(InternalLinkTypePremiumGiftPurchase value), required TResult proxy(InternalLinkTypeProxy value), required TResult publicChat(InternalLinkTypePublicChat value), required TResult qrCodeAuthentication(InternalLinkTypeQrCodeAuthentication value), required TResult requestManagedBot(InternalLinkTypeRequestManagedBot value), required TResult restorePurchases(InternalLinkTypeRestorePurchases value), required TResult savedMessages(InternalLinkTypeSavedMessages value), required TResult search(InternalLinkTypeSearch value), required TResult settings(InternalLinkTypeSettings value), required TResult starPurchase(InternalLinkTypeStarPurchase value), required TResult stickerSet(InternalLinkTypeStickerSet value), required TResult story(InternalLinkTypeStory value), required TResult storyAlbum(InternalLinkTypeStoryAlbum value), required TResult textCompositionStyle(InternalLinkTypeTextCompositionStyle value), required TResult theme(InternalLinkTypeTheme value), required TResult unknownDeepLink(InternalLinkTypeUnknownDeepLink value), required TResult upgradedGift(InternalLinkTypeUpgradedGift value), required TResult userPhoneNumber(InternalLinkTypeUserPhoneNumber value), required TResult userToken(InternalLinkTypeUserToken value), required TResult videoChat(InternalLinkTypeVideoChat value), required TResult webApp(InternalLinkTypeWebApp value)}) → TResult

Available on InternalLinkType, provided by the InternalLinkTypeExtensions extension

maybeMap<TResult extends Object?>({TResult attachmentMenuBot(InternalLinkTypeAttachmentMenuBot value)?, TResult authenticationCode(InternalLinkTypeAuthenticationCode value)?, TResult background(InternalLinkTypeBackground value)?, TResult botAddToChannel(InternalLinkTypeBotAddToChannel value)?, TResult botStart(InternalLinkTypeBotStart value)?, TResult botStartInGroup(InternalLinkTypeBotStartInGroup value)?, TResult businessChat(InternalLinkTypeBusinessChat value)?, TResult callsPage(InternalLinkTypeCallsPage value)?, TResult chatAffiliateProgram(InternalLinkTypeChatAffiliateProgram value)?, TResult chatBoost(InternalLinkTypeChatBoost value)?, TResult chatFolderInvite(InternalLinkTypeChatFolderInvite value)?, TResult chatInvite(InternalLinkTypeChatInvite value)?, TResult chatSelection(InternalLinkTypeChatSelection value)?, TResult contactsPage(InternalLinkTypeContactsPage value)?, TResult directMessagesChat(InternalLinkTypeDirectMessagesChat value)?, TResult game(InternalLinkTypeGame value)?, TResult giftAuction(InternalLinkTypeGiftAuction value)?, TResult giftCollection(InternalLinkTypeGiftCollection value)?, TResult groupCall(InternalLinkTypeGroupCall value)?, TResult instantView(InternalLinkTypeInstantView value)?, TResult invoice(InternalLinkTypeInvoice value)?, TResult languagePack(InternalLinkTypeLanguagePack value)?, TResult liveStory(InternalLinkTypeLiveStory value)?, TResult mainWebApp(InternalLinkTypeMainWebApp value)?, TResult message(InternalLinkTypeMessage value)?, TResult messageDraft(InternalLinkTypeMessageDraft value)?, TResult myProfilePage(InternalLinkTypeMyProfilePage value)?, TResult newChannelChat(InternalLinkTypeNewChannelChat value)?, TResult newGroupChat(InternalLinkTypeNewGroupChat value)?, TResult newPrivateChat(InternalLinkTypeNewPrivateChat value)?, TResult newStory(InternalLinkTypeNewStory value)?, TResult oauth(InternalLinkTypeOauth value)?, TResult passportDataRequest(InternalLinkTypePassportDataRequest value)?, TResult phoneNumberConfirmation(InternalLinkTypePhoneNumberConfirmation value)?, TResult premiumFeaturesPage(InternalLinkTypePremiumFeaturesPage value)?, TResult premiumGiftCode(InternalLinkTypePremiumGiftCode value)?, TResult premiumGiftPurchase(InternalLinkTypePremiumGiftPurchase value)?, TResult proxy(InternalLinkTypeProxy value)?, TResult publicChat(InternalLinkTypePublicChat value)?, TResult qrCodeAuthentication(InternalLinkTypeQrCodeAuthentication value)?, TResult requestManagedBot(InternalLinkTypeRequestManagedBot value)?, TResult restorePurchases(InternalLinkTypeRestorePurchases value)?, TResult savedMessages(InternalLinkTypeSavedMessages value)?, TResult search(InternalLinkTypeSearch value)?, TResult settings(InternalLinkTypeSettings value)?, TResult starPurchase(InternalLinkTypeStarPurchase value)?, TResult stickerSet(InternalLinkTypeStickerSet value)?, TResult story(InternalLinkTypeStory value)?, TResult storyAlbum(InternalLinkTypeStoryAlbum value)?, TResult textCompositionStyle(InternalLinkTypeTextCompositionStyle value)?, TResult theme(InternalLinkTypeTheme value)?, TResult unknownDeepLink(InternalLinkTypeUnknownDeepLink value)?, TResult upgradedGift(InternalLinkTypeUpgradedGift value)?, TResult userPhoneNumber(InternalLinkTypeUserPhoneNumber value)?, TResult userToken(InternalLinkTypeUserToken value)?, TResult videoChat(InternalLinkTypeVideoChat value)?, TResult webApp(InternalLinkTypeWebApp value)?, required TResult orElse()}) → TResult

Available on InternalLinkType, provided by the InternalLinkTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InternalLinkTypePremiumGiftPurchase?
Inherited by: InternalLinkTypeAttachmentMenuBot InternalLinkTypeAuthenticationCode InternalLinkTypeBackground InternalLinkTypeBotAddToChannel InternalLinkTypeBotStart InternalLinkTypeBotStartInGroup InternalLinkTypeBusinessChat InternalLinkTypeCallsPage InternalLinkTypeChatAffiliateProgram InternalLinkTypeChatBoost InternalLinkTypeChatFolderInvite InternalLinkTypeChatInvite InternalLinkTypeChatSelection InternalLinkTypeContactsPage InternalLinkTypeDirectMessagesChat InternalLinkTypeGame InternalLinkTypeGiftAuction InternalLinkTypeGiftCollection InternalLinkTypeGroupCall InternalLinkTypeInstantView InternalLinkTypeInvoice InternalLinkTypeLanguagePack InternalLinkTypeLiveStory InternalLinkTypeMainWebApp InternalLinkTypeMessage InternalLinkTypeMessageDraft InternalLinkTypeMyProfilePage InternalLinkTypeNewChannelChat InternalLinkTypeNewGroupChat InternalLinkTypeNewPrivateChat InternalLinkTypeNewStory InternalLinkTypeOauth InternalLinkTypePassportDataRequest InternalLinkTypePhoneNumberConfirmation InternalLinkTypePremiumFeaturesPage InternalLinkTypePremiumGiftCode InternalLinkTypePremiumGiftPurchase InternalLinkTypeProxy InternalLinkTypePublicChat InternalLinkTypeQrCodeAuthentication InternalLinkTypeRequestManagedBot InternalLinkTypeRestorePurchases InternalLinkTypeSavedMessages InternalLinkTypeSearch InternalLinkTypeSettings InternalLinkTypeStarPurchase InternalLinkTypeStickerSet InternalLinkTypeStory InternalLinkTypeStoryAlbum InternalLinkTypeTextCompositionStyle InternalLinkTypeTheme InternalLinkTypeUnknownDeepLink InternalLinkTypeUpgradedGift InternalLinkTypeUserPhoneNumber InternalLinkTypeUserToken InternalLinkTypeVideoChat InternalLinkTypeWebApp
override

Constants

constructor → const String