InviteGroupCallParticipant class final

Invites a user to an active group call; for group calls not bound to a chat only. Sends a service message of the type messageGroupCall. The group call can have at most getOption("group_call_participant_count_max") participants Returns InviteGroupCallParticipantResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InviteGroupCallParticipant({required int groupCallId, required int userId, required bool isVideo})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
isVideo bool
isVideo Pass true if the group call is a video call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? groupCallId, int? userId, bool? isVideo}) InviteGroupCallParticipant

Available on InviteGroupCallParticipant, provided by the InviteGroupCallParticipantExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String