InviteGroupCallParticipantResultUserAlreadyParticipant class final
The user can't be invited because they are already a participant of the call
- Inheritance
-
- Object
- TdObject
- InviteGroupCallParticipantResult
- InviteGroupCallParticipantResultUserAlreadyParticipant
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult success(InviteGroupCallParticipantResultSuccess value), required TResult userAlreadyParticipant(InviteGroupCallParticipantResultUserAlreadyParticipant value), required TResult userPrivacyRestricted(InviteGroupCallParticipantResultUserPrivacyRestricted value), required TResult userWasBanned(InviteGroupCallParticipantResultUserWasBanned value)}) → TResult -
Available on InviteGroupCallParticipantResult, provided by the InviteGroupCallParticipantResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult success(InviteGroupCallParticipantResultSuccess value)?, TResult userAlreadyParticipant(InviteGroupCallParticipantResultUserAlreadyParticipant value)?, TResult userPrivacyRestricted(InviteGroupCallParticipantResultUserPrivacyRestricted value)?, TResult userWasBanned(InviteGroupCallParticipantResultUserWasBanned value)?, required TResult orElse()}) → TResult -
Available on InviteGroupCallParticipantResult, provided by the InviteGroupCallParticipantResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InviteGroupCallParticipantResultUserAlreadyParticipant? -
Inherited by:
InviteGroupCallParticipantResultSuccess
InviteGroupCallParticipantResultUserAlreadyParticipant
InviteGroupCallParticipantResultUserPrivacyRestricted
InviteGroupCallParticipantResultUserWasBanned
override
Constants
- constructor → const String