InviteLinkChatTypeSupergroup class final

The link is an invite link for a supergroup

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InviteLinkChatTypeSupergroup()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult basicGroup(InviteLinkChatTypeBasicGroup value), required TResult channel(InviteLinkChatTypeChannel value), required TResult supergroup(InviteLinkChatTypeSupergroup value)}) → TResult

Available on InviteLinkChatType, provided by the InviteLinkChatTypeExtensions extension

maybeMap<TResult extends Object?>({TResult basicGroup(InviteLinkChatTypeBasicGroup value)?, TResult channel(InviteLinkChatTypeChannel value)?, TResult supergroup(InviteLinkChatTypeSupergroup value)?, required TResult orElse()}) → TResult

Available on InviteLinkChatType, provided by the InviteLinkChatTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String