IsProfileAudio class final

Checks whether a file is in the profile audio files of the current user. Returns a 404 error if it isn't Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

IsProfileAudio({required int fileId})

Properties

fileId int
fileId Identifier of the audio file to check
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId}) IsProfileAudio

Available on IsProfileAudio, provided by the IsProfileAudioExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String