JoinChat class final
Adds the current user as a new member to a chat. Private and secret chats can't be joined using this method Returns ChatJoinResult
- Inheritance
-
- Object
- TdFunction
- JoinChat
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{int? chatId}) → JoinChat -
Available on JoinChat, provided by the JoinChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String