JoinChatByInviteLink class final
Uses an invite link to add the current user to the chat if possible Returns ChatJoinResult
- Inheritance
-
- Object
- TdFunction
- JoinChatByInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- JoinChatByInviteLink({required String inviteLink})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Invite link to use
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? inviteLink}) → JoinChatByInviteLink -
Available on JoinChatByInviteLink, provided by the JoinChatByInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String