participantId property
participantId Identifier of a group call participant, which will be used to join the call; pass null to join as self
Implementation
final MessageSender? participantId;
participantId Identifier of a group call participant, which will be used to join the call; pass null to join as self
final MessageSender? participantId;