JsonValueNumber class final

Represents a numeric JSON value

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

JsonValueNumber({required double value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
value The value
final

Methods

copyWith({double? value}) JsonValueNumber

Available on JsonValueNumber, provided by the JsonValueNumberExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult array(JsonValueArray value), required TResult $boolean(JsonValueBoolean value), required TResult $null(JsonValueNull value), required TResult number(JsonValueNumber value), required TResult $object(JsonValueObject value), required TResult $string(JsonValueString value)}) → TResult

Available on JsonValue, provided by the JsonValueExtensions extension

maybeMap<TResult extends Object?>({TResult array(JsonValueArray value)?, TResult $boolean(JsonValueBoolean value)?, TResult $null(JsonValueNull value)?, TResult number(JsonValueNumber value)?, TResult $object(JsonValueObject value)?, TResult $string(JsonValueString value)?, required TResult orElse()}) → TResult

Available on JsonValue, provided by the JsonValueExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String