JsonValueObject class final
Represents a JSON object
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
JsonValueObject({required List<
JsonObjectMember> members})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
members
→ List<
JsonObjectMember> -
members The list of object members
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< JsonObjectMember> ? members}) → JsonValueObject -
Available on JsonValueObject, provided by the JsonValueObjectExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult array(JsonValueArray value), required TResult $boolean(JsonValueBoolean value), required TResult $null(JsonValueNull value), required TResult number(JsonValueNumber value), required TResult $object(JsonValueObject value), required TResult $string(JsonValueString value)}) → TResult -
Available on JsonValue, provided by the JsonValueExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult array(JsonValueArray value)?, TResult $boolean(JsonValueBoolean value)?, TResult $null(JsonValueNull value)?, TResult number(JsonValueNumber value)?, TResult $object(JsonValueObject value)?, TResult $string(JsonValueString value)?, required TResult orElse()}) → TResult -
Available on JsonValue, provided by the JsonValueExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → JsonValueObject? -
Inherited by:
JsonValueArray
JsonValueBoolean
JsonValueNull
JsonValueNumber
JsonValueObject
JsonValueString
override
Constants
- constructor → const String