iconCustomEmojiId property
iconCustomEmojiId Identifier of the custom emoji that must be shown on the button; 0 if none
Implementation
final int iconCustomEmojiId;
iconCustomEmojiId Identifier of the custom emoji that must be shown on the button; 0 if none
final int iconCustomEmojiId;