KeyboardButtonSource class sealed
Describes source of a keyboard button
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult message(KeyboardButtonSourceMessage value), required TResult webApp(KeyboardButtonSourceWebApp value)}) → TResult -
Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult message(KeyboardButtonSourceMessage value)?, TResult webApp(KeyboardButtonSourceWebApp value)?, required TResult orElse()}) → TResult -
Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → KeyboardButtonSource? - Inherited by: KeyboardButtonSourceMessage KeyboardButtonSourceWebApp
Constants
- constructor → const String