KeyboardButtonSourceMessage class final

The button is from a bot's message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

KeyboardButtonSourceMessage({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message with the button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) KeyboardButtonSourceMessage

Available on KeyboardButtonSourceMessage, provided by the KeyboardButtonSourceMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(KeyboardButtonSourceMessage value), required TResult webApp(KeyboardButtonSourceWebApp value)}) → TResult

Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension

maybeMap<TResult extends Object?>({TResult message(KeyboardButtonSourceMessage value)?, TResult webApp(KeyboardButtonSourceWebApp value)?, required TResult orElse()}) → TResult

Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) KeyboardButtonSourceMessage?
Inherited by: KeyboardButtonSourceMessage KeyboardButtonSourceWebApp
override

Constants

constructor → const String