KeyboardButtonTypeRequestChat class final

A button that requests a chat to be shared by the current user; available only in private chats. Use the method shareChatWithBot to complete the request

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

KeyboardButtonTypeRequestChat({required int id, required bool chatIsChannel, required bool restrictChatIsForum, required bool chatIsForum, required bool restrictChatHasUsername, required bool chatHasUsername, required bool chatIsCreated, ChatAdministratorRights? userAdministratorRights, ChatAdministratorRights? botAdministratorRights, required bool botIsMember, required bool requestTitle, required bool requestUsername, required bool requestPhoto})

Properties

botAdministratorRights ChatAdministratorRights?
botAdministratorRights Expected bot administrator rights in the chat; may be null if they aren't restricted
final
botIsMember bool
botIsMember True, if the bot must be a member of the chat; for basic group and supergroup chats only
final
chatHasUsername bool
chatHasUsername True, if the chat must have a username; otherwise, the chat must not have a username. Ignored if restrict_chat_has_username is false
final
chatIsChannel bool
chatIsChannel True, if the chat must be a channel; otherwise, a basic group or a supergroup chat is shared
final
chatIsCreated bool
chatIsCreated True, if the chat must be created by the current user
final
chatIsForum bool
chatIsForum True, if the chat must be a forum supergroup; otherwise, the chat must not be a forum supergroup. Ignored if restrict_chat_is_forum is false
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique button identifier
final
requestPhoto bool
requestPhoto Pass true to request photo of the chat; bots only
final
requestTitle bool
requestTitle Pass true to request title of the chat; bots only
final
requestUsername bool
requestUsername Pass true to request username of the chat; bots only
final
restrictChatHasUsername bool
restrictChatHasUsername True, if the chat must or must not have a username
final
restrictChatIsForum bool
restrictChatIsForum True, if the chat must or must not be a forum supergroup
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAdministratorRights ChatAdministratorRights?
userAdministratorRights Expected user administrator rights in the chat; may be null if they aren't restricted
final

Methods

copyWith({int? id, bool? chatIsChannel, bool? restrictChatIsForum, bool? chatIsForum, bool? restrictChatHasUsername, bool? chatHasUsername, bool? chatIsCreated, ChatAdministratorRights? userAdministratorRights, ChatAdministratorRights? botAdministratorRights, bool? botIsMember, bool? requestTitle, bool? requestUsername, bool? requestPhoto}) KeyboardButtonTypeRequestChat

Available on KeyboardButtonTypeRequestChat, provided by the KeyboardButtonTypeRequestChatExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult requestChat(KeyboardButtonTypeRequestChat value), required TResult requestLocation(KeyboardButtonTypeRequestLocation value), required TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value), required TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value), required TResult requestPoll(KeyboardButtonTypeRequestPoll value), required TResult requestUsers(KeyboardButtonTypeRequestUsers value), required TResult text(KeyboardButtonTypeText value), required TResult webApp(KeyboardButtonTypeWebApp value)}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

maybeMap<TResult extends Object?>({TResult requestChat(KeyboardButtonTypeRequestChat value)?, TResult requestLocation(KeyboardButtonTypeRequestLocation value)?, TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value)?, TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value)?, TResult requestPoll(KeyboardButtonTypeRequestPoll value)?, TResult requestUsers(KeyboardButtonTypeRequestUsers value)?, TResult text(KeyboardButtonTypeText value)?, TResult webApp(KeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String