KeyboardButtonTypeRequestManagedBot class final

A button that requests creation of a managed bot by the current user; available only in private chats. Use the method createBot to complete the request

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

KeyboardButtonTypeRequestManagedBot({required int id, required String suggestedName, required String suggestedUsername})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Unique button identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestedName String
suggestedName Suggested name for the bot; may be empty if not specified
final
suggestedUsername String
suggestedUsername Suggested username for the bot; may be empty if not specified
final

Methods

copyWith({int? id, String? suggestedName, String? suggestedUsername}) KeyboardButtonTypeRequestManagedBot

Available on KeyboardButtonTypeRequestManagedBot, provided by the KeyboardButtonTypeRequestManagedBotExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult requestChat(KeyboardButtonTypeRequestChat value), required TResult requestLocation(KeyboardButtonTypeRequestLocation value), required TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value), required TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value), required TResult requestPoll(KeyboardButtonTypeRequestPoll value), required TResult requestUsers(KeyboardButtonTypeRequestUsers value), required TResult text(KeyboardButtonTypeText value), required TResult webApp(KeyboardButtonTypeWebApp value)}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

maybeMap<TResult extends Object?>({TResult requestChat(KeyboardButtonTypeRequestChat value)?, TResult requestLocation(KeyboardButtonTypeRequestLocation value)?, TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value)?, TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value)?, TResult requestPoll(KeyboardButtonTypeRequestPoll value)?, TResult requestUsers(KeyboardButtonTypeRequestUsers value)?, TResult text(KeyboardButtonTypeText value)?, TResult webApp(KeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String