KeyboardButtonTypeRequestPoll class final

A button that allows the user to create and send a poll when pressed; available only in private chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

KeyboardButtonTypeRequestPoll({required bool forceRegular, required bool forceQuiz})

Properties

forceQuiz bool
forceQuiz If true, only polls in quiz mode must be allowed to create
final
forceRegular bool
forceRegular If true, only regular polls must be allowed to create
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? forceRegular, bool? forceQuiz}) KeyboardButtonTypeRequestPoll

Available on KeyboardButtonTypeRequestPoll, provided by the KeyboardButtonTypeRequestPollExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult requestChat(KeyboardButtonTypeRequestChat value), required TResult requestLocation(KeyboardButtonTypeRequestLocation value), required TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value), required TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value), required TResult requestPoll(KeyboardButtonTypeRequestPoll value), required TResult requestUsers(KeyboardButtonTypeRequestUsers value), required TResult text(KeyboardButtonTypeText value), required TResult webApp(KeyboardButtonTypeWebApp value)}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

maybeMap<TResult extends Object?>({TResult requestChat(KeyboardButtonTypeRequestChat value)?, TResult requestLocation(KeyboardButtonTypeRequestLocation value)?, TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value)?, TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value)?, TResult requestPoll(KeyboardButtonTypeRequestPoll value)?, TResult requestUsers(KeyboardButtonTypeRequestUsers value)?, TResult text(KeyboardButtonTypeText value)?, TResult webApp(KeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String