KeyboardButtonTypeRequestUsers class final

A button that requests users to be shared by the current user; available only in private chats. Use the method shareUsersWithBot to complete the request

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

KeyboardButtonTypeRequestUsers({required int id, required bool restrictUserIsBot, required bool userIsBot, required bool restrictUserIsPremium, required bool userIsPremium, required int maxQuantity, required bool requestName, required bool requestUsername, required bool requestPhoto})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Unique button identifier
final
maxQuantity int
maxQuantity The maximum number of users to share
final
requestName bool
requestName Pass true to request name of the users; bots only
final
requestPhoto bool
requestPhoto Pass true to request photo of the users; bots only
final
requestUsername bool
requestUsername Pass true to request username of the users; bots only
final
restrictUserIsBot bool
restrictUserIsBot True, if the shared users must or must not be bots
final
restrictUserIsPremium bool
restrictUserIsPremium True, if the shared users must or must not be Telegram Premium users
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIsBot bool
userIsBot True, if the shared users must be bots; otherwise, the shared users must not be bots. Ignored if restrict_user_is_bot is false
final
userIsPremium bool
userIsPremium True, if the shared users must be Telegram Premium users; otherwise, the shared users must not be Telegram Premium users. Ignored if restrict_user_is_premium is false
final

Methods

copyWith({int? id, bool? restrictUserIsBot, bool? userIsBot, bool? restrictUserIsPremium, bool? userIsPremium, int? maxQuantity, bool? requestName, bool? requestUsername, bool? requestPhoto}) KeyboardButtonTypeRequestUsers

Available on KeyboardButtonTypeRequestUsers, provided by the KeyboardButtonTypeRequestUsersExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult requestChat(KeyboardButtonTypeRequestChat value), required TResult requestLocation(KeyboardButtonTypeRequestLocation value), required TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value), required TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value), required TResult requestPoll(KeyboardButtonTypeRequestPoll value), required TResult requestUsers(KeyboardButtonTypeRequestUsers value), required TResult text(KeyboardButtonTypeText value), required TResult webApp(KeyboardButtonTypeWebApp value)}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

maybeMap<TResult extends Object?>({TResult requestChat(KeyboardButtonTypeRequestChat value)?, TResult requestLocation(KeyboardButtonTypeRequestLocation value)?, TResult requestManagedBot(KeyboardButtonTypeRequestManagedBot value)?, TResult requestPhoneNumber(KeyboardButtonTypeRequestPhoneNumber value)?, TResult requestPoll(KeyboardButtonTypeRequestPoll value)?, TResult requestUsers(KeyboardButtonTypeRequestUsers value)?, TResult text(KeyboardButtonTypeText value)?, TResult webApp(KeyboardButtonTypeWebApp value)?, required TResult orElse()}) → TResult

Available on KeyboardButtonType, provided by the KeyboardButtonTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String