restrictUserIsPremium property
restrictUserIsPremium True, if the shared users must or must not be Telegram Premium users
Implementation
final bool restrictUserIsPremium;
restrictUserIsPremium True, if the shared users must or must not be Telegram Premium users
final bool restrictUserIsPremium;