LabeledPricePart class final

Portion of the price of a product (e.g., "delivery cost", "tax amount")

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LabeledPricePart({required String label, required int amount})

Properties

amount int
amount Currency amount in the smallest units of the currency
final
hashCode int
The hash code for this object.
no setteroverride
label String
label Label for this portion of the product price
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? label, int? amount}) LabeledPricePart

Available on LabeledPricePart, provided by the LabeledPricePartExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LabeledPricePart?

Constants

constructor → const String