LanguagePackInfo class final
Contains information about a language pack
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- LanguagePackInfo({required String id, required String baseLanguagePackId, required String name, required String nativeName, required String pluralCode, required bool isOfficial, required bool isRtl, required bool isBeta, required bool isInstalled, required int totalStringCount, required int translatedStringCount, required int localStringCount, required String translationUrl})
Properties
- baseLanguagePackId → String
-
baseLanguagePackId Identifier of a base language pack; may be empty. If
a string is missed in the language pack, then it must be fetched from base
language pack. Unsupported in custom language packs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique language pack identifier
final
- isBeta → bool
-
isBeta True, if the language pack is a beta language pack
final
- isInstalled → bool
-
isInstalled True, if the language pack is installed by the current user
final
- isOfficial → bool
-
isOfficial True, if the language pack is official
final
- isRtl → bool
-
isRtl True, if the language pack strings are RTL
final
- localStringCount → int
-
localStringCount Total number of non-deleted strings from the language
pack available locally
final
- name → String
-
name Language name
final
- nativeName → String
-
nativeName Name of the language in that language
final
- pluralCode → String
-
pluralCode A language code to be used to apply plural forms. See
https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html
for more information
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalStringCount → int
-
totalStringCount Total number of non-deleted strings from the language
pack
final
- translatedStringCount → int
-
translatedStringCount Total number of translated strings from the
language pack
final
- translationUrl → String
-
translationUrl Link to language translation interface; empty for custom
local language packs
final
Methods
-
copyWith(
{String? id, String? baseLanguagePackId, String? name, String? nativeName, String? pluralCode, bool? isOfficial, bool? isRtl, bool? isBeta, bool? isInstalled, int? totalStringCount, int? translatedStringCount, int? localStringCount, String? translationUrl}) → LanguagePackInfo -
Available on LanguagePackInfo, provided by the LanguagePackInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LanguagePackInfo?
Constants
- constructor → const String