LanguagePackString class final

Represents one language pack string

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LanguagePackString({required String key, LanguagePackStringValue? value})

Properties

hashCode int
The hash code for this object.
no setteroverride
key String
key String key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value LanguagePackStringValue?
value String value; pass null if the string needs to be taken from the built-in English language pack
final

Methods

copyWith({String? key, LanguagePackStringValue? value}) LanguagePackString

Available on LanguagePackString, provided by the LanguagePackStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LanguagePackString?

Constants

constructor → const String