LanguagePackStringValue class sealed
Represents the value of a string in a language pack
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult deleted(LanguagePackStringValueDeleted value), required TResult ordinary(LanguagePackStringValueOrdinary value), required TResult pluralized(LanguagePackStringValuePluralized value)}) → TResult -
Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult deleted(LanguagePackStringValueDeleted value)?, TResult ordinary(LanguagePackStringValueOrdinary value)?, TResult pluralized(LanguagePackStringValuePluralized value)?, required TResult orElse()}) → TResult -
Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LanguagePackStringValue? - Inherited by: LanguagePackStringValueDeleted LanguagePackStringValueOrdinary LanguagePackStringValuePluralized
Constants
- constructor → const String