LanguagePackStringValueOrdinary class final

An ordinary language pack string

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LanguagePackStringValueOrdinary({required String value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
value String value
final

Methods

copyWith({String? value}) LanguagePackStringValueOrdinary

Available on LanguagePackStringValueOrdinary, provided by the LanguagePackStringValueOrdinaryExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult deleted(LanguagePackStringValueDeleted value), required TResult ordinary(LanguagePackStringValueOrdinary value), required TResult pluralized(LanguagePackStringValuePluralized value)}) → TResult

Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension

maybeMap<TResult extends Object?>({TResult deleted(LanguagePackStringValueDeleted value)?, TResult ordinary(LanguagePackStringValueOrdinary value)?, TResult pluralized(LanguagePackStringValuePluralized value)?, required TResult orElse()}) → TResult

Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String