LanguagePackStringValuePluralized class final

A language pack string which has different forms based on the number of some object it mentions. See https://www.unicode.org/cldr/charts/latest/supplemental/language_plural_rules.html for more information

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LanguagePackStringValuePluralized({required String zeroValue, required String oneValue, required String twoValue, required String fewValue, required String manyValue, required String otherValue})

Properties

fewValue String
fewValue Value for few objects
final
hashCode int
The hash code for this object.
no setteroverride
manyValue String
manyValue Value for many objects
final
oneValue String
oneValue Value for one object
final
otherValue String
otherValue Default value
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
twoValue String
twoValue Value for two objects
final
zeroValue String
zeroValue Value for zero objects
final

Methods

copyWith({String? zeroValue, String? oneValue, String? twoValue, String? fewValue, String? manyValue, String? otherValue}) LanguagePackStringValuePluralized

Available on LanguagePackStringValuePluralized, provided by the LanguagePackStringValuePluralizedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult deleted(LanguagePackStringValueDeleted value), required TResult ordinary(LanguagePackStringValueOrdinary value), required TResult pluralized(LanguagePackStringValuePluralized value)}) → TResult

Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension

maybeMap<TResult extends Object?>({TResult deleted(LanguagePackStringValueDeleted value)?, TResult ordinary(LanguagePackStringValueOrdinary value)?, TResult pluralized(LanguagePackStringValuePluralized value)?, required TResult orElse()}) → TResult

Available on LanguagePackStringValue, provided by the LanguagePackStringValueExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String