LanguagePackStrings class final

Contains a list of language pack strings

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LanguagePackStrings({required List<LanguagePackString> strings})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings List<LanguagePackString>
strings A list of language pack strings
final

Methods

copyWith({List<LanguagePackString>? strings}) LanguagePackStrings

Available on LanguagePackStrings, provided by the LanguagePackStringsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LanguagePackStrings?

Constants

constructor → const String