LeaveChat class final

Removes the current user from chat members. Private and secret chats can't be left using this method Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LeaveChat({required int chatId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) LeaveChat

Available on LeaveChat, provided by the LeaveChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String