showLargeMedia property
showLargeMedia True, if large media preview must be shown; otherwise, the media preview must be shown small and only the first frame must be shown for videos
Implementation
final bool showLargeMedia;
showLargeMedia True, if large media preview must be shown; otherwise, the media preview must be shown small and only the first frame must be shown for videos
final bool showLargeMedia;