showMediaAboveDescription property
showMediaAboveDescription True, if media must be shown above link preview description; otherwise, the media must be shown below the description
Implementation
final bool showMediaAboveDescription;
showMediaAboveDescription True, if media must be shown above link preview description; otherwise, the media must be shown below the description
final bool showMediaAboveDescription;