skipConfirmation property

bool skipConfirmation
final

skipConfirmation True, if there is no need to show an ordinary open URL confirmation, when opening the URL from the preview, because the URL is shown in the message text in clear

Implementation

final bool skipConfirmation;