LinkPreviewAlbumMediaPhoto class final

The media is a photo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LinkPreviewAlbumMediaPhoto({Photo? photo})

Properties

hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo Photo description
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Photo? photo}) LinkPreviewAlbumMediaPhoto

Available on LinkPreviewAlbumMediaPhoto, provided by the LinkPreviewAlbumMediaPhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(LinkPreviewAlbumMediaPhoto value), required TResult video(LinkPreviewAlbumMediaVideo value)}) → TResult

Available on LinkPreviewAlbumMedia, provided by the LinkPreviewAlbumMediaExtensions extension

maybeMap<TResult extends Object?>({TResult photo(LinkPreviewAlbumMediaPhoto value)?, TResult video(LinkPreviewAlbumMediaVideo value)?, required TResult orElse()}) → TResult

Available on LinkPreviewAlbumMedia, provided by the LinkPreviewAlbumMediaExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LinkPreviewAlbumMediaPhoto?
Inherited by: LinkPreviewAlbumMediaPhoto LinkPreviewAlbumMediaVideo
override

Constants

constructor → const String