showAboveText property

bool showAboveText
final

showAboveText True, if link preview must be shown above message text; otherwise, the link preview will be shown below the message text; ignored in secret chats

Implementation

final bool showAboveText;