customEmojiId property
customEmojiId Identifier of the custom emoji corresponding to the style; 0 if none
Implementation
final int customEmojiId;
customEmojiId Identifier of the custom emoji corresponding to the style; 0 if none
final int customEmojiId;