joinsAsSpeaker property

bool joinsAsSpeaker
final

joinsAsSpeaker True, if the user can use the link to join the video chat without being muted by administrators

Implementation

final bool joinsAsSpeaker;