LiveLocation class final

A live location

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LiveLocation({Location? location, required int livePeriod, required int heading, required int proximityAlertRadius})

Properties

hashCode int
The hash code for this object.
no setteroverride
heading int
heading The direction in which the location moves, in degrees; 1-360; 0 if unknown
final
livePeriod int
livePeriod Time relative to the message send date, for which the location can be updated, in seconds; if 0x7FFFFFFF, then location can be updated forever
final
location Location?
location The current location
final
proximityAlertRadius int
proximityAlertRadius The maximum distance to another chat member for proximity alerts, in meters (0-100000). 0 if the notification is disabled. Can't be enabled in direct messages chats, channels and Saved Messages. Available only to the message sender
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, int? livePeriod, int? heading, int? proximityAlertRadius}) LiveLocation

Available on LiveLocation, provided by the LiveLocationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LiveLocation?

Constants

constructor → const String