livePeriod property

int livePeriod
final

livePeriod Time relative to the message send date, for which the location can be updated, in seconds; if 0x7FFFFFFF, then location can be updated forever

Implementation

final int livePeriod;