LoadChats class final
Loads more chats from a chat list. The loaded chats and their positions in the chat list will be sent through updates. Chats are sorted by the pair (chat.position.order, chat.id) in descending order. Returns a 404 error if all chats have been loaded Returns Ok
- Inheritance
-
- Object
- TdFunction
- LoadChats
- Available extensions
- Annotations
-
- @immutable
Properties
- chatList → ChatList?
-
chatList The chat list in which to load chats; pass null to load chats
from the main chat list
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of chats to be loaded. For optimal performance,
the number of loaded chats is chosen by TDLib and can be smaller than the
specified limit, even if the end of the list is not reached
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatList? chatList, int? limit}) → LoadChats -
Available on LoadChats, provided by the LoadChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String