LoadDirectMessagesChatTopics class final

Loads more topics in a channel direct messages chat administered by the current user. The loaded topics will be sent through updateDirectMessagesChatTopic. Topics are sorted by their topic.order in descending order. Returns a 404 error if all topics have been loaded Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LoadDirectMessagesChatTopics({required int chatId, required int limit})

Properties

chatId int
chatId Chat identifier of the channel direct messages chat
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of topics to be loaded. For optimal performance, the number of loaded topics is chosen by TDLib and can be smaller than the specified limit, even if the end of the list is not reached
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? limit}) LoadDirectMessagesChatTopics

Available on LoadDirectMessagesChatTopics, provided by the LoadDirectMessagesChatTopicsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String