LoadGroupCallParticipants class final

Loads more participants of a group call; not supported in live stories. The loaded participants will be received through updates. Use the field groupCall.loaded_all_participants to check whether all participants have already been loaded Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LoadGroupCallParticipants({required int groupCallId, required int limit})

Properties

groupCallId int
groupCallId Group call identifier. The group call must be previously received through getGroupCall and must be joined or being joined
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of participants to load; up to 100
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? limit}) LoadGroupCallParticipants

Available on LoadGroupCallParticipants, provided by the LoadGroupCallParticipantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String