LoadQuickReplyShortcutMessages class final
Loads quick reply messages that can be sent by a given quick reply shortcut. The loaded messages will be sent through updateQuickReplyShortcutMessages Returns Ok
- Inheritance
-
- Object
- TdFunction
- LoadQuickReplyShortcutMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- LoadQuickReplyShortcutMessages({required int shortcutId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcutId → int
-
shortcutId Unique identifier of the quick reply shortcut
final
Methods
-
copyWith(
{int? shortcutId}) → LoadQuickReplyShortcutMessages -
Available on LoadQuickReplyShortcutMessages, provided by the LoadQuickReplyShortcutMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String