LocalFile class final

Represents a local file

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LocalFile({required String path, required bool canBeDownloaded, required bool canBeDeleted, required bool isDownloadingActive, required bool isDownloadingCompleted, required int downloadOffset, required int downloadedPrefixSize, required int downloadedSize})

Properties

canBeDeleted bool
canBeDeleted True, if the file can be deleted
final
canBeDownloaded bool
canBeDownloaded True, if it is possible to download or generate the file
final
downloadedPrefixSize int
downloadedPrefixSize If is_downloading_completed is false, then only some prefix of the file starting from download_offset is ready to be read. downloaded_prefix_size is the size of that prefix in bytes
final
downloadedSize int
downloadedSize Total downloaded file size, in bytes. Can be used only for calculating download progress. The actual file size may be bigger, and some parts of it may contain garbage
final
downloadOffset int
downloadOffset Download will be started from this offset. downloaded_prefix_size is calculated from this offset
final
hashCode int
The hash code for this object.
no setteroverride
isDownloadingActive bool
isDownloadingActive True, if the file is currently being downloaded (or a local copy is being generated by some other means)
final
isDownloadingCompleted bool
isDownloadingCompleted True, if the local copy is fully available
final
path String
path Local path to the locally available file part; may be empty
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? path, bool? canBeDownloaded, bool? canBeDeleted, bool? isDownloadingActive, bool? isDownloadingCompleted, int? downloadOffset, int? downloadedPrefixSize, int? downloadedSize}) LocalFile

Available on LocalFile, provided by the LocalFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LocalFile?

Constants

constructor → const String