LocalizationTargetInfo class final

Contains information about the current localization target

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LocalizationTargetInfo({required List<LanguagePackInfo> languagePacks})

Properties

hashCode int
The hash code for this object.
no setteroverride
languagePacks List<LanguagePackInfo>
languagePacks List of available language packs for this application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<LanguagePackInfo>? languagePacks}) LocalizationTargetInfo

Available on LocalizationTargetInfo, provided by the LocalizationTargetInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LocalizationTargetInfo?

Constants

constructor → const String