Location class final
Describes a location on planet Earth
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- horizontalAccuracy → double
-
horizontalAccuracy The estimated horizontal accuracy of the location, in
meters; as defined by the sender. 0 if unknown
final
- latitude → double
-
latitude Latitude of the location in degrees; as defined by the sender
final
- longitude → double
-
longitude Longitude of the location, in degrees; as defined by the
sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{double? latitude, double? longitude, double? horizontalAccuracy}) → Location -
Available on Location, provided by the LocationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String