LocationAddress class final

Describes an address of a location

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LocationAddress({required String countryCode, required String state, required String city, required String street})

Properties

city String
city City; empty if unknown
final
countryCode String
countryCode A two-letter ISO 3166-1 alpha-2 country code
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
state State, if applicable; empty if unknown
final
street String
street The address; empty if unknown
final

Methods

copyWith({String? countryCode, String? state, String? city, String? street}) LocationAddress

Available on LocationAddress, provided by the LocationAddressExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LocationAddress?

Constants

constructor → const String