LogStreamDefault class final

The log is written to stderr or an OS specific log

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

LogStreamDefault()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult $default(LogStreamDefault value), required TResult empty(LogStreamEmpty value), required TResult file(LogStreamFile value)}) → TResult

Available on LogStream, provided by the LogStreamExtensions extension

maybeMap<TResult extends Object?>({TResult $default(LogStreamDefault value)?, TResult empty(LogStreamEmpty value)?, TResult file(LogStreamFile value)?, required TResult orElse()}) → TResult

Available on LogStream, provided by the LogStreamExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LogStreamDefault?
Inherited by: LogStreamDefault LogStreamEmpty LogStreamFile
override

Constants

constructor → const String