LogStreamFile class final
The log is written to a file
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- LogStreamFile({required String path, required int maxFileSize, required bool redirectStderr})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxFileSize → int
-
maxFileSize The maximum size of the file to where the internal TDLib log
is written before the file will automatically be rotated, in bytes
final
- path → String
-
path Path to the file to where the internal TDLib log will be written
final
- redirectStderr → bool
-
redirectStderr Pass true to additionally redirect stderr to the log
file. Ignored on Windows
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? path, int? maxFileSize, bool? redirectStderr}) → LogStreamFile -
Available on LogStreamFile, provided by the LogStreamFileExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult $default(LogStreamDefault value), required TResult empty(LogStreamEmpty value), required TResult file(LogStreamFile value)}) → TResult -
Available on LogStream, provided by the LogStreamExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult $default(LogStreamDefault value)?, TResult empty(LogStreamEmpty value)?, TResult file(LogStreamFile value)?, required TResult orElse()}) → TResult -
Available on LogStream, provided by the LogStreamExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LogStreamFile? -
Inherited by:
LogStreamDefault
LogStreamEmpty
LogStreamFile
override
Constants
- constructor → const String