LoginUrlInfo class sealed

Contains information about an inline button of type inlineKeyboardButtonTypeLoginUrl or an external link

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult open(LoginUrlInfoOpen value), required TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)}) → TResult

Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension

maybeMap<TResult extends Object?>({TResult open(LoginUrlInfoOpen value)?, TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)?, required TResult orElse()}) → TResult

Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) LoginUrlInfo?
Inherited by: LoginUrlInfoOpen LoginUrlInfoRequestConfirmation

Constants

constructor → const String