MainWebApp class final

Contains information about the main Web App of a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MainWebApp({WebAppUrl? url, WebAppOpenMode? mode})

Properties

hashCode int
The hash code for this object.
no setteroverride
mode WebAppOpenMode?
mode The mode in which the Web App must be opened
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url WebAppUrl?
url URL of the Web App to open
final

Methods

copyWith({WebAppUrl? url, WebAppOpenMode? mode}) MainWebApp

Available on MainWebApp, provided by the MainWebAppExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MainWebApp?

Constants

constructor → const String