MarkChecklistTasksAsDone class final
Adds tasks of a checklist in a message as done or not done Returns Ok
- Inheritance
-
- Object
- TdFunction
- MarkChecklistTasksAsDone
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Identifier of the chat with the message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
markedAsDoneTaskIds
→ List<
int> -
markedAsDoneTaskIds Identifiers of tasks that were marked as done
final
-
markedAsNotDoneTaskIds
→ List<
int> -
markedAsNotDoneTaskIds Identifiers of tasks that were marked as not done
final
- messageId → int
-
messageId Identifier of the message containing the checklist. Use
messageProperties.can_mark_tasks_as_done to check whether the tasks can be
marked as done or not done
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, List< int> ? markedAsDoneTaskIds, List<int> ? markedAsNotDoneTaskIds}) → MarkChecklistTasksAsDone -
Available on MarkChecklistTasksAsDone, provided by the MarkChecklistTasksAsDoneExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String