MaskPointEyes class final

The mask is placed relatively to the eyes

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MaskPointEyes()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult chin(MaskPointChin value), required TResult eyes(MaskPointEyes value), required TResult forehead(MaskPointForehead value), required TResult mouth(MaskPointMouth value)}) → TResult

Available on MaskPoint, provided by the MaskPointExtensions extension

maybeMap<TResult extends Object?>({TResult chin(MaskPointChin value)?, TResult eyes(MaskPointEyes value)?, TResult forehead(MaskPointForehead value)?, TResult mouth(MaskPointMouth value)?, required TResult orElse()}) → TResult

Available on MaskPoint, provided by the MaskPointExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MaskPointEyes?
Inherited by: MaskPointChin MaskPointEyes MaskPointForehead MaskPointMouth
override

Constants

constructor → const String