autoDeleteIn property
autoDeleteIn Time left before the message will be automatically deleted by message_auto_delete_time setting of the chat, in seconds; 0 if never
Implementation
final double autoDeleteIn;
autoDeleteIn Time left before the message will be automatically deleted by message_auto_delete_time setting of the chat, in seconds; 0 if never
final double autoDeleteIn;