containsUnreadPollVotes property
containsUnreadPollVotes True, if the message is a poll message with unread votes
Implementation
final bool containsUnreadPollVotes;
containsUnreadPollVotes True, if the message is a poll message with unread votes
final bool containsUnreadPollVotes;