ephemeralMessageId property
ephemeralMessageId Unique identifier of the ephemeral message if the message is ephemeral; for bots only
Implementation
final int? ephemeralMessageId;
ephemeralMessageId Unique identifier of the ephemeral message if the message is ephemeral; for bots only
final int? ephemeralMessageId;