importInfo property
importInfo Information about the initial message for messages created with importMessages; may be null if the message isn't imported
Implementation
final MessageImportInfo? importInfo;
importInfo Information about the initial message for messages created with importMessages; may be null if the message isn't imported
final MessageImportInfo? importInfo;