isFromOffline property
isFromOffline True, if the message was sent because of a scheduled action by the message sender, for example, as away, or greeting service message
Implementation
final bool isFromOffline;
isFromOffline True, if the message was sent because of a scheduled action by the message sender, for example, as away, or greeting service message
final bool isFromOffline;