isPaidGramSuggestedPost property

bool isPaidGramSuggestedPost
final

isPaidGramSuggestedPost True, if the message is a suggested channel post which was paid in TON Grams; a warning must be shown if the message is deleted in less than getOption("suggested_post_lifetime_min") seconds after sending

Implementation

final bool isPaidGramSuggestedPost;