paidMessageStarCount property
paidMessageStarCount The number of Telegram Stars the sender paid to send the message
Implementation
final int paidMessageStarCount;
paidMessageStarCount The number of Telegram Stars the sender paid to send the message
final int paidMessageStarCount;