receiverId property
receiverId Identifier of the user or the chat which received the ephemeral message; may be null. Always null for non-ephemeral messages
Implementation
final MessageSender? receiverId;
receiverId Identifier of the user or the chat which received the ephemeral message; may be null. Always null for non-ephemeral messages
final MessageSender? receiverId;