restrictionInfo property
restrictionInfo Information about the restrictions that must be applied to the message content; may be null if none
Implementation
final RestrictionInfo? restrictionInfo;
restrictionInfo Information about the restrictions that must be applied to the message content; may be null if none
final RestrictionInfo? restrictionInfo;