senderBusinessBotUserId property
senderBusinessBotUserId If non-zero, the user identifier of the business bot that sent this message
Implementation
final int senderBusinessBotUserId;
senderBusinessBotUserId If non-zero, the user identifier of the business bot that sent this message
final int senderBusinessBotUserId;