summaryLanguageCode property
summaryLanguageCode IETF language tag of the message language on which it can be summarized; empty if summary isn't available for the message
Implementation
final String summaryLanguageCode;
summaryLanguageCode IETF language tag of the message language on which it can be summarized; empty if summary isn't available for the message
final String summaryLanguageCode;