MessageAutoDeleteTime class final

Contains default auto-delete timer setting for new chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageAutoDeleteTime({required int time})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time int
time Message auto-delete time, in seconds. If 0, then messages aren't deleted automatically
final

Methods

copyWith({int? time}) MessageAutoDeleteTime

Available on MessageAutoDeleteTime, provided by the MessageAutoDeleteTimeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageAutoDeleteTime?

Constants

constructor → const String