MessageCalendar class final

Contains information about found messages, split by days according to the option "utc_time_offset"

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageCalendar({required int totalCount, required List<MessageCalendarDay> days})

Properties

days List<MessageCalendarDay>
days Information about messages sent
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of found messages
final

Methods

copyWith({int? totalCount, List<MessageCalendarDay>? days}) MessageCalendar

Available on MessageCalendar, provided by the MessageCalendarExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageCalendar?

Constants

constructor → const String