MessageCalendarDay class final

Contains information about found messages sent on a specific day

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageCalendarDay({required int totalCount, Message? message})

Properties

hashCode int
The hash code for this object.
no setteroverride
message Message?
message First message sent on the day
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of found messages sent on the day
final

Methods

copyWith({int? totalCount, Message? message}) MessageCalendarDay

Available on MessageCalendarDay, provided by the MessageCalendarDayExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageCalendarDay?

Constants

constructor → const String