requestMessageId property

int requestMessageId
final

requestMessageId Identifier of the message with the request to change the setting; can be an identifier of a deleted message or 0

Implementation

final int requestMessageId;