newOwnerUserId property
newOwnerUserId Identifier of the user who will become the new owner of the chat if the previous owner isn't return; 0 if none
Implementation
final int newOwnerUserId;
newOwnerUserId Identifier of the user who will become the new owner of the chat if the previous owner isn't return; 0 if none
final int newOwnerUserId;