markedAsNotDoneTaskIds property
markedAsNotDoneTaskIds Identifiers of tasks that were marked as not done
Implementation
final List<int> markedAsNotDoneTaskIds;
markedAsNotDoneTaskIds Identifiers of tasks that were marked as not done
final List<int> markedAsNotDoneTaskIds;