newShowCaptionAboveMedia property

bool newShowCaptionAboveMedia
final

newShowCaptionAboveMedia True, if new caption must be shown above the media; otherwise, new caption must be shown below the media; not supported in secret chats. Ignored if replace_caption is false

Implementation

final bool newShowCaptionAboveMedia;