MessageEffect class final

Contains information about an effect added to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageEffect({required int id, Sticker? staticIcon, required String emoji, required bool isPremium, MessageEffectType? type})

Properties

emoji String
emoji Emoji corresponding to the effect that can be used if static icon isn't available
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the effect
final
isPremium bool
isPremium True, if Telegram Premium subscription is required to use the effect
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staticIcon Sticker?
staticIcon Static icon for the effect in WEBP format; may be null if none
final
type MessageEffectType?
type Type of the effect
final

Methods

copyWith({int? id, Sticker? staticIcon, String? emoji, bool? isPremium, MessageEffectType? type}) MessageEffect

Available on MessageEffect, provided by the MessageEffectExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageEffect?

Constants

constructor → const String