MessageEffectTypeEmojiReaction class final

An effect from an emoji reaction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageEffectTypeEmojiReaction({Sticker? selectAnimation, Sticker? effectAnimation})

Properties

effectAnimation Sticker?
effectAnimation Effect animation for the effect in TGS format
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectAnimation Sticker?
selectAnimation Select animation for the effect in TGS format
final

Methods

copyWith({Sticker? selectAnimation, Sticker? effectAnimation}) MessageEffectTypeEmojiReaction

Available on MessageEffectTypeEmojiReaction, provided by the MessageEffectTypeEmojiReactionExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult emojiReaction(MessageEffectTypeEmojiReaction value), required TResult premiumSticker(MessageEffectTypePremiumSticker value)}) → TResult

Available on MessageEffectType, provided by the MessageEffectTypeExtensions extension

maybeMap<TResult extends Object?>({TResult emojiReaction(MessageEffectTypeEmojiReaction value)?, TResult premiumSticker(MessageEffectTypePremiumSticker value)?, required TResult orElse()}) → TResult

Available on MessageEffectType, provided by the MessageEffectTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String