MessageEffectTypePremiumSticker class final

An effect from a premium sticker

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageEffectTypePremiumSticker({Sticker? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker Sticker?
sticker The premium sticker. The effect can be found at sticker.full_type.premium_animation
final

Methods

copyWith({Sticker? sticker}) MessageEffectTypePremiumSticker

Available on MessageEffectTypePremiumSticker, provided by the MessageEffectTypePremiumStickerExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult emojiReaction(MessageEffectTypeEmojiReaction value), required TResult premiumSticker(MessageEffectTypePremiumSticker value)}) → TResult

Available on MessageEffectType, provided by the MessageEffectTypeExtensions extension

maybeMap<TResult extends Object?>({TResult emojiReaction(MessageEffectTypeEmojiReaction value)?, TResult premiumSticker(MessageEffectTypePremiumSticker value)?, required TResult orElse()}) → TResult

Available on MessageEffectType, provided by the MessageEffectTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String