MessageFileType class sealed

Contains information about a file with messages exported from another app

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult group(MessageFileTypeGroup value), required TResult private(MessageFileTypePrivate value), required TResult unknown(MessageFileTypeUnknown value)}) → TResult

Available on MessageFileType, provided by the MessageFileTypeExtensions extension

maybeMap<TResult extends Object?>({TResult group(MessageFileTypeGroup value)?, TResult private(MessageFileTypePrivate value)?, TResult unknown(MessageFileTypeUnknown value)?, required TResult orElse()}) → TResult

Available on MessageFileType, provided by the MessageFileTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String