MessageFileTypePrivate class final

The messages were exported from a private chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageFileTypePrivate({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the other party; may be empty if unrecognized
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) MessageFileTypePrivate

Available on MessageFileTypePrivate, provided by the MessageFileTypePrivateExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult group(MessageFileTypeGroup value), required TResult private(MessageFileTypePrivate value), required TResult unknown(MessageFileTypeUnknown value)}) → TResult

Available on MessageFileType, provided by the MessageFileTypeExtensions extension

maybeMap<TResult extends Object?>({TResult group(MessageFileTypeGroup value)?, TResult private(MessageFileTypePrivate value)?, TResult unknown(MessageFileTypeUnknown value)?, required TResult orElse()}) → TResult

Available on MessageFileType, provided by the MessageFileTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String