publicServiceAnnouncementType property
publicServiceAnnouncementType The type of public service announcement for the forwarded message
Implementation
final String publicServiceAnnouncementType;
publicServiceAnnouncementType The type of public service announcement for the forwarded message
final String publicServiceAnnouncementType;