canBeUpgraded property
canBeUpgraded True, if the gift can be upgraded to a unique gift; only for the receiver of the gift
Implementation
final bool canBeUpgraded;
canBeUpgraded True, if the gift can be upgraded to a unique gift; only for the receiver of the gift
final bool canBeUpgraded;