receivedGiftId property
receivedGiftId Unique identifier of the received gift for the current user; only for the receiver of the gift
Implementation
final String receivedGiftId;
receivedGiftId Unique identifier of the received gift for the current user; only for the receiver of the gift
final String receivedGiftId;