sellStarCount property

int sellStarCount
final

sellStarCount Number of Telegram Stars that can be claimed by the receiver instead of the regular gift; 0 if the gift can't be sold by the receiver

Implementation

final int sellStarCount;