boostedChatId property
boostedChatId Identifier of the supergroup or channel chat, which was automatically boosted by the winners of the giveaway
Implementation
final int boostedChatId;
boostedChatId Identifier of the supergroup or channel chat, which was automatically boosted by the winners of the giveaway
final int boostedChatId;