isUnclaimed property
isUnclaimed True, if the corresponding winner wasn't chosen and the Telegram Stars were received by the owner of the boosted chat
Implementation
final bool isUnclaimed;
isUnclaimed True, if the corresponding winner wasn't chosen and the Telegram Stars were received by the owner of the boosted chat
final bool isUnclaimed;