additionalChatCount property
additionalChatCount Number of other chats that participated in the giveaway
Implementation
final int additionalChatCount;
additionalChatCount Number of other chats that participated in the giveaway
final int additionalChatCount;