giveawayMessageId property
giveawayMessageId Identifier of the message with the giveaway in the boosted chat
Implementation
final int giveawayMessageId;
giveawayMessageId Identifier of the message with the giveaway in the boosted chat
final int giveawayMessageId;