MessageImportInfo class final

Contains information about a message created with importMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageImportInfo({required String senderName, required int date})

Properties

date int
date Point in time (Unix timestamp) when the message was originally sent
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderName String
senderName Name of the original sender
final

Methods

copyWith({String? senderName, int? date}) MessageImportInfo

Available on MessageImportInfo, provided by the MessageImportInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageImportInfo?

Constants

constructor → const String