MessageInteractionInfo class final

Contains information about interactions with a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageInteractionInfo({required int viewCount, required int forwardCount, MessageReplyInfo? replyInfo, MessageReactions? reactions})

Properties

forwardCount int
forwardCount Number of times the message was forwarded
final
hashCode int
The hash code for this object.
no setteroverride
reactions MessageReactions?
reactions The list of reactions or tags added to the message; may be null
final
replyInfo MessageReplyInfo?
replyInfo Information about direct or indirect replies to the message; may be null. Currently, available only in channels with a discussion supergroup and discussion supergroups for messages, which are not replies itself
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewCount int
viewCount Number of times the message was viewed
final

Methods

copyWith({int? viewCount, int? forwardCount, MessageReplyInfo? replyInfo, MessageReactions? reactions}) MessageInteractionInfo

Available on MessageInteractionInfo, provided by the MessageInteractionInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageInteractionInfo?

Constants

constructor → const String