MessageLink class final
Contains an HTTPS link to a message in a supergroup or channel, or a forum topic
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageLink({required String link, required bool isPublic})
Properties
Methods
-
copyWith(
{String? link, bool? isPublic}) → MessageLink -
Available on MessageLink, provided by the MessageLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageLink?
Constants
- constructor → const String