topicId property

MessageTopic? topicId
final

topicId Identifier of the specific topic in which the message must be opened, or a topic to open if the message is missing; may be null if none

Implementation

final MessageTopic? topicId;