MessageOrigin class sealed

Contains information about the origin of a message

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(MessageOriginChannel value), required TResult chat(MessageOriginChat value), required TResult hiddenUser(MessageOriginHiddenUser value), required TResult user(MessageOriginUser value)}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

maybeMap<TResult extends Object?>({TResult channel(MessageOriginChannel value)?, TResult chat(MessageOriginChat value)?, TResult hiddenUser(MessageOriginHiddenUser value)?, TResult user(MessageOriginUser value)?, required TResult orElse()}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String