MessageOriginChannel class final

The message was originally a post in a channel

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageOriginChannel({required int chatId, required int messageId, required String authorSignature})

Properties

authorSignature String
authorSignature Original post author signature
final
chatId int
chatId Identifier of the channel chat to which the message was originally sent
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier of the original message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, String? authorSignature}) MessageOriginChannel

Available on MessageOriginChannel, provided by the MessageOriginChannelExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(MessageOriginChannel value), required TResult chat(MessageOriginChat value), required TResult hiddenUser(MessageOriginHiddenUser value), required TResult user(MessageOriginUser value)}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

maybeMap<TResult extends Object?>({TResult channel(MessageOriginChannel value)?, TResult chat(MessageOriginChat value)?, TResult hiddenUser(MessageOriginHiddenUser value)?, TResult user(MessageOriginUser value)?, required TResult orElse()}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String