MessageOriginChat class final

The message was originally sent on behalf of a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageOriginChat({required int senderChatId, required String authorSignature})

Properties

authorSignature String
authorSignature For messages originally sent by an anonymous chat administrator, original message author signature
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderChatId int
senderChatId Identifier of the chat that originally sent the message
final

Methods

copyWith({int? senderChatId, String? authorSignature}) MessageOriginChat

Available on MessageOriginChat, provided by the MessageOriginChatExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult channel(MessageOriginChannel value), required TResult chat(MessageOriginChat value), required TResult hiddenUser(MessageOriginHiddenUser value), required TResult user(MessageOriginUser value)}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

maybeMap<TResult extends Object?>({TResult channel(MessageOriginChannel value)?, TResult chat(MessageOriginChat value)?, TResult hiddenUser(MessageOriginHiddenUser value)?, TResult user(MessageOriginUser value)?, required TResult orElse()}) → TResult

Available on MessageOrigin, provided by the MessageOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String