showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the media; otherwise, the caption must be shown below the media
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the media; otherwise, the caption must be shown below the media
final bool showCaptionAboveMedia;