paidMessageStarCount property

int paidMessageStarCount
final

paidMessageStarCount The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message

Implementation

final int paidMessageStarCount;