MessagePosition class final

Contains information about a message in a specific position

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessagePosition({required int position, required int messageId, required int date})

Properties

date int
date Point in time (Unix timestamp) when the message was sent
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Message identifier
final
position int
position 0-based message position in the full list of suitable messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? position, int? messageId, int? date}) MessagePosition

Available on MessagePosition, provided by the MessagePositionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessagePosition?

Constants

constructor → const String