MessagePositions class final

Contains a list of message positions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessagePositions({required int totalCount, required List<MessagePosition> positions})

Properties

hashCode int
The hash code for this object.
no setteroverride
positions List<MessagePosition>
positions List of message positions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of messages found
final

Methods

copyWith({int? totalCount, List<MessagePosition>? positions}) MessagePositions

Available on MessagePositions, provided by the MessagePositionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessagePositions?

Constants

constructor → const String