creatorId property
creatorId Identifier of a chat or a user who created the gift code; may be null if unknown
Implementation
final MessageSender? creatorId;
creatorId Identifier of a chat or a user who created the gift code; may be null if unknown
final MessageSender? creatorId;