monthCount property
monthCount Number of months the Telegram Premium subscription will be active after code activation; 0 if the number of months isn't integer
Implementation
final int monthCount;
monthCount Number of months the Telegram Premium subscription will be active after code activation; 0 if the number of months isn't integer
final int monthCount;