canAddTasks property

bool canAddTasks
final

canAddTasks True, if tasks can be added to the message's checklist using addChecklistTasks if the current user has Telegram Premium subscription

Implementation

final bool canAddTasks;