canBeCopied property
canBeCopied True, if content of the message can be copied using inputMessageForwarded or forwardMessages with copy options
Implementation
final bool canBeCopied;
canBeCopied True, if content of the message can be copied using inputMessageForwarded or forwardMessages with copy options
final bool canBeCopied;