canBeCopiedToSecretChat property
canBeCopiedToSecretChat True, if content of the message can be copied to a secret chat using inputMessageForwarded or forwardMessages with copy options
Implementation
final bool canBeCopiedToSecretChat;
canBeCopiedToSecretChat True, if content of the message can be copied to a secret chat using inputMessageForwarded or forwardMessages with copy options
final bool canBeCopiedToSecretChat;