canBeDeclined property

bool canBeDeclined
final

canBeDeclined True, if the message is a suggested post that can be declined by the user using declineSuggestedPost

Implementation

final bool canBeDeclined;