canBeDeletedForAllUsers property
canBeDeletedForAllUsers True, if the message can be deleted for all users using the method deleteMessages with revoke == true
Implementation
final bool canBeDeletedForAllUsers;
canBeDeletedForAllUsers True, if the message can be deleted for all users using the method deleteMessages with revoke == true
final bool canBeDeletedForAllUsers;