canBeForwarded property
canBeForwarded True, if the message can be forwarded using inputMessageForwarded or forwardMessages without copy options
Implementation
final bool canBeForwarded;
canBeForwarded True, if the message can be forwarded using inputMessageForwarded or forwardMessages without copy options
final bool canBeForwarded;