canBeReplied property

bool canBeReplied
final

canBeReplied True, if the message can be replied in the same chat and forum topic using inputMessageReplyToMessage. Ephemeral messages can be replied only by other ephemeral messages

Implementation

final bool canBeReplied;