canBeRepliedInAnotherChat property
canBeRepliedInAnotherChat True, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage
Implementation
final bool canBeRepliedInAnotherChat;
canBeRepliedInAnotherChat True, if the message can be replied in another chat or forum topic using inputMessageReplyToExternalMessage
final bool canBeRepliedInAnotherChat;