canBeSharedInStory property
canBeSharedInStory True, if the message can be shared in a story using inputStoryAreaTypeMessage
Implementation
final bool canBeSharedInStory;
canBeSharedInStory True, if the message can be shared in a story using inputStoryAreaTypeMessage
final bool canBeSharedInStory;