canDeleteReactions property

bool canDeleteReactions
final

canDeleteReactions True, if the user can delete reactions of other users in the message using the method deleteMessageReactionsFromSender

Implementation

final bool canDeleteReactions;