canEditMedia property
canEditMedia True, if the message can be edited using the method editMessageMedia
Implementation
final bool canEditMedia;
canEditMedia True, if the message can be edited using the method editMessageMedia
final bool canEditMedia;