canEditSchedulingState property
canEditSchedulingState True, if scheduling state of the message can be edited
Implementation
final bool canEditSchedulingState;
canEditSchedulingState True, if scheduling state of the message can be edited
final bool canEditSchedulingState;