canGetAuthor property
canGetAuthor True, if author of the message sent on behalf of a chat can be received through getMessageAuthor
Implementation
final bool canGetAuthor;
canGetAuthor True, if author of the message sent on behalf of a chat can be received through getMessageAuthor
final bool canGetAuthor;