canGetPollVoteStatistics property
canGetPollVoteStatistics True, if the message is a poll and vote statistics are available through getPollVoteStatistics
Implementation
final bool canGetPollVoteStatistics;
canGetPollVoteStatistics True, if the message is a poll and vote statistics are available through getPollVoteStatistics
final bool canGetPollVoteStatistics;