canGetReadDate property
canGetReadDate True, if read date of the message can be received through getMessageReadDate
Implementation
final bool canGetReadDate;
canGetReadDate True, if read date of the message can be received through getMessageReadDate
final bool canGetReadDate;