canGetStatistics property

bool canGetStatistics
final

canGetStatistics True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards

Implementation

final bool canGetStatistics;