canGetVideoAdvertisements property
canGetVideoAdvertisements True, if advertisements for video of the message can be received through getVideoMessageAdvertisements
Implementation
final bool canGetVideoAdvertisements;
canGetVideoAdvertisements True, if advertisements for video of the message can be received through getVideoMessageAdvertisements
final bool canGetVideoAdvertisements;