canMarkTasksAsDone property
canMarkTasksAsDone True, if tasks can be marked as done or not done in the message's checklist using markChecklistTasksAsDone if the current user has Telegram Premium subscription
Implementation
final bool canMarkTasksAsDone;