canRecognizeSpeech property
canRecognizeSpeech True, if speech can be recognized for the message through recognizeSpeech
Implementation
final bool canRecognizeSpeech;
canRecognizeSpeech True, if speech can be recognized for the message through recognizeSpeech
final bool canRecognizeSpeech;