canReportSupergroupSpam property
canReportSupergroupSpam True, if the message can be reported using reportSupergroupSpam
Implementation
final bool canReportSupergroupSpam;
canReportSupergroupSpam True, if the message can be reported using reportSupergroupSpam
final bool canReportSupergroupSpam;