needShowStatistics property
needShowStatistics True, if message statistics must be available from context menu of the message
Implementation
final bool needShowStatistics;
needShowStatistics True, if message statistics must be available from context menu of the message
final bool needShowStatistics;