watcherId property
watcherId The identifier of a user or chat that subscribed for the proximity alert
Implementation
final MessageSender? watcherId;
watcherId The identifier of a user or chat that subscribed for the proximity alert
final MessageSender? watcherId;