MessageReaction class final

Contains information about a reaction to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageReaction({ReactionType? type, required int totalCount, required bool isChosen, MessageSender? usedSenderId, required List<MessageSender> recentSenderIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
isChosen bool
isChosen True, if the reaction is chosen by the current user
final
recentSenderIds List<MessageSender>
recentSenderIds Identifiers of at most 3 recent message senders, added the reaction; available in private, basic group and supergroup chats
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Number of times the reaction was added
final
type ReactionType?
type Type of the reaction
final
usedSenderId MessageSender?
usedSenderId Identifier of the message sender used by the current user to add the reaction; may be null if unknown or the reaction isn't chosen
final

Methods

copyWith({ReactionType? type, int? totalCount, bool? isChosen, MessageSender? usedSenderId, List<MessageSender>? recentSenderIds}) MessageReaction

Available on MessageReaction, provided by the MessageReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageReaction?

Constants

constructor → const String