usedSenderId property
usedSenderId Identifier of the message sender used by the current user to add the reaction; may be null if unknown or the reaction isn't chosen
Implementation
final MessageSender? usedSenderId;
usedSenderId Identifier of the message sender used by the current user to add the reaction; may be null if unknown or the reaction isn't chosen
final MessageSender? usedSenderId;