MessageReadDate class sealed
Describes read date of a recent outgoing message in a private chat
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult myPrivacyRestricted(MessageReadDateMyPrivacyRestricted value), required TResult read(MessageReadDateRead value), required TResult tooOld(MessageReadDateTooOld value), required TResult unread(MessageReadDateUnread value), required TResult userPrivacyRestricted(MessageReadDateUserPrivacyRestricted value)}) → TResult -
Available on MessageReadDate, provided by the MessageReadDateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult myPrivacyRestricted(MessageReadDateMyPrivacyRestricted value)?, TResult read(MessageReadDateRead value)?, TResult tooOld(MessageReadDateTooOld value)?, TResult unread(MessageReadDateUnread value)?, TResult userPrivacyRestricted(MessageReadDateUserPrivacyRestricted value)?, required TResult orElse()}) → TResult -
Available on MessageReadDate, provided by the MessageReadDateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageReadDate? - Inherited by: MessageReadDateMyPrivacyRestricted MessageReadDateRead MessageReadDateTooOld MessageReadDateUnread MessageReadDateUserPrivacyRestricted
Constants
- constructor → const String