checklistTaskId property
checklistTaskId Identifier of the checklist task in the original message that was replied; 0 if none
Implementation
final int checklistTaskId;
checklistTaskId Identifier of the checklist task in the original message that was replied; 0 if none
final int checklistTaskId;