origin property
origin Information about origin of the message if the message was from another chat or topic; may be null for messages from the same chat
Implementation
final MessageOrigin? origin;
origin Information about origin of the message if the message was from another chat or topic; may be null for messages from the same chat
final MessageOrigin? origin;