MessageReplyToStory class final

Describes a story replied by a given message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageReplyToStory({required int storyPosterChatId, required int storyId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId The identifier of the story
final
storyPosterChatId int
storyPosterChatId The identifier of the poster of the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId}) MessageReplyToStory

Available on MessageReplyToStory, provided by the MessageReplyToStoryExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(MessageReplyToMessage value), required TResult story(MessageReplyToStory value)}) → TResult

Available on MessageReplyTo, provided by the MessageReplyToExtensions extension

maybeMap<TResult extends Object?>({TResult message(MessageReplyToMessage value)?, TResult story(MessageReplyToStory value)?, required TResult orElse()}) → TResult

Available on MessageReplyTo, provided by the MessageReplyToExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageReplyToStory?
Inherited by: MessageReplyToMessage MessageReplyToStory
override

Constants

constructor → const String