MessageSchedulingState class sealed
Contains information about the time when a scheduled message will be sent
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult sendAtDate(MessageSchedulingStateSendAtDate value), required TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value), required TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)}) → TResult -
Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult sendAtDate(MessageSchedulingStateSendAtDate value)?, TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value)?, TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)?, required TResult orElse()}) → TResult -
Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageSchedulingState? - Inherited by: MessageSchedulingStateSendAtDate MessageSchedulingStateSendWhenOnline MessageSchedulingStateSendWhenVideoProcessed
Constants
- constructor → const String