MessageSchedulingStateSendAtDate class final

The message will be sent at the specified date

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageSchedulingStateSendAtDate({required int sendDate, required int repeatPeriod})

Properties

hashCode int
The hash code for this object.
no setteroverride
repeatPeriod int
repeatPeriod Period after which the message will be sent again; in seconds; 0 if never; for Telegram Premium users only; may be non-zero only in sendMessage and forwardMessages with one message requests; must be one of 0, 86400, 7 * 86400, 14 * 86400, 30 * 86400, 91 * 86400, 182 * 86400, 365 * 86400, or additionally 60, or 300 in the Test DC
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendDate int
sendDate Point in time (Unix timestamp) when the message will be sent. The date must be within 367 days in the future
final

Methods

copyWith({int? sendDate, int? repeatPeriod}) MessageSchedulingStateSendAtDate

Available on MessageSchedulingStateSendAtDate, provided by the MessageSchedulingStateSendAtDateExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult sendAtDate(MessageSchedulingStateSendAtDate value), required TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value), required TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)}) → TResult

Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension

maybeMap<TResult extends Object?>({TResult sendAtDate(MessageSchedulingStateSendAtDate value)?, TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value)?, TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)?, required TResult orElse()}) → TResult

Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String