MessageSelfDestructTypeImmediately class final
The message can be opened only once and will be self-destructed once closed
- Inheritance
-
- Object
- TdObject
- MessageSelfDestructType
- MessageSelfDestructTypeImmediately
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult immediately(MessageSelfDestructTypeImmediately value), required TResult timer(MessageSelfDestructTypeTimer value)}) → TResult -
Available on MessageSelfDestructType, provided by the MessageSelfDestructTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult immediately(MessageSelfDestructTypeImmediately value)?, TResult timer(MessageSelfDestructTypeTimer value)?, required TResult orElse()}) → TResult -
Available on MessageSelfDestructType, provided by the MessageSelfDestructTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageSelfDestructTypeImmediately? -
Inherited by:
MessageSelfDestructTypeImmediately
MessageSelfDestructTypeTimer
override
Constants
- constructor → const String