MessageSelfDestructTypeTimer class final

The message will be self-destructed in the specified time after its content was opened

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageSelfDestructTypeTimer({required int selfDestructTime})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfDestructTime int
selfDestructTime The message's self-destruct time, in seconds; must be between 0 and 60 in private chats
final

Methods

copyWith({int? selfDestructTime}) MessageSelfDestructTypeTimer

Available on MessageSelfDestructTypeTimer, provided by the MessageSelfDestructTypeTimerExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult immediately(MessageSelfDestructTypeImmediately value), required TResult timer(MessageSelfDestructTypeTimer value)}) → TResult

Available on MessageSelfDestructType, provided by the MessageSelfDestructTypeExtensions extension

maybeMap<TResult extends Object?>({TResult immediately(MessageSelfDestructTypeImmediately value)?, TResult timer(MessageSelfDestructTypeTimer value)?, required TResult orElse()}) → TResult

Available on MessageSelfDestructType, provided by the MessageSelfDestructTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String