allowPaidBroadcast property
allowPaidBroadcast Pass true to allow the message to ignore regular broadcast limits for a small fee; for bots only
Implementation
final bool? allowPaidBroadcast;
allowPaidBroadcast Pass true to allow the message to ignore regular broadcast limits for a small fee; for bots only
final bool? allowPaidBroadcast;