paidMessageStarCount property
paidMessageStarCount The number of Telegram Stars the user agreed to pay to send the messages
Implementation
final int paidMessageStarCount;
paidMessageStarCount The number of Telegram Stars the user agreed to pay to send the messages
final int paidMessageStarCount;