MessageSenders class final

Represents a list of message senders

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageSenders({required int totalCount, required List<MessageSender> senders})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senders List<MessageSender>
senders List of message senders
final
totalCount int
totalCount Approximate total number of message senders found
final

Methods

copyWith({int? totalCount, List<MessageSender>? senders}) MessageSenders

Available on MessageSenders, provided by the MessageSendersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageSenders?

Constants

constructor → const String