MessageSendingState class sealed

Contains information about the sending state of the message

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult failed(MessageSendingStateFailed value), required TResult pending(MessageSendingStatePending value)}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

maybeMap<TResult extends Object?>({TResult failed(MessageSendingStateFailed value)?, TResult pending(MessageSendingStatePending value)?, required TResult orElse()}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageSendingState?
Inherited by: MessageSendingStateFailed MessageSendingStatePending

Constants

constructor → const String