MessageSendingStateFailed class final

The message failed to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageSendingStateFailed({TdError? error, required bool canRetry, required bool needAnotherSender, required bool needAnotherReplyQuote, required bool needDropReply, required int requiredPaidMessageStarCount, required double retryAfter})

Properties

canRetry bool
canRetry True, if the message can be re-sent using resendMessages or readdQuickReplyShortcutMessages
final
error TdError?
error The cause of the message sending failure
final
hashCode int
The hash code for this object.
no setteroverride
needAnotherReplyQuote bool
needAnotherReplyQuote True, if the message can be re-sent only if another quote is chosen in the message that is replied by the given message
final
needAnotherSender bool
needAnotherSender True, if the message can be re-sent only on behalf of a different sender
final
needDropReply bool
needDropReply True, if the message can be re-sent only if the message to be replied is removed. This will be done automatically by resendMessages
final
requiredPaidMessageStarCount int
requiredPaidMessageStarCount The number of Telegram Stars that must be paid to send the message; 0 if the current amount is correct
final
retryAfter double
retryAfter Time left before the message can be re-sent, in seconds. No update is sent when this field changes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TdError? error, bool? canRetry, bool? needAnotherSender, bool? needAnotherReplyQuote, bool? needDropReply, int? requiredPaidMessageStarCount, double? retryAfter}) MessageSendingStateFailed

Available on MessageSendingStateFailed, provided by the MessageSendingStateFailedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult failed(MessageSendingStateFailed value), required TResult pending(MessageSendingStatePending value)}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

maybeMap<TResult extends Object?>({TResult failed(MessageSendingStateFailed value)?, TResult pending(MessageSendingStatePending value)?, required TResult orElse()}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageSendingStateFailed?
Inherited by: MessageSendingStateFailed MessageSendingStatePending
override

Constants

constructor → const String