needDropReply property
needDropReply True, if the message can be re-sent only if the message to be replied is removed. This will be done automatically by resendMessages
Implementation
final bool needDropReply;
needDropReply True, if the message can be re-sent only if the message to be replied is removed. This will be done automatically by resendMessages
final bool needDropReply;