requiredPaidMessageStarCount property
requiredPaidMessageStarCount The number of Telegram Stars that must be paid to send the message; 0 if the current amount is correct
Implementation
final int requiredPaidMessageStarCount;
requiredPaidMessageStarCount The number of Telegram Stars that must be paid to send the message; 0 if the current amount is correct
final int requiredPaidMessageStarCount;