MessageSendingStatePending class final

The message is being sent now, but has not yet been delivered to the server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageSendingStatePending({required int sendingId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendingId int
sendingId Non-persistent message sending identifier, specified by the application
final

Methods

copyWith({int? sendingId}) MessageSendingStatePending

Available on MessageSendingStatePending, provided by the MessageSendingStatePendingExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult failed(MessageSendingStateFailed value), required TResult pending(MessageSendingStatePending value)}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

maybeMap<TResult extends Object?>({TResult failed(MessageSendingStateFailed value)?, TResult pending(MessageSendingStatePending value)?, required TResult orElse()}) → TResult

Available on MessageSendingState, provided by the MessageSendingStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageSendingStatePending?
Inherited by: MessageSendingStateFailed MessageSendingStatePending
override

Constants

constructor → const String