linkPreviewOptions property
linkPreviewOptions Options which were used for generation of the link preview; may be null if default options were used
Implementation
final LinkPreviewOptions? linkPreviewOptions;
linkPreviewOptions Options which were used for generation of the link preview; may be null if default options were used
final LinkPreviewOptions? linkPreviewOptions;