MessageTopic class sealed
Describes a topic of messages in a chat
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult directMessages(MessageTopicDirectMessages value), required TResult forum(MessageTopicForum value), required TResult savedMessages(MessageTopicSavedMessages value), required TResult thread(MessageTopicThread value)}) → TResult -
Available on MessageTopic, provided by the MessageTopicExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult directMessages(MessageTopicDirectMessages value)?, TResult forum(MessageTopicForum value)?, TResult savedMessages(MessageTopicSavedMessages value)?, TResult thread(MessageTopicThread value)?, required TResult orElse()}) → TResult -
Available on MessageTopic, provided by the MessageTopicExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageTopic? - Inherited by: MessageTopicDirectMessages MessageTopicForum MessageTopicSavedMessages MessageTopicThread
Constants
- constructor → const String