MessageTopicForum class final

A topic in a forum supergroup chat or a chat with a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageTopicForum({required int forumTopicId})

Properties

forumTopicId int
forumTopicId Unique identifier of the forum topic
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? forumTopicId}) MessageTopicForum

Available on MessageTopicForum, provided by the MessageTopicForumExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult directMessages(MessageTopicDirectMessages value), required TResult forum(MessageTopicForum value), required TResult savedMessages(MessageTopicSavedMessages value), required TResult thread(MessageTopicThread value)}) → TResult

Available on MessageTopic, provided by the MessageTopicExtensions extension

maybeMap<TResult extends Object?>({TResult directMessages(MessageTopicDirectMessages value)?, TResult forum(MessageTopicForum value)?, TResult savedMessages(MessageTopicSavedMessages value)?, TResult thread(MessageTopicThread value)?, required TResult orElse()}) → TResult

Available on MessageTopic, provided by the MessageTopicExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String