MessageTopicSavedMessages class final

A topic in Saved Messages chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageTopicSavedMessages({required int savedMessagesTopicId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Unique identifier of the Saved Messages topic
final

Methods

copyWith({int? savedMessagesTopicId}) MessageTopicSavedMessages

Available on MessageTopicSavedMessages, provided by the MessageTopicSavedMessagesExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult directMessages(MessageTopicDirectMessages value), required TResult forum(MessageTopicForum value), required TResult savedMessages(MessageTopicSavedMessages value), required TResult thread(MessageTopicThread value)}) → TResult

Available on MessageTopic, provided by the MessageTopicExtensions extension

maybeMap<TResult extends Object?>({TResult directMessages(MessageTopicDirectMessages value)?, TResult forum(MessageTopicForum value)?, TResult savedMessages(MessageTopicSavedMessages value)?, TResult thread(MessageTopicThread value)?, required TResult orElse()}) → TResult

Available on MessageTopic, provided by the MessageTopicExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String