canBeTransferred property
canBeTransferred True, if the gift can be transferred to another owner; only for the receiver of the gift
Implementation
final bool canBeTransferred;
canBeTransferred True, if the gift can be transferred to another owner; only for the receiver of the gift
final bool canBeTransferred;