wasTransferred property
wasTransferred True, if the gift has already been transferred to another owner; only for the receiver of the gift
Implementation
final bool wasTransferred;
wasTransferred True, if the gift has already been transferred to another owner; only for the receiver of the gift
final bool wasTransferred;