showCaptionAboveMedia property

bool showCaptionAboveMedia
final

showCaptionAboveMedia True, if the caption must be shown above the video; otherwise, the caption must be shown below the video

Implementation

final bool showCaptionAboveMedia;