MessageViewer class final

Represents a viewer of a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageViewer({required int userId, required int viewDate})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier of the viewer
final
viewDate int
viewDate Approximate point in time (Unix timestamp) when the message was viewed
final

Methods

copyWith({int? userId, int? viewDate}) MessageViewer

Available on MessageViewer, provided by the MessageViewerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageViewer?

Constants

constructor → const String