MessageViewers class final

Represents a list of message viewers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageViewers({required List<MessageViewer> viewers})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewers List<MessageViewer>
viewers List of message viewers
final

Methods

copyWith({List<MessageViewer>? viewers}) MessageViewers

Available on MessageViewers, provided by the MessageViewersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageViewers?

Constants

constructor → const String