Minithumbnail class final

Thumbnail image of a very poor quality and low resolution

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Minithumbnail({required int width, required int height, required String data})

Properties

data String
data The thumbnail in JPEG format
final
hashCode int
The hash code for this object.
no setteroverride
height int
height Thumbnail height, usually doesn't exceed 40
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
width Thumbnail width, usually doesn't exceed 40
final

Methods

copyWith({int? width, int? height, String? data}) Minithumbnail

Available on Minithumbnail, provided by the MinithumbnailExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Minithumbnail?

Constants

constructor → const String