NetworkStatisticsEntryCall class final

Contains information about the total amount of data that was used for calls

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NetworkStatisticsEntryCall({NetworkType? networkType, required int sentBytes, required int receivedBytes, required double duration})

Properties

duration double
duration Total call duration, in seconds
final
hashCode int
The hash code for this object.
no setteroverride
networkType NetworkType?
networkType Type of the network the data was sent through. Call setNetworkType to maintain the actual network type
final
receivedBytes int
receivedBytes Total number of bytes received
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentBytes int
sentBytes Total number of bytes sent
final

Methods

copyWith({NetworkType? networkType, int? sentBytes, int? receivedBytes, double? duration}) NetworkStatisticsEntryCall

Available on NetworkStatisticsEntryCall, provided by the NetworkStatisticsEntryCallExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult call(NetworkStatisticsEntryCall value), required TResult file(NetworkStatisticsEntryFile value)}) → TResult

Available on NetworkStatisticsEntry, provided by the NetworkStatisticsEntryExtensions extension

maybeMap<TResult extends Object?>({TResult call(NetworkStatisticsEntryCall value)?, TResult file(NetworkStatisticsEntryFile value)?, required TResult orElse()}) → TResult

Available on NetworkStatisticsEntry, provided by the NetworkStatisticsEntryExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) NetworkStatisticsEntryCall?
Inherited by: NetworkStatisticsEntryCall NetworkStatisticsEntryFile
override

Constants

constructor → const String