NetworkStatisticsEntryFile class final
Contains information about the total amount of data that was used to send and receive files
- Inheritance
-
- Object
- TdObject
- NetworkStatisticsEntry
- NetworkStatisticsEntryFile
- Available extensions
- Annotations
-
- @immutable
Constructors
- NetworkStatisticsEntryFile({FileType? fileType, NetworkType? networkType, required int sentBytes, required int receivedBytes})
Properties
- fileType → FileType?
-
fileType Type of the file the data is part of; pass null if the data
isn't related to files
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- networkType → NetworkType?
-
networkType Type of the network the data was sent through. Call
setNetworkType to maintain the actual network type
final
- receivedBytes → int
-
receivedBytes Total number of bytes received
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentBytes → int
-
sentBytes Total number of bytes sent
final
Methods
-
copyWith(
{FileType? fileType, NetworkType? networkType, int? sentBytes, int? receivedBytes}) → NetworkStatisticsEntryFile -
Available on NetworkStatisticsEntryFile, provided by the NetworkStatisticsEntryFileExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult call(NetworkStatisticsEntryCall value), required TResult file(NetworkStatisticsEntryFile value)}) → TResult -
Available on NetworkStatisticsEntry, provided by the NetworkStatisticsEntryExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult call(NetworkStatisticsEntryCall value)?, TResult file(NetworkStatisticsEntryFile value)?, required TResult orElse()}) → TResult -
Available on NetworkStatisticsEntry, provided by the NetworkStatisticsEntryExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → NetworkStatisticsEntryFile? -
Inherited by:
NetworkStatisticsEntryCall
NetworkStatisticsEntryFile
override
Constants
- constructor → const String