NetworkTypeNone class final

The network is not available

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NetworkTypeNone()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult mobile(NetworkTypeMobile value), required TResult mobileRoaming(NetworkTypeMobileRoaming value), required TResult none(NetworkTypeNone value), required TResult other(NetworkTypeOther value), required TResult wiFi(NetworkTypeWiFi value)}) → TResult

Available on NetworkType, provided by the NetworkTypeExtensions extension

maybeMap<TResult extends Object?>({TResult mobile(NetworkTypeMobile value)?, TResult mobileRoaming(NetworkTypeMobileRoaming value)?, TResult none(NetworkTypeNone value)?, TResult other(NetworkTypeOther value)?, TResult wiFi(NetworkTypeWiFi value)?, required TResult orElse()}) → TResult

Available on NetworkType, provided by the NetworkTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String