NewChatPrivacySettings class final

Contains privacy settings for chats with non-contacts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NewChatPrivacySettings({required bool allowNewChatsFromUnknownUsers, required int incomingPaidMessageStarCount})

Properties

allowNewChatsFromUnknownUsers bool
allowNewChatsFromUnknownUsers True, if non-contacts users are able to write first to the current user. Telegram Premium subscribers are able to write first regardless of this setting
final
hashCode int
The hash code for this object.
no setteroverride
incomingPaidMessageStarCount int
incomingPaidMessageStarCount Number of Telegram Stars that must be paid for every incoming private message by non-contacts; 0-getOption("paid_message_star_count_max"). If positive, then allow_new_chats_from_unknown_users must be true. The current user will receive getOption("paid_message_earnings_per_mille") Telegram Stars for each 1000 Telegram Stars paid for message sending. Can be positive, only if getOption("can_enable_paid_messages") is true
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? allowNewChatsFromUnknownUsers, int? incomingPaidMessageStarCount}) NewChatPrivacySettings

Available on NewChatPrivacySettings, provided by the NewChatPrivacySettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) NewChatPrivacySettings?

Constants

constructor → const String