allowNewChatsFromUnknownUsers property

bool allowNewChatsFromUnknownUsers
final

allowNewChatsFromUnknownUsers True, if non-contacts users are able to write first to the current user. Telegram Premium subscribers are able to write first regardless of this setting

Implementation

final bool allowNewChatsFromUnknownUsers;