NewSticker class final

A sticker to be added to a sticker set

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NewSticker({InputFile? sticker, StickerFormat? format, required String emojis, MaskPosition? maskPosition, required List<String> keywords})

Properties

emojis String
emojis String with 1-20 emoji corresponding to the sticker
final
format StickerFormat?
format Format of the sticker
final
hashCode int
The hash code for this object.
no setteroverride
keywords List<String>
keywords List of up to 20 keywords with total length up to 64 characters, which can be used to find the sticker
final
maskPosition MaskPosition?
maskPosition Position where the mask is placed; pass null if not specified
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker File with the sticker; must fit in a 512x512 square. For WEBP stickers the file must be in WEBP or PNG format, which will be converted to WEBP server-side. See https://core.telegram.org/animated_stickers#technical-requirements for technical requirements
final

Methods

copyWith({InputFile? sticker, StickerFormat? format, String? emojis, MaskPosition? maskPosition, List<String>? keywords}) NewSticker

Available on NewSticker, provided by the NewStickerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) NewSticker?

Constants

constructor → const String