Notification class final

Contains information about a notification

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Notification({required int id, required int date, required bool isSilent, NotificationType? type})

Properties

date int
date Notification date
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique persistent identifier of this notification
final
isSilent bool
isSilent True, if the notification was explicitly sent without sound
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type NotificationType?
type Notification type
final

Methods

copyWith({int? id, int? date, bool? isSilent, NotificationType? type}) Notification

Available on Notification, provided by the NotificationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Notification?

Constants

constructor → const String