NotificationGroup class final

Describes a group of notifications

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NotificationGroup({required int id, NotificationGroupType? type, required int chatId, required int totalCount, required List<Notification> notifications})

Properties

chatId int
chatId Identifier of a chat to which all notifications in the group belong
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique persistent auto-incremented from 1 identifier of the notification group
final
notifications List<Notification>
notifications The list of active notifications
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of active notifications in the group
final
type NotificationGroupType?
type Type of the group
final

Methods

copyWith({int? id, NotificationGroupType? type, int? chatId, int? totalCount, List<Notification>? notifications}) NotificationGroup

Available on NotificationGroup, provided by the NotificationGroupExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) NotificationGroup?

Constants

constructor → const String