NotificationGroupTypeMessages class final
A group containing notifications of type notificationTypeNewMessage and notificationTypeNewPushMessage with ordinary unread messages
- Inheritance
-
- Object
- TdObject
- NotificationGroupType
- NotificationGroupTypeMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- NotificationGroupTypeMessages()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult calls(NotificationGroupTypeCalls value), required TResult mentions(NotificationGroupTypeMentions value), required TResult messages(NotificationGroupTypeMessages value), required TResult secretChat(NotificationGroupTypeSecretChat value)}) → TResult -
Available on NotificationGroupType, provided by the NotificationGroupTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult calls(NotificationGroupTypeCalls value)?, TResult mentions(NotificationGroupTypeMentions value)?, TResult messages(NotificationGroupTypeMessages value)?, TResult secretChat(NotificationGroupTypeSecretChat value)?, required TResult orElse()}) → TResult -
Available on NotificationGroupType, provided by the NotificationGroupTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → NotificationGroupTypeMessages? -
Inherited by:
NotificationGroupTypeCalls
NotificationGroupTypeMentions
NotificationGroupTypeMessages
NotificationGroupTypeSecretChat
override
Constants
- constructor → const String