NotificationSettingsScopeChannelChats class final

Notification settings applied to all channel chats when the corresponding chat setting has a default value

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult channelChats(NotificationSettingsScopeChannelChats value), required TResult groupChats(NotificationSettingsScopeGroupChats value), required TResult privateChats(NotificationSettingsScopePrivateChats value)}) → TResult

Available on NotificationSettingsScope, provided by the NotificationSettingsScopeExtensions extension

maybeMap<TResult extends Object?>({TResult channelChats(NotificationSettingsScopeChannelChats value)?, TResult groupChats(NotificationSettingsScopeGroupChats value)?, TResult privateChats(NotificationSettingsScopePrivateChats value)?, required TResult orElse()}) → TResult

Available on NotificationSettingsScope, provided by the NotificationSettingsScopeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String