NotificationTypeNewPushMessage class final

New message was received through a push notification

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NotificationTypeNewPushMessage({required int messageId, MessageSender? senderId, required String senderName, required bool isOutgoing, PushMessageContent? content})

Properties

content PushMessageContent?
content Push message content
final
hashCode int
The hash code for this object.
no setteroverride
isOutgoing bool
isOutgoing True, if the message is outgoing
final
messageId int
messageId The message identifier. The message will not be available in the chat history, but the identifier can be used in viewMessages, or as a message to be replied in the same chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender of the message. Corresponding user or chat may be inaccessible
final
senderName String
senderName Name of the sender
final

Methods

copyWith({int? messageId, MessageSender? senderId, String? senderName, bool? isOutgoing, PushMessageContent? content}) NotificationTypeNewPushMessage

Available on NotificationTypeNewPushMessage, provided by the NotificationTypeNewPushMessageExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult newCall(NotificationTypeNewCall value), required TResult newMessage(NotificationTypeNewMessage value), required TResult newPushMessage(NotificationTypeNewPushMessage value), required TResult newSecretChat(NotificationTypeNewSecretChat value)}) → TResult

Available on NotificationType, provided by the NotificationTypeExtensions extension

maybeMap<TResult extends Object?>({TResult newCall(NotificationTypeNewCall value)?, TResult newMessage(NotificationTypeNewMessage value)?, TResult newPushMessage(NotificationTypeNewPushMessage value)?, TResult newSecretChat(NotificationTypeNewSecretChat value)?, required TResult orElse()}) → TResult

Available on NotificationType, provided by the NotificationTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String