NotificationTypeNewSecretChat class final

New secret chat was created

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

NotificationTypeNewSecretChat()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult newCall(NotificationTypeNewCall value), required TResult newMessage(NotificationTypeNewMessage value), required TResult newPushMessage(NotificationTypeNewPushMessage value), required TResult newSecretChat(NotificationTypeNewSecretChat value)}) → TResult

Available on NotificationType, provided by the NotificationTypeExtensions extension

maybeMap<TResult extends Object?>({TResult newCall(NotificationTypeNewCall value)?, TResult newMessage(NotificationTypeNewMessage value)?, TResult newPushMessage(NotificationTypeNewPushMessage value)?, TResult newSecretChat(NotificationTypeNewSecretChat value)?, required TResult orElse()}) → TResult

Available on NotificationType, provided by the NotificationTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String