OauthLinkInfo class final

Information about the OAuth authorization

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

OauthLinkInfo({required int userId, required String url, required String domain, required bool fromApp, required String verifiedAppName, required int botUserId, required bool requestWriteAccess, required bool requestPhoneNumberAccess, required String browser, required String platform, required String ipAddress, required String location, required bool matchCodeFirst, required List<String> matchCodes})

Properties

botUserId int
botUserId User identifier of a bot linked with the website
final
browser String
browser The version of a browser used for the authorization
final
domain String
domain A domain of the URL
final
fromApp bool
fromApp True, if the authorization originates from an application
final
hashCode int
The hash code for this object.
no setteroverride
ipAddress String
ipAddress IP address from which the authorization is performed, in human-readable format
final
location String
location Human-readable description of a country and a region from which the authorization is performed, based on the IP address
final
matchCodeFirst bool
matchCodeFirst True, if code matching dialog must be shown first and checkOauthRequestMatchCode must be called before acceptOauthRequest. Otherwise, checkOauthRequestMatchCode must not be called
final
matchCodes List<String>
matchCodes The list of codes to match; may be empty if irrelevant
final
platform String
platform Operating system the browser is running on
final
requestPhoneNumberAccess bool
requestPhoneNumberAccess True, if the user must be asked for the permission to share their phone number
final
requestWriteAccess bool
requestWriteAccess True, if the user must be asked for the permission to the bot to send them messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url An HTTP URL where the user authorizes
final
userId int
userId Identifier of the user for which the link was generated; may be 0 if unknown. The corresponding user may be unknown. If the user is logged in the application, then they must be chosen for authorization by default
final
verifiedAppName String
verifiedAppName Verified name of the application; if empty, then "Unverified App" must be shown instead
final

Methods

copyWith({int? userId, String? url, String? domain, bool? fromApp, String? verifiedAppName, int? botUserId, bool? requestWriteAccess, bool? requestPhoneNumberAccess, String? browser, String? platform, String? ipAddress, String? location, bool? matchCodeFirst, List<String>? matchCodes}) OauthLinkInfo

Available on OauthLinkInfo, provided by the OauthLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) OauthLinkInfo?

Constants

constructor → const String