OpenBotSimilarBot class final
Informs TDLib that a bot was opened from the list of similar bots Returns Ok
- Inheritance
-
- Object
- TdFunction
- OpenBotSimilarBot
- Available extensions
- Annotations
-
- @immutable
Constructors
- OpenBotSimilarBot({required int botUserId, required int openedBotUserId})
Properties
- botUserId → int
-
botUserId Identifier of the original bot, which similar bots were
requested
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- openedBotUserId → int
-
openedBotUserId Identifier of the opened bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, int? openedBotUserId}) → OpenBotSimilarBot -
Available on OpenBotSimilarBot, provided by the OpenBotSimilarBotExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String