OpenGiftAuction class final

Informs TDLib that a gift auction was opened by the user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

OpenGiftAuction({required int giftId})

Properties

giftId int
giftId Identifier of the gift, which auction was opened
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? giftId}) OpenGiftAuction

Available on OpenGiftAuction, provided by the OpenGiftAuctionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String