OpenSponsoredChat class final
Informs TDLib that the user opened a sponsored chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- OpenSponsoredChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- OpenSponsoredChat({required int sponsoredChatUniqueId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sponsoredChatUniqueId → int
-
sponsoredChatUniqueId Unique identifier of the sponsored chat
final
Methods
-
copyWith(
{int? sponsoredChatUniqueId}) → OpenSponsoredChat -
Available on OpenSponsoredChat, provided by the OpenSponsoredChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String