botUserId property

int botUserId
final

botUserId Identifier of the bot, providing the Web App. If the bot is restricted for the current user, then show an error instead of calling the method

Implementation

final int botUserId;