replyTo property

InputMessageReplyTo? replyTo
final

replyTo Information about the message or story to be replied in the message sent by the Web App; pass null if none

Implementation

final InputMessageReplyTo? replyTo;