OptionValue class sealed
Represents the value of an option
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult $boolean(OptionValueBoolean value), required TResult empty(OptionValueEmpty value), required TResult integer(OptionValueInteger value), required TResult $string(OptionValueString value)}) → TResult -
Available on OptionValue, provided by the OptionValueExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult $boolean(OptionValueBoolean value)?, TResult empty(OptionValueEmpty value)?, TResult integer(OptionValueInteger value)?, TResult $string(OptionValueString value)?, required TResult orElse()}) → TResult -
Available on OptionValue, provided by the OptionValueExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → OptionValue? - Inherited by: OptionValueBoolean OptionValueEmpty OptionValueInteger OptionValueString
Constants
- constructor → const String