OptionValueInteger class final

Represents an integer option

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

OptionValueInteger({required int value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
value The value of the option
final

Methods

copyWith({int? value}) OptionValueInteger

Available on OptionValueInteger, provided by the OptionValueIntegerExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult $boolean(OptionValueBoolean value), required TResult empty(OptionValueEmpty value), required TResult integer(OptionValueInteger value), required TResult $string(OptionValueString value)}) → TResult

Available on OptionValue, provided by the OptionValueExtensions extension

maybeMap<TResult extends Object?>({TResult $boolean(OptionValueBoolean value)?, TResult empty(OptionValueEmpty value)?, TResult integer(OptionValueInteger value)?, TResult $string(OptionValueString value)?, required TResult orElse()}) → TResult

Available on OptionValue, provided by the OptionValueExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String