PageBlockCaption class final

Contains a caption of another block

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PageBlockCaption({RichText? text, RichText? credit})

Properties

credit RichText?
credit Block credit (like HTML tag ); may be null if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text RichText?
text Content of the caption
final

Methods

copyWith({RichText? text, RichText? credit}) PageBlockCaption

Available on PageBlockCaption, provided by the PageBlockCaptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PageBlockCaption?

Constants

constructor → const String