PageBlockHorizontalAlignmentLeft class final
The content must be left-aligned
- Inheritance
-
- Object
- TdObject
- PageBlockHorizontalAlignment
- PageBlockHorizontalAlignmentLeft
- Available extensions
- Annotations
-
- @immutable
Constructors
- PageBlockHorizontalAlignmentLeft()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult center(PageBlockHorizontalAlignmentCenter value), required TResult left(PageBlockHorizontalAlignmentLeft value), required TResult right(PageBlockHorizontalAlignmentRight value)}) → TResult -
Available on PageBlockHorizontalAlignment, provided by the PageBlockHorizontalAlignmentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult center(PageBlockHorizontalAlignmentCenter value)?, TResult left(PageBlockHorizontalAlignmentLeft value)?, TResult right(PageBlockHorizontalAlignmentRight value)?, required TResult orElse()}) → TResult -
Available on PageBlockHorizontalAlignment, provided by the PageBlockHorizontalAlignmentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PageBlockHorizontalAlignmentLeft? -
Inherited by:
PageBlockHorizontalAlignmentCenter
PageBlockHorizontalAlignmentLeft
PageBlockHorizontalAlignmentRight
override
Constants
- constructor → const String