PageBlockVerticalAlignment class sealed
Describes a Vertical alignment of a table cell content
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bottom(PageBlockVerticalAlignmentBottom value), required TResult middle(PageBlockVerticalAlignmentMiddle value), required TResult top(PageBlockVerticalAlignmentTop value)}) → TResult -
Available on PageBlockVerticalAlignment, provided by the PageBlockVerticalAlignmentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bottom(PageBlockVerticalAlignmentBottom value)?, TResult middle(PageBlockVerticalAlignmentMiddle value)?, TResult top(PageBlockVerticalAlignmentTop value)?, required TResult orElse()}) → TResult -
Available on PageBlockVerticalAlignment, provided by the PageBlockVerticalAlignmentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PageBlockVerticalAlignment? - Inherited by: PageBlockVerticalAlignmentBottom PageBlockVerticalAlignmentMiddle PageBlockVerticalAlignmentTop
Constants
- constructor → const String