PaidMediaPhoto class final

The media is a photo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaidMediaPhoto({Photo? photo, Video? video})

Properties

hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo The photo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
video Video?
video The video representing the live photo; may be null if the photo is static
final

Methods

copyWith({Photo? photo, Video? video}) PaidMediaPhoto

Available on PaidMediaPhoto, provided by the PaidMediaPhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(PaidMediaPhoto value), required TResult preview(PaidMediaPreview value), required TResult unsupported(PaidMediaUnsupported value), required TResult video(PaidMediaVideo value)}) → TResult

Available on PaidMedia, provided by the PaidMediaExtensions extension

maybeMap<TResult extends Object?>({TResult photo(PaidMediaPhoto value)?, TResult preview(PaidMediaPreview value)?, TResult unsupported(PaidMediaUnsupported value)?, TResult video(PaidMediaVideo value)?, required TResult orElse()}) → TResult

Available on PaidMedia, provided by the PaidMediaExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PaidMediaPhoto?
Inherited by: PaidMediaPhoto PaidMediaPreview PaidMediaUnsupported PaidMediaVideo
override

Constants

constructor → const String