PaidMediaVideo class final

The media is a video

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaidMediaVideo({Video? video, Photo? cover, required int startTimestamp})

Properties

cover Photo?
cover Cover of the video; may be null if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp int
startTimestamp Timestamp from which the video playing must start, in seconds
final
video Video?
video The video
final

Methods

copyWith({Video? video, Photo? cover, int? startTimestamp}) PaidMediaVideo

Available on PaidMediaVideo, provided by the PaidMediaVideoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult photo(PaidMediaPhoto value), required TResult preview(PaidMediaPreview value), required TResult unsupported(PaidMediaUnsupported value), required TResult video(PaidMediaVideo value)}) → TResult

Available on PaidMedia, provided by the PaidMediaExtensions extension

maybeMap<TResult extends Object?>({TResult photo(PaidMediaPhoto value)?, TResult preview(PaidMediaPreview value)?, TResult unsupported(PaidMediaUnsupported value)?, TResult video(PaidMediaVideo value)?, required TResult orElse()}) → TResult

Available on PaidMedia, provided by the PaidMediaExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PaidMediaVideo?
Inherited by: PaidMediaPhoto PaidMediaPreview PaidMediaUnsupported PaidMediaVideo
override

Constants

constructor → const String