PaidReactionTypeAnonymous class final
An anonymous paid reaction
- Inheritance
-
- Object
- TdObject
- PaidReactionType
- PaidReactionTypeAnonymous
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaidReactionTypeAnonymous()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult anonymous(PaidReactionTypeAnonymous value), required TResult chat(PaidReactionTypeChat value), required TResult regular(PaidReactionTypeRegular value)}) → TResult -
Available on PaidReactionType, provided by the PaidReactionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult anonymous(PaidReactionTypeAnonymous value)?, TResult chat(PaidReactionTypeChat value)?, TResult regular(PaidReactionTypeRegular value)?, required TResult orElse()}) → TResult -
Available on PaidReactionType, provided by the PaidReactionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaidReactionTypeAnonymous? -
Inherited by:
PaidReactionTypeAnonymous
PaidReactionTypeChat
PaidReactionTypeRegular
override
Constants
- constructor → const String