PaidReactionTypeChat class final

A paid reaction on behalf of an owned chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaidReactionTypeChat({required int chatId})

Properties

chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) PaidReactionTypeChat

Available on PaidReactionTypeChat, provided by the PaidReactionTypeChatExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult anonymous(PaidReactionTypeAnonymous value), required TResult chat(PaidReactionTypeChat value), required TResult regular(PaidReactionTypeRegular value)}) → TResult

Available on PaidReactionType, provided by the PaidReactionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult anonymous(PaidReactionTypeAnonymous value)?, TResult chat(PaidReactionTypeChat value)?, TResult regular(PaidReactionTypeRegular value)?, required TResult orElse()}) → TResult

Available on PaidReactionType, provided by the PaidReactionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String