ParseMarkdown class final

Parses Markdown entities in a human-friendly format, ignoring markup errors. Can be called synchronously Returns FormattedText

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ParseMarkdown({FormattedText? text})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text The text to parse. For example, "italic strikethrough ||spoiler|| bold code pre __italic__ text_url __italicbold italic__bold"
final

Methods

copyWith({FormattedText? text}) ParseMarkdown

Available on ParseMarkdown, provided by the ParseMarkdownExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String