ParseTextEntities class final
Parses Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, BlockQuote, ExpandableBlockQuote, Code, Pre, PreCode, TextUrl, MentionName, and DateTime entities from a marked-up text. Can be called synchronously Returns FormattedText
- Inheritance
-
- Object
- TdFunction
- ParseTextEntities
- Available extensions
- Annotations
-
- @immutable
Constructors
- ParseTextEntities({required String text, TextParseMode? parseMode})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- parseMode → TextParseMode?
-
parseMode Text parse mode
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
text The text to parse
final
Methods
-
copyWith(
{String? text, TextParseMode? parseMode}) → ParseTextEntities -
Available on ParseTextEntities, provided by the ParseTextEntitiesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String