softwareIconCustomEmojiId property

int softwareIconCustomEmojiId
final

softwareIconCustomEmojiId Identifier of the custom emoji that is used as the icon of the software, which created the passkey; 0 if unknown

Implementation

final int softwareIconCustomEmojiId;