Passkeys class final

Contains a list of passkeys

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Passkeys({required List<Passkey> passkeys})

Properties

hashCode int
The hash code for this object.
no setteroverride
passkeys List<Passkey>
passkeys List of passkeys
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<Passkey>? passkeys}) Passkeys

Available on Passkeys, provided by the PasskeysExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Passkeys?

Constants

constructor → const String