PassportAuthorizationForm class final
Contains information about a Telegram Passport authorization form that was requested
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PassportAuthorizationForm({required int id, required List<
PassportRequiredElement> requiredElements, required String privacyPolicyUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique identifier of the authorization form
final
- privacyPolicyUrl → String
-
privacyPolicyUrl URL for the privacy policy of the service; may be empty
final
-
requiredElements
→ List<
PassportRequiredElement> -
requiredElements Telegram Passport elements that must be provided to
complete the form
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, List< PassportRequiredElement> ? requiredElements, String? privacyPolicyUrl}) → PassportAuthorizationForm -
Available on PassportAuthorizationForm, provided by the PassportAuthorizationFormExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PassportAuthorizationForm?
Constants
- constructor → const String