PassportRequiredElement class final

Contains a description of the required Telegram Passport element that was requested by a service

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PassportRequiredElement({required List<PassportSuitableElement> suitableElements})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suitableElements List<PassportSuitableElement>
suitableElements List of Telegram Passport elements any of which is enough to provide
final

Methods

copyWith({List<PassportSuitableElement>? suitableElements}) PassportRequiredElement

Available on PassportRequiredElement, provided by the PassportRequiredElementExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PassportRequiredElement?

Constants

constructor → const String