PaymentFormTypeStars class final

The payment form is for a payment in Telegram Stars

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaymentFormTypeStars({required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Number of Telegram Stars that will be paid
final

Methods

copyWith({int? starCount}) PaymentFormTypeStars

Available on PaymentFormTypeStars, provided by the PaymentFormTypeStarsExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult regular(PaymentFormTypeRegular value), required TResult starSubscription(PaymentFormTypeStarSubscription value), required TResult stars(PaymentFormTypeStars value)}) → TResult

Available on PaymentFormType, provided by the PaymentFormTypeExtensions extension

maybeMap<TResult extends Object?>({TResult regular(PaymentFormTypeRegular value)?, TResult starSubscription(PaymentFormTypeStarSubscription value)?, TResult stars(PaymentFormTypeStars value)?, required TResult orElse()}) → TResult

Available on PaymentFormType, provided by the PaymentFormTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String