PaymentOption class final

Describes an additional payment option

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaymentOption({required String title, required String url})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Title for the payment option
final
url String
url Payment form URL to be opened in a web view
final

Methods

copyWith({String? title, String? url}) PaymentOption

Available on PaymentOption, provided by the PaymentOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PaymentOption?

Constants

constructor → const String