PaymentProvider class sealed
Contains information about a payment provider
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult other(PaymentProviderOther value), required TResult smartGlocal(PaymentProviderSmartGlocal value), required TResult stripe(PaymentProviderStripe value)}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult other(PaymentProviderOther value)?, TResult smartGlocal(PaymentProviderSmartGlocal value)?, TResult stripe(PaymentProviderStripe value)?, required TResult orElse()}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentProvider? - Inherited by: PaymentProviderOther PaymentProviderSmartGlocal PaymentProviderStripe
Constants
- constructor → const String