PaymentProviderOther class final

Some other payment provider, for which a web payment form must be shown

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaymentProviderOther({required String url})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url Payment form URL
final

Methods

copyWith({String? url}) PaymentProviderOther

Available on PaymentProviderOther, provided by the PaymentProviderOtherExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult other(PaymentProviderOther value), required TResult smartGlocal(PaymentProviderSmartGlocal value), required TResult stripe(PaymentProviderStripe value)}) → TResult

Available on PaymentProvider, provided by the PaymentProviderExtensions extension

maybeMap<TResult extends Object?>({TResult other(PaymentProviderOther value)?, TResult smartGlocal(PaymentProviderSmartGlocal value)?, TResult stripe(PaymentProviderStripe value)?, required TResult orElse()}) → TResult

Available on PaymentProvider, provided by the PaymentProviderExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String