PaymentReceiptType class sealed

Describes type of successful payment

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult regular(PaymentReceiptTypeRegular value), required TResult stars(PaymentReceiptTypeStars value)}) → TResult

Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension

maybeMap<TResult extends Object?>({TResult regular(PaymentReceiptTypeRegular value)?, TResult stars(PaymentReceiptTypeStars value)?, required TResult orElse()}) → TResult

Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PaymentReceiptType?
Inherited by: PaymentReceiptTypeRegular PaymentReceiptTypeStars

Constants

constructor → const String