transactionId property
transactionId Unique identifier of the transaction that can be used to dispute it
Implementation
final String transactionId;
transactionId Unique identifier of the transaction that can be used to dispute it
final String transactionId;