PaymentResult class final

Contains the result of a payment request

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PaymentResult({required bool success, required String verificationUrl})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
success True, if the payment request was successful; otherwise, the verification_url will be non-empty
final
verificationUrl String
verificationUrl URL for additional payment credentials verification
final

Methods

copyWith({bool? success, String? verificationUrl}) PaymentResult

Available on PaymentResult, provided by the PaymentResultExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PaymentResult?

Constants

constructor → const String