PersonalDocument class final
A personal document, containing some information about a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PersonalDocument({required List<
DatedFile> files, required List<DatedFile> translation})
Properties
-
files
→ List<
DatedFile> -
files List of files containing the pages of the document
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
DatedFile> -
translation List of files containing a certified English translation of
the document
final
Methods
-
copyWith(
{List< DatedFile> ? files, List<DatedFile> ? translation}) → PersonalDocument -
Available on PersonalDocument, provided by the PersonalDocumentExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PersonalDocument?
Constants
- constructor → const String