hasUnknownPhoneNumber property
hasUnknownPhoneNumber Pass true if there is a SIM card in the current device, but it is not possible to check whether phone number matches
Implementation
final bool hasUnknownPhoneNumber;
hasUnknownPhoneNumber Pass true if there is a SIM card in the current device, but it is not possible to check whether phone number matches
final bool hasUnknownPhoneNumber;