PhoneNumberInfo class final
Contains information about a phone number
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PhoneNumberInfo({CountryInfo? country, required String countryCallingCode, required String formattedPhoneNumber, required bool isAnonymous})
Properties
- country → CountryInfo?
-
country Information about the country to which the phone number belongs;
may be null
final
- countryCallingCode → String
-
countryCallingCode The part of the phone number denoting country calling
code or its part
final
- formattedPhoneNumber → String
-
formattedPhoneNumber The phone number without country calling code
formatted accordingly to local rules. Expected digits are returned as '-',
but even more digits might be entered by the user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAnonymous → bool
-
isAnonymous True, if the phone number was bought at https://fragment.com
and isn't tied to a SIM card. Information about the phone number can be
received using getCollectibleItemInfo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{CountryInfo? country, String? countryCallingCode, String? formattedPhoneNumber, bool? isAnonymous}) → PhoneNumberInfo -
Available on PhoneNumberInfo, provided by the PhoneNumberInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PhoneNumberInfo?
Constants
- constructor → const String