Photo class final

Describes a photo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Photo({required bool hasStickers, Minithumbnail? minithumbnail, required List<PhotoSize> sizes})

Properties

hashCode int
The hash code for this object.
no setteroverride
hasStickers bool
hasStickers True, if stickers were added to the photo. The list of corresponding sticker sets can be received using getAttachedStickerSets
final
minithumbnail Minithumbnail?
minithumbnail Photo minithumbnail; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizes List<PhotoSize>
sizes Available variants of the photo, in different sizes
final

Methods

copyWith({bool? hasStickers, Minithumbnail? minithumbnail, List<PhotoSize>? sizes}) Photo

Available on Photo, provided by the PhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Photo?

Constants

constructor → const String