PhotoSize class final

Describes an image in JPEG format

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PhotoSize({required String type, File? photo, required int width, required int height, required List<int> progressiveSizes})

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
height Image height
final
photo File?
photo Information about the image file
final
progressiveSizes List<int>
progressiveSizes Sizes of progressive JPEG file prefixes, which can be used to preliminarily show the image; in bytes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
type Image type (see https://core.telegram.org/constructor/photoSize)
final
width int
width Image width
final

Methods

copyWith({String? type, File? photo, int? width, int? height, List<int>? progressiveSizes}) PhotoSize

Available on PhotoSize, provided by the PhotoSizeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PhotoSize?

Constants

constructor → const String