PlaceGiftAuctionBid class final

Places a bid on an auction gift Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PlaceGiftAuctionBid({required int giftId, required int starCount, required int userId, FormattedText? text, required bool isPrivate})

Properties

giftId int
giftId Identifier of the gift to place the bid on
final
hashCode int
The hash code for this object.
no setteroverride
isPrivate bool
isPrivate Pass true to show gift text and sender only to the gift receiver; otherwise, everyone will be able to see them
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars to place in the bid
final
text FormattedText?
text Text to show along with the gift; 0-getOption("gift_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed. Must be empty if the receiver enabled paid messages
final
userId int
userId Identifier of the user who will receive the gift
final

Methods

copyWith({int? giftId, int? starCount, int? userId, FormattedText? text, bool? isPrivate}) PlaceGiftAuctionBid

Available on PlaceGiftAuctionBid, provided by the PlaceGiftAuctionBidExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String