Point class final

A point on a Cartesian plane

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Point({required double x, required double y})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
x The point's first coordinate
final
y double
y The point's second coordinate
final

Methods

copyWith({double? x, double? y}) Point

Available on Point, provided by the PointExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Point?

Constants

constructor → const String