allowsMultipleAnswers property
allowsMultipleAnswers True, if multiple answer options can be chosen simultaneously
Implementation
final bool allowsMultipleAnswers;
allowsMultipleAnswers True, if multiple answer options can be chosen simultaneously
final bool allowsMultipleAnswers;