canGetVoters property
canGetVoters True, if the current user can get voters in the poll using getPollVoters
Implementation
final bool canGetVoters;
canGetVoters True, if the current user can get voters in the poll using getPollVoters
final bool canGetVoters;