countryCodes property

List<String> countryCodes
final

countryCodes The list of two-letter ISO 3166-1 alpha-2 codes of countries, users from which will be able to vote. If empty, then all users can participate in the poll

Implementation

final List<String> countryCodes;