membersOnly property
membersOnly True, if only the users that are members of the chat for more than a day will be able to vote
Implementation
final bool membersOnly;
membersOnly True, if only the users that are members of the chat for more than a day will be able to vote
final bool membersOnly;