optionOrder property

List<int> optionOrder
final

optionOrder The list of 0-based poll identifiers in which the options of the poll must be shown; empty if the order of options must not be changed

Implementation

final List<int> optionOrder;