voteRestrictionReason property

PollVoteRestrictionReason? voteRestrictionReason
final

voteRestrictionReason The reason describing, why the current user can't vote in the poll; may be null if the user can vote in the poll

Implementation

final PollVoteRestrictionReason? voteRestrictionReason;