PollMediaAnimation class final

An animation

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PollMediaAnimation({Animation? animation})

Properties

animation Animation?
animation The animation
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Animation? animation}) PollMediaAnimation

Available on PollMediaAnimation, provided by the PollMediaAnimationExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult animation(PollMediaAnimation value), required TResult audio(PollMediaAudio value), required TResult document(PollMediaDocument value), required TResult link(PollMediaLink value), required TResult location(PollMediaLocation value), required TResult photo(PollMediaPhoto value), required TResult sticker(PollMediaSticker value), required TResult venue(PollMediaVenue value), required TResult video(PollMediaVideo value)}) → TResult

Available on PollMedia, provided by the PollMediaExtensions extension

maybeMap<TResult extends Object?>({TResult animation(PollMediaAnimation value)?, TResult audio(PollMediaAudio value)?, TResult document(PollMediaDocument value)?, TResult link(PollMediaLink value)?, TResult location(PollMediaLocation value)?, TResult photo(PollMediaPhoto value)?, TResult sticker(PollMediaSticker value)?, TResult venue(PollMediaVenue value)?, TResult video(PollMediaVideo value)?, required TResult orElse()}) → TResult

Available on PollMedia, provided by the PollMediaExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String