additionDate property
additionDate Point in time (Unix timestamp) when the option was added; 0 if the option existed from creation of the poll
Implementation
final int additionDate;
additionDate Point in time (Unix timestamp) when the option was added; 0 if the option existed from creation of the poll
final int additionDate;