recentVoterIds property
recentVoterIds Identifiers of recent voters for the option, if the poll is non-anonymous and poll results are available
Implementation
final List<MessageSender> recentVoterIds;
recentVoterIds Identifiers of recent voters for the option, if the poll is non-anonymous and poll results are available
final List<MessageSender> recentVoterIds;