canBeReplied property

bool canBeReplied
final

canBeReplied True, if the poll option can be replied in the same chat and forum topic using inputMessageReplyToMessage

Implementation

final bool canBeReplied;