canGetLink property
canGetLink True, if a link can be generated for the poll option using getMessageLink
Implementation
final bool canGetLink;
canGetLink True, if a link can be generated for the poll option using getMessageLink
final bool canGetLink;