explanation property

FormattedText? explanation
final

explanation Text that is shown when the user chooses an incorrect answer or taps on the lamp icon; empty for a yet unanswered poll

Implementation

final FormattedText? explanation;