PollTypeRegular class final
A regular poll
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PollTypeRegular()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult quiz(PollTypeQuiz value), required TResult regular(PollTypeRegular value)}) → TResult -
Available on PollType, provided by the PollTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult quiz(PollTypeQuiz value)?, TResult regular(PollTypeRegular value)?, required TResult orElse()}) → TResult -
Available on PollType, provided by the PollTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PollTypeRegular? -
Inherited by:
PollTypeQuiz
PollTypeRegular
override
Constants
- constructor → const String