PollVoter class final

Represents a poll voter

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PollVoter({MessageSender? voterId, required int date})

Properties

date int
date Point in time (Unix timestamp) when the vote was added
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voterId MessageSender?
voterId The voter identifier
final

Methods

copyWith({MessageSender? voterId, int? date}) PollVoter

Available on PollVoter, provided by the PollVoterExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PollVoter?

Constants

constructor → const String