fromStoryFullId property
fromStoryFullId Full identifier of the original story, which content was used to create the story; pass null if the story isn't repost of another story
Implementation
final StoryFullId? fromStoryFullId;
fromStoryFullId Full identifier of the original story, which content was used to create the story; pass null if the story isn't repost of another story
final StoryFullId? fromStoryFullId;