isPostedToChatPage property
isPostedToChatPage Pass true to keep the story accessible after expiration
Implementation
final bool isPostedToChatPage;
isPostedToChatPage Pass true to keep the story accessible after expiration
final bool isPostedToChatPage;