PremiumFeatures class final

Contains information about features, available to Premium users

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumFeatures({required List<PremiumFeature> features, required List<PremiumLimit> limits, InternalLinkType? paymentLink})

Properties

features List<PremiumFeature>
features The list of available features
final
hashCode int
The hash code for this object.
no setteroverride
limits List<PremiumLimit>
limits The list of limits, increased for Premium users
final
paymentLink An internal link to be opened to pay for Telegram Premium if store payment isn't possible; may be null if direct payment isn't available
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<PremiumFeature>? features, List<PremiumLimit>? limits, InternalLinkType? paymentLink}) PremiumFeatures

Available on PremiumFeatures, provided by the PremiumFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PremiumFeatures?

Constants

constructor → const String