PremiumGiftPaymentOptions class final
Contains a list of options for gifting Telegram Premium to a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PremiumGiftPaymentOptions({required List<
PremiumGiftPaymentOption> options})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
options
→ List<
PremiumGiftPaymentOption> -
options The list of options sorted by Telegram Premium subscription
duration
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< PremiumGiftPaymentOption> ? options}) → PremiumGiftPaymentOptions -
Available on PremiumGiftPaymentOptions, provided by the PremiumGiftPaymentOptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumGiftPaymentOptions?
Constants
- constructor → const String