PremiumGiveawayPaymentOption class final

Describes an option for creating of Telegram Premium giveaway or manual distribution of Telegram Premium among chat members. Use telegramPaymentPurposePremiumGiftCodes or telegramPaymentPurposePremiumGiveaway for out-of-store payments

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumGiveawayPaymentOption({required String currency, required int amount, required int winnerCount, required int monthCount, required String storeProductId, required int storeProductQuantity})

Properties

amount int
amount The amount to pay, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code for Telegram Premium gift code payment
final
hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeProductId String
storeProductId Identifier of the store product associated with the option; may be empty if none
final
storeProductQuantity int
storeProductQuantity Number of times the store product must be paid
final
winnerCount int
winnerCount Number of users which will be able to activate the gift codes
final

Methods

copyWith({String? currency, int? amount, int? winnerCount, int? monthCount, String? storeProductId, int? storeProductQuantity}) PremiumGiveawayPaymentOption

Available on PremiumGiveawayPaymentOption, provided by the PremiumGiveawayPaymentOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PremiumGiveawayPaymentOption?

Constants

constructor → const String