PremiumLimitType class sealed
Describes type of limit, increased for Premium users
- Inheritance
- Implementers
- PremiumLimitTypeActiveStoryCount
- PremiumLimitTypeBioLength
- PremiumLimitTypeCaptionLength
- PremiumLimitTypeChatFolderChosenChatCount
- PremiumLimitTypeChatFolderCount
- PremiumLimitTypeChatFolderInviteLinkCount
- PremiumLimitTypeCreatedPublicChatCount
- PremiumLimitTypeCustomTextCompositionStyleCount
- PremiumLimitTypeFavoriteStickerCount
- PremiumLimitTypeMessageTextLength
- PremiumLimitTypeMonthlyPostedStoryCount
- PremiumLimitTypeOwnedBotCount
- PremiumLimitTypePinnedArchivedChatCount
- PremiumLimitTypePinnedChatCount
- PremiumLimitTypePinnedSavedMessagesTopicCount
- PremiumLimitTypeSavedAnimationCount
- PremiumLimitTypeShareableChatFolderCount
- PremiumLimitTypeSimilarChatCount
- PremiumLimitTypeStoryCaptionLength
- PremiumLimitTypeStorySuggestedReactionAreaCount
- PremiumLimitTypeSupergroupCount
- PremiumLimitTypeWeeklyPostedStoryCount
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult activeStoryCount(PremiumLimitTypeActiveStoryCount value), required TResult bioLength(PremiumLimitTypeBioLength value), required TResult captionLength(PremiumLimitTypeCaptionLength value), required TResult chatFolderChosenChatCount(PremiumLimitTypeChatFolderChosenChatCount value), required TResult chatFolderCount(PremiumLimitTypeChatFolderCount value), required TResult chatFolderInviteLinkCount(PremiumLimitTypeChatFolderInviteLinkCount value), required TResult createdPublicChatCount(PremiumLimitTypeCreatedPublicChatCount value), required TResult customTextCompositionStyleCount(PremiumLimitTypeCustomTextCompositionStyleCount value), required TResult favoriteStickerCount(PremiumLimitTypeFavoriteStickerCount value), required TResult messageTextLength(PremiumLimitTypeMessageTextLength value), required TResult monthlyPostedStoryCount(PremiumLimitTypeMonthlyPostedStoryCount value), required TResult ownedBotCount(PremiumLimitTypeOwnedBotCount value), required TResult pinnedArchivedChatCount(PremiumLimitTypePinnedArchivedChatCount value), required TResult pinnedChatCount(PremiumLimitTypePinnedChatCount value), required TResult pinnedSavedMessagesTopicCount(PremiumLimitTypePinnedSavedMessagesTopicCount value), required TResult savedAnimationCount(PremiumLimitTypeSavedAnimationCount value), required TResult similarChatCount(PremiumLimitTypeSimilarChatCount value), required TResult storyCaptionLength(PremiumLimitTypeStoryCaptionLength value), required TResult storySuggestedReactionAreaCount(PremiumLimitTypeStorySuggestedReactionAreaCount value), required TResult supergroupCount(PremiumLimitTypeSupergroupCount value), required TResult weeklyPostedStoryCount(PremiumLimitTypeWeeklyPostedStoryCount value)}) → TResult -
Available on PremiumLimitType, provided by the PremiumLimitTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult activeStoryCount(PremiumLimitTypeActiveStoryCount value)?, TResult bioLength(PremiumLimitTypeBioLength value)?, TResult captionLength(PremiumLimitTypeCaptionLength value)?, TResult chatFolderChosenChatCount(PremiumLimitTypeChatFolderChosenChatCount value)?, TResult chatFolderCount(PremiumLimitTypeChatFolderCount value)?, TResult chatFolderInviteLinkCount(PremiumLimitTypeChatFolderInviteLinkCount value)?, TResult createdPublicChatCount(PremiumLimitTypeCreatedPublicChatCount value)?, TResult customTextCompositionStyleCount(PremiumLimitTypeCustomTextCompositionStyleCount value)?, TResult favoriteStickerCount(PremiumLimitTypeFavoriteStickerCount value)?, TResult messageTextLength(PremiumLimitTypeMessageTextLength value)?, TResult monthlyPostedStoryCount(PremiumLimitTypeMonthlyPostedStoryCount value)?, TResult ownedBotCount(PremiumLimitTypeOwnedBotCount value)?, TResult pinnedArchivedChatCount(PremiumLimitTypePinnedArchivedChatCount value)?, TResult pinnedChatCount(PremiumLimitTypePinnedChatCount value)?, TResult pinnedSavedMessagesTopicCount(PremiumLimitTypePinnedSavedMessagesTopicCount value)?, TResult savedAnimationCount(PremiumLimitTypeSavedAnimationCount value)?, TResult similarChatCount(PremiumLimitTypeSimilarChatCount value)?, TResult storyCaptionLength(PremiumLimitTypeStoryCaptionLength value)?, TResult storySuggestedReactionAreaCount(PremiumLimitTypeStorySuggestedReactionAreaCount value)?, TResult supergroupCount(PremiumLimitTypeSupergroupCount value)?, TResult weeklyPostedStoryCount(PremiumLimitTypeWeeklyPostedStoryCount value)?, required TResult orElse()}) → TResult -
Available on PremiumLimitType, provided by the PremiumLimitTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumLimitType? - Inherited by: PremiumLimitTypeActiveStoryCount PremiumLimitTypeBioLength PremiumLimitTypeCaptionLength PremiumLimitTypeChatFolderChosenChatCount PremiumLimitTypeChatFolderCount PremiumLimitTypeChatFolderInviteLinkCount PremiumLimitTypeCreatedPublicChatCount PremiumLimitTypeCustomTextCompositionStyleCount PremiumLimitTypeFavoriteStickerCount PremiumLimitTypeMessageTextLength PremiumLimitTypeMonthlyPostedStoryCount PremiumLimitTypeOwnedBotCount PremiumLimitTypePinnedArchivedChatCount PremiumLimitTypePinnedChatCount PremiumLimitTypePinnedSavedMessagesTopicCount PremiumLimitTypeSavedAnimationCount PremiumLimitTypeShareableChatFolderCount PremiumLimitTypeSimilarChatCount PremiumLimitTypeStoryCaptionLength PremiumLimitTypeStorySuggestedReactionAreaCount PremiumLimitTypeSupergroupCount PremiumLimitTypeWeeklyPostedStoryCount
Constants
- constructor → const String