PremiumPaymentOption class final

Describes an option for buying Telegram Premium to a user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumPaymentOption({required String currency, required int amount, required int discountPercentage, required int monthCount, required String storeProductId, InternalLinkType? paymentLink})

Properties

amount int
amount The amount to pay, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code for Telegram Premium subscription payment
final
discountPercentage int
discountPercentage The discount associated with this option, as a percentage
final
hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active. Use getPremiumInfoSticker to get the sticker to be used as representation of the Telegram Premium subscription
final
paymentLink An internal link to be opened for buying Telegram Premium to the user if store payment isn't possible; may be null if direct payment isn't available
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storeProductId String
storeProductId Identifier of the store product associated with the option
final

Methods

copyWith({String? currency, int? amount, int? discountPercentage, int? monthCount, String? storeProductId, InternalLinkType? paymentLink}) PremiumPaymentOption

Available on PremiumPaymentOption, provided by the PremiumPaymentOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PremiumPaymentOption?

Constants

constructor → const String