PremiumSource class sealed
Describes a source from which the Premium features screen is opened
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult businessFeature(PremiumSourceBusinessFeature value), required TResult feature(PremiumSourceFeature value), required TResult limitExceeded(PremiumSourceLimitExceeded value), required TResult link(PremiumSourceLink value), required TResult settings(PremiumSourceSettings value), required TResult storyFeature(PremiumSourceStoryFeature value)}) → TResult -
Available on PremiumSource, provided by the PremiumSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult businessFeature(PremiumSourceBusinessFeature value)?, TResult feature(PremiumSourceFeature value)?, TResult limitExceeded(PremiumSourceLimitExceeded value)?, TResult link(PremiumSourceLink value)?, TResult settings(PremiumSourceSettings value)?, TResult storyFeature(PremiumSourceStoryFeature value)?, required TResult orElse()}) → TResult -
Available on PremiumSource, provided by the PremiumSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumSource? - Inherited by: PremiumSourceBusinessFeature PremiumSourceFeature PremiumSourceLimitExceeded PremiumSourceLink PremiumSourceSettings PremiumSourceStoryFeature
Constants
- constructor → const String