PremiumState class final

Contains state of Telegram Premium subscription and promotion videos for Premium features

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumState({FormattedText? state, required List<PremiumStatePaymentOption> paymentOptions, required List<PremiumFeaturePromotionAnimation> animations, required List<BusinessFeaturePromotionAnimation> businessAnimations})

Properties

animations List<PremiumFeaturePromotionAnimation>
animations The list of available promotion animations for Premium features
final
businessAnimations List<BusinessFeaturePromotionAnimation>
businessAnimations The list of available promotion animations for Business features
final
hashCode int
The hash code for this object.
no setteroverride
paymentOptions List<PremiumStatePaymentOption>
paymentOptions The list of available options for buying Telegram Premium
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state FormattedText?
state Text description of the state of the current Premium subscription; may be empty if the current user has no Telegram Premium subscription
final

Methods

copyWith({FormattedText? state, List<PremiumStatePaymentOption>? paymentOptions, List<PremiumFeaturePromotionAnimation>? animations, List<BusinessFeaturePromotionAnimation>? businessAnimations}) PremiumState

Available on PremiumState, provided by the PremiumStateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PremiumState?

Constants

constructor → const String