state property
state Text description of the state of the current Premium subscription; may be empty if the current user has no Telegram Premium subscription
Implementation
final FormattedText? state;
state Text description of the state of the current Premium subscription; may be empty if the current user has no Telegram Premium subscription
final FormattedText? state;