PremiumStoryFeatureLinksAndFormatting class final

The ability to use links and formatting in story caption, and use inputStoryAreaTypeLink areas

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult customExpirationDuration(PremiumStoryFeatureCustomExpirationDuration value), required TResult linksAndFormatting(PremiumStoryFeatureLinksAndFormatting value), required TResult permanentViewsHistory(PremiumStoryFeaturePermanentViewsHistory value), required TResult priorityOrder(PremiumStoryFeaturePriorityOrder value), required TResult saveStories(PremiumStoryFeatureSaveStories value), required TResult stealthMode(PremiumStoryFeatureStealthMode value), required TResult videoQuality(PremiumStoryFeatureVideoQuality value)}) → TResult

Available on PremiumStoryFeature, provided by the PremiumStoryFeatureExtensions extension

maybeMap<TResult extends Object?>({TResult customExpirationDuration(PremiumStoryFeatureCustomExpirationDuration value)?, TResult linksAndFormatting(PremiumStoryFeatureLinksAndFormatting value)?, TResult permanentViewsHistory(PremiumStoryFeaturePermanentViewsHistory value)?, TResult priorityOrder(PremiumStoryFeaturePriorityOrder value)?, TResult saveStories(PremiumStoryFeatureSaveStories value)?, TResult stealthMode(PremiumStoryFeatureStealthMode value)?, TResult videoQuality(PremiumStoryFeatureVideoQuality value)?, required TResult orElse()}) → TResult

Available on PremiumStoryFeature, provided by the PremiumStoryFeatureExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String