PreparedInlineMessage class final

Represents a ready to send inline message. Use sendInlineQueryResultMessage to send the message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PreparedInlineMessage({required int inlineQueryId, InlineQueryResult? result, TargetChatTypes? chatTypes})

Properties

chatTypes TargetChatTypes?
chatTypes Types of the chats to which the message can be sent
final
hashCode int
The hash code for this object.
no setteroverride
inlineQueryId int
inlineQueryId Unique identifier of the inline query to pass to sendInlineQueryResultMessage
final
result InlineQueryResult?
result Resulted inline message of the query
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? inlineQueryId, InlineQueryResult? result, TargetChatTypes? chatTypes}) PreparedInlineMessage

Available on PreparedInlineMessage, provided by the PreparedInlineMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PreparedInlineMessage?

Constants

constructor → const String