inlineQueryId property
inlineQueryId Unique identifier of the inline query to pass to sendInlineQueryResultMessage
Implementation
final int inlineQueryId;
inlineQueryId Unique identifier of the inline query to pass to sendInlineQueryResultMessage
final int inlineQueryId;