ProcessChatFolderNewChats class final

Process new chats added to a shareable chat folder by its owner Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProcessChatFolderNewChats({required int chatFolderId, required List<int> addedChatIds})

Properties

addedChatIds List<int>
addedChatIds Identifiers of the new chats, which are added to the chat folder. The chats are automatically joined if they aren't joined yet
final
chatFolderId int
chatFolderId Chat folder identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId, List<int>? addedChatIds}) ProcessChatFolderNewChats

Available on ProcessChatFolderNewChats, provided by the ProcessChatFolderNewChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String