ProcessChatJoinRequest class final

Handles a pending join request in a chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProcessChatJoinRequest({required int chatId, required int userId, required bool approve})

Properties

approve bool
approve Pass true to approve the request; pass false to decline it
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user who sent the request
final

Methods

copyWith({int? chatId, int? userId, bool? approve}) ProcessChatJoinRequest

Available on ProcessChatJoinRequest, provided by the ProcessChatJoinRequestExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String