ProcessChatJoinRequests class final

Handles all pending join requests for a given link in a chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProcessChatJoinRequests({required int chatId, required String inviteLink, required bool approve})

Properties

approve bool
approve Pass true to approve all requests; pass false to decline them
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink Invite link for which to process join requests. If empty, all join requests will be processed. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? inviteLink, bool? approve}) ProcessChatJoinRequests

Available on ProcessChatJoinRequests, provided by the ProcessChatJoinRequestsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String