ProductInfo class final

Contains information about a product that can be paid with invoice

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProductInfo({required String title, FormattedText? description, Photo? photo})

Properties

description FormattedText?
param_description Product description
final
hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo Product photo; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Product title
final

Methods

copyWith({String? title, FormattedText? description, Photo? photo}) ProductInfo

Available on ProductInfo, provided by the ProductInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ProductInfo?

Constants

constructor → const String