ProfileAccentColor class final

Contains information about supported accent color for user profile photo background

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProfileAccentColor({required int id, ProfileAccentColors? lightThemeColors, ProfileAccentColors? darkThemeColors, required int minSupergroupChatBoostLevel, required int minChannelChatBoostLevel})

Properties

darkThemeColors ProfileAccentColors?
darkThemeColors Accent colors expected to be used in dark themes
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Profile accent color identifier
final
lightThemeColors ProfileAccentColors?
lightThemeColors Accent colors expected to be used in light themes
final
minChannelChatBoostLevel int
minChannelChatBoostLevel The minimum chat boost level required to use the color in a channel chat
final
minSupergroupChatBoostLevel int
minSupergroupChatBoostLevel The minimum chat boost level required to use the color in a supergroup chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, ProfileAccentColors? lightThemeColors, ProfileAccentColors? darkThemeColors, int? minSupergroupChatBoostLevel, int? minChannelChatBoostLevel}) ProfileAccentColor

Available on ProfileAccentColor, provided by the ProfileAccentColorExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ProfileAccentColor?

Constants

constructor → const String