lightThemeColors property
lightThemeColors Accent colors expected to be used in light themes
Implementation
final ProfileAccentColors? lightThemeColors;
lightThemeColors Accent colors expected to be used in light themes
final ProfileAccentColors? lightThemeColors;