minSupergroupChatBoostLevel property
minSupergroupChatBoostLevel The minimum chat boost level required to use the color in a supergroup chat
Implementation
final int minSupergroupChatBoostLevel;
minSupergroupChatBoostLevel The minimum chat boost level required to use the color in a supergroup chat
final int minSupergroupChatBoostLevel;