backgroundColors property
backgroundColors The list of 1-2 colors in RGB format, describing the colors, as expected to be used for the profile photo background
Implementation
final List<int> backgroundColors;
backgroundColors The list of 1-2 colors in RGB format, describing the colors, as expected to be used for the profile photo background
final List<int> backgroundColors;