paletteColors property
paletteColors The list of 1-2 colors in RGB format, describing the colors, as expected to be shown in the color palette settings
Implementation
final List<int> paletteColors;
paletteColors The list of 1-2 colors in RGB format, describing the colors, as expected to be shown in the color palette settings
final List<int> paletteColors;