storyColors property

List<int> storyColors
final

storyColors The list of 2 colors in RGB format, describing the colors of the gradient to be used for the unread active story indicator around profile photo

Implementation

final List<int> storyColors;