ProfileTab class sealed

Describes a tab shown in a user or a chat profile

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult files(ProfileTabFiles value), required TResult gifs(ProfileTabGifs value), required TResult gifts(ProfileTabGifts value), required TResult links(ProfileTabLinks value), required TResult media(ProfileTabMedia value), required TResult music(ProfileTabMusic value), required TResult posts(ProfileTabPosts value), required TResult voice(ProfileTabVoice value)}) → TResult

Available on ProfileTab, provided by the ProfileTabExtensions extension

maybeMap<TResult extends Object?>({TResult files(ProfileTabFiles value)?, TResult gifs(ProfileTabGifs value)?, TResult gifts(ProfileTabGifts value)?, TResult links(ProfileTabLinks value)?, TResult media(ProfileTabMedia value)?, TResult music(ProfileTabMusic value)?, TResult posts(ProfileTabPosts value)?, TResult voice(ProfileTabVoice value)?, required TResult orElse()}) → TResult

Available on ProfileTab, provided by the ProfileTabExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String