ProfileTabLinks class final
A tab with messages posted by the channel and containing links
- Inheritance
-
- Object
- TdObject
- ProfileTab
- ProfileTabLinks
- Available extensions
- Annotations
-
- @immutable
Constructors
- ProfileTabLinks()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult files(ProfileTabFiles value), required TResult gifs(ProfileTabGifs value), required TResult gifts(ProfileTabGifts value), required TResult links(ProfileTabLinks value), required TResult media(ProfileTabMedia value), required TResult music(ProfileTabMusic value), required TResult posts(ProfileTabPosts value), required TResult voice(ProfileTabVoice value)}) → TResult -
Available on ProfileTab, provided by the ProfileTabExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult files(ProfileTabFiles value)?, TResult gifs(ProfileTabGifs value)?, TResult gifts(ProfileTabGifts value)?, TResult links(ProfileTabLinks value)?, TResult media(ProfileTabMedia value)?, TResult music(ProfileTabMusic value)?, TResult posts(ProfileTabPosts value)?, TResult voice(ProfileTabVoice value)?, required TResult orElse()}) → TResult -
Available on ProfileTab, provided by the ProfileTabExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ProfileTabLinks? -
Inherited by:
ProfileTabFiles
ProfileTabGifs
ProfileTabGifts
ProfileTabLinks
ProfileTabMedia
ProfileTabMusic
ProfileTabPosts
ProfileTabVoice
override
Constants
- constructor → const String