Proxy class final

Describes a proxy server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Proxy({required String server, required int port, ProxyType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
port int
port Proxy server port
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server String
server Proxy server domain or IP address
final
type ProxyType?
type Type of the proxy
final

Methods

copyWith({String? server, int? port, ProxyType? type}) Proxy

Available on Proxy, provided by the ProxyExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Proxy?

Constants

constructor → const String