ProxyTypeHttp class final

A HTTP transparent proxy server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProxyTypeHttp({required String username, required String password, required bool httpOnly})

Properties

hashCode int
The hash code for this object.
no setteroverride
httpOnly bool
httpOnly Pass true if the proxy supports only HTTP requests and doesn't support transparent TCP connections via HTTP CONNECT method
final
password String
password Password for logging in; may be empty
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
username Username for logging in; may be empty
final

Methods

copyWith({String? username, String? password, bool? httpOnly}) ProxyTypeHttp

Available on ProxyTypeHttp, provided by the ProxyTypeHttpExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult http(ProxyTypeHttp value), required TResult mtproto(ProxyTypeMtproto value), required TResult socks5(ProxyTypeSocks5 value)}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

maybeMap<TResult extends Object?>({TResult http(ProxyTypeHttp value)?, TResult mtproto(ProxyTypeMtproto value)?, TResult socks5(ProxyTypeSocks5 value)?, required TResult orElse()}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ProxyTypeHttp?
Inherited by: ProxyTypeHttp ProxyTypeMtproto ProxyTypeSocks5
override

Constants

constructor → const String