ProxyTypeSocks5 class final

A SOCKS5 proxy server

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProxyTypeSocks5({required String username, required String password})

Properties

hashCode int
The hash code for this object.
no setteroverride
password String
password Password for logging in; may be empty
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
username Username for logging in; may be empty
final

Methods

copyWith({String? username, String? password}) ProxyTypeSocks5

Available on ProxyTypeSocks5, provided by the ProxyTypeSocks5Extensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult http(ProxyTypeHttp value), required TResult mtproto(ProxyTypeMtproto value), required TResult socks5(ProxyTypeSocks5 value)}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

maybeMap<TResult extends Object?>({TResult http(ProxyTypeHttp value)?, TResult mtproto(ProxyTypeMtproto value)?, TResult socks5(ProxyTypeSocks5 value)?, required TResult orElse()}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ProxyTypeSocks5?
Inherited by: ProxyTypeHttp ProxyTypeMtproto ProxyTypeSocks5
override

Constants

constructor → const String