PublicForward class sealed

Describes a public forward or repost of a story

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult message(PublicForwardMessage value), required TResult story(PublicForwardStory value)}) → TResult

Available on PublicForward, provided by the PublicForwardExtensions extension

maybeMap<TResult extends Object?>({TResult message(PublicForwardMessage value)?, TResult story(PublicForwardStory value)?, required TResult orElse()}) → TResult

Available on PublicForward, provided by the PublicForwardExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PublicForward?
Inherited by: PublicForwardMessage PublicForwardStory

Constants

constructor → const String