PublicForwardStory class final

Contains a public repost to a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PublicForwardStory({Story? story})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
story Story?
story Information about the story
final

Methods

copyWith({Story? story}) PublicForwardStory

Available on PublicForwardStory, provided by the PublicForwardStoryExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult message(PublicForwardMessage value), required TResult story(PublicForwardStory value)}) → TResult

Available on PublicForward, provided by the PublicForwardExtensions extension

maybeMap<TResult extends Object?>({TResult message(PublicForwardMessage value)?, TResult story(PublicForwardStory value)?, required TResult orElse()}) → TResult

Available on PublicForward, provided by the PublicForwardExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PublicForwardStory?
Inherited by: PublicForwardMessage PublicForwardStory
override

Constants

constructor → const String