PublicForwards class final

Represents a list of public forwards and reposts as a story of a message or a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PublicForwards({required int totalCount, required List<PublicForward> forwards, required String nextOffset})

Properties

forwards List<PublicForward>
forwards List of found public forwards and reposts
final
hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of messages and stories found
final

Methods

copyWith({int? totalCount, List<PublicForward>? forwards, String? nextOffset}) PublicForwards

Available on PublicForwards, provided by the PublicForwardsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PublicForwards?

Constants

constructor → const String