isCurrentQueryFree property
isCurrentQueryFree True, if the search for the specified query isn't charged
Implementation
final bool isCurrentQueryFree;
isCurrentQueryFree True, if the search for the specified query isn't charged
final bool isCurrentQueryFree;