nextFreeQueryIn property
nextFreeQueryIn Amount of time till the next free query can be sent; 0 if it can be sent now
Implementation
final int nextFreeQueryIn;
nextFreeQueryIn Amount of time till the next free query can be sent; 0 if it can be sent now
final int nextFreeQueryIn;