asPremiumAccount property
asPremiumAccount True, if the user joined Telegram as a Telegram Premium account
Implementation
final bool asPremiumAccount;
asPremiumAccount True, if the user joined Telegram as a Telegram Premium account
final bool asPremiumAccount;