isPrepaidUpgrade property
isPrepaidUpgrade True, if the message is about prepaid upgrade of the gift by another user instead of actual receiving of a new gift
Implementation
final bool isPrepaidUpgrade;
isPrepaidUpgrade True, if the message is about prepaid upgrade of the gift by another user instead of actual receiving of a new gift
final bool isPrepaidUpgrade;