isCurrentUser property
isCurrentUser True, if the current user was invited to the video chat or the live stream
Implementation
final bool isCurrentUser;
isCurrentUser True, if the current user was invited to the video chat or the live stream
final bool isCurrentUser;