monthCount property
monthCount Number of months the Telegram Premium subscription will be active after code activation
Implementation
final int monthCount;
monthCount Number of months the Telegram Premium subscription will be active after code activation
final int monthCount;