isUpgrade property

bool isUpgrade
final

isUpgrade True, if the gift was obtained by upgrading of a previously received gift; otherwise, if is_prepaid_upgrade == false, then this is a transferred or resold gift

Implementation

final bool isUpgrade;