PushReceiverId class final

Contains a globally unique push receiver identifier, which can be used to identify which account has received a push notification

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PushReceiverId({required int id})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id The globally unique identifier of push notification subscription
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id}) PushReceiverId

Available on PushReceiverId, provided by the PushReceiverIdExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PushReceiverId?

Constants

constructor → const String