QuickReplyMessage class final
Describes a message that can be used for quick reply
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- QuickReplyMessage({required int id, MessageSendingState? sendingState, required bool canBeEdited, required int replyToMessageId, required int viaBotUserId, required int mediaAlbumId, MessageContent? content, ReplyMarkup? replyMarkup})
Properties
- canBeEdited → bool
-
canBeEdited True, if the message can be edited
final
- content → MessageContent?
-
content Content of the message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique message identifier among all quick replies
final
- mediaAlbumId → int
-
mediaAlbumId Unique identifier of an album this message belongs to; 0 if
none. Only audios, documents, photos and videos can be grouped together in
albums
final
- replyMarkup → ReplyMarkup?
-
replyMarkup Inline keyboard reply markup for the message; may be null if
none
final
- replyToMessageId → int
-
replyToMessageId The identifier of the quick reply message to which the
message replies; 0 if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendingState → MessageSendingState?
-
sendingState The sending state of the message; may be null if the
message isn't being sent and didn't fail to be sent
final
- viaBotUserId → int
-
viaBotUserId If non-zero, the user identifier of the bot through which
this message was sent
final
Methods
-
copyWith(
{int? id, MessageSendingState? sendingState, bool? canBeEdited, int? replyToMessageId, int? viaBotUserId, int? mediaAlbumId, MessageContent? content, ReplyMarkup? replyMarkup}) → QuickReplyMessage -
Available on QuickReplyMessage, provided by the QuickReplyMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → QuickReplyMessage?
Constants
- constructor → const String