replyToMessageId property
replyToMessageId The identifier of the quick reply message to which the message replies; 0 if none
Implementation
final int replyToMessageId;
replyToMessageId The identifier of the quick reply message to which the message replies; 0 if none
final int replyToMessageId;