QuickReplyShortcut class final

Describes a shortcut that can be used for a quick reply

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

QuickReplyShortcut({required int id, required String name, QuickReplyMessage? firstMessage, required int messageCount})

Properties

firstMessage → QuickReplyMessage?
firstMessage The first shortcut message
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
id Unique shortcut identifier
final
messageCount → int
messageCount The total number of messages in the shortcut
final
name → String
name The name of the shortcut that can be used to use the shortcut
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name, QuickReplyMessage? firstMessage, int? messageCount}) → QuickReplyShortcut

Available on QuickReplyShortcut, provided by the QuickReplyShortcutExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → QuickReplyShortcut?

Constants

constructor → const String