ReactionNotificationSettings class final

Contains information about notification settings for reactions and poll votes

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReactionNotificationSettings({ReactionNotificationSource? messageReactionSource, ReactionNotificationSource? storyReactionSource, ReactionNotificationSource? pollVoteSource, required int soundId, required bool showPreview})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageReactionSource ReactionNotificationSource?
messageReactionSource Source of message reactions for which notifications are shown
final
pollVoteSource ReactionNotificationSource?
pollVoteSource Source of poll votes for which notifications are shown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPreview bool
showPreview True, if reaction sender and emoji must be displayed in notifications
final
soundId int
soundId Identifier of the notification sound to be played; 0 if sound is disabled; pass -1 to use the app-dependent default sound
final
storyReactionSource ReactionNotificationSource?
storyReactionSource Source of story reactions for which notifications are shown
final

Methods

copyWith({ReactionNotificationSource? messageReactionSource, ReactionNotificationSource? storyReactionSource, ReactionNotificationSource? pollVoteSource, int? soundId, bool? showPreview}) ReactionNotificationSettings

Available on ReactionNotificationSettings, provided by the ReactionNotificationSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ReactionNotificationSettings?

Constants

constructor → const String