pollVoteSource property
pollVoteSource Source of poll votes for which notifications are shown
Implementation
final ReactionNotificationSource? pollVoteSource;
pollVoteSource Source of poll votes for which notifications are shown
final ReactionNotificationSource? pollVoteSource;