storyReactionSource property
storyReactionSource Source of story reactions for which notifications are shown
Implementation
final ReactionNotificationSource? storyReactionSource;
storyReactionSource Source of story reactions for which notifications are shown
final ReactionNotificationSource? storyReactionSource;