ReactionNotificationSource class sealed

Describes sources of reactions for which notifications will be shown

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult all(ReactionNotificationSourceAll value), required TResult contacts(ReactionNotificationSourceContacts value), required TResult none(ReactionNotificationSourceNone value)}) → TResult

Available on ReactionNotificationSource, provided by the ReactionNotificationSourceExtensions extension

maybeMap<TResult extends Object?>({TResult all(ReactionNotificationSourceAll value)?, TResult contacts(ReactionNotificationSourceContacts value)?, TResult none(ReactionNotificationSourceNone value)?, required TResult orElse()}) → TResult

Available on ReactionNotificationSource, provided by the ReactionNotificationSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String