ReactionTypeEmoji class final

A reaction with an emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReactionTypeEmoji({required String emoji})

Properties

emoji String
emoji Text representation of the reaction
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emoji}) ReactionTypeEmoji

Available on ReactionTypeEmoji, provided by the ReactionTypeEmojiExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(ReactionTypeCustomEmoji value), required TResult emoji(ReactionTypeEmoji value), required TResult paid(ReactionTypePaid value)}) → TResult

Available on ReactionType, provided by the ReactionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(ReactionTypeCustomEmoji value)?, TResult emoji(ReactionTypeEmoji value)?, TResult paid(ReactionTypePaid value)?, required TResult orElse()}) → TResult

Available on ReactionType, provided by the ReactionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ReactionTypeEmoji?
Inherited by: ReactionTypeCustomEmoji ReactionTypeEmoji ReactionTypePaid
override

Constants

constructor → const String