ReactionUnavailabilityReason class sealed

Describes why the current user can't add reactions to the message, despite some other users can

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult anonymousAdministrator(ReactionUnavailabilityReasonAnonymousAdministrator value), required TResult guest(ReactionUnavailabilityReasonGuest value), required TResult restricted(ReactionUnavailabilityReasonRestricted value)}) → TResult

Available on ReactionUnavailabilityReason, provided by the ReactionUnavailabilityReasonExtensions extension

maybeMap<TResult extends Object?>({TResult anonymousAdministrator(ReactionUnavailabilityReasonAnonymousAdministrator value)?, TResult guest(ReactionUnavailabilityReasonGuest value)?, TResult restricted(ReactionUnavailabilityReasonRestricted value)?, required TResult orElse()}) → TResult

Available on ReactionUnavailabilityReason, provided by the ReactionUnavailabilityReasonExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String