ReadAllDirectMessagesChatTopicReactions class final
Removes all unread reactions in the topic in a channel direct messages chat administered by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReadAllDirectMessagesChatTopicReactions
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReadAllDirectMessagesChatTopicReactions({required int chatId, required int topicId})
Properties
Methods
-
copyWith(
{int? chatId, int? topicId}) → ReadAllDirectMessagesChatTopicReactions -
Available on ReadAllDirectMessagesChatTopicReactions, provided by the ReadAllDirectMessagesChatTopicReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String