ReadAllForumTopicMentions class final

Marks all mentions in a topic in a forum supergroup chat as read Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReadAllForumTopicMentions({required int chatId, required int forumTopicId})

Properties

chatId int
chatId Chat identifier
final
forumTopicId int
forumTopicId Forum topic identifier in which mentions are marked as read
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId}) ReadAllForumTopicMentions

Available on ReadAllForumTopicMentions, provided by the ReadAllForumTopicMentionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String