ReadAllForumTopicPollVotes class final
Marks all poll votes in a topic in a forum supergroup chat as read Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReadAllForumTopicPollVotes
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReadAllForumTopicPollVotes({required int chatId, required int forumTopicId})
Properties
- chatId → int
-
chatId Chat identifier
final
- forumTopicId → int
-
forumTopicId Forum topic identifier in which poll votes are marked as
read
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId}) → ReadAllForumTopicPollVotes -
Available on ReadAllForumTopicPollVotes, provided by the ReadAllForumTopicPollVotesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String