ReadBusinessMessage class final

Reads a message on behalf of a business account; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReadBusinessMessage({required String businessConnectionId, required int chatId, required int messageId})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection through which the message was received
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId}) ReadBusinessMessage

Available on ReadBusinessMessage, provided by the ReadBusinessMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String