ReadDatePrivacySettings class final

Contains privacy settings for message read date in private chats. Read dates are always shown to the users that can see online status of the current user regardless of this setting

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReadDatePrivacySettings({required bool showReadDate})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showReadDate bool
showReadDate True, if message read date is shown to other users in private chats. If false and the current user isn't a Telegram Premium user, then they will not be able to see other's message read date
final

Methods

copyWith({bool? showReadDate}) ReadDatePrivacySettings

Available on ReadDatePrivacySettings, provided by the ReadDatePrivacySettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ReadDatePrivacySettings?

Constants

constructor → const String