ReaddQuickReplyShortcutMessages class final

Re-adds quick reply messages which failed to add. Can be called only for messages for which messageSendingStateFailed.can_retry is true and after specified in messageSendingStateFailed.retry_after time passed. If a message is re-added, the corresponding failed to send message is deleted. Returns the sent messages in the same order as the message identifiers passed in message_ids. If a message can't be readded, null will be returned instead of the message Returns QuickReplyMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReaddQuickReplyShortcutMessages({required String shortcutName, required List<int> messageIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Identifiers of the quick reply messages to re-add. Message identifiers must be in a strictly increasing order
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcutName String
shortcutName Name of the target shortcut
final

Methods

copyWith({String? shortcutName, List<int>? messageIds}) ReaddQuickReplyShortcutMessages

Available on ReaddQuickReplyShortcutMessages, provided by the ReaddQuickReplyShortcutMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String