messageIds property

List<int> messageIds
final

messageIds Identifiers of the quick reply messages to re-add. Message identifiers must be in a strictly increasing order

Implementation

final List<int> messageIds;