canBeTransferred property
canBeTransferred True, if the gift is an upgraded gift that can be transferred to another owner; only for the receiver of the gift
Implementation
final bool canBeTransferred;
canBeTransferred True, if the gift is an upgraded gift that can be transferred to another owner; only for the receiver of the gift
final bool canBeTransferred;