canBeUpgraded property
canBeUpgraded True, if the gift is a regular gift that can be upgraded to a unique gift; only for the receiver of the gift
Implementation
final bool canBeUpgraded;
canBeUpgraded True, if the gift is a regular gift that can be upgraded to a unique gift; only for the receiver of the gift
final bool canBeUpgraded;