collectionIds property
collectionIds Identifiers of collections to which the gift is added; only for the receiver of the gift
Implementation
final List<int> collectionIds;
collectionIds Identifiers of collections to which the gift is added; only for the receiver of the gift
final List<int> collectionIds;