isUpgradeSeparate property

bool isUpgradeSeparate
final

isUpgradeSeparate True, if the upgrade was bought after the gift was sent. In this case, prepaid upgrade cost must not be added to the gift cost

Implementation

final bool isUpgradeSeparate;