prepaidUpgradeStarCount property

int prepaidUpgradeStarCount
final

prepaidUpgradeStarCount Number of Telegram Stars that were paid by the sender for the ability to upgrade the gift

Implementation

final int prepaidUpgradeStarCount;