transferStarCount property
transferStarCount Number of Telegram Stars that must be paid to transfer the upgraded gift; only for the receiver of the gift
Implementation
final int transferStarCount;
transferStarCount Number of Telegram Stars that must be paid to transfer the upgraded gift; only for the receiver of the gift
final int transferStarCount;