ReceivedGifts class final

Represents a list of gifts received by a user or a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReceivedGifts({required int totalCount, required List<ReceivedGift> gifts, required bool areNotificationsEnabled, required String nextOffset})

Properties

areNotificationsEnabled bool
areNotificationsEnabled True, if notifications about new gifts of the owner are enabled
final
gifts List<ReceivedGift>
gifts The list of gifts
final
hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount The total number of received gifts
final

Methods

copyWith({int? totalCount, List<ReceivedGift>? gifts, bool? areNotificationsEnabled, String? nextOffset}) ReceivedGifts

Available on ReceivedGifts, provided by the ReceivedGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ReceivedGifts?

Constants

constructor → const String