RecognizeSpeech class final

Recognizes speech in a video note or a voice note message Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RecognizeSpeech({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message. Use messageProperties.can_recognize_speech to check whether the message is suitable
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) RecognizeSpeech

Available on RecognizeSpeech, provided by the RecognizeSpeechExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String