RecommendedChatFolders class final

Contains a list of recommended chat folders

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RecommendedChatFolders({required List<RecommendedChatFolder> chatFolders})

Properties

chatFolders List<RecommendedChatFolder>
chatFolders List of recommended chat folders
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<RecommendedChatFolder>? chatFolders}) RecommendedChatFolders

Available on RecommendedChatFolders, provided by the RecommendedChatFoldersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) RecommendedChatFolders?

Constants

constructor → const String