RecoverPassword class final
Recovers the 2-step verification password using a recovery code sent to an email address that was previously set up Returns PasswordState
- Inheritance
-
- Object
- TdFunction
- RecoverPassword
- Available extensions
- Annotations
-
- @immutable
Constructors
- RecoverPassword({required String recoveryCode, required String newPassword, required String newHint})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- newHint → String
-
newHint New password hint; may be empty
final
- newPassword → String
-
newPassword New 2-step verification password of the user; may be empty
to remove the password
final
- recoveryCode → String
-
recoveryCode Recovery code to check
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? recoveryCode, String? newPassword, String? newHint}) → RecoverPassword -
Available on RecoverPassword, provided by the RecoverPasswordExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String