RecoveryEmailAddress class final
Contains information about the current recovery email address
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- RecoveryEmailAddress({required String recoveryEmailAddress})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- recoveryEmailAddress → String
-
recoveryEmailAddress Recovery email address
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? recoveryEmailAddress}) → RecoveryEmailAddress -
Available on RecoveryEmailAddress, provided by the RecoveryEmailAddressExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RecoveryEmailAddress?
Constants
- constructor → const String