RefundStarPayment class final

Refunds a previously done payment in Telegram Stars; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RefundStarPayment({required int userId, required String telegramPaymentChargeId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
telegramPaymentChargeId String
telegramPaymentChargeId Telegram payment identifier
final
userId int
userId Identifier of the user who did the payment
final

Methods

copyWith({int? userId, String? telegramPaymentChargeId}) RefundStarPayment

Available on RefundStarPayment, provided by the RefundStarPaymentExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String