RegisterDevice class final

Registers the currently used device for receiving push notifications. Returns a globally unique identifier of the push notification subscription Returns PushReceiverId

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RegisterDevice({DeviceToken? deviceToken, required List<int> otherUserIds})

Properties

deviceToken DeviceToken?
deviceToken Device token
final
hashCode int
The hash code for this object.
no setteroverride
otherUserIds List<int>
otherUserIds List of user identifiers of other users currently using the application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({DeviceToken? deviceToken, List<int>? otherUserIds}) RegisterDevice

Available on RegisterDevice, provided by the RegisterDeviceExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String