disableNotification property

bool disableNotification
final

disableNotification Pass true to disable notification about the current user joining Telegram for other users that added them to contact list

Implementation

final bool disableNotification;