RemoteFile class final
Represents a remote file
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Remote file identifier; may be empty. Can be used by the current user
across application restarts or even from other devices. Uniquely
identifies a file, but a file can have a lot of different valid
identifiers. If the identifier starts with "http://" or "https://", it
represents the HTTP URL of the file. TDLib is currently unable to download
files if only their URL is known. If downloadFile/addFileToDownloads is
called on such a file or if it is sent to a secret chat, TDLib starts a
file generation process by sending updateFileGenerationStart to the
application with the HTTP URL in the original_path and "#url#" as the
conversion string. Application must generate the file by downloading it to
the specified location
final
- isUploadingActive → bool
-
isUploadingActive True, if the file is currently being uploaded (or a
remote copy is being generated by some other means)
final
- isUploadingCompleted → bool
-
isUploadingCompleted True, if a remote copy is fully available
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uniqueId → String
-
uniqueId Unique file identifier; may be empty if unknown. The unique
file identifier which is the same for the same file even for different
users and is persistent over time
final
- uploadedSize → int
-
uploadedSize Size of the remote available part of the file, in bytes; 0
if unknown
final
Methods
-
copyWith(
{String? id, String? uniqueId, bool? isUploadingActive, bool? isUploadingCompleted, int? uploadedSize}) → RemoteFile -
Available on RemoteFile, provided by the RemoteFileExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RemoteFile?
Constants
- constructor → const String