RemoveAllFilesFromDownloads class final

Removes all files from the file download list Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveAllFilesFromDownloads({required bool onlyActive, required bool onlyCompleted, required bool deleteFromCache})

Properties

deleteFromCache bool
deleteFromCache Pass true to delete the file from the TDLib file cache
final
hashCode int
The hash code for this object.
no setteroverride
onlyActive bool
onlyActive Pass true to remove only active downloads, including paused
final
onlyCompleted bool
onlyCompleted Pass true to remove only completed downloads
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? onlyActive, bool? onlyCompleted, bool? deleteFromCache}) RemoveAllFilesFromDownloads

Available on RemoveAllFilesFromDownloads, provided by the RemoveAllFilesFromDownloadsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String