RemoveBusinessConnectedBotFromChat class final
Removes the connected business bot from a specific chat by adding the chat to businessRecipients.excluded_chat_ids Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveBusinessConnectedBotFromChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveBusinessConnectedBotFromChat({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → RemoveBusinessConnectedBotFromChat -
Available on RemoveBusinessConnectedBotFromChat, provided by the RemoveBusinessConnectedBotFromChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String