RemoveChatActionBar class final

Removes a chat action bar without any other action Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveChatActionBar({required int chatId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) RemoveChatActionBar

Available on RemoveChatActionBar, provided by the RemoveChatActionBarExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String