RemoveContacts class final

Removes users from the contact list Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveContacts({required List<int> userIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<int>
userIds Identifiers of users to be deleted
final

Methods

copyWith({List<int>? userIds}) RemoveContacts

Available on RemoveContacts, provided by the RemoveContactsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String