RemoveFavoriteSticker class final

Removes a sticker from the list of favorite stickers Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveFavoriteSticker({InputFile? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker Sticker file to delete from the list
final

Methods

copyWith({InputFile? sticker}) RemoveFavoriteSticker

Available on RemoveFavoriteSticker, provided by the RemoveFavoriteStickerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String