RemoveFileFromDownloads class final

Removes a file from the file download list Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveFileFromDownloads({required int fileId, required bool deleteFromCache})

Properties

deleteFromCache bool
deleteFromCache Pass true to delete the file from the TDLib file cache
final
fileId int
fileId Identifier of the downloaded file
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, bool? deleteFromCache}) RemoveFileFromDownloads

Available on RemoveFileFromDownloads, provided by the RemoveFileFromDownloadsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String