receivedGiftIds property
receivedGiftIds Identifier of the gifts to remove from the collection
Implementation
final List<String> receivedGiftIds;
receivedGiftIds Identifier of the gifts to remove from the collection
final List<String> receivedGiftIds;