RemoveMessageReaction class final

Removes a reaction from a message. A chosen reaction can always be removed Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveMessageReaction({required int chatId, required int messageId, ReactionType? reactionType})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
reactionType ReactionType?
reactionType Type of the reaction to remove. The paid reaction can't be removed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, ReactionType? reactionType}) RemoveMessageReaction

Available on RemoveMessageReaction, provided by the RemoveMessageReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String