verifiedId property
verifiedId Identifier of the user or the supergroup or channel chat, which verification is removed
Implementation
final MessageSender? verifiedId;
verifiedId Identifier of the user or the supergroup or channel chat, which verification is removed
final MessageSender? verifiedId;