RemoveNotification class final

Removes an active notification from notification list. Needs to be called only if the notification is removed by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveNotification({required int notificationGroupId, required int notificationId})

Properties

hashCode int
The hash code for this object.
no setteroverride
notificationGroupId int
notificationGroupId Identifier of notification group to which the notification belongs
final
notificationId int
notificationId Identifier of removed notification
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationGroupId, int? notificationId}) RemoveNotification

Available on RemoveNotification, provided by the RemoveNotificationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String