RemovePendingPaidMessageReactions class final

Removes all pending paid reactions on a message Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemovePendingPaidMessageReactions({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) RemovePendingPaidMessageReactions

Available on RemovePendingPaidMessageReactions, provided by the RemovePendingPaidMessageReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String