RemoveProfileAudio class final
Removes an audio file from the profile audio files of the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveProfileAudio
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveProfileAudio({required int fileId})
Properties
Methods
-
copyWith(
{int? fileId}) → RemoveProfileAudio -
Available on RemoveProfileAudio, provided by the RemoveProfileAudioExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String