RemoveRecentHashtag class final

Removes a hashtag from the list of recently used hashtags Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveRecentHashtag({required String hashtag})

Properties

hashCode int
The hash code for this object.
no setteroverride
hashtag String
hashtag Hashtag to delete
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? hashtag}) RemoveRecentHashtag

Available on RemoveRecentHashtag, provided by the RemoveRecentHashtagExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String