RemoveRecentSticker class final

Removes a sticker from the list of recently used stickers Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveRecentSticker({required bool isAttached, InputFile? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
isAttached bool
isAttached Pass true to remove the sticker from the list of stickers recently attached to photo or video files; pass false to remove the sticker from the list of recently sent stickers
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker Sticker file to delete
final

Methods

copyWith({bool? isAttached, InputFile? sticker}) RemoveRecentSticker

Available on RemoveRecentSticker, provided by the RemoveRecentStickerExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String