RemoveRecentlyFoundChat class final

Removes a chat from the list of recently found chats Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveRecentlyFoundChat({required int chatId})

Properties

chatId int
chatId Identifier of the chat to be removed
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) RemoveRecentlyFoundChat

Available on RemoveRecentlyFoundChat, provided by the RemoveRecentlyFoundChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String