RemoveSavedAnimation class final

Removes an animation from the list of saved animations Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveSavedAnimation({InputFile? animation})

Properties

animation InputFile?
animation Animation file to be removed
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputFile? animation}) RemoveSavedAnimation

Available on RemoveSavedAnimation, provided by the RemoveSavedAnimationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String