RemoveSearchedForTag class final
Removes a hashtag or a cashtag from the list of recently searched for hashtags or cashtags Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveSearchedForTag
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveSearchedForTag({required String tag})
Properties
Methods
-
copyWith(
{String? tag}) → RemoveSearchedForTag -
Available on RemoveSearchedForTag, provided by the RemoveSearchedForTagExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String