RemoveStickerFromSet class final
Removes a sticker from the set to which it belongs. The sticker set must be owned by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveStickerFromSet
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveStickerFromSet({InputFile? sticker})
Properties
Methods
-
copyWith(
{InputFile? sticker}) → RemoveStickerFromSet -
Available on RemoveStickerFromSet, provided by the RemoveStickerFromSetExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String