RemoveTopChat class final

Removes a chat from the list of frequently used chats. Supported only if the chat info database is enabled Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveTopChat({TopChatCategory? category, required int chatId})

Properties

category TopChatCategory?
category Category of frequently used chats
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TopChatCategory? category, int? chatId}) RemoveTopChat

Available on RemoveTopChat, provided by the RemoveTopChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String