RemoveWebBrowserSettingsException class final
Removes a special handling for the opening of the specified URL Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveWebBrowserSettingsException
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveWebBrowserSettingsException({required String url})
Properties
Methods
-
copyWith(
{String? url}) → RemoveWebBrowserSettingsException -
Available on RemoveWebBrowserSettingsException, provided by the RemoveWebBrowserSettingsExceptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String