ReorderBotActiveUsernames class final

Changes order of active usernames of a bot. Can be called only if userTypeBot.can_be_edited == true Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReorderBotActiveUsernames({required int botUserId, required List<String> usernames})

Properties

botUserId int
botUserId Identifier of the target bot
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usernames List<String>
usernames The new order of active usernames. All currently active usernames must be specified
final

Methods

copyWith({int? botUserId, List<String>? usernames}) ReorderBotActiveUsernames

Available on ReorderBotActiveUsernames, provided by the ReorderBotActiveUsernamesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String