ReorderGiftCollectionGifts class final

Changes order of gifts in a collection. If the collection is owned by a channel chat, then requires can_post_messages administrator right in the channel chat. Returns the changed collection Returns GiftCollection

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReorderGiftCollectionGifts({MessageSender? ownerId, required int collectionId, required List<String> receivedGiftIds})

Properties

collectionId int
collectionId Identifier of the gift collection
final
hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that owns the collection
final
receivedGiftIds List<String>
receivedGiftIds Identifier of the gifts to move to the beginning of the collection. All other gifts are placed in the current order after the specified gifts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, int? collectionId, List<String>? receivedGiftIds}) ReorderGiftCollectionGifts

Available on ReorderGiftCollectionGifts, provided by the ReorderGiftCollectionGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String