receivedGiftIds property

List<String> receivedGiftIds
final

receivedGiftIds Identifier of the gifts to move to the beginning of the collection. All other gifts are placed in the current order after the specified gifts

Implementation

final List<String> receivedGiftIds;