ReorderInstalledStickerSets class final

Changes the order of installed sticker sets Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReorderInstalledStickerSets({StickerType? stickerType, required List<int> stickerSetIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerSetIds List<int>
stickerSetIds Identifiers of installed sticker sets in the new correct order
final
stickerType StickerType?
stickerType Type of the sticker sets to reorder
final

Methods

copyWith({StickerType? stickerType, List<int>? stickerSetIds}) ReorderInstalledStickerSets

Available on ReorderInstalledStickerSets, provided by the ReorderInstalledStickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String