ReorderSupergroupActiveUsernames class final

Changes order of active usernames of a supergroup or channel, requires owner privileges in the supergroup or channel Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReorderSupergroupActiveUsernames({required int supergroupId, required List<String> usernames})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup or channel
final
usernames List<String>
usernames The new order of active usernames. All currently active usernames must be specified
final

Methods

copyWith({int? supergroupId, List<String>? usernames}) ReorderSupergroupActiveUsernames

Available on ReorderSupergroupActiveUsernames, provided by the ReorderSupergroupActiveUsernamesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String