ReplacePrimaryChatInviteLink class final
Replaces current primary invite link for a chat with a new primary invite link. Available for basic groups, supergroups, and channels. Requires administrator privileges and can_invite_users right Returns ChatInviteLink
- Inheritance
-
- Object
- TdFunction
- ReplacePrimaryChatInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReplacePrimaryChatInviteLink({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → ReplacePrimaryChatInviteLink -
Available on ReplacePrimaryChatInviteLink, provided by the ReplacePrimaryChatInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String