ReplaceStickerInSet class final
Replaces existing sticker in a set. The function is equivalent to removeStickerFromSet, then addStickerToSet, then setStickerPositionInSet Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReplaceStickerInSet
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReplaceStickerInSet({required int userId, required String name, InputFile? oldSticker, NewSticker? newSticker})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Sticker set name. The sticker set must be owned by the current user
final
- newSticker → NewSticker?
-
newSticker Sticker to add to the set
final
- oldSticker → InputFile?
-
oldSticker Sticker to remove from the set
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Sticker set owner; ignored for regular users
final
Methods
-
copyWith(
{int? userId, String? name, InputFile? oldSticker, NewSticker? newSticker}) → ReplaceStickerInSet -
Available on ReplaceStickerInSet, provided by the ReplaceStickerInSetExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String