ReplaceVideoChatRtmpUrl class final
Replaces the current RTMP URL for streaming to the video chat of a chat; requires owner privileges in the chat Returns RtmpUrl
- Inheritance
-
- Object
- TdFunction
- ReplaceVideoChatRtmpUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReplaceVideoChatRtmpUrl({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → ReplaceVideoChatRtmpUrl -
Available on ReplaceVideoChatRtmpUrl, provided by the ReplaceVideoChatRtmpUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String