ReplyMarkup class sealed

Contains a description of a custom keyboard and actions that can be done with it to quickly reply to bots

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult forceReply(ReplyMarkupForceReply value), required TResult inlineKeyboard(ReplyMarkupInlineKeyboard value), required TResult removeKeyboard(ReplyMarkupRemoveKeyboard value), required TResult showKeyboard(ReplyMarkupShowKeyboard value)}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

maybeMap<TResult extends Object?>({TResult forceReply(ReplyMarkupForceReply value)?, TResult inlineKeyboard(ReplyMarkupInlineKeyboard value)?, TResult removeKeyboard(ReplyMarkupRemoveKeyboard value)?, TResult showKeyboard(ReplyMarkupShowKeyboard value)?, required TResult orElse()}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String