ReplyMarkupInlineKeyboard class final

Contains an inline keyboard layout

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReplyMarkupInlineKeyboard({required List<List<InlineKeyboardButton>> rows})

Properties

hashCode int
The hash code for this object.
no setteroverride
rows List<List<InlineKeyboardButton>>
rows A list of rows of inline keyboard buttons
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<List<InlineKeyboardButton>>? rows}) ReplyMarkupInlineKeyboard

Available on ReplyMarkupInlineKeyboard, provided by the ReplyMarkupInlineKeyboardExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forceReply(ReplyMarkupForceReply value), required TResult inlineKeyboard(ReplyMarkupInlineKeyboard value), required TResult removeKeyboard(ReplyMarkupRemoveKeyboard value), required TResult showKeyboard(ReplyMarkupShowKeyboard value)}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

maybeMap<TResult extends Object?>({TResult forceReply(ReplyMarkupForceReply value)?, TResult inlineKeyboard(ReplyMarkupInlineKeyboard value)?, TResult removeKeyboard(ReplyMarkupRemoveKeyboard value)?, TResult showKeyboard(ReplyMarkupShowKeyboard value)?, required TResult orElse()}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String