ReplyMarkupRemoveKeyboard class final

Instructs application to remove the keyboard once this message has been received. This kind of keyboard can't be received in an incoming message; instead, updateChatReplyMarkup with reply_markup_message == null will be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReplyMarkupRemoveKeyboard({required bool isPersonal})

Properties

hashCode int
The hash code for this object.
no setteroverride
isPersonal bool
isPersonal True, if the keyboard is removed only for the mentioned users or the target user of a reply
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isPersonal}) ReplyMarkupRemoveKeyboard

Available on ReplyMarkupRemoveKeyboard, provided by the ReplyMarkupRemoveKeyboardExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forceReply(ReplyMarkupForceReply value), required TResult inlineKeyboard(ReplyMarkupInlineKeyboard value), required TResult removeKeyboard(ReplyMarkupRemoveKeyboard value), required TResult showKeyboard(ReplyMarkupShowKeyboard value)}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

maybeMap<TResult extends Object?>({TResult forceReply(ReplyMarkupForceReply value)?, TResult inlineKeyboard(ReplyMarkupInlineKeyboard value)?, TResult removeKeyboard(ReplyMarkupRemoveKeyboard value)?, TResult showKeyboard(ReplyMarkupShowKeyboard value)?, required TResult orElse()}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String