ReportChat class final

Reports a chat to the Telegram moderators. A chat can be reported only from the chat action bar, or if chat.can_be_reported Returns ReportChatResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportChat({required int chatId, required String optionId, required List<int> messageIds, required String text})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Identifiers of reported messages. Use messageProperties.can_report_chat to check whether the message can be reported
final
optionId String
optionId Option identifier chosen by the user; leave empty for the initial request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text Additional report details if asked by the server; 0-1024 characters; leave empty for the initial request
final

Methods

copyWith({int? chatId, String? optionId, List<int>? messageIds, String? text}) ReportChat

Available on ReportChat, provided by the ReportChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String