messageIds property
messageIds Identifiers of reported messages. Use messageProperties.can_report_chat to check whether the message can be reported
Implementation
final List<int> messageIds;
messageIds Identifiers of reported messages. Use messageProperties.can_report_chat to check whether the message can be reported
final List<int> messageIds;