ReportChatResultTextRequired class final

The user must add additional text details to the report

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportChatResultTextRequired({required String optionId, bool? isOptional})

Properties

hashCode int
The hash code for this object.
no setteroverride
isOptional bool?
isOptional True, if the user can skip text adding
final
optionId String
optionId Option identifier for the next reportChat request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? optionId, bool? isOptional}) ReportChatResultTextRequired

Available on ReportChatResultTextRequired, provided by the ReportChatResultTextRequiredExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult messagesRequired(ReportChatResultMessagesRequired value), required TResult ok(ReportChatResultOk value), required TResult optionRequired(ReportChatResultOptionRequired value), required TResult textRequired(ReportChatResultTextRequired value)}) → TResult

Available on ReportChatResult, provided by the ReportChatResultExtensions extension

maybeMap<TResult extends Object?>({TResult messagesRequired(ReportChatResultMessagesRequired value)?, TResult ok(ReportChatResultOk value)?, TResult optionRequired(ReportChatResultOptionRequired value)?, TResult textRequired(ReportChatResultTextRequired value)?, required TResult orElse()}) → TResult

Available on ReportChatResult, provided by the ReportChatResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String