ReportChatSponsoredMessage class final

Reports a sponsored message to Telegram moderators Returns ReportSponsoredResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportChatSponsoredMessage({required int chatId, required int messageId, required String optionId})

Properties

chatId int
chatId Chat identifier of the sponsored message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the sponsored message
final
optionId String
optionId Option identifier chosen by the user; leave empty for the initial request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, String? optionId}) ReportChatSponsoredMessage

Available on ReportChatSponsoredMessage, provided by the ReportChatSponsoredMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String