ReportMessageReactions class final
Reports reactions set on a message to the Telegram moderators. Reactions on a message can be reported only if messageProperties.can_report_reactions Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReportMessageReactions
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReportMessageReactions({required int chatId, required int messageId, MessageSender? senderId})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Message identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the sender, which added the reaction
final
Methods
-
copyWith(
{int? chatId, int? messageId, MessageSender? senderId}) → ReportMessageReactions -
Available on ReportMessageReactions, provided by the ReportMessageReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String