ReportOption class final

Describes an option to report an entity to Telegram

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportOption({required String id, required String text})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the option
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text Text of the option
final

Methods

copyWith({String? id, String? text}) ReportOption

Available on ReportOption, provided by the ReportOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ReportOption?

Constants

constructor → const String