ReportPhoneNumberCodeMissing class final

Reports that authentication code wasn't delivered via SMS to the specified phone number; for official mobile applications only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportPhoneNumberCodeMissing({required String mobileNetworkCode})

Properties

hashCode int
The hash code for this object.
no setteroverride
mobileNetworkCode String
mobileNetworkCode Current mobile network code
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? mobileNetworkCode}) ReportPhoneNumberCodeMissing

Available on ReportPhoneNumberCodeMissing, provided by the ReportPhoneNumberCodeMissingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String