ReportReasonUnrelatedLocation class final

The location-based chat is unrelated to its stated location

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportReasonUnrelatedLocation()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult childAbuse(ReportReasonChildAbuse value), required TResult copyright(ReportReasonCopyright value), required TResult custom(ReportReasonCustom value), required TResult fake(ReportReasonFake value), required TResult illegalDrugs(ReportReasonIllegalDrugs value), required TResult personalDetails(ReportReasonPersonalDetails value), required TResult pornography(ReportReasonPornography value), required TResult spam(ReportReasonSpam value), required TResult unrelatedLocation(ReportReasonUnrelatedLocation value), required TResult violence(ReportReasonViolence value)}) → TResult

Available on ReportReason, provided by the ReportReasonExtensions extension

maybeMap<TResult extends Object?>({TResult childAbuse(ReportReasonChildAbuse value)?, TResult copyright(ReportReasonCopyright value)?, TResult custom(ReportReasonCustom value)?, TResult fake(ReportReasonFake value)?, TResult illegalDrugs(ReportReasonIllegalDrugs value)?, TResult personalDetails(ReportReasonPersonalDetails value)?, TResult pornography(ReportReasonPornography value)?, TResult spam(ReportReasonSpam value)?, TResult unrelatedLocation(ReportReasonUnrelatedLocation value)?, TResult violence(ReportReasonViolence value)?, required TResult orElse()}) → TResult

Available on ReportReason, provided by the ReportReasonExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String