ReportSponsoredChat class final

Reports a sponsored chat to Telegram moderators Returns ReportSponsoredResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportSponsoredChat({required int sponsoredChatUniqueId, required String optionId})

Properties

hashCode int
The hash code for this object.
no setteroverride
optionId String
optionId Option identifier chosen by the user; leave empty for the initial request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sponsoredChatUniqueId int
sponsoredChatUniqueId Unique identifier of the sponsored chat
final

Methods

copyWith({int? sponsoredChatUniqueId, String? optionId}) ReportSponsoredChat

Available on ReportSponsoredChat, provided by the ReportSponsoredChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String