ReportStory class final

Reports a story to the Telegram moderators Returns ReportStoryResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportStory({required int storyPosterChatId, required int storyId, required String optionId, required String text})

Properties

hashCode int
The hash code for this object.
no setteroverride
optionId String
optionId Option identifier chosen by the user; leave empty for the initial request
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId The identifier of the story to report
final
storyPosterChatId int
storyPosterChatId The identifier of the poster of the story to report
final
text String
text Additional report details; 0-1024 characters; leave empty for the initial request
final

Methods

copyWith({int? storyPosterChatId, int? storyId, String? optionId, String? text}) ReportStory

Available on ReportStory, provided by the ReportStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String