ReportSupergroupAntiSpamFalsePositive class final
Reports a false deletion of a message by aggressive anti-spam checks; requires administrator rights in the supergroup. Can be called only for messages from chatEventMessageDeleted with can_report_anti_spam_false_positive == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReportSupergroupAntiSpamFalsePositive
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReportSupergroupAntiSpamFalsePositive({required int supergroupId, required int messageId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the erroneously deleted message from
chatEventMessageDeleted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId Supergroup identifier
final
Methods
-
copyWith(
{int? supergroupId, int? messageId}) → ReportSupergroupAntiSpamFalsePositive -
Available on ReportSupergroupAntiSpamFalsePositive, provided by the ReportSupergroupAntiSpamFalsePositiveExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String