ReportSupergroupSpam class final

Reports messages in a supergroup as spam; requires administrator rights in the supergroup Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReportSupergroupSpam({required int supergroupId, required List<int> messageIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageIds List<int>
messageIds Identifiers of messages to report. Use messageProperties.can_report_supergroup_spam to check whether the message can be reported
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Supergroup identifier
final

Methods

copyWith({int? supergroupId, List<int>? messageIds}) ReportSupergroupSpam

Available on ReportSupergroupSpam, provided by the ReportSupergroupSpamExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String