messageIds property
messageIds Identifiers of messages to report. Use messageProperties.can_report_supergroup_spam to check whether the message can be reported
Implementation
final List<int> messageIds;
messageIds Identifiers of messages to report. Use messageProperties.can_report_supergroup_spam to check whether the message can be reported
final List<int> messageIds;