ResendCodeReason class sealed

Describes the reason why a code needs to be re-sent

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult userRequest(ResendCodeReasonUserRequest value), required TResult verificationFailed(ResendCodeReasonVerificationFailed value)}) → TResult

Available on ResendCodeReason, provided by the ResendCodeReasonExtensions extension

maybeMap<TResult extends Object?>({TResult userRequest(ResendCodeReasonUserRequest value)?, TResult verificationFailed(ResendCodeReasonVerificationFailed value)?, required TResult orElse()}) → TResult

Available on ResendCodeReason, provided by the ResendCodeReasonExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String