ResendCodeReasonVerificationFailed class final

The code is re-sent, because device verification has failed

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ResendCodeReasonVerificationFailed({required String errorMessage})

Properties

errorMessage String
errorMessage Cause of the verification failure, for example, "PLAY_SERVICES_NOT_AVAILABLE", "APNS_RECEIVE_TIMEOUT", or "APNS_INIT_FAILED"
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? errorMessage}) ResendCodeReasonVerificationFailed

Available on ResendCodeReasonVerificationFailed, provided by the ResendCodeReasonVerificationFailedExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult userRequest(ResendCodeReasonUserRequest value), required TResult verificationFailed(ResendCodeReasonVerificationFailed value)}) → TResult

Available on ResendCodeReason, provided by the ResendCodeReasonExtensions extension

maybeMap<TResult extends Object?>({TResult userRequest(ResendCodeReasonUserRequest value)?, TResult verificationFailed(ResendCodeReasonVerificationFailed value)?, required TResult orElse()}) → TResult

Available on ResendCodeReason, provided by the ResendCodeReasonExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String