ResendMessages class final
Resends messages which failed to send. Can be called only for messages for which messageSendingStateFailed.can_retry is true and after specified in messageSendingStateFailed.retry_after time passed. If a message is re-sent, the corresponding failed to send message is deleted. Returns the sent messages in the same order as the message identifiers passed in message_ids. If a message can't be re-sent, null will be returned instead of the message Returns Messages
- Inheritance
-
- Object
- TdFunction
- ResendMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ResendMessages({required int chatId, required List<
int> messageIds, InputTextQuote? quote, required int paidMessageStarCount})
Properties
- chatId → int
-
chatId Identifier of the chat to send messages
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messageIds
→ List<
int> -
messageIds Identifiers of the messages to resend. Message identifiers
must be in a strictly increasing order
final
- paidMessageStarCount → int
-
paidMessageStarCount The number of Telegram Stars the user agreed to pay
to send the messages. Ignored if
messageSendingStateFailed.required_paid_message_star_count == 0
final
- quote → InputTextQuote?
-
quote New manually chosen quote from the message to be replied; pass
null if none. Ignored if more than one message is re-sent, or if
messageSendingStateFailed.need_another_reply_quote == false
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, List< int> ? messageIds, InputTextQuote? quote, int? paidMessageStarCount}) → ResendMessages -
Available on ResendMessages, provided by the ResendMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String