ResendPhoneNumberCode class final

Resends the authentication code sent to a phone number. Works only if the previously received authenticationCodeInfo next_code_type was not null and the server-specified timeout has passed Returns AuthenticationCodeInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ResendPhoneNumberCode({ResendCodeReason? reason})

Properties

hashCode int
The hash code for this object.
no setteroverride
reason ResendCodeReason?
reason Reason of code resending; pass null if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ResendCodeReason? reason}) ResendPhoneNumberCode

Available on ResendPhoneNumberCode, provided by the ResendPhoneNumberCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String