restrictionReason property

String restrictionReason
final

restrictionReason A human-readable description of the reason why access to the content must be restricted. If empty, then the content can be accessed, but may be covered by hidden with 18+ spoiler anyway

Implementation

final String restrictionReason;