ReuseStarSubscription class final

Reuses an active Telegram Star subscription to a channel chat and joins the chat again Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReuseStarSubscription({required String subscriptionId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId String
subscriptionId Identifier of the subscription
final

Methods

copyWith({String? subscriptionId}) ReuseStarSubscription

Available on ReuseStarSubscription, provided by the ReuseStarSubscriptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String