RevenueWithdrawalStateSucceeded class final

Withdrawal succeeded

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RevenueWithdrawalStateSucceeded({required int date, required String url})

Properties

date int
date Point in time (Unix timestamp) when the withdrawal was completed
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The URL where the withdrawal transaction can be viewed
final

Methods

copyWith({int? date, String? url}) RevenueWithdrawalStateSucceeded

Available on RevenueWithdrawalStateSucceeded, provided by the RevenueWithdrawalStateSucceededExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult failed(RevenueWithdrawalStateFailed value), required TResult pending(RevenueWithdrawalStatePending value), required TResult succeeded(RevenueWithdrawalStateSucceeded value)}) → TResult

Available on RevenueWithdrawalState, provided by the RevenueWithdrawalStateExtensions extension

maybeMap<TResult extends Object?>({TResult failed(RevenueWithdrawalStateFailed value)?, TResult pending(RevenueWithdrawalStatePending value)?, TResult succeeded(RevenueWithdrawalStateSucceeded value)?, required TResult orElse()}) → TResult

Available on RevenueWithdrawalState, provided by the RevenueWithdrawalStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String