RichMessage class final

Describes a message with rich formatting

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RichMessage({required List<PageBlock> blocks, required bool isRtl, required bool isFull})

Properties

blocks List<PageBlock>
blocks Content of the message
final
hashCode int
The hash code for this object.
no setteroverride
isFull bool
isFull True, if the object contains the full message. Otherwise, getFullRichMessage must be used to get the full message
final
isRtl bool
isRtl True, if the message must be shown from right to left
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<PageBlock>? blocks, bool? isRtl, bool? isFull}) RichMessage

Available on RichMessage, provided by the RichMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) RichMessage?

Constants

constructor → const String