RichMessageSourceBlocks class final

A rich message defined by blocks

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RichMessageSourceBlocks({required List<InputPageBlock> blocks})

Properties

blocks List<InputPageBlock>
blocks Content of the message
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<InputPageBlock>? blocks}) RichMessageSourceBlocks

Available on RichMessageSourceBlocks, provided by the RichMessageSourceBlocksExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult blocks(RichMessageSourceBlocks value), required TResult html(RichMessageSourceHtml value), required TResult markdown(RichMessageSourceMarkdown value)}) → TResult

Available on RichMessageSource, provided by the RichMessageSourceExtensions extension

maybeMap<TResult extends Object?>({TResult blocks(RichMessageSourceBlocks value)?, TResult html(RichMessageSourceHtml value)?, TResult markdown(RichMessageSourceMarkdown value)?, required TResult orElse()}) → TResult

Available on RichMessageSource, provided by the RichMessageSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String