RichMessageSourceMarkdown class final

A Markdown-formatted rich message; for bots only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RichMessageSourceMarkdown({required String text, required List<InputRichMessageMedia> media})

Properties

hashCode int
The hash code for this object.
no setteroverride
media List<InputRichMessageMedia>
media Media used in the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text Markdown-formatted text of the message
final

Methods

copyWith({String? text, List<InputRichMessageMedia>? media}) RichMessageSourceMarkdown

Available on RichMessageSourceMarkdown, provided by the RichMessageSourceMarkdownExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult blocks(RichMessageSourceBlocks value), required TResult html(RichMessageSourceHtml value), required TResult markdown(RichMessageSourceMarkdown value)}) → TResult

Available on RichMessageSource, provided by the RichMessageSourceExtensions extension

maybeMap<TResult extends Object?>({TResult blocks(RichMessageSourceBlocks value)?, TResult html(RichMessageSourceHtml value)?, TResult markdown(RichMessageSourceMarkdown value)?, required TResult orElse()}) → TResult

Available on RichMessageSource, provided by the RichMessageSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String