RichTextBotCommand class final
A bot command
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- RichTextBotCommand({RichText? text, required String botCommand})
Properties
- botCommand → String
-
botCommand The bot command
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → RichText?
-
text Text
final
Methods
-
copyWith(
{RichText? text, String? botCommand}) → RichTextBotCommand -
Available on RichTextBotCommand, provided by the RichTextBotCommandExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult anchor(RichTextAnchor value), required TResult anchorLink(RichTextAnchorLink value), required TResult bankCardNumber(RichTextBankCardNumber value), required TResult bold(RichTextBold value), required TResult botCommand(RichTextBotCommand value), required TResult cashtag(RichTextCashtag value), required TResult customEmoji(RichTextCustomEmoji value), required TResult dateTime(RichTextDateTime value), required TResult diff(RichTextDiff value), required TResult emailAddress(RichTextEmailAddress value), required TResult fixed(RichTextFixed value), required TResult hashtag(RichTextHashtag value), required TResult icon(RichTextIcon value), required TResult italic(RichTextItalic value), required TResult marked(RichTextMarked value), required TResult mathematicalExpression(RichTextMathematicalExpression value), required TResult mention(RichTextMention value), required TResult mentionName(RichTextMentionName value), required TResult phoneNumber(RichTextPhoneNumber value), required TResult plain(RichTextPlain value), required TResult reference(RichTextReference value), required TResult referenceLink(RichTextReferenceLink value), required TResult spoiler(RichTextSpoiler value), required TResult strikethrough(RichTextStrikethrough value), required TResult subscript(RichTextSubscript value), required TResult superscript(RichTextSuperscript value), required TResult underline(RichTextUnderline value), required TResult url(RichTextUrl value), required TResult s(RichTexts value)}) → TResult -
Available on RichText, provided by the RichTextExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult anchor(RichTextAnchor value)?, TResult anchorLink(RichTextAnchorLink value)?, TResult bankCardNumber(RichTextBankCardNumber value)?, TResult bold(RichTextBold value)?, TResult botCommand(RichTextBotCommand value)?, TResult cashtag(RichTextCashtag value)?, TResult customEmoji(RichTextCustomEmoji value)?, TResult dateTime(RichTextDateTime value)?, TResult diff(RichTextDiff value)?, TResult emailAddress(RichTextEmailAddress value)?, TResult fixed(RichTextFixed value)?, TResult hashtag(RichTextHashtag value)?, TResult icon(RichTextIcon value)?, TResult italic(RichTextItalic value)?, TResult marked(RichTextMarked value)?, TResult mathematicalExpression(RichTextMathematicalExpression value)?, TResult mention(RichTextMention value)?, TResult mentionName(RichTextMentionName value)?, TResult phoneNumber(RichTextPhoneNumber value)?, TResult plain(RichTextPlain value)?, TResult reference(RichTextReference value)?, TResult referenceLink(RichTextReferenceLink value)?, TResult spoiler(RichTextSpoiler value)?, TResult strikethrough(RichTextStrikethrough value)?, TResult subscript(RichTextSubscript value)?, TResult superscript(RichTextSuperscript value)?, TResult underline(RichTextUnderline value)?, TResult url(RichTextUrl value)?, TResult s(RichTexts value)?, required TResult orElse()}) → TResult -
Available on RichText, provided by the RichTextExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RichTextBotCommand? -
Inherited by:
RichTextAnchor
RichTextAnchorLink
RichTextBankCardNumber
RichTextBold
RichTextBotCommand
RichTextCashtag
RichTextCustomEmoji
RichTextDateTime
RichTextDiff
RichTextEmailAddress
RichTextFixed
RichTextHashtag
RichTextIcon
RichTextItalic
RichTextMarked
RichTextMathematicalExpression
RichTextMention
RichTextMentionName
RichTextPhoneNumber
RichTextPlain
RichTextReference
RichTextReferenceLink
RichTextSpoiler
RichTextStrikethrough
RichTextSubscript
RichTextSuperscript
RichTextUnderline
RichTextUrl
RichTexts
override
Constants
- constructor → const String