formattingType property
formattingType Date and time formatting type; may be null if none and the original text must not be changed
Implementation
final DateTimeFormattingType? formattingType;
formattingType Date and time formatting type; may be null if none and the original text must not be changed
final DateTimeFormattingType? formattingType;