RtmpUrl class final

Represents an RTMP URL

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RtmpUrl({required String url, required String streamKey})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamKey String
streamKey Stream key
final
url String
url The URL
final

Methods

copyWith({String? url, String? streamKey}) RtmpUrl

Available on RtmpUrl, provided by the RtmpUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) RtmpUrl?

Constants

constructor → const String