SavePreparedInlineMessage class final

Saves an inline message to be sent by the given user; for bots only Returns PreparedInlineMessageId

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SavePreparedInlineMessage({required int userId, InputInlineQueryResult? result, TargetChatTypes? chatTypes})

Properties

chatTypes TargetChatTypes?
chatTypes Types of the chats to which the message can be sent
final
hashCode int
The hash code for this object.
no setteroverride
result InputInlineQueryResult?
result The description of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId, InputInlineQueryResult? result, TargetChatTypes? chatTypes}) SavePreparedInlineMessage

Available on SavePreparedInlineMessage, provided by the SavePreparedInlineMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String