SavedCredentials class final

Contains information about saved payment credentials

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SavedCredentials({required String id, required String title})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the saved credentials
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Title of the saved credentials
final

Methods

copyWith({String? id, String? title}) SavedCredentials

Available on SavedCredentials, provided by the SavedCredentialsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SavedCredentials?

Constants

constructor → const String