SavedMessagesTag class final

Represents a tag used in Saved Messages or a Saved Messages topic

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SavedMessagesTag({ReactionType? tag, required String label, required int count})

Properties

count int
count Number of times the tag was used; may be 0 if the tag has non-empty label
final
hashCode int
The hash code for this object.
no setteroverride
label String
label Label of the tag; 0-12 characters. Always empty if the tag is returned for a Saved Messages topic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag ReactionType?
tag The tag
final

Methods

copyWith({ReactionType? tag, String? label, int? count}) SavedMessagesTag

Available on SavedMessagesTag, provided by the SavedMessagesTagExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SavedMessagesTag?

Constants

constructor → const String