SavedMessagesTags class final

Contains a list of tags used in Saved Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SavedMessagesTags({required List<SavedMessagesTag> tags})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<SavedMessagesTag>
tags List of tags
final

Methods

copyWith({List<SavedMessagesTag>? tags}) SavedMessagesTags

Available on SavedMessagesTags, provided by the SavedMessagesTagsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SavedMessagesTags?

Constants

constructor → const String