SavedMessagesTopicTypeMyNotes class final
Topic containing messages sent by the current user of forwarded from an unknown chat
- Inheritance
-
- Object
- TdObject
- SavedMessagesTopicType
- SavedMessagesTopicTypeMyNotes
- Available extensions
- Annotations
-
- @immutable
Constructors
- SavedMessagesTopicTypeMyNotes()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult authorHidden(SavedMessagesTopicTypeAuthorHidden value), required TResult myNotes(SavedMessagesTopicTypeMyNotes value), required TResult savedFromChat(SavedMessagesTopicTypeSavedFromChat value)}) → TResult -
Available on SavedMessagesTopicType, provided by the SavedMessagesTopicTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult authorHidden(SavedMessagesTopicTypeAuthorHidden value)?, TResult myNotes(SavedMessagesTopicTypeMyNotes value)?, TResult savedFromChat(SavedMessagesTopicTypeSavedFromChat value)?, required TResult orElse()}) → TResult -
Available on SavedMessagesTopicType, provided by the SavedMessagesTopicTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SavedMessagesTopicTypeMyNotes? -
Inherited by:
SavedMessagesTopicTypeAuthorHidden
SavedMessagesTopicTypeMyNotes
SavedMessagesTopicTypeSavedFromChat
override
Constants
- constructor → const String