showStoryPoster property
showStoryPoster True, if the chat that posted a story must be displayed in notifications
Implementation
final bool showStoryPoster;
showStoryPoster True, if the chat that posted a story must be displayed in notifications
final bool showStoryPoster;