storySoundId property
storySoundId Identifier of the notification sound to be played for stories; 0 if sound is disabled; pass -1 to use the app-dependent default sound
Implementation
final int storySoundId;
storySoundId Identifier of the notification sound to be played for stories; 0 if sound is disabled; pass -1 to use the app-dependent default sound
final int storySoundId;