SearchAffiliatePrograms class final

Searches affiliate programs that can be connected to the given affiliate Returns FoundAffiliatePrograms

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchAffiliatePrograms({AffiliateType? affiliate, AffiliateProgramSortOrder? sortOrder, required String offset, required int limit})

Properties

affiliate AffiliateType?
affiliate The affiliate for which affiliate programs are searched for
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of affiliate programs to return
final
offset String
offset Offset of the first affiliate program to return as received from the previous request; use empty string to get the first chunk of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortOrder AffiliateProgramSortOrder?
sortOrder Sort order for the results
final

Methods

copyWith({AffiliateType? affiliate, AffiliateProgramSortOrder? sortOrder, String? offset, int? limit}) SearchAffiliatePrograms

Available on SearchAffiliatePrograms, provided by the SearchAffiliateProgramsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String