SearchBackground class final

Searches for a background by its name Returns Background

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchBackground({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name The name of the background
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) SearchBackground

Available on SearchBackground, provided by the SearchBackgroundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String