SearchChatAffiliateProgram class final
Searches a chat with an affiliate program. Returns the chat if found and the program is active Returns Chat
- Inheritance
-
- Object
- TdFunction
- SearchChatAffiliateProgram
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchChatAffiliateProgram({required String username, required String referrer})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- referrer → String
-
referrer The referrer from an internalLinkTypeChatAffiliateProgram link
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String
-
username Username of the chat
final
Methods
-
copyWith(
{String? username, String? referrer}) → SearchChatAffiliateProgram -
Available on SearchChatAffiliateProgram, provided by the SearchChatAffiliateProgramExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String