SearchChatMembers class final

Searches for a specified query in the first name, last name and usernames of the members of a specified chat. Requires administrator rights if the chat is a channel Returns ChatMembers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchChatMembers({required int chatId, required String query, required int limit, ChatMembersFilter? filter})

Properties

chatId int
chatId Chat identifier
final
filter ChatMembersFilter?
filter The type of users to search for; pass null to search among all chat members
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of users to be returned; up to 200
final
query String
query Query to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? query, int? limit, ChatMembersFilter? filter}) SearchChatMembers

Available on SearchChatMembers, provided by the SearchChatMembersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String