topicId property

MessageTopic? topicId
final

topicId Pass topic identifier to search messages only in specific topic; pass null to search for messages in all topics

Implementation

final MessageTopic? topicId;