SearchContacts class final

Searches for the specified query in the first names, last names and usernames of the known user contacts Returns Users

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchContacts({required String query, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of users to be returned
final
query String
query Query to search for; may be empty to return all contacts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query, int? limit}) SearchContacts

Available on SearchContacts, provided by the SearchContactsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String