attributes property

List<UpgradedGiftAttributeId> attributes
final

attributes Attributes used to filter received gifts. If multiple attributes of the same type are specified, then all of them are allowed. If none attributes of specific type are specified, then all values for this attribute type are allowed

Implementation

final List<UpgradedGiftAttributeId> attributes;