offset property

String offset
final

offset Offset of the first entry to return as received from the previous request with the same order and attributes; use empty string to get the first chunk of results

Implementation

final String offset;