SearchHashtags class final

Searches for recently used hashtags by their prefix Returns Hashtags

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchHashtags({required String prefix, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of hashtags to be returned
final
prefix String
prefix Hashtag prefix to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? prefix, int? limit}) SearchHashtags

Available on SearchHashtags, provided by the SearchHashtagsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String