SearchMessagesFilterEmpty class final
Returns all found messages, no filter is applied
- Inheritance
-
- Object
- TdObject
- SearchMessagesFilter
- SearchMessagesFilterEmpty
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchMessagesFilterEmpty()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(SearchMessagesFilterAnimation value), required TResult audio(SearchMessagesFilterAudio value), required TResult chatPhoto(SearchMessagesFilterChatPhoto value), required TResult document(SearchMessagesFilterDocument value), required TResult empty(SearchMessagesFilterEmpty value), required TResult failedToSend(SearchMessagesFilterFailedToSend value), required TResult mention(SearchMessagesFilterMention value), required TResult photo(SearchMessagesFilterPhoto value), required TResult photoAndVideo(SearchMessagesFilterPhotoAndVideo value), required TResult pinned(SearchMessagesFilterPinned value), required TResult poll(SearchMessagesFilterPoll value), required TResult unreadMention(SearchMessagesFilterUnreadMention value), required TResult unreadPollVote(SearchMessagesFilterUnreadPollVote value), required TResult unreadReaction(SearchMessagesFilterUnreadReaction value), required TResult url(SearchMessagesFilterUrl value), required TResult video(SearchMessagesFilterVideo value), required TResult videoNote(SearchMessagesFilterVideoNote value), required TResult voiceAndVideoNote(SearchMessagesFilterVoiceAndVideoNote value), required TResult voiceNote(SearchMessagesFilterVoiceNote value)}) → TResult -
Available on SearchMessagesFilter, provided by the SearchMessagesFilterExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(SearchMessagesFilterAnimation value)?, TResult audio(SearchMessagesFilterAudio value)?, TResult chatPhoto(SearchMessagesFilterChatPhoto value)?, TResult document(SearchMessagesFilterDocument value)?, TResult empty(SearchMessagesFilterEmpty value)?, TResult failedToSend(SearchMessagesFilterFailedToSend value)?, TResult mention(SearchMessagesFilterMention value)?, TResult photo(SearchMessagesFilterPhoto value)?, TResult photoAndVideo(SearchMessagesFilterPhotoAndVideo value)?, TResult pinned(SearchMessagesFilterPinned value)?, TResult poll(SearchMessagesFilterPoll value)?, TResult unreadMention(SearchMessagesFilterUnreadMention value)?, TResult unreadPollVote(SearchMessagesFilterUnreadPollVote value)?, TResult unreadReaction(SearchMessagesFilterUnreadReaction value)?, TResult url(SearchMessagesFilterUrl value)?, TResult video(SearchMessagesFilterVideo value)?, TResult videoNote(SearchMessagesFilterVideoNote value)?, TResult voiceAndVideoNote(SearchMessagesFilterVoiceAndVideoNote value)?, TResult voiceNote(SearchMessagesFilterVoiceNote value)?, required TResult orElse()}) → TResult -
Available on SearchMessagesFilter, provided by the SearchMessagesFilterExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SearchMessagesFilterEmpty? -
Inherited by:
SearchMessagesFilterAnimation
SearchMessagesFilterAudio
SearchMessagesFilterChatPhoto
SearchMessagesFilterDocument
SearchMessagesFilterEmpty
SearchMessagesFilterFailedToSend
SearchMessagesFilterMention
SearchMessagesFilterPhoto
SearchMessagesFilterPhotoAndVideo
SearchMessagesFilterPinned
SearchMessagesFilterPoll
SearchMessagesFilterUnreadMention
SearchMessagesFilterUnreadPollVote
SearchMessagesFilterUnreadReaction
SearchMessagesFilterUrl
SearchMessagesFilterVideo
SearchMessagesFilterVideoNote
SearchMessagesFilterVoiceAndVideoNote
SearchMessagesFilterVoiceNote
override
Constants
- constructor → const String