SearchOutgoingDocumentMessages class final

Searches for outgoing messages with content of the type messageDocument in all chats except secret chats. Returns the results in reverse chronological order Returns FoundMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchOutgoingDocumentMessages({required String query, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; up to 100
final
query String
query Query to search for in document file name and message caption
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query, int? limit}) SearchOutgoingDocumentMessages

Available on SearchOutgoingDocumentMessages, provided by the SearchOutgoingDocumentMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String