SearchPublicChat class final
Searches a public chat by its username. Currently, only private chats, supergroups and channels can be public. Returns the chat if found; otherwise, an error is returned Returns Chat
- Inheritance
-
- Object
- TdFunction
- SearchPublicChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchPublicChat({required String username})
Properties
Methods
-
copyWith(
{String? username}) → SearchPublicChat -
Available on SearchPublicChat, provided by the SearchPublicChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String