SearchPublicMessagesByTag class final

Searches for public channel posts containing the given hashtag or cashtag. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit Returns FoundMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchPublicMessagesByTag({required String tag, required String offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; up to 100. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
tag Hashtag or cashtag to search for
final

Methods

copyWith({String? tag, String? offset, int? limit}) SearchPublicMessagesByTag

Available on SearchPublicMessagesByTag, provided by the SearchPublicMessagesByTagExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String