SearchPublicPosts class final

Searches for public channel posts using the given query. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit Returns FoundPublicPosts

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchPublicPosts({required String query, required String offset, required int limit, required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; up to 100. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
query String
query Query to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount the user agreed to pay for the search; pass 0 for free searches
final

Methods

copyWith({String? query, String? offset, int? limit, int? starCount}) SearchPublicPosts

Available on SearchPublicPosts, provided by the SearchPublicPostsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String