SearchPublicStoriesByTag class final

Searches for public stories containing the given hashtag or cashtag. For optimal performance, the number of returned stories is chosen by TDLib and can be smaller than the specified limit Returns FoundStories

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchPublicStoriesByTag({required int storyPosterChatId, required String tag, required String offset, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of stories to be returned; up to 100. For optimal performance, the number of returned stories is chosen by TDLib and can be smaller than the specified limit
final
offset String
offset Offset of the first entry to return as received from the previous request; use empty string to get the first chunk of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyPosterChatId int
storyPosterChatId Identifier of the chat that posted the stories to search for; pass 0 to search stories in all chats
final
tag String
tag Hashtag or cashtag to search for
final

Methods

copyWith({int? storyPosterChatId, String? tag, String? offset, int? limit}) SearchPublicStoriesByTag

Available on SearchPublicStoriesByTag, provided by the SearchPublicStoriesByTagExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String