SearchQuote class final

Searches for a given quote in a text. Returns found quote start position in UTF-16 code units. Returns a 404 error if the quote is not found. Can be called synchronously Returns FoundPosition

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchQuote({FormattedText? text, FormattedText? quote, required int quotePosition})

Properties

hashCode int
The hash code for this object.
no setteroverride
quote FormattedText?
quote Quote to search for
final
quotePosition int
quotePosition Approximate quote position in UTF-16 code units
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text in which to search for the quote
final

Methods

copyWith({FormattedText? text, FormattedText? quote, int? quotePosition}) SearchQuote

Available on SearchQuote, provided by the SearchQuoteExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String