SearchRecentlyFoundChats class final
Searches for the specified query in the title and username of up to 50 recently found chats. This is an offline method Returns Chats
- Inheritance
-
- Object
- TdFunction
- SearchRecentlyFoundChats
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchRecentlyFoundChats({required String query, SearchChatTypeFilter? typeFilter, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of chats to be returned
final
- query → String
-
query Query to search for
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeFilter → SearchChatTypeFilter?
-
typeFilter Additional filter for type of the chats to be returned; pass
null to search for chats of all types
final
Methods
-
copyWith(
{String? query, SearchChatTypeFilter? typeFilter, int? limit}) → SearchRecentlyFoundChats -
Available on SearchRecentlyFoundChats, provided by the SearchRecentlyFoundChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String