SearchSavedMessages class final

Searches for messages tagged by the given reaction and with the given words in the Saved Messages chat; for Telegram Premium users only. Returns the results in reverse chronological order, i.e. in order of decreasing message_id. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit Returns FoundChatMessages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchSavedMessages({required int savedMessagesTopicId, ReactionType? tag, required String query, required int fromMessageId, required int offset, required int limit})

Properties

fromMessageId int
fromMessageId Identifier of the message starting from which messages must be fetched; use 0 to get results from the last message
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, then the limit must be greater than -offset. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset int
offset Specify 0 to get results from exactly the message from_message_id or a negative number to get the specified message and some newer messages
final
query String
query Query to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all messages
final
tag ReactionType?
tag Tag to search for; pass null to return all suitable messages
final

Methods

copyWith({int? savedMessagesTopicId, ReactionType? tag, String? query, int? fromMessageId, int? offset, int? limit}) SearchSavedMessages

Available on SearchSavedMessages, provided by the SearchSavedMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String