savedMessagesTopicId property
savedMessagesTopicId If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all messages
Implementation
final int savedMessagesTopicId;
savedMessagesTopicId If not 0, only messages in the specified Saved Messages topic will be considered; pass 0 to consider all messages
final int savedMessagesTopicId;