SearchSecretMessages class final
Searches for messages in secret chats. Returns the results in reverse chronological order. For optimal performance, the number of returned messages is chosen by TDLib Returns FoundMessages
- Inheritance
-
- Object
- TdFunction
- SearchSecretMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchSecretMessages({required int chatId, required String query, required String offset, required int limit, SearchMessagesFilter? filter})
Properties
- chatId → int
-
chatId Identifier of the chat in which to search. Specify 0 to search in
all secret chats
final
- filter → SearchMessagesFilter?
-
filter Additional filter for messages to search; pass null to search for
all messages
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of messages to be returned; up to 100. For
optimal performance, the number of returned messages is chosen by TDLib
and can be smaller than the specified limit
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- query → String
-
query Query to search for. If empty, searchChatMessages must be used
instead
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? query, String? offset, int? limit, SearchMessagesFilter? filter}) → SearchSecretMessages -
Available on SearchSecretMessages, provided by the SearchSecretMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String