SearchStickerSets class final

Searches for sticker sets by looking for specified query in their title and name. Excludes installed sticker sets from the results Returns StickerSets

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchStickerSets({StickerType? stickerType, required String query})

Properties

hashCode int
The hash code for this object.
no setteroverride
query String
query Query to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerType StickerType?
stickerType Type of the sticker sets to return
final

Methods

copyWith({StickerType? stickerType, String? query}) SearchStickerSets

Available on SearchStickerSets, provided by the SearchStickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String