SearchStringsByPrefix class final

Searches specified query by word prefixes in the provided strings. Returns 0-based positions of strings that matched. Can be called synchronously Returns FoundPositions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchStringsByPrefix({required List<String> strings, required String query, required int limit, required bool returnNoneForEmptyQuery})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of objects to return
final
query String
query Query to search for
final
returnNoneForEmptyQuery bool
returnNoneForEmptyQuery Pass true to receive no results for an empty query
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings List<String>
strings The strings to search in for the query
final

Methods

copyWith({List<String>? strings, String? query, int? limit, bool? returnNoneForEmptyQuery}) SearchStringsByPrefix

Available on SearchStringsByPrefix, provided by the SearchStringsByPrefixExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String