SearchTextCompositionStyle class final
Searches a custom text composition style by its name Returns TextCompositionStyle
- Inheritance
-
- Object
- TdFunction
- SearchTextCompositionStyle
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchTextCompositionStyle({required String name})
Properties
Methods
-
copyWith(
{String? name}) → SearchTextCompositionStyle -
Available on SearchTextCompositionStyle, provided by the SearchTextCompositionStyleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String