SearchUserByPhoneNumber class final

Searches a user by their phone number. Returns a 404 error if the user can't be found Returns User

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchUserByPhoneNumber({required String phoneNumber, required bool onlyLocal})

Properties

hashCode int
The hash code for this object.
no setteroverride
onlyLocal bool
onlyLocal Pass true to get only locally available information without sending network requests
final
phoneNumber String
phoneNumber Phone number to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? phoneNumber, bool? onlyLocal}) SearchUserByPhoneNumber

Available on SearchUserByPhoneNumber, provided by the SearchUserByPhoneNumberExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String