SearchUserByToken class final
Searches a user by a token from the user's link Returns User
- Inheritance
-
- Object
- TdFunction
- SearchUserByToken
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchUserByToken({required String token})
Properties
Methods
-
copyWith(
{String? token}) → SearchUserByToken -
Available on SearchUserByToken, provided by the SearchUserByTokenExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String