SecretChatStateReady class final
The secret chat is ready to use
- Inheritance
-
- Object
- TdObject
- SecretChatState
- SecretChatStateReady
- Available extensions
- Annotations
-
- @immutable
Constructors
- SecretChatStateReady()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult closed(SecretChatStateClosed value), required TResult pending(SecretChatStatePending value), required TResult ready(SecretChatStateReady value)}) → TResult -
Available on SecretChatState, provided by the SecretChatStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult closed(SecretChatStateClosed value)?, TResult pending(SecretChatStatePending value)?, TResult ready(SecretChatStateReady value)?, required TResult orElse()}) → TResult -
Available on SecretChatState, provided by the SecretChatStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SecretChatStateReady? -
Inherited by:
SecretChatStateClosed
SecretChatStatePending
SecretChatStateReady
override
Constants
- constructor → const String