SendBotStartMessage class final

Invites a bot to a chat (if it is not yet a member) and sends it the /start command; requires can_invite_users member right. Bots can't be invited to a private chat other than the chat with the bot. Bots can't be invited to channels (although they can be added as admins) and secret chats. Returns the sent message Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendBotStartMessage({required int botUserId, required int chatId, required String parameter})

Properties

botUserId int
botUserId Identifier of the bot
final
chatId int
chatId Identifier of the target chat
final
hashCode int
The hash code for this object.
no setteroverride
parameter String
parameter A hidden parameter sent to the bot for deep linking purposes (https://core.telegram.org/bots#deep-linking)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, int? chatId, String? parameter}) SendBotStartMessage

Available on SendBotStartMessage, provided by the SendBotStartMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String