SendBusinessMessage class final

Sends a message on behalf of a business account; for bots only. Returns the message after it was sent Returns BusinessMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendBusinessMessage({required String businessConnectionId, required int chatId, InputMessageReplyTo? replyTo, required bool disableNotification, required bool protectContent, required int effectId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which to send the request
final
chatId int
chatId Target chat
final
disableNotification bool
disableNotification Pass true to disable notification for the message
final
effectId int
effectId Identifier of the effect to apply to the message
final
hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be sent
final
protectContent bool
protectContent Pass true if the content of the message must be protected from forwarding and saving
final
replyMarkup ReplyMarkup?
replyMarkup Markup for replying to the message; pass null if none
final
replyTo InputMessageReplyTo?
replyTo Information about the message to be replied; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, InputMessageReplyTo? replyTo, bool? disableNotification, bool? protectContent, int? effectId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) SendBusinessMessage

Available on SendBusinessMessage, provided by the SendBusinessMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String