businessConnectionId property
businessConnectionId Unique identifier of business connection on behalf of which to send the request
Implementation
final String businessConnectionId;
businessConnectionId Unique identifier of business connection on behalf of which to send the request
final String businessConnectionId;