protectContent property
protectContent Pass true if the content of the message must be protected from forwarding and saving
Implementation
final bool protectContent;
protectContent Pass true if the content of the message must be protected from forwarding and saving
final bool protectContent;