SendCallLog class final

Sends log file for a call to Telegram servers Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendCallLog({InputCall? callId, InputFile? logFile})

Properties

callId InputCall?
callId Call identifier
final
hashCode int
The hash code for this object.
no setteroverride
logFile InputFile?
logFile Call log file. Only inputFileLocal and inputFileGenerated are supported
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputCall? callId, InputFile? logFile}) SendCallLog

Available on SendCallLog, provided by the SendCallLogExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String