SendCallSignalingData class final

Sends call signaling data Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendCallSignalingData({required int callId, required String data})

Properties

callId int
callId Call identifier
final
data String
data The data
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? callId, String? data}) SendCallSignalingData

Available on SendCallSignalingData, provided by the SendCallSignalingDataExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String