SendChatAction class final
Sends a notification about user activity in a chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendChatAction
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendChatAction({required int chatId, MessageTopic? topicId, String? businessConnectionId, ChatAction? action})
Properties
- action → ChatAction?
-
action The action description; pass null to cancel the currently active
action
final
- businessConnectionId → String?
-
businessConnectionId Unique identifier of business connection on behalf
of which to send the request; for bots only
final
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Identifier of the topic in which the action is performed; pass
null if none
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, String? businessConnectionId, ChatAction? action}) → SendChatAction -
Available on SendChatAction, provided by the SendChatActionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String