topicId property
topicId Identifier of the topic in which the action is performed; pass null if none
Implementation
final MessageTopic? topicId;
topicId Identifier of the topic in which the action is performed; pass null if none
final MessageTopic? topicId;