SendCustomRequest class final
Sends a custom request; for bots only Returns CustomRequestResult
- Inheritance
-
- Object
- TdFunction
- SendCustomRequest
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendCustomRequest({required String method, required String parameters})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- method → String
-
method The method name
final
- parameters → String
-
parameters JSON-serialized method parameters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? method, String? parameters}) → SendCustomRequest -
Available on SendCustomRequest, provided by the SendCustomRequestExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String