SendEmailAddressVerificationCode class final

Sends a code to verify an email address to be added to a user's Telegram Passport Returns EmailAddressAuthenticationCodeInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendEmailAddressVerificationCode({required String emailAddress})

Properties

emailAddress String
emailAddress Email address
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? emailAddress}) SendEmailAddressVerificationCode

Available on SendEmailAddressVerificationCode, provided by the SendEmailAddressVerificationCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String