callbackQueryId property
callbackQueryId Identifier of the callback query which triggered the message; for bots only
Implementation
final int? callbackQueryId;
callbackQueryId Identifier of the callback query which triggered the message; for bots only
final int? callbackQueryId;