SendGift class final

Sends a gift to another user or channel chat. May return an error with a message "STARGIFT_USAGE_LIMITED" if the gift was sold out Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendGift({required int giftId, MessageSender? ownerId, FormattedText? text, required bool isPrivate, required bool payForUpgrade})

Properties

giftId int
giftId Identifier of the gift to send
final
hashCode int
The hash code for this object.
no setteroverride
isPrivate bool
isPrivate Pass true to show gift text and sender only to the gift receiver; otherwise, everyone will be able to see them
final
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that will receive the gift; limited gifts can't be sent to channel chats
final
payForUpgrade bool
payForUpgrade Pass true to additionally pay for the gift upgrade and allow the receiver to upgrade it for free
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text to show along with the gift; 0-getOption("gift_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed. Must be empty if the receiver enabled paid messages
final

Methods

copyWith({int? giftId, MessageSender? ownerId, FormattedText? text, bool? isPrivate, bool? payForUpgrade}) SendGift

Available on SendGift, provided by the SendGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String