ownerId property
ownerId Identifier of the user or the channel chat that will receive the gift; limited gifts can't be sent to channel chats
Implementation
final MessageSender? ownerId;
ownerId Identifier of the user or the channel chat that will receive the gift; limited gifts can't be sent to channel chats
final MessageSender? ownerId;