payForUpgrade property
payForUpgrade Pass true to additionally pay for the gift upgrade and allow the receiver to upgrade it for free
Implementation
final bool payForUpgrade;
payForUpgrade Pass true to additionally pay for the gift upgrade and allow the receiver to upgrade it for free
final bool payForUpgrade;