paidMessageStarCount property
paidMessageStarCount The number of Telegram Stars the user agreed to pay additionally for sending of the offer message to the current gift owner; pass userFullInfo.outgoing_paid_message_star_count for users and 0 otherwise
Implementation
final int paidMessageStarCount;