SendGroupCallMessage class final

Sends a message to other participants of a group call. Requires groupCall.can_send_messages right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendGroupCallMessage({required int groupCallId, FormattedText? text, required int paidMessageStarCount})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
paidMessageStarCount int
paidMessageStarCount The number of Telegram Stars the user agreed to pay to send the message; for live stories only; 0-getOption("paid_group_call_message_star_count_max"). Must be 0 for messages sent to live stories posted by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text of the message to send; 1-getOption("group_call_message_text_length_max") characters for non-live-stories; see updateGroupCallMessageLevels for live story restrictions, which depends on paid_message_star_count. Can't contain line feeds for live stories. Can contain only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities for live stories
final

Methods

copyWith({int? groupCallId, FormattedText? text, int? paidMessageStarCount}) SendGroupCallMessage

Available on SendGroupCallMessage, provided by the SendGroupCallMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String