replyTo property
replyTo Information about the message or story to be replied; pass null if none
Implementation
final InputMessageReplyTo? replyTo;
replyTo Information about the message or story to be replied; pass null if none
final InputMessageReplyTo? replyTo;