SendMessageViewMetrics class final

Informs TDLib about details of a message view by the user from a chat, a message thread or a forum topic history. The method must be called if the message wasn't seen for more than 300 milliseconds, the viewport was destroyed, or the total view duration exceeded 5 minutes Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendMessageViewMetrics({required int chatId, required int messageId, required int timeInViewMs, required int activeTimeInViewMs, required int heightToViewportRatioPerMille, required int seenRangeRatioPerMille})

Properties

activeTimeInViewMs int
activeTimeInViewMs The amount of time the message was seen by at least 1 pixel within 15 seconds after any action from the user; in milliseconds
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
heightToViewportRatioPerMille int
heightToViewportRatioPerMille The ratio of the post height to the viewport height in 1/1000 fractions
final
messageId int
messageId The identifier of the message being viewed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seenRangeRatioPerMille int
seenRangeRatioPerMille The ratio of the viewed post height to the full post height in 1/1000 fractions; 0-1000
final
timeInViewMs int
timeInViewMs The amount of time the message was seen by at least 1 pixel; in milliseconds
final

Methods

copyWith({int? chatId, int? messageId, int? timeInViewMs, int? activeTimeInViewMs, int? heightToViewportRatioPerMille, int? seenRangeRatioPerMille}) SendMessageViewMetrics

Available on SendMessageViewMetrics, provided by the SendMessageViewMetricsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String