activeTimeInViewMs property
activeTimeInViewMs The amount of time the message was seen by at least 1 pixel within 15 seconds after any action from the user; in milliseconds
Implementation
final int activeTimeInViewMs;
activeTimeInViewMs The amount of time the message was seen by at least 1 pixel within 15 seconds after any action from the user; in milliseconds
final int activeTimeInViewMs;