SendPassportAuthorizationForm class final
Sends a Telegram Passport authorization form, effectively sharing data with the service. This method must be called after getPassportAuthorizationFormAvailableElements if some previously available elements are going to be reused Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendPassportAuthorizationForm
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SendPassportAuthorizationForm({required int authorizationFormId, required List<
PassportElementType> types})
Properties
-
authorizationFormId Authorization form identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
types
→ List<
PassportElementType> -
types Types of Telegram Passport elements chosen by user to complete the
authorization form
final
Methods
-
copyWith(
{int? authorizationFormId, List< PassportElementType> ? types}) → SendPassportAuthorizationForm -
Available on SendPassportAuthorizationForm, provided by the SendPassportAuthorizationFormExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String