SendPaymentForm class final

Sends a filled-out payment form to the bot for final verification Returns PaymentResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendPaymentForm({InputInvoice? inputInvoice, required int paymentFormId, required String orderInfoId, required String shippingOptionId, InputCredentials? credentials, required int tipAmount})

Properties

credentials InputCredentials?
credentials The credentials chosen by user for payment; pass null for a payment in Telegram Stars
final
hashCode int
The hash code for this object.
no setteroverride
inputInvoice InputInvoice?
inputInvoice The invoice
final
orderInfoId String
orderInfoId Identifier returned by validateOrderInfo, or an empty string
final
paymentFormId int
paymentFormId Payment form identifier returned by getPaymentForm
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingOptionId String
shippingOptionId Identifier of a chosen shipping option, if applicable
final
tipAmount int
tipAmount Chosen by the user amount of tip in the smallest units of the currency
final

Methods

copyWith({InputInvoice? inputInvoice, int? paymentFormId, String? orderInfoId, String? shippingOptionId, InputCredentials? credentials, int? tipAmount}) SendPaymentForm

Available on SendPaymentForm, provided by the SendPaymentFormExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String