SendPhoneNumberCode class final

Sends a code to the specified phone number. Aborts previous phone number verification if there was one. On success, returns information about the sent code Returns AuthenticationCodeInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendPhoneNumberCode({required String phoneNumber, PhoneNumberAuthenticationSettings? settings, PhoneNumberCodeType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
phoneNumber String
phoneNumber The phone number, in international format
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings PhoneNumberAuthenticationSettings?
settings Settings for the authentication of the user's phone number; pass null to use default settings
final
type PhoneNumberCodeType?
type Type of the request for which the code is sent
final

Methods

copyWith({String? phoneNumber, PhoneNumberAuthenticationSettings? settings, PhoneNumberCodeType? type}) SendPhoneNumberCode

Available on SendPhoneNumberCode, provided by the SendPhoneNumberCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String