SendResoldGift class final

Sends an upgraded gift that is available for resale to another user or channel chat; gifts already owned by the current user must be transferred using transferGift and can't be passed to the method Returns GiftResaleResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendResoldGift({required String giftName, MessageSender? ownerId, GiftResalePrice? price})

Properties

giftName String
giftName Name of the upgraded gift to send
final
hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that will receive the gift
final
price GiftResalePrice?
price The price that the user agreed to pay for the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? giftName, MessageSender? ownerId, GiftResalePrice? price}) SendResoldGift

Available on SendResoldGift, provided by the SendResoldGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String