SendTextMessageDraft class final

Sends a draft for a being generated text message; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendTextMessageDraft({required int chatId, required int forumTopicId, required int draftId, FormattedText? text})

Properties

chatId int
chatId Chat identifier
final
draftId int
draftId Unique identifier of the draft
final
forumTopicId int
forumTopicId The forum topic identifier in which the message will be sent; pass 0 if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Draft text of the message; pass null to show a "Thinking..." placeholder
final

Methods

copyWith({int? chatId, int? forumTopicId, int? draftId, FormattedText? text}) SendTextMessageDraft

Available on SendTextMessageDraft, provided by the SendTextMessageDraftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String