SendWebAppCustomRequest class final
Sends a custom request from a Web App Returns CustomRequestResult
- Inheritance
-
- Object
- TdFunction
- SendWebAppCustomRequest
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendWebAppCustomRequest({required int botUserId, required String method, required String parameters})
Properties
- botUserId → int
-
botUserId Identifier of the bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- method → String
-
method The method name
final
- parameters → String
-
parameters JSON-serialized method parameters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? method, String? parameters}) → SendWebAppCustomRequest -
Available on SendWebAppCustomRequest, provided by the SendWebAppCustomRequestExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String