SentGiftUpgraded class final
Upgraded gift
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- SentGiftUpgraded({UpgradedGift? gift})
Properties
- gift → UpgradedGift?
-
gift The gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{UpgradedGift? gift}) → SentGiftUpgraded -
Available on SentGiftUpgraded, provided by the SentGiftUpgradedExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult regular(SentGiftRegular value), required TResult upgraded(SentGiftUpgraded value)}) → TResult -
Available on SentGift, provided by the SentGiftExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult regular(SentGiftRegular value)?, TResult upgraded(SentGiftUpgraded value)?, required TResult orElse()}) → TResult -
Available on SentGift, provided by the SentGiftExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SentGiftUpgraded? -
Inherited by:
SentGiftRegular
SentGiftUpgraded
override
Constants
- constructor → const String