deviceType property

SessionDeviceType? deviceType
final

deviceType Session device type based on the system and application version, which can be used to display a corresponding icon

Implementation

final SessionDeviceType? deviceType;