SessionType class sealed

Describes type of user session

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult connectedBot(SessionTypeConnectedBot value), required TResult device(SessionTypeDevice value)}) → TResult

Available on SessionType, provided by the SessionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult connectedBot(SessionTypeConnectedBot value)?, TResult device(SessionTypeDevice value)?, required TResult orElse()}) → TResult

Available on SessionType, provided by the SessionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SessionType?
Inherited by: SessionTypeConnectedBot SessionTypeDevice

Constants

constructor → const String