SessionTypeDevice class final

A regular session from a device

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SessionTypeDevice({required int sessionId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
sessionId Unique identifier of the session. Use terminateSession to terminate it or confirmSession to confirm it if it isn't confirmed yet
final

Methods

copyWith({int? sessionId}) SessionTypeDevice

Available on SessionTypeDevice, provided by the SessionTypeDeviceExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult connectedBot(SessionTypeConnectedBot value), required TResult device(SessionTypeDevice value)}) → TResult

Available on SessionType, provided by the SessionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult connectedBot(SessionTypeConnectedBot value)?, TResult device(SessionTypeDevice value)?, required TResult orElse()}) → TResult

Available on SessionType, provided by the SessionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SessionTypeDevice?
Inherited by: SessionTypeConnectedBot SessionTypeDevice
override

Constants

constructor → const String