Sessions class final
Contains a list of sessions
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inactiveSessionTtlDays → int
-
inactiveSessionTtlDays Number of days of inactivity before sessions will
automatically be terminated; 1-366 days
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
Session> -
sessions List of sessions
final
Methods
-
copyWith(
{List< Session> ? sessions, int? inactiveSessionTtlDays}) → Sessions -
Available on Sessions, provided by the SessionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String