SetAccentColor class final
Changes accent color and background custom emoji for the current user; for Telegram Premium users only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetAccentColor
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetAccentColor({required int accentColorId, required int backgroundCustomEmojiId})
Properties
- accentColorId → int
-
accentColorId Identifier of the accent color to use
final
- backgroundCustomEmojiId → int
-
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the
reply header and link preview background; 0 if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? accentColorId, int? backgroundCustomEmojiId}) → SetAccentColor -
Available on SetAccentColor, provided by the SetAccentColorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String