SetAccountTtl class final

Changes the period of inactivity after which the account of the current user will automatically be deleted Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetAccountTtl({AccountTtl? ttl})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl AccountTtl?
ttl New account TTL
final

Methods

copyWith({AccountTtl? ttl}) SetAccountTtl

Available on SetAccountTtl, provided by the SetAccountTtlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String