SetAlarm class final

Succeeds after a specified amount of time has passed. Can be called before initialization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetAlarm({required double seconds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seconds double
seconds Number of seconds before the function returns
final

Methods

copyWith({double? seconds}) SetAlarm

Available on SetAlarm, provided by the SetAlarmExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String