SetArchiveChatListSettings class final

Changes settings for automatic moving of chats to and from the Archive chat lists Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ArchiveChatListSettings?
settings New settings
final

Methods

copyWith({ArchiveChatListSettings? settings}) SetArchiveChatListSettings

Available on SetArchiveChatListSettings, provided by the SetArchiveChatListSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String