SetAuthenticationPremiumPurchaseTransaction class final
Informs server about an in-store purchase of Telegram Premium before authorization. Works only when the current authorization state is authorizationStateWaitPremiumPurchase Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetAuthenticationPremiumPurchaseTransaction
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetAuthenticationPremiumPurchaseTransaction({StoreTransaction? transaction, required bool isRestore, required String currency, required int amount})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRestore → bool
-
isRestore Pass true if this is a restore of a Telegram Premium purchase;
only for App Store
final
-
premiumDayCount The number of days for which the Telegram Premium
subscription will be granted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transaction → StoreTransaction?
-
transaction Information about the transaction
final
Methods
-
copyWith(
{StoreTransaction? transaction, bool? isRestore, String? currency, int? amount}) → SetAuthenticationPremiumPurchaseTransaction -
Available on SetAuthenticationPremiumPurchaseTransaction, provided by the SetAuthenticationPremiumPurchaseTransactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String