premiumDayCount property
premiumDayCount The number of days for which the Telegram Premium subscription will be granted
Implementation
final int premiumDayCount;
premiumDayCount The number of days for which the Telegram Premium subscription will be granted
final int premiumDayCount;