SetBio class final

Changes the bio of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBio({required String bio})

Properties

bio String
bio The new value of the user bio; 0-getOption("bio_length_max") characters without line feeds
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? bio}) SetBio

Available on SetBio, provided by the SetBioExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String