SetBirthdate class final

Changes the birthdate of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBirthdate({Birthdate? birthdate})

Properties

birthdate Birthdate?
birthdate The new value of the current user's birthdate; pass null to remove the birthdate
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Birthdate? birthdate}) SetBirthdate

Available on SetBirthdate, provided by the SetBirthdateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String