SetBotInfoShortDescription class final
Sets the text shown on a bot's profile page and sent together with the link when users share the bot. Can be called only if userTypeBot.can_be_edited == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBotInfoShortDescription
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBotInfoShortDescription({required int botUserId, required String languageCode, required String shortDescription})
Properties
- botUserId → int
-
botUserId Identifier of the target bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode A two-letter ISO 639-1 language code. If empty, the short
description will be shown to all users for whose languages there is no
dedicated description
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDescription → String
-
shortDescription New bot's short description on the specified language
final
Methods
-
copyWith(
{int? botUserId, String? languageCode, String? shortDescription}) → SetBotInfoShortDescription -
Available on SetBotInfoShortDescription, provided by the SetBotInfoShortDescriptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String