SetBotProfilePhoto class final
Changes a profile photo for a bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBotProfilePhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBotProfilePhoto({required int botUserId, InputChatPhoto? photo})
Properties
- botUserId → int
-
botUserId Identifier of the target bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- photo → InputChatPhoto?
-
photo Profile photo to set; pass null to delete the chat photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, InputChatPhoto? photo}) → SetBotProfilePhoto -
Available on SetBotProfilePhoto, provided by the SetBotProfilePhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String