SetBusinessAccountBio class final
Changes the bio of a business account; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBusinessAccountBio
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBusinessAccountBio({required String businessConnectionId, required String bio})
Properties
- bio → String
-
bio The new value of the bio; 0-getOption("bio_length_max") characters
without line feeds
final
- businessConnectionId → String
-
businessConnectionId Unique identifier of business connection
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId, String? bio}) → SetBusinessAccountBio -
Available on SetBusinessAccountBio, provided by the SetBusinessAccountBioExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String