SetBusinessAccountProfilePhoto class final

Changes a profile photo of a business account; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessAccountProfilePhoto({required String businessConnectionId, InputChatPhoto? photo, required bool isPublic})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection
final
hashCode int
The hash code for this object.
no setteroverride
isPublic bool
isPublic Pass true to set the public photo, which will be visible even if the main photo is hidden by privacy settings
final
photo InputChatPhoto?
photo Profile photo to set; pass null to remove the photo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, InputChatPhoto? photo, bool? isPublic}) SetBusinessAccountProfilePhoto

Available on SetBusinessAccountProfilePhoto, provided by the SetBusinessAccountProfilePhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String