SetBusinessAccountUsername class final

Changes the editable username of a business account; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessAccountUsername({required String businessConnectionId, required String username})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
username The new value of the username
final

Methods

copyWith({String? businessConnectionId, String? username}) SetBusinessAccountUsername

Available on SetBusinessAccountUsername, provided by the SetBusinessAccountUsernameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String