SetBusinessAwayMessageSettings class final

Changes the business away message settings of the current user. Requires Telegram Business subscription Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessAwayMessageSettings({BusinessAwayMessageSettings? awayMessageSettings})

Properties

awayMessageSettings BusinessAwayMessageSettings?
awayMessageSettings The new settings for the away message of the business; pass null to disable the away message
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BusinessAwayMessageSettings? awayMessageSettings}) SetBusinessAwayMessageSettings

Available on SetBusinessAwayMessageSettings, provided by the SetBusinessAwayMessageSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String