SetBusinessGreetingMessageSettings class final

Changes the business greeting message settings of the current user. Requires Telegram Business subscription Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessGreetingMessageSettings({BusinessGreetingMessageSettings? greetingMessageSettings})

Properties

greetingMessageSettings BusinessGreetingMessageSettings?
greetingMessageSettings The new settings for the greeting message of the business; pass null to disable the greeting message
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({BusinessGreetingMessageSettings? greetingMessageSettings}) SetBusinessGreetingMessageSettings

Available on SetBusinessGreetingMessageSettings, provided by the SetBusinessGreetingMessageSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String