greetingMessageSettings property
greetingMessageSettings The new settings for the greeting message of the business; pass null to disable the greeting message
Implementation
final BusinessGreetingMessageSettings? greetingMessageSettings;
greetingMessageSettings The new settings for the greeting message of the business; pass null to disable the greeting message
final BusinessGreetingMessageSettings? greetingMessageSettings;