SetBusinessMessageIsPinned class final

Pins or unpins a message sent on behalf of a business account; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessMessageIsPinned({required String businessConnectionId, required int chatId, required int messageId, required bool isPinned})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which the message was sent
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
isPinned bool
isPinned Pass true to pin the message, pass false to unpin it
final
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, bool? isPinned}) SetBusinessMessageIsPinned

Available on SetBusinessMessageIsPinned, provided by the SetBusinessMessageIsPinnedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String