SetBusinessStartPage class final

Changes the business start page of the current user. Requires Telegram Business subscription Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetBusinessStartPage({InputBusinessStartPage? startPage})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startPage InputBusinessStartPage?
startPage The new start page of the business; pass null to remove custom start page
final

Methods

copyWith({InputBusinessStartPage? startPage}) SetBusinessStartPage

Available on SetBusinessStartPage, provided by the SetBusinessStartPageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String