backgroundCustomEmojiId property

int backgroundCustomEmojiId
final

backgroundCustomEmojiId Identifier of a custom emoji to be shown on the reply header and link preview background; 0 if none. Use chatBoostLevelFeatures.can_set_background_custom_emoji to check whether a custom emoji can be set

Implementation

final int backgroundCustomEmojiId;