SetChatActiveStoriesList class final
Changes story list in which stories from the chat are shown Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatActiveStoriesList
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatActiveStoriesList({required int chatId, StoryList? storyList})
Properties
- chatId → int
-
chatId Identifier of the chat that posted stories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyList → StoryList?
-
storyList New list for active stories posted by the chat
final
Methods
-
copyWith(
{int? chatId, StoryList? storyList}) → SetChatActiveStoriesList -
Available on SetChatActiveStoriesList, provided by the SetChatActiveStoriesListExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String