SetChatAffiliateProgram class final

Changes affiliate program for a bot Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatAffiliateProgram({required int chatId, AffiliateProgramParameters? parameters})

Properties

chatId int
chatId Identifier of the chat with an owned bot for which affiliate program is changed
final
hashCode int
The hash code for this object.
no setteroverride
parameters AffiliateProgramParameters?
parameters Parameters of the affiliate program; pass null to close the currently active program. If there is an active program, then commission and program duration can only be increased. If the active program is scheduled to be closed, then it can't be changed anymore
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, AffiliateProgramParameters? parameters}) SetChatAffiliateProgram

Available on SetChatAffiliateProgram, provided by the SetChatAffiliateProgramExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String