parameters property

AffiliateProgramParameters? parameters
final

parameters Parameters of the affiliate program; pass null to close the currently active program. If there is an active program, then commission and program duration can only be increased. If the active program is scheduled to be closed, then it can't be changed anymore

Implementation

final AffiliateProgramParameters? parameters;