SetChatAvailableReactions class final

Changes reactions, available in a chat. Available for basic groups, supergroups, and channels. Requires can_change_info member right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatAvailableReactions({required int chatId, ChatAvailableReactions? availableReactions})

Properties

availableReactions ChatAvailableReactions?
availableReactions Reactions available in the chat. All explicitly specified emoji reactions must be active. In channel chats up to the chat's boost level custom emoji reactions can be explicitly specified
final
chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatAvailableReactions? availableReactions}) SetChatAvailableReactions

Available on SetChatAvailableReactions, provided by the SetChatAvailableReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String