background property
background The input background to use; pass null to create a new filled or chat theme background
Implementation
final InputBackground? background;
background The input background to use; pass null to create a new filled or chat theme background
final InputBackground? background;