SetChatClientData class final
Changes application-specific data associated with a chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatClientData
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatClientData({required int chatId, required String clientData})
Properties
- chatId → int
-
chatId Chat identifier
final
- clientData → String
-
clientData New value of client_data
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? clientData}) → SetChatClientData -
Available on SetChatClientData, provided by the SetChatClientDataExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String