SetChatDescription class final

Changes information about a chat. Available for basic groups, supergroups, and channels. Requires can_change_info member right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatDescription({required int chatId, required String description})

Properties

chatId int
chatId Identifier of the chat
final
description String
param_description New chat description; 0-255 characters
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? description}) SetChatDescription

Available on SetChatDescription, provided by the SetChatDescriptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String