SetChatDraftMessage class final
Changes the draft message in a chat or a topic Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatDraftMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatDraftMessage({required int chatId, MessageTopic? topicId, DraftMessage? draftMessage})
Properties
- chatId → int
-
chatId Chat identifier
final
- draftMessage → DraftMessage?
-
draftMessage New draft message; pass null to remove the draft. All files
in draft message content must be of the type inputFileLocal. Media
thumbnails and captions are ignored
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Topic in which the draft will be changed; pass null to change
the draft for the chat itself
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, DraftMessage? draftMessage}) → SetChatDraftMessage -
Available on SetChatDraftMessage, provided by the SetChatDraftMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String