topicId property
topicId Topic in which the draft will be changed; pass null to change the draft for the chat itself
Implementation
final MessageTopic? topicId;
topicId Topic in which the draft will be changed; pass null to change the draft for the chat itself
final MessageTopic? topicId;