SetChatMessageSender class final

Selects a message sender to send messages in a chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatMessageSender({required int chatId, MessageSender? messageSenderId})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
messageSenderId MessageSender?
messageSenderId New message sender for the chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, MessageSender? messageSenderId}) SetChatMessageSender

Available on SetChatMessageSender, provided by the SetChatMessageSenderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String