notificationSettings property
notificationSettings New notification settings for the chat. If the chat is muted for more than 366 days, it is considered to be muted forever
Implementation
final ChatNotificationSettings? notificationSettings;
notificationSettings New notification settings for the chat. If the chat is muted for more than 366 days, it is considered to be muted forever
final ChatNotificationSettings? notificationSettings;