SetChatPermissions class final

Changes the chat members permissions. Supported only for basic groups and supergroups. Requires can_restrict_members administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatPermissions({required int chatId, ChatPermissions? permissions})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
permissions ChatPermissions?
permissions New non-administrator members permissions in the chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, ChatPermissions? permissions}) SetChatPermissions

Available on SetChatPermissions, provided by the SetChatPermissionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String