SetChatPhoto class final
Changes the photo of a chat. Supported only for basic groups, supergroups and channels. Requires can_change_info member right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatPhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatPhoto({required int chatId, InputChatPhoto? photo})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- photo → InputChatPhoto?
-
photo New chat photo; pass null to delete the chat photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, InputChatPhoto? photo}) → SetChatPhoto -
Available on SetChatPhoto, provided by the SetChatPhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String