SetChatSlowModeDelay class final
Changes the slow mode delay of a chat. Available only for supergroups; requires can_restrict_members administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatSlowModeDelay
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatSlowModeDelay({required int chatId, required int slowModeDelay})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slowModeDelay → int
-
slowModeDelay New slow mode delay for the chat, in seconds; must be one
of 0, 5, 10, 30, 60, 300, 900, 3600
final
Methods
-
copyWith(
{int? chatId, int? slowModeDelay}) → SetChatSlowModeDelay -
Available on SetChatSlowModeDelay, provided by the SetChatSlowModeDelayExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String