SetChatTheme class final
Changes the chat theme. Supported only in private and secret chats Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatTheme
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatTheme({required int chatId, InputChatTheme? theme})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → InputChatTheme?
-
theme New chat theme; pass null to return the default theme
final
Methods
-
copyWith(
{int? chatId, InputChatTheme? theme}) → SetChatTheme -
Available on SetChatTheme, provided by the SetChatThemeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String