SetChatTitle class final

Changes the chat title. Supported only for basic groups, supergroups and channels. Requires can_change_info member right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetChatTitle({required int chatId, required String title})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title New title of the chat; 1-128 characters
final

Methods

copyWith({int? chatId, String? title}) SetChatTitle

Available on SetChatTitle, provided by the SetChatTitleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String