SetCloseFriends class final

Changes the list of close friends of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetCloseFriends({required List<int> userIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<int>
userIds User identifiers of close friends; the users must be contacts of the current user
final

Methods

copyWith({List<int>? userIds}) SetCloseFriends

Available on SetCloseFriends, provided by the SetCloseFriendsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String