SetCustomEmojiStickerSetThumbnail class final

Sets a custom emoji sticker set thumbnail Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetCustomEmojiStickerSetThumbnail({required String name, required int customEmojiId})

Properties

customEmojiId int
customEmojiId Identifier of the custom emoji from the sticker set, which will be set as sticker set thumbnail; pass 0 to remove the sticker set thumbnail
final
hashCode int
The hash code for this object.
no setteroverride
name String
name Sticker set name. The sticker set must be owned by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, int? customEmojiId}) SetCustomEmojiStickerSetThumbnail

Available on SetCustomEmojiStickerSetThumbnail, provided by the SetCustomEmojiStickerSetThumbnailExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String