SetCustomLanguagePack class final
Adds or changes a custom local language pack to the current localization target Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetCustomLanguagePack
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SetCustomLanguagePack({LanguagePackInfo? info, required List<
LanguagePackString> strings})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- info → LanguagePackInfo?
-
info Information about the language pack. Language pack identifier must
start with 'X', consist only of English letters, digits and hyphens, and
must not exceed 64 characters. Can be called before authorization
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
strings
→ List<
LanguagePackString> -
strings Strings of the new language pack
final
Methods
-
copyWith(
{LanguagePackInfo? info, List< LanguagePackString> ? strings}) → SetCustomLanguagePack -
Available on SetCustomLanguagePack, provided by the SetCustomLanguagePackExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String