SetDatabaseEncryptionKey class final
Changes the database encryption key. Usually the encryption key is never changed and is stored in some OS keychain Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetDatabaseEncryptionKey
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDatabaseEncryptionKey({required String newEncryptionKey})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- newEncryptionKey → String
-
newEncryptionKey New encryption key
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? newEncryptionKey}) → SetDatabaseEncryptionKey -
Available on SetDatabaseEncryptionKey, provided by the SetDatabaseEncryptionKeyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String