type property
type Background type; pass null to use the default type of the remote background; backgroundTypeChatTheme isn't supported
Implementation
final BackgroundType? type;
type Background type; pass null to use the default type of the remote background; backgroundTypeChatTheme isn't supported
final BackgroundType? type;