SetDefaultChannelAdministratorRights class final
Sets default administrator rights for adding the bot to channel chats; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetDefaultChannelAdministratorRights
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDefaultChannelAdministratorRights({ChatAdministratorRights? defaultChannelAdministratorRights})
Properties
- defaultChannelAdministratorRights → ChatAdministratorRights?
-
defaultChannelAdministratorRights Default administrator rights for
adding the bot to channels; pass null to remove default rights
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatAdministratorRights? defaultChannelAdministratorRights}) → SetDefaultChannelAdministratorRights -
Available on SetDefaultChannelAdministratorRights, provided by the SetDefaultChannelAdministratorRightsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String