SetDefaultReactionType class final

Changes type of default reaction for the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetDefaultReactionType({ReactionType? reactionType})

Properties

hashCode int
The hash code for this object.
no setteroverride
reactionType ReactionType?
reactionType New type of the default reaction. The paid reaction can't be set as default
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ReactionType? reactionType}) SetDefaultReactionType

Available on SetDefaultReactionType, provided by the SetDefaultReactionTypeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String