SetEmojiStatus class final
Changes the emoji status of the current user; for Telegram Premium users only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetEmojiStatus
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetEmojiStatus({EmojiStatus? emojiStatus})
Properties
- emojiStatus → EmojiStatus?
-
emojiStatus New emoji status; pass null to switch to the default badge
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{EmojiStatus? emojiStatus}) → SetEmojiStatus -
Available on SetEmojiStatus, provided by the SetEmojiStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String