SetFileGenerationProgress class final

Informs TDLib on a file generation progress Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetFileGenerationProgress({required int generationId, required int expectedSize, required int localPrefixSize})

Properties

expectedSize int
expectedSize Expected size of the generated file, in bytes; 0 if unknown
final
generationId int
generationId The identifier of the generation process
final
hashCode int
The hash code for this object.
no setteroverride
localPrefixSize int
localPrefixSize The number of bytes already generated
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, int? expectedSize, int? localPrefixSize}) SetFileGenerationProgress

Available on SetFileGenerationProgress, provided by the SetFileGenerationProgressExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String