SetForumTopicNotificationSettings class final

Changes the notification settings of a forum topic in a forum supergroup chat or a chat with a bot with topics Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetForumTopicNotificationSettings({required int chatId, required int forumTopicId, ChatNotificationSettings? notificationSettings})

Properties

chatId int
chatId Chat identifier
final
forumTopicId int
forumTopicId Forum topic identifier
final
hashCode int
The hash code for this object.
no setteroverride
notificationSettings ChatNotificationSettings?
notificationSettings New notification settings for the forum topic. If the topic is muted for more than 366 days, it is considered to be muted forever
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId, ChatNotificationSettings? notificationSettings}) SetForumTopicNotificationSettings

Available on SetForumTopicNotificationSettings, provided by the SetForumTopicNotificationSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String