SetGameScore class final
Updates the game score of the specified user in the game; for bots only Returns Message
- Inheritance
-
- Object
- TdFunction
- SetGameScore
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId The chat to which the message with the game belongs
final
- editMessage → bool
-
editMessage Pass true to edit the game message to include the current
scoreboard
final
- force → bool
-
force Pass true to update the score even if it decreases. If the score
is 0, the user will be deleted from the high score table
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
score The new score
final
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? chatId, int? messageId, bool? editMessage, int? userId, int? score, bool? force}) → SetGameScore -
Available on SetGameScore, provided by the SetGameScoreExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String