SetGiftCollectionName class final

Changes name of a gift collection. If the collection is owned by a channel chat, then requires can_post_messages administrator right in the channel chat. Returns the changed collection Returns GiftCollection

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetGiftCollectionName({MessageSender? ownerId, required int collectionId, required String name})

Properties

collectionId int
collectionId Identifier of the gift collection
final
hashCode int
The hash code for this object.
no setteroverride
name String
name New name of the collection; 1-12 characters
final
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that owns the collection
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, int? collectionId, String? name}) SetGiftCollectionName

Available on SetGiftCollectionName, provided by the SetGiftCollectionNameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String