SetGiftResalePrice class final

Changes resale price of a unique gift owned by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetGiftResalePrice({required String receivedGiftId, GiftResalePrice? price})

Properties

hashCode int
The hash code for this object.
no setteroverride
price GiftResalePrice?
price The new price for the unique gift; pass null to disallow gift resale. The current user will receive getOption("gift_resale_star_earnings_per_mille") Telegram Stars for each 1000 Telegram Stars paid for the gift if the gift price is in Telegram Stars or getOption("gift_resale_gram_earnings_per_mille") TON Grams for each 1000 Grams paid for the gift if the gift price is in Grams
final
receivedGiftId String
receivedGiftId Identifier of the unique gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? receivedGiftId, GiftResalePrice? price}) SetGiftResalePrice

Available on SetGiftResalePrice, provided by the SetGiftResalePriceExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String