SetGroupCallPaidMessageStarCount class final

Changes the minimum number of Telegram Stars that must be paid by general participant for each sent message to a live story call. Requires groupCall.can_be_managed right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetGroupCallPaidMessageStarCount({required int groupCallId, required int paidMessageStarCount})

Properties

groupCallId int
groupCallId Group call identifier; must be an identifier of a live story call
final
hashCode int
The hash code for this object.
no setteroverride
paidMessageStarCount int
paidMessageStarCount The new minimum number of Telegram Stars; 0-getOption("paid_group_call_message_star_count_max")
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? paidMessageStarCount}) SetGroupCallPaidMessageStarCount

Available on SetGroupCallPaidMessageStarCount, provided by the SetGroupCallPaidMessageStarCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String