SetGroupCallParticipantIsSpeaking class final

Informs TDLib that speaking state of a participant of an active group call has changed. Returns identifier of the participant if it is found Returns MessageSender

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetGroupCallParticipantIsSpeaking({required int groupCallId, required int audioSource, required bool isSpeaking})

Properties

audioSource int
audioSource Group call participant's synchronization audio source identifier, or 0 for the current user
final
groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
isSpeaking bool
isSpeaking Pass true if the user is speaking
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? audioSource, bool? isSpeaking}) SetGroupCallParticipantIsSpeaking

Available on SetGroupCallParticipantIsSpeaking, provided by the SetGroupCallParticipantIsSpeakingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String