SetLiveStoryMessageSender class final

Selects a message sender to send messages in a live story call Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetLiveStoryMessageSender({required int groupCallId, MessageSender? messageSenderId})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
messageSenderId MessageSender?
messageSenderId New message sender for the group call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? messageSenderId}) SetLiveStoryMessageSender

Available on SetLiveStoryMessageSender, provided by the SetLiveStoryMessageSenderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String