SetLoginEmailAddress class final

Changes the login email address of the user. The email address can be changed only if the current user already has login email and passwordState.login_email_address_pattern is non-empty, or the user received suggestedActionSetLoginEmailAddress and isLoginEmailAddressRequired succeeds. The change will not be applied until the new login email address is confirmed with checkLoginEmailAddressCode. To use Apple ID/Google ID instead of an email address, call checkLoginEmailAddressCode directly Returns EmailAddressAuthenticationCodeInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetLoginEmailAddress({required String newLoginEmailAddress})

Properties

hashCode int
The hash code for this object.
no setteroverride
newLoginEmailAddress String
newLoginEmailAddress New login email address
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? newLoginEmailAddress}) SetLoginEmailAddress

Available on SetLoginEmailAddress, provided by the SetLoginEmailAddressExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String