SetMainProfileTab class final

Changes the main profile tab of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetMainProfileTab({ProfileTab? mainProfileTab})

Properties

hashCode int
The hash code for this object.
no setteroverride
mainProfileTab ProfileTab?
mainProfileTab The new value of the main profile tab
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ProfileTab? mainProfileTab}) SetMainProfileTab

Available on SetMainProfileTab, provided by the SetMainProfileTabExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String