SetMenuButton class final

Sets menu button for the given user or for all users; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetMenuButton({required int userId, BotMenuButton? menuButton})

Properties

hashCode int
The hash code for this object.
no setteroverride
menuButton New menu button
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user or 0 to set menu button for all users
final

Methods

copyWith({int? userId, BotMenuButton? menuButton}) SetMenuButton

Available on SetMenuButton, provided by the SetMenuButtonExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String