SetMessageSenderBlockList class final

Changes the block list of a message sender. Currently, only users and supergroup chats can be blocked Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetMessageSenderBlockList({MessageSender? senderId, BlockList? blockList})

Properties

blockList BlockList?
blockList New block list for the message sender; pass null to unblock the message sender
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of a message sender to block/unblock
final

Methods

copyWith({MessageSender? senderId, BlockList? blockList}) SetMessageSenderBlockList

Available on SetMessageSenderBlockList, provided by the SetMessageSenderBlockListExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String