verifiedId property
verifiedId Identifier of the user or the supergroup or channel chat, which will be verified by the bot
Implementation
final MessageSender? verifiedId;
verifiedId Identifier of the user or the supergroup or channel chat, which will be verified by the bot
final MessageSender? verifiedId;