SetNewChatPrivacySettings class final

Changes privacy settings for new chat creation; can be used only if getOption("can_set_new_chat_privacy_settings") Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings NewChatPrivacySettings?
settings New settings
final

Methods

copyWith({NewChatPrivacySettings? settings}) SetNewChatPrivacySettings

Available on SetNewChatPrivacySettings, provided by the SetNewChatPrivacySettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String