SetOption class final

Sets the value of an option. (Check the list of available options on https://core.telegram.org/tdlib/options.) Only writable options can be set. Can be called before authorization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetOption({required String name, OptionValue? value})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name The name of the option
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value OptionValue?
value The new value of the option; pass null to reset option value to a default value
final

Methods

copyWith({String? name, OptionValue? value}) SetOption

Available on SetOption, provided by the SetOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String