SetPaidMessageReactionType class final

Changes type of paid message reaction of the current user on a message. The message must have paid reaction added by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPaidMessageReactionType({required int chatId, required int messageId, PaidReactionType? type})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PaidReactionType?
type New type of the paid reaction
final

Methods

copyWith({int? chatId, int? messageId, PaidReactionType? type}) SetPaidMessageReactionType

Available on SetPaidMessageReactionType, provided by the SetPaidMessageReactionTypeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String