SetPassportElementErrors class final

Informs the user that some of the elements in their Telegram Passport contain errors; for bots only. The user will not be able to resend the elements, until the errors are fixed Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPassportElementErrors({required int userId, required List<InputPassportElementError> errors})

Properties

errors List<InputPassportElementError>
errors The errors
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, List<InputPassportElementError>? errors}) SetPassportElementErrors

Available on SetPassportElementErrors, provided by the SetPassportElementErrorsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String