SetPassword class final

Changes the 2-step verification password for the current user. If a new recovery email address is specified, then the change will not be applied until the new recovery email address is confirmed Returns PasswordState

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPassword({required String oldPassword, required String newPassword, required String newHint, required bool setRecoveryEmailAddress, required String newRecoveryEmailAddress})

Properties

hashCode int
The hash code for this object.
no setteroverride
newHint String
newHint New password hint; may be empty
final
newPassword String
newPassword New 2-step verification password of the user; may be empty to remove the password
final
newRecoveryEmailAddress String
newRecoveryEmailAddress New recovery email address; may be empty
final
oldPassword String
oldPassword Previous 2-step verification password of the user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setRecoveryEmailAddress bool
setRecoveryEmailAddress Pass true to change also the recovery email address
final

Methods

copyWith({String? oldPassword, String? newPassword, String? newHint, bool? setRecoveryEmailAddress, String? newRecoveryEmailAddress}) SetPassword

Available on SetPassword, provided by the SetPasswordExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String