SetPersonalChat class final

Changes the personal chat of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPersonalChat({required int chatId})

Properties

chatId int
chatId Identifier of the new personal chat; pass 0 to remove the chat. Use getSuitablePersonalChats to get suitable chats
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId}) SetPersonalChat

Available on SetPersonalChat, provided by the SetPersonalChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String