SetPinnedChats class final

Changes the order of pinned chats Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPinnedChats({ChatList? chatList, required List<int> chatIds})

Properties

chatIds List<int>
chatIds The new list of pinned chats
final
chatList ChatList?
chatList Chat list in which to change the order of pinned chats
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList, List<int>? chatIds}) SetPinnedChats

Available on SetPinnedChats, provided by the SetPinnedChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String