SetPinnedForumTopics class final

Changes the order of pinned topics in a forum supergroup chat or a chat with a bot with topics; requires can_manage_topics administrator right in the supergroup Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPinnedForumTopics({required int chatId, required List<int> forumTopicIds})

Properties

chatId int
chatId Chat identifier
final
forumTopicIds List<int>
forumTopicIds The new list of identifiers of the pinned forum topics
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, List<int>? forumTopicIds}) SetPinnedForumTopics

Available on SetPinnedForumTopics, provided by the SetPinnedForumTopicsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String