SetPinnedGifts class final

Changes the list of pinned gifts on the current user's or the channel's profile page; requires can_post_messages administrator right in the channel chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPinnedGifts({MessageSender? ownerId, required List<String> receivedGiftIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that received the gifts
final
receivedGiftIds List<String>
receivedGiftIds New list of pinned gifts. All gifts must be upgraded and saved on the profile page first. There can be up to getOption("pinned_gift_count_max") pinned gifts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, List<String>? receivedGiftIds}) SetPinnedGifts

Available on SetPinnedGifts, provided by the SetPinnedGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String