profileBackgroundCustomEmojiId property
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown on the user's profile photo background; 0 if none
Implementation
final int profileBackgroundCustomEmojiId;
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown on the user's profile photo background; 0 if none
final int profileBackgroundCustomEmojiId;