SetProfileAudioPosition class final

Changes position of an audio file in the profile audio files of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetProfileAudioPosition({required int fileId, required int afterFileId})

Properties

afterFileId int
afterFileId Identifier of the file from profile audio files after which the file will be positioned; pass 0 to move the file to the beginning of the list
final
fileId int
fileId Identifier of the file from profile audio files, which position will be changed
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, int? afterFileId}) SetProfileAudioPosition

Available on SetProfileAudioPosition, provided by the SetProfileAudioPositionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String