SetProfilePhoto class final

Changes a profile photo for the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetProfilePhoto({InputChatPhoto? photo, required bool isPublic})

Properties

hashCode int
The hash code for this object.
no setteroverride
isPublic bool
isPublic Pass true to set the public photo, which will be visible even if the main photo is hidden by privacy settings
final
photo InputChatPhoto?
photo Profile photo to set
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputChatPhoto? photo, bool? isPublic}) SetProfilePhoto

Available on SetProfilePhoto, provided by the SetProfilePhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String