SetReadDatePrivacySettings class final

Changes privacy settings for message read date Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
settings ReadDatePrivacySettings?
settings New settings
final

Methods

copyWith({ReadDatePrivacySettings? settings}) SetReadDatePrivacySettings

Available on SetReadDatePrivacySettings, provided by the SetReadDatePrivacySettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String