notificationSettings property
notificationSettings The new notification settings for the given scope
Implementation
final ScopeNotificationSettings? notificationSettings;
notificationSettings The new notification settings for the given scope
final ScopeNotificationSettings? notificationSettings;