SetStickerEmojis class final

Changes the list of emojis corresponding to a sticker. The sticker must belong to a regular or custom emoji sticker set that is owned by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetStickerEmojis({InputFile? sticker, required String emojis})

Properties

emojis String
emojis New string with 1-20 emoji corresponding to the sticker
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker Sticker
final

Methods

copyWith({InputFile? sticker, String? emojis}) SetStickerEmojis

Available on SetStickerEmojis, provided by the SetStickerEmojisExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String