SetStickerMaskPosition class final
Changes the mask position of a mask sticker. The sticker must belong to a mask sticker set that is owned by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetStickerMaskPosition
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetStickerMaskPosition({InputFile? sticker, MaskPosition? maskPosition})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maskPosition → MaskPosition?
-
maskPosition Position where the mask is placed; pass null to remove mask
position
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputFile?
-
sticker Sticker
final
Methods
-
copyWith(
{InputFile? sticker, MaskPosition? maskPosition}) → SetStickerMaskPosition -
Available on SetStickerMaskPosition, provided by the SetStickerMaskPositionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String