SetStickerPositionInSet class final
Changes the position of a sticker in the set to which it belongs. The sticker set must be owned by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetStickerPositionInSet
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetStickerPositionInSet({InputFile? sticker, required int position})
Properties
Methods
-
copyWith(
{InputFile? sticker, int? position}) → SetStickerPositionInSet -
Available on SetStickerPositionInSet, provided by the SetStickerPositionInSetExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String