SetStickerSetThumbnail class final

Sets a sticker set thumbnail Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetStickerSetThumbnail({required int userId, required String name, InputFile? thumbnail, StickerFormat? format})

Properties

format StickerFormat?
format Format of the thumbnail; pass null if thumbnail is removed
final
hashCode int
The hash code for this object.
no setteroverride
name String
name Sticker set name. The sticker set must be owned by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail InputFile?
thumbnail Thumbnail to set; pass null to remove the sticker set thumbnail
final
userId int
userId Sticker set owner; ignored for regular users
final

Methods

copyWith({int? userId, String? name, InputFile? thumbnail, StickerFormat? format}) SetStickerSetThumbnail

Available on SetStickerSetThumbnail, provided by the SetStickerSetThumbnailExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String