SetStickerSetTitle class final

Sets a sticker set title Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetStickerSetTitle({required String name, required String title})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Sticker set name. The sticker set must be owned by the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title New sticker set title
final

Methods

copyWith({String? name, String? title}) SetStickerSetTitle

Available on SetStickerSetTitle, provided by the SetStickerSetTitleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String