SetStoryPrivacySettings class final

Changes privacy settings of a story. The method can be called only for stories posted on behalf of the current user and if story.can_set_privacy_settings == true Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetStoryPrivacySettings({required int storyId, StoryPrivacySettings? privacySettings})

Properties

hashCode int
The hash code for this object.
no setteroverride
privacySettings StoryPrivacySettings?
privacySettings The new privacy settings for the story
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story
final

Methods

copyWith({int? storyId, StoryPrivacySettings? privacySettings}) SetStoryPrivacySettings

Available on SetStoryPrivacySettings, provided by the SetStoryPrivacySettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String