SetSupergroupCustomEmojiStickerSet class final

Changes the custom emoji sticker set of a supergroup; requires can_change_info administrator right. The chat must have at least chatBoostFeatures.min_custom_emoji_sticker_set_boost_level boost level to pass the corresponding color Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetSupergroupCustomEmojiStickerSet({required int supergroupId, required int customEmojiStickerSetId})

Properties

customEmojiStickerSetId int
customEmojiStickerSetId New value of the custom emoji sticker set identifier for the supergroup. Use 0 to remove the custom emoji sticker set in the supergroup
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup
final

Methods

copyWith({int? supergroupId, int? customEmojiStickerSetId}) SetSupergroupCustomEmojiStickerSet

Available on SetSupergroupCustomEmojiStickerSet, provided by the SetSupergroupCustomEmojiStickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String