customEmojiStickerSetId property

int customEmojiStickerSetId
final

customEmojiStickerSetId New value of the custom emoji sticker set identifier for the supergroup. Use 0 to remove the custom emoji sticker set in the supergroup

Implementation

final int customEmojiStickerSetId;