SetSupergroupMainProfileTab class final

Changes the main profile tab of the channel; requires can_change_info administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetSupergroupMainProfileTab({required int supergroupId, ProfileTab? mainProfileTab})

Properties

hashCode int
The hash code for this object.
no setteroverride
mainProfileTab ProfileTab?
mainProfileTab The new value of the main profile tab
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the channel
final

Methods

copyWith({int? supergroupId, ProfileTab? mainProfileTab}) SetSupergroupMainProfileTab

Available on SetSupergroupMainProfileTab, provided by the SetSupergroupMainProfileTabExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String