SetSupergroupStickerSet class final
Changes the sticker set of a supergroup; requires can_change_info administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetSupergroupStickerSet
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetSupergroupStickerSet({required int supergroupId, required int stickerSetId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerSetId → int
-
stickerSetId New value of the supergroup sticker set identifier. Use 0
to remove the supergroup sticker set
final
- supergroupId → int
-
supergroupId Identifier of the supergroup
final
Methods
-
copyWith(
{int? supergroupId, int? stickerSetId}) → SetSupergroupStickerSet -
Available on SetSupergroupStickerSet, provided by the SetSupergroupStickerSetExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String