SetSupergroupUnrestrictBoostCount class final

Changes the number of times the supergroup must be boosted by a user to ignore slow mode and chat permission restrictions; requires can_restrict_members administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetSupergroupUnrestrictBoostCount({required int supergroupId, required int unrestrictBoostCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup
final
unrestrictBoostCount int
unrestrictBoostCount New value of the unrestrict_boost_count supergroup setting; 0-8. Use 0 to remove the setting
final

Methods

copyWith({int? supergroupId, int? unrestrictBoostCount}) SetSupergroupUnrestrictBoostCount

Available on SetSupergroupUnrestrictBoostCount, provided by the SetSupergroupUnrestrictBoostCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String