SetSupergroupUsername class final
Changes the editable username of a supergroup or channel, requires owner privileges in the supergroup or channel Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetSupergroupUsername
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetSupergroupUsername({required int supergroupId, required String username})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId Identifier of the supergroup or channel
final
- username → String
-
username New value of the username. Use an empty string to remove the
username. The username can't be completely removed if there is another
active or disabled username
final
Methods
-
copyWith(
{int? supergroupId, String? username}) → SetSupergroupUsername -
Available on SetSupergroupUsername, provided by the SetSupergroupUsernameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String