SetTdlibParameters class final
Sets the parameters for TDLib initialization. Works only when the current authorization state is authorizationStateWaitTdlibParameters Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetTdlibParameters
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetTdlibParameters({required bool useTestDc, required String databaseDirectory, required String filesDirectory, required String databaseEncryptionKey, required bool useFileDatabase, required bool useChatInfoDatabase, required bool useMessageDatabase, required bool useSecretChats, required int apiId, required String apiHash, required String systemLanguageCode, required String deviceModel, required String systemVersion, required String applicationVersion})
Properties
- apiHash → String
-
apiHash Application identifier hash for Telegram API access, which can
be obtained at https://my.telegram.org
final
- apiId → int
-
apiId Application identifier for Telegram API access, which can be
obtained at https://my.telegram.org
final
- applicationVersion → String
-
applicationVersion Application version; must be non-empty
final
- databaseDirectory → String
-
databaseDirectory The path to the directory for the persistent database;
if empty, the current working directory will be used
final
- databaseEncryptionKey → String
-
databaseEncryptionKey Encryption key for the database. If the encryption
key is invalid, then an error with code 401 will be returned
final
- deviceModel → String
-
deviceModel Model of the device the application is being run on; must be
non-empty
final
- filesDirectory → String
-
filesDirectory The path to the directory for storing files; if empty,
database_directory will be used
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemLanguageCode → String
-
systemLanguageCode IETF language tag of the user's operating system
language; must be non-empty
final
- systemVersion → String
-
systemVersion Version of the operating system the application is being
run on. If empty, the version is automatically detected by TDLib
final
- useChatInfoDatabase → bool
-
useChatInfoDatabase Pass true to keep cache of users, basic groups,
supergroups, channels and secret chats between restarts. Implies
use_file_database
final
- useFileDatabase → bool
-
useFileDatabase Pass true to keep information about downloaded and
uploaded files between application restarts
final
- useMessageDatabase → bool
-
useMessageDatabase Pass true to keep cache of chats and messages between
restarts. Implies use_chat_info_database
final
- useSecretChats → bool
-
useSecretChats Pass true to enable support for secret chats
final
- useTestDc → bool
-
useTestDc Pass true to use Telegram test environment instead of the
production environment
final
Methods
-
copyWith(
{bool? useTestDc, String? databaseDirectory, String? filesDirectory, String? databaseEncryptionKey, bool? useFileDatabase, bool? useChatInfoDatabase, bool? useMessageDatabase, bool? useSecretChats, int? apiId, String? apiHash, String? systemLanguageCode, String? deviceModel, String? systemVersion, String? applicationVersion}) → SetTdlibParameters -
Available on SetTdlibParameters, provided by the SetTdlibParametersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String