SetUpgradedGiftColors class final

Changes color scheme for the current user based on an owned or a hosted upgraded gift; for Telegram Premium users only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetUpgradedGiftColors({required int upgradedGiftColorsId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upgradedGiftColorsId int
upgradedGiftColorsId Identifier of the upgradedGiftColors scheme to use
final

Methods

copyWith({int? upgradedGiftColorsId}) SetUpgradedGiftColors

Available on SetUpgradedGiftColors, provided by the SetUpgradedGiftColorsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String