SetUserEmojiStatus class final

Changes the emoji status of a user; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetUserEmojiStatus({required int userId, EmojiStatus? emojiStatus})

Properties

emojiStatus EmojiStatus?
emojiStatus New emoji status; pass null to switch to the default badge
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId, EmojiStatus? emojiStatus}) SetUserEmojiStatus

Available on SetUserEmojiStatus, provided by the SetUserEmojiStatusExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String