SetUserPersonalProfilePhoto class final
Changes a personal profile photo of a contact user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetUserPersonalProfilePhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetUserPersonalProfilePhoto({required int userId, InputChatPhoto? photo})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- photo → InputChatPhoto?
-
photo Profile photo to set; pass null to delete the photo;
inputChatPhotoPrevious isn't supported in this function
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, InputChatPhoto? photo}) → SetUserPersonalProfilePhoto -
Available on SetUserPersonalProfilePhoto, provided by the SetUserPersonalProfilePhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String