SetUserPrivacySettingRules class final

Changes user privacy settings Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
rules UserPrivacySettingRules?
rules The new privacy rules
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setting UserPrivacySetting?
setting The privacy setting
final

Methods

copyWith({UserPrivacySetting? setting, UserPrivacySettingRules? rules}) SetUserPrivacySettingRules

Available on SetUserPrivacySettingRules, provided by the SetUserPrivacySettingRulesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String