SetUserSupportInfo class final
Sets support information for the given user; for Telegram support only Returns UserSupportInfo
- Inheritance
-
- Object
- TdFunction
- SetUserSupportInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetUserSupportInfo({required int userId, FormattedText? message})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → FormattedText?
-
message New information message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, FormattedText? message}) → SetUserSupportInfo -
Available on SetUserSupportInfo, provided by the SetUserSupportInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String