SetUsername class final

Changes the editable username of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetUsername({required String username})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
username The new value of the username. Use an empty string to remove the username. The username can't be completely removed if there is another active or disabled username
final

Methods

copyWith({String? username}) SetUsername

Available on SetUsername, provided by the SetUsernameExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String