defaultParticipantId property
defaultParticipantId Default group call participant identifier to join the video chats in the chat
Implementation
final MessageSender? defaultParticipantId;
defaultParticipantId Default group call participant identifier to join the video chats in the chat
final MessageSender? defaultParticipantId;