SetVideoChatTitle class final

Sets title of a video chat; requires groupCall.can_be_managed right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetVideoChatTitle({required int groupCallId, required String title})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title New group call title; 1-64 characters
final

Methods

copyWith({int? groupCallId, String? title}) SetVideoChatTitle

Available on SetVideoChatTitle, provided by the SetVideoChatTitleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String