SettingsSection class sealed

Describes a section of the application settings

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult appearance(SettingsSectionAppearance value), required TResult askQuestion(SettingsSectionAskQuestion value), required TResult business(SettingsSectionBusiness value), required TResult chatFolders(SettingsSectionChatFolders value), required TResult dataAndStorage(SettingsSectionDataAndStorage value), required TResult devices(SettingsSectionDevices value), required TResult editProfile(SettingsSectionEditProfile value), required TResult faq(SettingsSectionFaq value), required TResult features(SettingsSectionFeatures value), required TResult inAppBrowser(SettingsSectionInAppBrowser value), required TResult language(SettingsSectionLanguage value), required TResult myGrams(SettingsSectionMyGrams value), required TResult myStars(SettingsSectionMyStars value), required TResult notifications(SettingsSectionNotifications value), required TResult powerSaving(SettingsSectionPowerSaving value), required TResult premium(SettingsSectionPremium value), required TResult privacyAndSecurity(SettingsSectionPrivacyAndSecurity value), required TResult privacyPolicy(SettingsSectionPrivacyPolicy value), required TResult qrCode(SettingsSectionQrCode value), required TResult search(SettingsSectionSearch value), required TResult sendGift(SettingsSectionSendGift value)}) → TResult

Available on SettingsSection, provided by the SettingsSectionExtensions extension

maybeMap<TResult extends Object?>({TResult appearance(SettingsSectionAppearance value)?, TResult askQuestion(SettingsSectionAskQuestion value)?, TResult business(SettingsSectionBusiness value)?, TResult chatFolders(SettingsSectionChatFolders value)?, TResult dataAndStorage(SettingsSectionDataAndStorage value)?, TResult devices(SettingsSectionDevices value)?, TResult editProfile(SettingsSectionEditProfile value)?, TResult faq(SettingsSectionFaq value)?, TResult features(SettingsSectionFeatures value)?, TResult inAppBrowser(SettingsSectionInAppBrowser value)?, TResult language(SettingsSectionLanguage value)?, TResult myGrams(SettingsSectionMyGrams value)?, TResult myStars(SettingsSectionMyStars value)?, TResult notifications(SettingsSectionNotifications value)?, TResult powerSaving(SettingsSectionPowerSaving value)?, TResult premium(SettingsSectionPremium value)?, TResult privacyAndSecurity(SettingsSectionPrivacyAndSecurity value)?, TResult privacyPolicy(SettingsSectionPrivacyPolicy value)?, TResult qrCode(SettingsSectionQrCode value)?, TResult search(SettingsSectionSearch value)?, TResult sendGift(SettingsSectionSendGift value)?, required TResult orElse()}) → TResult

Available on SettingsSection, provided by the SettingsSectionExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String