ShareChatWithBot class final
Shares a chat after pressing a keyboardButtonTypeRequestChat button with the bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- ShareChatWithBot
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
buttonId Identifier of the button
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyCheck → bool
-
onlyCheck Pass true to check that the chat can be shared by the button
instead of actually sharing it. Doesn't check bot_is_member and
bot_administrator_rights restrictions. If the bot must be a member, then
all chats from getGroupsInCommon and all chats, where the user can add the
bot, are suitable. In the latter case the bot will be automatically added
to the chat. If the bot must be an administrator, then all chats, where
the bot already has requested rights or can be added to administrators by
the user, are suitable. In the latter case the bot will be automatically
granted requested rights
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sharedChatId Identifier of the shared chat
final
- source → KeyboardButtonSource?
-
source Source of the button
final
Methods
-
copyWith(
{KeyboardButtonSource? source, int? buttonId, bool? onlyCheck}) → ShareChatWithBot -
Available on ShareChatWithBot, provided by the ShareChatWithBotExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String