SharePhoneNumber class final
Shares the phone number of the current user with a mutual contact. Supposed to be called when the user clicks on chatActionBarSharePhoneNumber Returns Ok
- Inheritance
-
- Object
- TdFunction
- SharePhoneNumber
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
Methods
-
copyWith(
{int? userId}) → SharePhoneNumber -
Available on SharePhoneNumber, provided by the SharePhoneNumberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String