ShareUsersWithBot class final

Shares users after pressing a keyboardButtonTypeRequestUsers button with the bot Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ShareUsersWithBot({KeyboardButtonSource? source, required int buttonId, required List<int> sharedUserIds, required bool onlyCheck})

Properties

buttonId int
buttonId Identifier of the button
final
hashCode int
The hash code for this object.
no setteroverride
onlyCheck bool
onlyCheck Pass true to check that the users can be shared by the button instead of actually sharing them
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedUserIds List<int>
sharedUserIds Identifiers of the shared users
final
source KeyboardButtonSource?
source Source of the button
final

Methods

copyWith({KeyboardButtonSource? source, int? buttonId, List<int>? sharedUserIds, bool? onlyCheck}) ShareUsersWithBot

Available on ShareUsersWithBot, provided by the ShareUsersWithBotExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String