SharedChat class final

Contains information about a chat shared with a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SharedChat({required int chatId, String? title, String? username, Photo? photo})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo Photo of the chat; for bots only; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
title Title of the chat; for bots only
final
username String?
username Username of the chat; for bots only
final

Methods

copyWith({int? chatId, String? title, String? username, Photo? photo}) SharedChat

Available on SharedChat, provided by the SharedChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SharedChat?

Constants

constructor → const String