SharedUser class final

Contains information about a user shared with a bot

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SharedUser({required int userId, String? firstName, String? lastName, String? username, Photo? photo})

Properties

firstName String?
firstName First name of the user; for bots only
final
hashCode int
The hash code for this object.
no setteroverride
lastName String?
lastName Last name of the user; for bots only
final
photo Photo?
photo Profile photo of the user; for bots only; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final
username String?
username Username of the user; for bots only
final

Methods

copyWith({int? userId, String? firstName, String? lastName, String? username, Photo? photo}) SharedUser

Available on SharedUser, provided by the SharedUserExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SharedUser?

Constants

constructor → const String