SpeechRecognitionResult class sealed

Describes result of speech recognition in a voice note

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult error(SpeechRecognitionResultError value), required TResult pending(SpeechRecognitionResultPending value), required TResult text(SpeechRecognitionResultText value)}) → TResult

Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension

maybeMap<TResult extends Object?>({TResult error(SpeechRecognitionResultError value)?, TResult pending(SpeechRecognitionResultPending value)?, TResult text(SpeechRecognitionResultText value)?, required TResult orElse()}) → TResult

Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String