SpeechRecognitionResultError class final

The speech recognition failed

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SpeechRecognitionResultError({TdError? error})

Properties

error TdError?
error Recognition error. An error with a message "MSG_VOICE_TOO_LONG" is returned when media duration is too big to be recognized
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TdError? error}) SpeechRecognitionResultError

Available on SpeechRecognitionResultError, provided by the SpeechRecognitionResultErrorExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult error(SpeechRecognitionResultError value), required TResult pending(SpeechRecognitionResultPending value), required TResult text(SpeechRecognitionResultText value)}) → TResult

Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension

maybeMap<TResult extends Object?>({TResult error(SpeechRecognitionResultError value)?, TResult pending(SpeechRecognitionResultPending value)?, TResult text(SpeechRecognitionResultText value)?, required TResult orElse()}) → TResult

Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String