SponsoredChat class final

Describes a sponsored chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SponsoredChat({required int uniqueId, required int chatId, String? sponsorInfo, required String additionalInfo})

Properties

additionalInfo String
additionalInfo If non-empty, additional information about the sponsored chat to be shown along with the chat
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sponsorInfo String?
sponsorInfo Additional optional information about the sponsor to be shown along with the chat
final
uniqueId int
uniqueId Unique identifier of this result
final

Methods

copyWith({int? uniqueId, int? chatId, String? sponsorInfo, String? additionalInfo}) SponsoredChat

Available on SponsoredChat, provided by the SponsoredChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SponsoredChat?

Constants

constructor → const String