additionalInfo property
additionalInfo If non-empty, additional information about the sponsored chat to be shown along with the chat
Implementation
final String additionalInfo;
additionalInfo If non-empty, additional information about the sponsored chat to be shown along with the chat
final String additionalInfo;