sponsorInfo property
sponsorInfo Additional optional information about the sponsor to be shown along with the chat
Implementation
final String? sponsorInfo;
sponsorInfo Additional optional information about the sponsor to be shown along with the chat
final String? sponsorInfo;