SponsoredChats class final
Contains a list of sponsored chats
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SponsoredChats({required List<
SponsoredChat> chats})
Properties
-
chats
→ List<
SponsoredChat> -
chats List of sponsored chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< SponsoredChat> ? chats}) → SponsoredChats -
Available on SponsoredChats, provided by the SponsoredChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SponsoredChats?
Constants
- constructor → const String