accentColorId property
accentColorId Identifier of the accent color for title, button text and message background
Implementation
final int accentColorId;
accentColorId Identifier of the accent color for title, button text and message background
final int accentColorId;