backgroundCustomEmojiId property
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the message background; 0 if none
Implementation
final int backgroundCustomEmojiId;
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the message background; 0 if none
final int backgroundCustomEmojiId;