canBeReported property
canBeReported True, if the message can be reported to Telegram moderators through reportChatSponsoredMessage
Implementation
final bool canBeReported;
canBeReported True, if the message can be reported to Telegram moderators through reportChatSponsoredMessage
final bool canBeReported;