StarCount class final

Contains a number of Telegram Stars

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarCount({required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Number of Telegram Stars
final

Methods

copyWith({int? starCount}) StarCount

Available on StarCount, provided by the StarCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarCount?

Constants

constructor → const String