yearlyBoostCount property
yearlyBoostCount Number of times the chat will be boosted for one year if the option is chosen
Implementation
final int yearlyBoostCount;
yearlyBoostCount Number of times the chat will be boosted for one year if the option is chosen
final int yearlyBoostCount;