StarGiveawayWinnerOption class final

Describes an option for the number of winners of a Telegram Star giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarGiveawayWinnerOption({required int winnerCount, required int wonStarCount, required bool isDefault})

Properties

hashCode int
The hash code for this object.
no setteroverride
isDefault bool
isDefault True, if the option must be chosen by default
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winnerCount int
winnerCount The number of users that will be chosen as winners
final
wonStarCount int
wonStarCount The number of Telegram Stars that will be won by the winners of the giveaway
final

Methods

copyWith({int? winnerCount, int? wonStarCount, bool? isDefault}) StarGiveawayWinnerOption

Available on StarGiveawayWinnerOption, provided by the StarGiveawayWinnerOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarGiveawayWinnerOption?

Constants

constructor → const String