StarPaymentOption class final

Describes an option for buying Telegram Stars. Use telegramPaymentPurposeStars for out-of-store payments

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarPaymentOption({required String currency, required int amount, required int starCount, required String storeProductId, required bool isAdditional})

Properties

amount int
amount The amount to pay, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code for the payment
final
hashCode int
The hash code for this object.
no setteroverride
isAdditional bool
isAdditional True, if the option must be shown only in the full list of payment options
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Number of Telegram Stars that will be purchased
final
storeProductId String
storeProductId Identifier of the store product associated with the option; may be empty if none
final

Methods

copyWith({String? currency, int? amount, int? starCount, String? storeProductId, bool? isAdditional}) StarPaymentOption

Available on StarPaymentOption, provided by the StarPaymentOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarPaymentOption?

Constants

constructor → const String