isAdditional property
isAdditional True, if the option must be shown only in the full list of payment options
Implementation
final bool isAdditional;
isAdditional True, if the option must be shown only in the full list of payment options
final bool isAdditional;