StarRevenueStatistics class final

A detailed statistics about Telegram Stars earned by a user or a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarRevenueStatistics({StatisticalGraph? revenueByDayGraph, StarRevenueStatus? status, required double usdRate})

Properties

hashCode int
The hash code for this object.
no setteroverride
revenueByDayGraph StatisticalGraph?
revenueByDayGraph A graph containing amount of revenue in a given day
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status StarRevenueStatus?
status Telegram Star revenue status
final
usdRate double
usdRate Current conversion rate of a Telegram Star to USD
final

Methods

copyWith({StatisticalGraph? revenueByDayGraph, StarRevenueStatus? status, double? usdRate}) StarRevenueStatistics

Available on StarRevenueStatistics, provided by the StarRevenueStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarRevenueStatistics?

Constants

constructor → const String