StarRevenueStatus class final

Contains information about Telegram Stars earned by a user or a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarRevenueStatus({StarAmount? totalAmount, StarAmount? currentAmount, StarAmount? availableAmount, required bool withdrawalEnabled, required int nextWithdrawalIn})

Properties

availableAmount StarAmount?
availableAmount The Telegram Star amount that is available for withdrawal
final
currentAmount StarAmount?
currentAmount The Telegram Star amount that isn't withdrawn yet
final
hashCode int
The hash code for this object.
no setteroverride
nextWithdrawalIn int
nextWithdrawalIn Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAmount StarAmount?
totalAmount Total Telegram Star amount earned
final
withdrawalEnabled bool
withdrawalEnabled True, if Telegram Stars can be withdrawn now or later
final

Methods

copyWith({StarAmount? totalAmount, StarAmount? currentAmount, StarAmount? availableAmount, bool? withdrawalEnabled, int? nextWithdrawalIn}) StarRevenueStatus

Available on StarRevenueStatus, provided by the StarRevenueStatusExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarRevenueStatus?

Constants

constructor → const String