nextWithdrawalIn property
nextWithdrawalIn Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now
Implementation
final int nextWithdrawalIn;
nextWithdrawalIn Time left before the next withdrawal can be started, in seconds; 0 if withdrawal can be started now
final int nextWithdrawalIn;