isExpiring property
isExpiring True, if the subscription expires soon and there aren't enough Telegram Stars on the user's balance to extend it
Implementation
final bool isExpiring;
isExpiring True, if the subscription expires soon and there aren't enough Telegram Stars on the user's balance to extend it
final bool isExpiring;