StarSubscriptionPricing class final

Describes subscription plan paid in Telegram Stars

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarSubscriptionPricing({required int period, required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
period int
period The number of seconds between consecutive Telegram Star debiting
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount that must be paid for each period
final

Methods

copyWith({int? period, int? starCount}) StarSubscriptionPricing

Available on StarSubscriptionPricing, provided by the StarSubscriptionPricingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarSubscriptionPricing?

Constants

constructor → const String