StarSubscriptionType class sealed
Describes type of subscription paid in Telegram Stars
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bot(StarSubscriptionTypeBot value), required TResult channel(StarSubscriptionTypeChannel value)}) → TResult -
Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bot(StarSubscriptionTypeBot value)?, TResult channel(StarSubscriptionTypeChannel value)?, required TResult orElse()}) → TResult -
Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StarSubscriptionType? - Inherited by: StarSubscriptionTypeBot StarSubscriptionTypeChannel
Constants
- constructor → const String