StarSubscriptionTypeBot class final

Describes a subscription in a bot or a business account

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarSubscriptionTypeBot({required bool isCanceledByBot, required String title, Photo? photo, required String invoiceLink})

Properties

hashCode int
The hash code for this object.
no setteroverride
invoiceLink The link to the subscription invoice
final
isCanceledByBot bool
isCanceledByBot True, if the subscription was canceled by the bot and can't be extended
final
photo Photo?
photo Subscription invoice photo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Subscription invoice title
final

Methods

copyWith({bool? isCanceledByBot, String? title, Photo? photo, String? invoiceLink}) StarSubscriptionTypeBot

Available on StarSubscriptionTypeBot, provided by the StarSubscriptionTypeBotExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult bot(StarSubscriptionTypeBot value), required TResult channel(StarSubscriptionTypeChannel value)}) → TResult

Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult bot(StarSubscriptionTypeBot value)?, TResult channel(StarSubscriptionTypeChannel value)?, required TResult orElse()}) → TResult

Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarSubscriptionTypeBot?
Inherited by: StarSubscriptionTypeBot StarSubscriptionTypeChannel
override

Constants

constructor → const String