StarSubscriptionTypeChannel class final

Describes a subscription to a channel chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarSubscriptionTypeChannel({required bool canReuse, required String inviteLink})

Properties

canReuse bool
canReuse True, if the subscription is active and the user can use the method reuseStarSubscription to join the subscribed chat again
final
hashCode int
The hash code for this object.
no setteroverride
inviteLink The invite link that can be used to renew the subscription if it has expired; may be empty if the link isn't available anymore
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? canReuse, String? inviteLink}) StarSubscriptionTypeChannel

Available on StarSubscriptionTypeChannel, provided by the StarSubscriptionTypeChannelExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult bot(StarSubscriptionTypeBot value), required TResult channel(StarSubscriptionTypeChannel value)}) → TResult

Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult bot(StarSubscriptionTypeBot value)?, TResult channel(StarSubscriptionTypeChannel value)?, required TResult orElse()}) → TResult

Available on StarSubscriptionType, provided by the StarSubscriptionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarSubscriptionTypeChannel?
Inherited by: StarSubscriptionTypeBot StarSubscriptionTypeChannel
override

Constants

constructor → const String