inviteLink property
inviteLink The invite link that can be used to renew the subscription if it has expired; may be empty if the link isn't available anymore
Implementation
final String inviteLink;
inviteLink The invite link that can be used to renew the subscription if it has expired; may be empty if the link isn't available anymore
final String inviteLink;