StarTransaction class final

Represents a transaction changing the amount of owned Telegram Stars

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarTransaction({required String id, StarAmount? starAmount, required bool isRefund, required int date, StarTransactionType? type})

Properties

date int
date Point in time (Unix timestamp) when the transaction was completed
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the transaction
final
isRefund bool
isRefund True, if the transaction is a refund of a previous transaction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starAmount StarAmount?
starAmount The amount of added owned Telegram Stars; negative for outgoing transactions
final
type StarTransactionType?
type Type of the transaction
final

Methods

copyWith({String? id, StarAmount? starAmount, bool? isRefund, int? date, StarTransactionType? type}) StarTransaction

Available on StarTransaction, provided by the StarTransactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarTransaction?

Constants

constructor → const String