affiliate property
affiliate Information about the affiliate which received commission from the transaction; may be null if none
Implementation
final AffiliateInfo? affiliate;
affiliate Information about the affiliate which received commission from the transaction; may be null if none
final AffiliateInfo? affiliate;