StarTransactions class final

Represents a list of Telegram Star transactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StarTransactions({StarAmount? starAmount, required List<StarTransaction> transactions, required String nextOffset})

Properties

hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starAmount StarAmount?
starAmount The amount of owned Telegram Stars
final
transactions List<StarTransaction>
transactions List of transactions with Telegram Stars
final

Methods

copyWith({StarAmount? starAmount, List<StarTransaction>? transactions, String? nextOffset}) StarTransactions

Available on StarTransactions, provided by the StarTransactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StarTransactions?

Constants

constructor → const String