StartGroupCallRecording class final
Starts recording of an active group call; for video chats only. Requires groupCall.can_be_managed right Returns Ok
- Inheritance
-
- Object
- TdFunction
- StartGroupCallRecording
- Available extensions
- Annotations
-
- @immutable
Constructors
- StartGroupCallRecording({required int groupCallId, required String title, required bool recordVideo, required bool usePortraitOrientation})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- recordVideo → bool
-
recordVideo Pass true to record a video file instead of an audio file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Group call recording title; 0-64 characters
final
- usePortraitOrientation → bool
-
usePortraitOrientation Pass true to use portrait orientation for video
instead of landscape one
final
Methods
-
copyWith(
{int? groupCallId, String? title, bool? recordVideo, bool? usePortraitOrientation}) → StartGroupCallRecording -
Available on StartGroupCallRecording, provided by the StartGroupCallRecordingExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String