StartGroupCallScreenSharing class final

Starts screen sharing in a joined group call; not supported in live stories. Returns join response payload for tgcalls Returns Text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StartGroupCallScreenSharing({required int groupCallId, required int audioSourceId, required String payload})

Properties

audioSourceId int
audioSourceId Screen sharing audio channel synchronization source identifier; received from tgcalls
final
groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
payload String
payload Group call join payload; received from tgcalls
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, int? audioSourceId, String? payload}) StartGroupCallScreenSharing

Available on StartGroupCallScreenSharing, provided by the StartGroupCallScreenSharingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String