StartLiveStory class final

Starts a new live story on behalf of a chat; requires can_post_stories administrator right for channel chats Returns StartLiveStoryResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StartLiveStory({required int chatId, StoryPrivacySettings? privacySettings, required bool protectContent, required bool isRtmpStream, required bool enableMessages, required int paidMessageStarCount})

Properties

chatId int
chatId Identifier of the chat that will start the live story. Pass Saved Messages chat identifier when starting a live story on behalf of the current user, or a channel chat identifier
final
enableMessages bool
enableMessages Pass true to allow viewers of the story to send messages
final
hashCode int
The hash code for this object.
no setteroverride
isRtmpStream bool
isRtmpStream Pass true to create an RTMP stream instead of an ordinary group call
final
paidMessageStarCount int
paidMessageStarCount The minimum number of Telegram Stars that must be paid by viewers for each sent message to the call; 0-getOption("paid_group_call_message_star_count_max")
final
privacySettings StoryPrivacySettings?
privacySettings The privacy settings for the story; ignored for stories posted on behalf of channel chats
final
protectContent bool
protectContent Pass true if the content of the story must be protected from screenshotting
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, StoryPrivacySettings? privacySettings, bool? protectContent, bool? isRtmpStream, bool? enableMessages, int? paidMessageStarCount}) StartLiveStory

Available on StartLiveStory, provided by the StartLiveStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String