paidMessageStarCount property
paidMessageStarCount The minimum number of Telegram Stars that must be paid by viewers for each sent message to the call; 0-getOption("paid_group_call_message_star_count_max")
Implementation
final int paidMessageStarCount;