protectContent property
protectContent Pass true if the content of the story must be protected from screenshotting
Implementation
final bool protectContent;
protectContent Pass true if the content of the story must be protected from screenshotting
final bool protectContent;