StartLiveStoryResult class sealed

Represents result of starting a live story

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult fail(StartLiveStoryResultFail value), required TResult ok(StartLiveStoryResultOk value)}) → TResult

Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension

maybeMap<TResult extends Object?>({TResult fail(StartLiveStoryResultFail value)?, TResult ok(StartLiveStoryResultOk value)?, required TResult orElse()}) → TResult

Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StartLiveStoryResult?
Inherited by: StartLiveStoryResultFail StartLiveStoryResultOk

Constants

constructor → const String