StartLiveStoryResultOk class final

The live story was successfully posted

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StartLiveStoryResultOk({Story? story})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
story Story?
story The live story
final

Methods

copyWith({Story? story}) StartLiveStoryResultOk

Available on StartLiveStoryResultOk, provided by the StartLiveStoryResultOkExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult fail(StartLiveStoryResultFail value), required TResult ok(StartLiveStoryResultOk value)}) → TResult

Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension

maybeMap<TResult extends Object?>({TResult fail(StartLiveStoryResultFail value)?, TResult ok(StartLiveStoryResultOk value)?, required TResult orElse()}) → TResult

Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StartLiveStoryResultOk?
Inherited by: StartLiveStoryResultFail StartLiveStoryResultOk
override

Constants

constructor → const String