StatisticalGraph class sealed

Describes a statistical graph

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult async(StatisticalGraphAsync value), required TResult data(StatisticalGraphData value), required TResult error(StatisticalGraphError value)}) → TResult

Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension

maybeMap<TResult extends Object?>({TResult async(StatisticalGraphAsync value)?, TResult data(StatisticalGraphData value)?, TResult error(StatisticalGraphError value)?, required TResult orElse()}) → TResult

Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String