StatisticalValue class final

A value with information about its recent changes

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StatisticalValue({required double value, required double previousValue, required double growthRatePercentage})

Properties

growthRatePercentage double
growthRatePercentage The growth rate of the value, as a percentage
final
hashCode int
The hash code for this object.
no setteroverride
previousValue double
previousValue The value for the previous day
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
value The current value
final

Methods

copyWith({double? value, double? previousValue, double? growthRatePercentage}) StatisticalValue

Available on StatisticalValue, provided by the StatisticalValueExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StatisticalValue?

Constants

constructor → const String