StickerFormat class sealed
Describes format of a sticker
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult tgs(StickerFormatTgs value), required TResult webm(StickerFormatWebm value), required TResult webp(StickerFormatWebp value)}) → TResult -
Available on StickerFormat, provided by the StickerFormatExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult tgs(StickerFormatTgs value)?, TResult webm(StickerFormatWebm value)?, TResult webp(StickerFormatWebp value)?, required TResult orElse()}) → TResult -
Available on StickerFormat, provided by the StickerFormatExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StickerFormat? - Inherited by: StickerFormatTgs StickerFormatWebm StickerFormatWebp
Constants
- constructor → const String