StickerFormatWebp class final

The sticker is an image in WEBP format

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerFormatWebp()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult tgs(StickerFormatTgs value), required TResult webm(StickerFormatWebm value), required TResult webp(StickerFormatWebp value)}) → TResult

Available on StickerFormat, provided by the StickerFormatExtensions extension

maybeMap<TResult extends Object?>({TResult tgs(StickerFormatTgs value)?, TResult webm(StickerFormatWebm value)?, TResult webp(StickerFormatWebp value)?, required TResult orElse()}) → TResult

Available on StickerFormat, provided by the StickerFormatExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StickerFormatWebp?
Inherited by: StickerFormatTgs StickerFormatWebm StickerFormatWebp
override

Constants

constructor → const String