StickerFullType class sealed

Contains full information about sticker type

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(StickerFullTypeCustomEmoji value), required TResult mask(StickerFullTypeMask value), required TResult regular(StickerFullTypeRegular value)}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(StickerFullTypeCustomEmoji value)?, TResult mask(StickerFullTypeMask value)?, TResult regular(StickerFullTypeRegular value)?, required TResult orElse()}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String