StickerFullTypeMask class final

The sticker is a mask in WEBP format to be placed on photos or videos

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerFullTypeMask({MaskPosition? maskPosition})

Properties

hashCode int
The hash code for this object.
no setteroverride
maskPosition MaskPosition?
maskPosition Position where the mask is placed; may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MaskPosition? maskPosition}) StickerFullTypeMask

Available on StickerFullTypeMask, provided by the StickerFullTypeMaskExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(StickerFullTypeCustomEmoji value), required TResult mask(StickerFullTypeMask value), required TResult regular(StickerFullTypeRegular value)}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(StickerFullTypeCustomEmoji value)?, TResult mask(StickerFullTypeMask value)?, TResult regular(StickerFullTypeRegular value)?, required TResult orElse()}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String