StickerSet class final

Represents a sticker set

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerSet({required int id, required String title, required String name, Thumbnail? thumbnail, Outline? thumbnailOutline, required bool isOwned, required bool isInstalled, required bool isArchived, required bool isOfficial, StickerType? stickerType, required bool needsRepainting, required bool isAllowedAsChatEmojiStatus, required bool isViewed, required List<Sticker> stickers, required List<Emojis> emojis})

Properties

emojis List<Emojis>
emojis A list of emojis corresponding to the stickers in the same order. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Identifier of the sticker set
final
isAllowedAsChatEmojiStatus bool
isAllowedAsChatEmojiStatus True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only
final
isArchived bool
isArchived True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
final
isInstalled bool
isInstalled True, if the sticker set has been installed by the current user
final
isOfficial bool
isOfficial True, if the sticker set is official
final
isOwned bool
isOwned True, if the sticker set is owned by the current user
final
isViewed bool
isViewed True for already viewed trending sticker sets
final
name String
name Name of the sticker set
final
needsRepainting bool
needsRepainting True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickers List<Sticker>
stickers List of stickers in this set
final
stickerType StickerType?
stickerType Type of the stickers in the set
final
thumbnail Thumbnail?
thumbnail Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
final
thumbnailOutline Outline?
thumbnailOutline Sticker set thumbnail's outline; may be null if unknown
final
title String
title Title of the sticker set
final

Methods

copyWith({int? id, String? title, String? name, Thumbnail? thumbnail, Outline? thumbnailOutline, bool? isOwned, bool? isInstalled, bool? isArchived, bool? isOfficial, StickerType? stickerType, bool? needsRepainting, bool? isAllowedAsChatEmojiStatus, bool? isViewed, List<Sticker>? stickers, List<Emojis>? emojis}) StickerSet

Available on StickerSet, provided by the StickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StickerSet?

Constants

constructor → const String