isAllowedAsChatEmojiStatus property

bool isAllowedAsChatEmojiStatus
final

isAllowedAsChatEmojiStatus True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only

Implementation

final bool isAllowedAsChatEmojiStatus;