StickerSetInfo class final

Represents short information about a sticker set

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerSetInfo({required int id, required String title, required String name, Thumbnail? thumbnail, Outline? thumbnailOutline, required bool isOwned, required bool isInstalled, required bool isArchived, required bool isOfficial, StickerType? stickerType, required bool needsRepainting, required bool isAllowedAsChatEmojiStatus, required bool isViewed, required int size, required List<Sticker> covers})

Properties

covers List<Sticker>
covers Up to the first 5 stickers from the set, depending on the context. If the application needs more stickers the full sticker set needs to be requested
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Identifier of the sticker set
final
isAllowedAsChatEmojiStatus bool
isAllowedAsChatEmojiStatus True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only
final
isArchived bool
isArchived True, if the sticker set has been archived. A sticker set can't be installed and archived simultaneously
final
isInstalled bool
isInstalled True, if the sticker set has been installed by the current user
final
isOfficial bool
isOfficial True, if the sticker set is official
final
isOwned bool
isOwned True, if the sticker set is owned by the current user
final
isViewed bool
isViewed True for already viewed trending sticker sets
final
name String
name Name of the sticker set
final
needsRepainting bool
needsRepainting True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
size Total number of stickers in the set
final
stickerType StickerType?
stickerType Type of the stickers in the set
final
thumbnail Thumbnail?
thumbnail Sticker set thumbnail in WEBP, TGS, or WEBM format with width and height 100; may be null. The file can be downloaded only before the thumbnail is changed
final
thumbnailOutline Outline?
thumbnailOutline Sticker set thumbnail's outline; may be null if unknown
final
title String
title Title of the sticker set
final

Methods

copyWith({int? id, String? title, String? name, Thumbnail? thumbnail, Outline? thumbnailOutline, bool? isOwned, bool? isInstalled, bool? isArchived, bool? isOfficial, StickerType? stickerType, bool? needsRepainting, bool? isAllowedAsChatEmojiStatus, bool? isViewed, int? size, List<Sticker>? covers}) StickerSetInfo

Available on StickerSetInfo, provided by the StickerSetInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StickerSetInfo?

Constants

constructor → const String