needsRepainting property
needsRepainting True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only
Implementation
final bool needsRepainting;
needsRepainting True, if stickers in the sticker set are custom emoji that must be repainted; for custom emoji sticker sets only
final bool needsRepainting;