StickerSets class final

Represents a list of sticker sets

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerSets({required int totalCount, required List<StickerSetInfo> sets})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sets List<StickerSetInfo>
sets List of sticker sets
final
totalCount int
totalCount Approximate total number of sticker sets found
final

Methods

copyWith({int? totalCount, List<StickerSetInfo>? sets}) StickerSets

Available on StickerSets, provided by the StickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StickerSets?

Constants

constructor → const String