Stickers class final

Represents a list of stickers

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Stickers({required List<Sticker> stickers})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickers List<Sticker>
stickers List of stickers
final

Methods

copyWith({List<Sticker>? stickers}) Stickers

Available on Stickers, provided by the StickersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Stickers?

Constants

constructor → const String