StopBusinessPoll class final

Stops a poll sent on behalf of a business account; for bots only Returns BusinessMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StopBusinessPoll({required String businessConnectionId, required int chatId, required int messageId, ReplyMarkup? replyMarkup})

Properties

businessConnectionId String
businessConnectionId Unique identifier of business connection on behalf of which the message with the poll was sent
final
chatId int
chatId The chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message containing the poll
final
replyMarkup ReplyMarkup?
replyMarkup The new message reply markup; pass null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? businessConnectionId, int? chatId, int? messageId, ReplyMarkup? replyMarkup}) StopBusinessPoll

Available on StopBusinessPoll, provided by the StopBusinessPollExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String