StorageStatistics class final

Contains the exact storage usage statistics split by chats and file type

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StorageStatistics({required int size, required int count, required List<StorageStatisticsByChat> byChat})

Properties

byChat List<StorageStatisticsByChat>
byChat Statistics split by chats
final
count int
count Total number of files
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
size Total size of files, in bytes
final

Methods

copyWith({int? size, int? count, List<StorageStatisticsByChat>? byChat}) StorageStatistics

Available on StorageStatistics, provided by the StorageStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StorageStatistics?

Constants

constructor → const String