StorageStatisticsByFileType class final

Contains the storage usage statistics for a specific file type

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StorageStatisticsByFileType({FileType? fileType, required int size, required int count})

Properties

count int
count Total number of files
final
fileType FileType?
fileType File type
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
size Total size of the files, in bytes
final

Methods

copyWith({FileType? fileType, int? size, int? count}) StorageStatisticsByFileType

Available on StorageStatisticsByFileType, provided by the StorageStatisticsByFileTypeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StorageStatisticsByFileType?

Constants

constructor → const String