StorageStatisticsFast class final
Contains approximate storage usage statistics, excluding files of unknown file type
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- databaseSize → int
-
databaseSize Size of the database
final
- fileCount → int
-
fileCount Approximate number of files
final
- filesSize → int
-
filesSize Approximate total size of files, in bytes
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languagePackDatabaseSize → int
-
languagePackDatabaseSize Size of the language pack database
final
- logSize → int
-
logSize Size of the TDLib internal log
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? filesSize, int? fileCount, int? databaseSize, int? languagePackDatabaseSize, int? logSize}) → StorageStatisticsFast -
Available on StorageStatisticsFast, provided by the StorageStatisticsFastExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorageStatisticsFast?
Constants
- constructor → const String