StorePaymentPurposePremiumGift class final

The user gifting Telegram Premium to another user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StorePaymentPurposePremiumGift({required String currency, required int amount, required int userId, FormattedText? text})

Properties

amount int
amount Paid amount, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code of the payment currency
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text to show along with the gift codes; 0-getOption("gift_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed
final
userId int
userId Identifiers of the user which will receive Telegram Premium
final

Methods

copyWith({String? currency, int? amount, int? userId, FormattedText? text}) StorePaymentPurposePremiumGift

Available on StorePaymentPurposePremiumGift, provided by the StorePaymentPurposePremiumGiftExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult premiumGift(StorePaymentPurposePremiumGift value), required TResult premiumGiftCodes(StorePaymentPurposePremiumGiftCodes value), required TResult premiumGiveaway(StorePaymentPurposePremiumGiveaway value), required TResult premiumSubscription(StorePaymentPurposePremiumSubscription value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult

Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension

maybeMap<TResult extends Object?>({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult premiumGift(StorePaymentPurposePremiumGift value)?, TResult premiumGiftCodes(StorePaymentPurposePremiumGiftCodes value)?, TResult premiumGiveaway(StorePaymentPurposePremiumGiveaway value)?, TResult premiumSubscription(StorePaymentPurposePremiumSubscription value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult

Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String