StorePaymentPurposePremiumGiftCodes class final
The user boosting a chat by creating Telegram Premium gift codes for other users
- Inheritance
-
- Object
- TdObject
- StorePaymentPurpose
- StorePaymentPurposePremiumGiftCodes
- Available extensions
- Annotations
-
- @immutable
Constructors
-
StorePaymentPurposePremiumGiftCodes({required int boostedChatId, required String currency, required int amount, required List<
int> userIds, FormattedText? text})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- boostedChatId → int
-
boostedChatId Identifier of the supergroup or channel chat, which will
be automatically boosted by the users for duration of the Premium
subscription and which is administered by the user
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Text to show along with the gift codes;
0-getOption("gift_text_length_max") characters. Only Bold, Italic,
Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are
allowed
final
-
userIds
→ List<
int> -
userIds Identifiers of the users which can activate the gift codes
final
Methods
-
copyWith(
{int? boostedChatId, String? currency, int? amount, List< int> ? userIds, FormattedText? text}) → StorePaymentPurposePremiumGiftCodes -
Available on StorePaymentPurposePremiumGiftCodes, provided by the StorePaymentPurposePremiumGiftCodesExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorePaymentPurposePremiumGiftCodes? -
Inherited by:
StorePaymentPurposeGiftedStars
StorePaymentPurposePremiumGift
StorePaymentPurposePremiumGiftCodes
StorePaymentPurposePremiumGiveaway
StorePaymentPurposePremiumSubscription
StorePaymentPurposeStarGiveaway
StorePaymentPurposeStars
override
Constants
- constructor → const String