StorePaymentPurposePremiumSubscription class final
The user subscribing to Telegram Premium
- Inheritance
-
- Object
- TdObject
- StorePaymentPurpose
- StorePaymentPurposePremiumSubscription
- Available extensions
- Annotations
-
- @immutable
Constructors
- StorePaymentPurposePremiumSubscription({required bool isRestore, required bool isUpgrade})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRestore → bool
-
isRestore Pass true if this is a restore of a Telegram Premium purchase;
only for App Store
final
- isUpgrade → bool
-
isUpgrade Pass true if this is an upgrade from a monthly subscription to
early subscription; only for App Store
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isRestore, bool? isUpgrade}) → StorePaymentPurposePremiumSubscription -
Available on StorePaymentPurposePremiumSubscription, provided by the StorePaymentPurposePremiumSubscriptionExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorePaymentPurposePremiumSubscription? -
Inherited by:
StorePaymentPurposeGiftedStars
StorePaymentPurposePremiumGift
StorePaymentPurposePremiumGiftCodes
StorePaymentPurposePremiumGiveaway
StorePaymentPurposePremiumSubscription
StorePaymentPurposeStarGiveaway
StorePaymentPurposeStars
override
Constants
- constructor → const String