StorePaymentPurposeStarGiveaway class final

The user creating a Telegram Star giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StorePaymentPurposeStarGiveaway({GiveawayParameters? parameters, required String currency, required int amount, required int winnerCount, required int starCount})

Properties

amount int
amount Paid amount, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code of the payment currency
final
hashCode int
The hash code for this object.
no setteroverride
parameters GiveawayParameters?
parameters Giveaway parameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars to be distributed through the giveaway
final
winnerCount int
winnerCount The number of users to receive Telegram Stars
final

Methods

copyWith({GiveawayParameters? parameters, String? currency, int? amount, int? winnerCount, int? starCount}) StorePaymentPurposeStarGiveaway

Available on StorePaymentPurposeStarGiveaway, provided by the StorePaymentPurposeStarGiveawayExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult premiumGift(StorePaymentPurposePremiumGift value), required TResult premiumGiftCodes(StorePaymentPurposePremiumGiftCodes value), required TResult premiumGiveaway(StorePaymentPurposePremiumGiveaway value), required TResult premiumSubscription(StorePaymentPurposePremiumSubscription value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult

Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension

maybeMap<TResult extends Object?>({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult premiumGift(StorePaymentPurposePremiumGift value)?, TResult premiumGiftCodes(StorePaymentPurposePremiumGiftCodes value)?, TResult premiumGiveaway(StorePaymentPurposePremiumGiveaway value)?, TResult premiumSubscription(StorePaymentPurposePremiumSubscription value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult

Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String