StoreTransaction class sealed

Describes an in-store transaction

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult appStore(StoreTransactionAppStore value), required TResult googlePlay(StoreTransactionGooglePlay value)}) → TResult

Available on StoreTransaction, provided by the StoreTransactionExtensions extension

maybeMap<TResult extends Object?>({TResult appStore(StoreTransactionAppStore value)?, TResult googlePlay(StoreTransactionGooglePlay value)?, required TResult orElse()}) → TResult

Available on StoreTransaction, provided by the StoreTransactionExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoreTransaction?
Inherited by: StoreTransactionAppStore StoreTransactionGooglePlay

Constants

constructor → const String