StoreTransactionAppStore class final

A purchase through App Store

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoreTransactionAppStore({required String receipt})

Properties

hashCode int
The hash code for this object.
no setteroverride
receipt String
receipt App Store receipt
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? receipt}) StoreTransactionAppStore

Available on StoreTransactionAppStore, provided by the StoreTransactionAppStoreExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult appStore(StoreTransactionAppStore value), required TResult googlePlay(StoreTransactionGooglePlay value)}) → TResult

Available on StoreTransaction, provided by the StoreTransactionExtensions extension

maybeMap<TResult extends Object?>({TResult appStore(StoreTransactionAppStore value)?, TResult googlePlay(StoreTransactionGooglePlay value)?, required TResult orElse()}) → TResult

Available on StoreTransaction, provided by the StoreTransactionExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoreTransactionAppStore?
Inherited by: StoreTransactionAppStore StoreTransactionGooglePlay
override

Constants

constructor → const String