Stories class final

Represents a list of stories

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Stories({required int totalCount, required List<Story> stories, required List<int> pinnedStoryIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
pinnedStoryIds List<int>
pinnedStoryIds Identifiers of the pinned stories; returned only in getChatPostedToChatPageStories with from_story_id == 0
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stories List<Story>
stories The list of stories
final
totalCount int
totalCount Approximate total number of stories found
final

Methods

copyWith({int? totalCount, List<Story>? stories, List<int>? pinnedStoryIds}) Stories

Available on Stories, provided by the StoriesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Stories?

Constants

constructor → const String