canBeReplied property
canBeReplied True, if the story can be replied in the chat with the user who posted the story
Implementation
final bool canBeReplied;
canBeReplied True, if the story can be replied in the chat with the user who posted the story
final bool canBeReplied;