canGetInteractions property
canGetInteractions True, if interactions with the story can be received through getStoryInteractions
Implementation
final bool canGetInteractions;
canGetInteractions True, if interactions with the story can be received through getStoryInteractions
final bool canGetInteractions;