canGetStatistics property
canGetStatistics True, if the story statistics are available through getStoryStatistics
Implementation
final bool canGetStatistics;
canGetStatistics True, if the story statistics are available through getStoryStatistics
final bool canGetStatistics;