canSetPrivacySettings property
canSetPrivacySettings True, if the story privacy settings can be changed
Implementation
final bool canSetPrivacySettings;
canSetPrivacySettings True, if the story privacy settings can be changed
final bool canSetPrivacySettings;