isPostedToChatPage property
isPostedToChatPage True, if the story is saved in the profile of the chat that posted it and will be available there after expiration
Implementation
final bool isPostedToChatPage;
isPostedToChatPage True, if the story is saved in the profile of the chat that posted it and will be available there after expiration
final bool isPostedToChatPage;