posterId property
posterId Identifier of the user or chat that posted the story; may be null if the story is posted on behalf of the poster_chat_id
Implementation
final MessageSender? posterId;
posterId Identifier of the user or chat that posted the story; may be null if the story is posted on behalf of the poster_chat_id
final MessageSender? posterId;