StoryAlbums class final

Represents a list of story albums

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryAlbums({required List<StoryAlbum> albums})

Properties

albums List<StoryAlbum>
albums List of story albums
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<StoryAlbum>? albums}) StoryAlbums

Available on StoryAlbums, provided by the StoryAlbumsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryAlbums?

Constants

constructor → const String