StoryArea class final

Describes a clickable rectangle area on a story media

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryArea({StoryAreaPosition? position, StoryAreaType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
position StoryAreaPosition?
position Position of the area
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type StoryAreaType?
type Type of the area
final

Methods

copyWith({StoryAreaPosition? position, StoryAreaType? type}) StoryArea

Available on StoryArea, provided by the StoryAreaExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryArea?

Constants

constructor → const String