StoryAreaPosition class final
Describes position of a clickable rectangle area on a story media
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- cornerRadiusPercentage → double
-
cornerRadiusPercentage The radius of the rectangle corner rounding, as a
percentage of the media width
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- heightPercentage → double
-
heightPercentage The height of the rectangle, as a percentage of the
media height
final
- rotationAngle → double
-
rotationAngle Clockwise rotation angle of the rectangle, in degrees;
0-360
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthPercentage → double
-
widthPercentage The width of the rectangle, as a percentage of the media
width
final
- xPercentage → double
-
xPercentage The abscissa of the rectangle's center, as a percentage of
the media width
final
- yPercentage → double
-
yPercentage The ordinate of the rectangle's center, as a percentage of
the media height
final
Methods
-
copyWith(
{double? xPercentage, double? yPercentage, double? widthPercentage, double? heightPercentage, double? rotationAngle, double? cornerRadiusPercentage}) → StoryAreaPosition -
Available on StoryAreaPosition, provided by the StoryAreaPositionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryAreaPosition?
Constants
- constructor → const String