StoryAreaTypeSuggestedReaction class final

An area pointing to a suggested reaction. App needs to show a clickable reaction on the area and call setStoryReaction when the area is clicked

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryAreaTypeSuggestedReaction({ReactionType? reactionType, required int totalCount, required bool isDark, required bool isFlipped})

Properties

hashCode int
The hash code for this object.
no setteroverride
isDark bool
isDark True, if reaction has a dark background
final
isFlipped bool
isFlipped True, if reaction corner is flipped
final
reactionType ReactionType?
reactionType Type of the reaction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Number of times the reaction was added
final

Methods

copyWith({ReactionType? reactionType, int? totalCount, bool? isDark, bool? isFlipped}) StoryAreaTypeSuggestedReaction

Available on StoryAreaTypeSuggestedReaction, provided by the StoryAreaTypeSuggestedReactionExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult link(StoryAreaTypeLink value), required TResult location(StoryAreaTypeLocation value), required TResult message(StoryAreaTypeMessage value), required TResult suggestedReaction(StoryAreaTypeSuggestedReaction value), required TResult upgradedGift(StoryAreaTypeUpgradedGift value), required TResult venue(StoryAreaTypeVenue value), required TResult weather(StoryAreaTypeWeather value)}) → TResult

Available on StoryAreaType, provided by the StoryAreaTypeExtensions extension

maybeMap<TResult extends Object?>({TResult link(StoryAreaTypeLink value)?, TResult location(StoryAreaTypeLocation value)?, TResult message(StoryAreaTypeMessage value)?, TResult suggestedReaction(StoryAreaTypeSuggestedReaction value)?, TResult upgradedGift(StoryAreaTypeUpgradedGift value)?, TResult venue(StoryAreaTypeVenue value)?, TResult weather(StoryAreaTypeWeather value)?, required TResult orElse()}) → TResult

Available on StoryAreaType, provided by the StoryAreaTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String