groupCallId property
groupCallId Identifier of the corresponding group call. The group call can be received through the method getGroupCall
Implementation
final int groupCallId;
groupCallId Identifier of the corresponding group call. The group call can be received through the method getGroupCall
final int groupCallId;