StoryContentPhoto class final

A photo story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryContentPhoto({Photo? photo})

Properties

hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo The photo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Photo? photo}) StoryContentPhoto

Available on StoryContentPhoto, provided by the StoryContentPhotoExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult live(StoryContentLive value), required TResult photo(StoryContentPhoto value), required TResult unsupported(StoryContentUnsupported value), required TResult video(StoryContentVideo value)}) → TResult

Available on StoryContent, provided by the StoryContentExtensions extension

maybeMap<TResult extends Object?>({TResult live(StoryContentLive value)?, TResult photo(StoryContentPhoto value)?, TResult unsupported(StoryContentUnsupported value)?, TResult video(StoryContentVideo value)?, required TResult orElse()}) → TResult

Available on StoryContent, provided by the StoryContentExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String