StoryContentType class sealed

Contains the type of the content of a story

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult live(StoryContentTypeLive value), required TResult photo(StoryContentTypePhoto value), required TResult unsupported(StoryContentTypeUnsupported value), required TResult video(StoryContentTypeVideo value)}) → TResult

Available on StoryContentType, provided by the StoryContentTypeExtensions extension

maybeMap<TResult extends Object?>({TResult live(StoryContentTypeLive value)?, TResult photo(StoryContentTypePhoto value)?, TResult unsupported(StoryContentTypeUnsupported value)?, TResult video(StoryContentTypeVideo value)?, required TResult orElse()}) → TResult

Available on StoryContentType, provided by the StoryContentTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String