StoryContentTypePhoto class final
A photo story
- Inheritance
-
- Object
- TdObject
- StoryContentType
- StoryContentTypePhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- StoryContentTypePhoto()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult live(StoryContentTypeLive value), required TResult photo(StoryContentTypePhoto value), required TResult unsupported(StoryContentTypeUnsupported value), required TResult video(StoryContentTypeVideo value)}) → TResult -
Available on StoryContentType, provided by the StoryContentTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult live(StoryContentTypeLive value)?, TResult photo(StoryContentTypePhoto value)?, TResult unsupported(StoryContentTypeUnsupported value)?, TResult video(StoryContentTypeVideo value)?, required TResult orElse()}) → TResult -
Available on StoryContentType, provided by the StoryContentTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryContentTypePhoto? -
Inherited by:
StoryContentTypeLive
StoryContentTypePhoto
StoryContentTypeUnsupported
StoryContentTypeVideo
override
Constants
- constructor → const String