StoryFullId class final

Contains identifier of a story along with identifier of the chat that posted it

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryFullId({required int posterChatId, required int storyId})

Properties

hashCode int
The hash code for this object.
no setteroverride
posterChatId int
posterChatId Identifier of the chat that posted the story
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Unique story identifier among stories of the chat
final

Methods

copyWith({int? posterChatId, int? storyId}) StoryFullId

Available on StoryFullId, provided by the StoryFullIdExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryFullId?

Constants

constructor → const String