StoryInteraction class final

Represents interaction with a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryInteraction({MessageSender? actorId, required int interactionDate, BlockList? blockList, StoryInteractionType? type})

Properties

actorId MessageSender?
actorId Identifier of the user or chat that made the interaction
final
blockList BlockList?
blockList Block list to which the actor is added; may be null if none or for chat stories
final
hashCode int
The hash code for this object.
no setteroverride
interactionDate int
interactionDate Approximate point in time (Unix timestamp) when the interaction happened
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type StoryInteractionType?
type Type of the interaction
final

Methods

copyWith({MessageSender? actorId, int? interactionDate, BlockList? blockList, StoryInteractionType? type}) StoryInteraction

Available on StoryInteraction, provided by the StoryInteractionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryInteraction?

Constants

constructor → const String