StoryInteractionInfo class final

Contains information about interactions with a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryInteractionInfo({required int viewCount, required int forwardCount, required int reactionCount, required List<int> recentViewerUserIds})

Properties

forwardCount int
forwardCount Number of times the story was forwarded; 0 if none or unknown
final
hashCode int
The hash code for this object.
no setteroverride
reactionCount int
reactionCount Number of reactions added to the story; 0 if none or unknown
final
recentViewerUserIds List<int>
recentViewerUserIds Identifiers of at most 3 recent viewers of the story
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewCount int
viewCount Number of times the story was viewed
final

Methods

copyWith({int? viewCount, int? forwardCount, int? reactionCount, List<int>? recentViewerUserIds}) StoryInteractionInfo

Available on StoryInteractionInfo, provided by the StoryInteractionInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryInteractionInfo?

Constants

constructor → const String