StoryInteractionTypeForward class final

A forward of the story as a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryInteractionTypeForward({Message? message})

Properties

hashCode int
The hash code for this object.
no setteroverride
message Message?
message The message with story forward
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Message? message}) StoryInteractionTypeForward

Available on StoryInteractionTypeForward, provided by the StoryInteractionTypeForwardExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forward(StoryInteractionTypeForward value), required TResult repost(StoryInteractionTypeRepost value), required TResult view(StoryInteractionTypeView value)}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult forward(StoryInteractionTypeForward value)?, TResult repost(StoryInteractionTypeRepost value)?, TResult view(StoryInteractionTypeView value)?, required TResult orElse()}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String