StoryInteractionTypeRepost class final

A repost of the story as a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryInteractionTypeRepost({Story? story})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
story Story?
story The reposted story
final

Methods

copyWith({Story? story}) StoryInteractionTypeRepost

Available on StoryInteractionTypeRepost, provided by the StoryInteractionTypeRepostExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forward(StoryInteractionTypeForward value), required TResult repost(StoryInteractionTypeRepost value), required TResult view(StoryInteractionTypeView value)}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult forward(StoryInteractionTypeForward value)?, TResult repost(StoryInteractionTypeRepost value)?, TResult view(StoryInteractionTypeView value)?, required TResult orElse()}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String