StoryInteractionTypeView class final

A view of the story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryInteractionTypeView({ReactionType? chosenReactionType})

Properties

chosenReactionType ReactionType?
chosenReactionType Type of the reaction that was chosen by the viewer; may be null if none
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ReactionType? chosenReactionType}) StoryInteractionTypeView

Available on StoryInteractionTypeView, provided by the StoryInteractionTypeViewExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forward(StoryInteractionTypeForward value), required TResult repost(StoryInteractionTypeRepost value), required TResult view(StoryInteractionTypeView value)}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

maybeMap<TResult extends Object?>({TResult forward(StoryInteractionTypeForward value)?, TResult repost(StoryInteractionTypeRepost value)?, TResult view(StoryInteractionTypeView value)?, required TResult orElse()}) → TResult

Available on StoryInteractionType, provided by the StoryInteractionTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String