chosenReactionType property
chosenReactionType Type of the reaction that was chosen by the viewer; may be null if none
Implementation
final ReactionType? chosenReactionType;
chosenReactionType Type of the reaction that was chosen by the viewer; may be null if none
final ReactionType? chosenReactionType;