StoryListMain class final

The list of stories, shown in the main chat list and folder chat lists

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryListMain()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult archive(StoryListArchive value), required TResult main(StoryListMain value)}) → TResult

Available on StoryList, provided by the StoryListExtensions extension

maybeMap<TResult extends Object?>({TResult archive(StoryListArchive value)?, TResult main(StoryListMain value)?, required TResult orElse()}) → TResult

Available on StoryList, provided by the StoryListExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryListMain?
Inherited by: StoryListArchive StoryListMain
override

Constants

constructor → const String