StoryOrigin class sealed

Contains information about the origin of a story that was reposted

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult hiddenUser(StoryOriginHiddenUser value), required TResult publicStory(StoryOriginPublicStory value)}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

maybeMap<TResult extends Object?>({TResult hiddenUser(StoryOriginHiddenUser value)?, TResult publicStory(StoryOriginPublicStory value)?, required TResult orElse()}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryOrigin?
Inherited by: StoryOriginHiddenUser StoryOriginPublicStory

Constants

constructor → const String