StoryOriginHiddenUser class final

The original story was posted by an unknown user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryOriginHiddenUser({required String posterName})

Properties

hashCode int
The hash code for this object.
no setteroverride
posterName String
posterName Name of the user or the chat that posted the story
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? posterName}) StoryOriginHiddenUser

Available on StoryOriginHiddenUser, provided by the StoryOriginHiddenUserExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult hiddenUser(StoryOriginHiddenUser value), required TResult publicStory(StoryOriginPublicStory value)}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

maybeMap<TResult extends Object?>({TResult hiddenUser(StoryOriginHiddenUser value)?, TResult publicStory(StoryOriginPublicStory value)?, required TResult orElse()}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryOriginHiddenUser?
Inherited by: StoryOriginHiddenUser StoryOriginPublicStory
override

Constants

constructor → const String