StoryOriginPublicStory class final
The original story was a public story that was posted by a known chat
- Inheritance
-
- Object
- TdObject
- StoryOrigin
- StoryOriginPublicStory
- Available extensions
- Annotations
-
- @immutable
Constructors
- StoryOriginPublicStory({required int chatId, required int storyId})
Properties
Methods
-
copyWith(
{int? chatId, int? storyId}) → StoryOriginPublicStory -
Available on StoryOriginPublicStory, provided by the StoryOriginPublicStoryExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult publicStory(StoryOriginPublicStory value)}) → TResult -
Available on StoryOrigin, provided by the StoryOriginExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult publicStory(StoryOriginPublicStory value)?, required TResult orElse()}) → TResult -
Available on StoryOrigin, provided by the StoryOriginExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryOriginPublicStory? -
Inherited by:
StoryOriginHiddenUser
StoryOriginPublicStory
override
Constants
- constructor → const String