StoryPrivacySettings class sealed

Describes privacy settings of a story

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult closeFriends(StoryPrivacySettingsCloseFriends value), required TResult contacts(StoryPrivacySettingsContacts value), required TResult everyone(StoryPrivacySettingsEveryone value), required TResult selectedUsers(StoryPrivacySettingsSelectedUsers value)}) → TResult

Available on StoryPrivacySettings, provided by the StoryPrivacySettingsExtensions extension

maybeMap<TResult extends Object?>({TResult closeFriends(StoryPrivacySettingsCloseFriends value)?, TResult contacts(StoryPrivacySettingsContacts value)?, TResult everyone(StoryPrivacySettingsEveryone value)?, TResult selectedUsers(StoryPrivacySettingsSelectedUsers value)?, required TResult orElse()}) → TResult

Available on StoryPrivacySettings, provided by the StoryPrivacySettingsExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String