StoryRepostInfo class final

Contains information about original story that was reposted

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryRepostInfo({StoryOrigin? origin, required bool isContentModified})

Properties

hashCode int
The hash code for this object.
no setteroverride
isContentModified bool
isContentModified True, if story content was modified during reposting; otherwise, story wasn't modified
final
origin StoryOrigin?
origin Origin of the story that was reposted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({StoryOrigin? origin, bool? isContentModified}) StoryRepostInfo

Available on StoryRepostInfo, provided by the StoryRepostInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryRepostInfo?

Constants

constructor → const String