StoryStatistics class final

A detailed statistics about a story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryStatistics({StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyInteractionGraph StatisticalGraph?
storyInteractionGraph A graph containing number of story views and shares
final
storyReactionGraph StatisticalGraph?
storyReactionGraph A graph containing number of story reactions
final

Methods

copyWith({StatisticalGraph? storyInteractionGraph, StatisticalGraph? storyReactionGraph}) StoryStatistics

Available on StoryStatistics, provided by the StoryStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryStatistics?

Constants

constructor → const String