SuggestUserBirthdate class final

Suggests a birthdate to another regular user with common messages and allowing non-paid messages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SuggestUserBirthdate({required int userId, Birthdate? birthdate})

Properties

birthdate Birthdate?
birthdate Birthdate to suggest
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, Birthdate? birthdate}) SuggestUserBirthdate

Available on SuggestUserBirthdate, provided by the SuggestUserBirthdateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String