SuggestUserProfilePhoto class final

Suggests a profile photo to another regular user with common messages and allowing non-paid messages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SuggestUserProfilePhoto({required int userId, InputChatPhoto? photo})

Properties

hashCode int
The hash code for this object.
no setteroverride
photo InputChatPhoto?
photo Profile photo to suggest; inputChatPhotoPrevious isn't supported in this function
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, InputChatPhoto? photo}) SuggestUserProfilePhoto

Available on SuggestUserProfilePhoto, provided by the SuggestUserProfilePhotoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String