canBeHidden property

bool canBeHidden
final

canBeHidden True, if the suggested action can be hidden using hideSuggestedAction. Otherwise, the user must not be able to use the application without setting up the email address

Implementation

final bool canBeHidden;