SuggestedPostInfo class final

Contains information about a suggested post. If the post can be approved or declined, then changes to the post can be also suggested. Use sendMessage with reply to the message and suggested post information to suggest message changes. Use addOffer to suggest price or time changes

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SuggestedPostInfo({SuggestedPostPrice? price, required int sendDate, SuggestedPostState? state, required bool canBeApproved, required bool canBeDeclined})

Properties

canBeApproved bool
canBeApproved True, if the suggested post can be approved by the current user using approveSuggestedPost; updates aren't sent when value of this field changes
final
canBeDeclined bool
canBeDeclined True, if the suggested post can be declined by the current user using declineSuggestedPost; updates aren't sent when value of this field changes
final
hashCode int
The hash code for this object.
no setteroverride
price SuggestedPostPrice?
price Price of the suggested post; may be null if the post is non-paid
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendDate int
sendDate Point in time (Unix timestamp) when the post is expected to be published; 0 if the specific date isn't set yet
final
state SuggestedPostState?
state State of the post
final

Methods

copyWith({SuggestedPostPrice? price, int? sendDate, SuggestedPostState? state, bool? canBeApproved, bool? canBeDeclined}) SuggestedPostInfo

Available on SuggestedPostInfo, provided by the SuggestedPostInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SuggestedPostInfo?

Constants

constructor → const String