canBeApproved property
canBeApproved True, if the suggested post can be approved by the current user using approveSuggestedPost; updates aren't sent when value of this field changes
Implementation
final bool canBeApproved;
canBeApproved True, if the suggested post can be approved by the current user using approveSuggestedPost; updates aren't sent when value of this field changes
final bool canBeApproved;