canBeDeclined property
canBeDeclined True, if the suggested post can be declined by the current user using declineSuggestedPost; updates aren't sent when value of this field changes
Implementation
final bool canBeDeclined;
canBeDeclined True, if the suggested post can be declined by the current user using declineSuggestedPost; updates aren't sent when value of this field changes
final bool canBeDeclined;