SuggestedPostPrice class sealed

Describes price of a suggested post

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult gram(SuggestedPostPriceGram value), required TResult star(SuggestedPostPriceStar value)}) → TResult

Available on SuggestedPostPrice, provided by the SuggestedPostPriceExtensions extension

maybeMap<TResult extends Object?>({TResult gram(SuggestedPostPriceGram value)?, TResult star(SuggestedPostPriceStar value)?, required TResult orElse()}) → TResult

Available on SuggestedPostPrice, provided by the SuggestedPostPriceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SuggestedPostPrice?
Inherited by: SuggestedPostPriceGram SuggestedPostPriceStar

Constants

constructor → const String