SuggestedPostPriceGram class final

Describes price of a suggested post in TON Grams

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SuggestedPostPriceGram({required int gramCentCount})

Properties

gramCentCount int
gramCentCount The amount of 1/100 of Gram expected to be paid for the post; getOption("suggested_post_gram_cent_count_min")-getOption("suggested_post_gram_cent_count_max")
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? gramCentCount}) SuggestedPostPriceGram

Available on SuggestedPostPriceGram, provided by the SuggestedPostPriceGramExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult gram(SuggestedPostPriceGram value), required TResult star(SuggestedPostPriceStar value)}) → TResult

Available on SuggestedPostPrice, provided by the SuggestedPostPriceExtensions extension

maybeMap<TResult extends Object?>({TResult gram(SuggestedPostPriceGram value)?, TResult star(SuggestedPostPriceStar value)?, required TResult orElse()}) → TResult

Available on SuggestedPostPrice, provided by the SuggestedPostPriceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SuggestedPostPriceGram?
Inherited by: SuggestedPostPriceGram SuggestedPostPriceStar
override

Constants

constructor → const String