SummarizeMessage class final
Summarizes content of the message with non-empty summary_language_code Returns FormattedText
- Inheritance
-
- Object
- TdFunction
- SummarizeMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- SummarizeMessage({required int chatId, required int messageId, required String translateToLanguageCode, required String tone})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tone → String
-
tone Tone of the summarization; see translateText.tone for the list of
supported values
final
- translateToLanguageCode → String
-
translateToLanguageCode Pass a language code to which the summary will
be translated; pass an empty string if translation isn't needed. See
translateText.to_language_code for the list of supported values
final
Methods
-
copyWith(
{int? chatId, int? messageId, String? translateToLanguageCode, String? tone}) → SummarizeMessage -
Available on SummarizeMessage, provided by the SummarizeMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String