Supergroup class final

Represents a supergroup or channel with zero or more members (subscribers in the case of channels)

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Supergroup({required int id, Usernames? usernames, required int date, ChatMemberStatus? status, required int memberCount, required int boostLevel, required bool hasAutomaticTranslation, required bool hasLinkedChat, required bool hasLocation, required bool signMessages, required bool showMessageSender, required bool joinToSendMessages, required bool joinByRequest, required bool isSlowModeEnabled, required bool isChannel, required bool isBroadcastGroup, required bool isForum, required bool isDirectMessagesGroup, required bool isAdministeredDirectMessagesGroup, VerificationStatus? verificationStatus, required bool hasDirectMessagesGroup, required bool hasForumTabs, RestrictionInfo? restrictionInfo, required int paidMessageStarCount, ActiveStoryState? activeStoryState})

Properties

activeStoryState ActiveStoryState?
activeStoryState State of active stories of the supergroup or channel; may be null if there are no active stories
final
boostLevel int
boostLevel Approximate boost level for the chat
final
date int
date Point in time (Unix timestamp) when the current user joined, or the point in time when the supergroup or channel was created, in case the user is not a member
final
hasAutomaticTranslation bool
hasAutomaticTranslation True, if automatic translation of messages is enabled in the channel
final
hasDirectMessagesGroup bool
hasDirectMessagesGroup True, if the channel has direct messages group
final
hasForumTabs bool
hasForumTabs True, if the supergroup is a forum, which topics are shown in the same way as in channel direct messages groups
final
hashCode int
The hash code for this object.
no setteroverride
hasLinkedChat bool
hasLinkedChat True, if the channel has a discussion group, or the supergroup is the designated discussion group for a channel
final
hasLocation bool
hasLocation True, if the supergroup is connected to a location, i.e. the supergroup is a location-based supergroup
final
id int
id Supergroup or channel identifier
final
isAdministeredDirectMessagesGroup bool
isAdministeredDirectMessagesGroup True, if the supergroup is a direct messages group for a channel chat that is administered by the current user
final
isBroadcastGroup bool
isBroadcastGroup True, if the supergroup is a broadcast group, i.e. only administrators can send messages and there is no limit on the number of members
final
isChannel bool
isChannel True, if the supergroup is a channel, which can have an unlimited number of subscribers, but only administrators can post there and see the list of subscribers
final
isDirectMessagesGroup bool
isDirectMessagesGroup True, if the supergroup is a direct message group for a channel chat
final
isForum bool
isForum True, if the supergroup is a forum with topics
final
isSlowModeEnabled bool
isSlowModeEnabled True, if the slow mode is enabled in the supergroup
final
joinByRequest bool
joinByRequest True, if all users directly joining the supergroup need to be approved by supergroup administrators
final
joinToSendMessages bool
joinToSendMessages True, if users need to join the supergroup before they can send messages. May be false only for discussion supergroups and channel direct messages groups
final
memberCount int
memberCount Number of members in the supergroup or channel; 0 if unknown. Currently, it is guaranteed to be known only if the supergroup or channel was received through getChatSimilarChats, getChatsToPostStories, getCreatedPublicChats, getGroupsInCommon, getInactiveSupergroupChats, getRecommendedChats, getSuitableDiscussionChats, getUserPrivacySettingRules, getVideoChatAvailableParticipants, searchPublicChats, or in chatFolderInviteLinkInfo.missing_chat_ids, or in userFullInfo.personal_chat_id, or for chats with messages or stories from publicForwards and foundStories
final
paidMessageStarCount int
paidMessageStarCount Number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message
final
restrictionInfo RestrictionInfo?
restrictionInfo Information about the restrictions that must be applied to the corresponding supergroup or channel chat; may be null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showMessageSender bool
showMessageSender True, if messages sent to the channel have information about the sender user. This field is only applicable to channels
final
signMessages bool
signMessages True, if messages sent to the channel contains name of the sender. This field is only applicable to channels
final
status ChatMemberStatus?
status Status of the current user in the supergroup or channel
final
usernames Usernames?
usernames Usernames of the supergroup or channel; may be null
final
verificationStatus VerificationStatus?
verificationStatus Information about verification status of the supergroup or channel; may be null if none
final

Methods

copyWith({int? id, Usernames? usernames, int? date, ChatMemberStatus? status, int? memberCount, int? boostLevel, bool? hasAutomaticTranslation, bool? hasLinkedChat, bool? hasLocation, bool? signMessages, bool? showMessageSender, bool? joinToSendMessages, bool? joinByRequest, bool? isSlowModeEnabled, bool? isChannel, bool? isBroadcastGroup, bool? isForum, bool? isDirectMessagesGroup, bool? isAdministeredDirectMessagesGroup, VerificationStatus? verificationStatus, bool? hasDirectMessagesGroup, bool? hasForumTabs, RestrictionInfo? restrictionInfo, int? paidMessageStarCount, ActiveStoryState? activeStoryState}) Supergroup

Available on Supergroup, provided by the SupergroupExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Supergroup?

Constants

constructor → const String