hasAutomaticTranslation property
hasAutomaticTranslation True, if automatic translation of messages is enabled in the channel
Implementation
final bool hasAutomaticTranslation;
hasAutomaticTranslation True, if automatic translation of messages is enabled in the channel
final bool hasAutomaticTranslation;