hasForumTabs property

bool hasForumTabs
final

hasForumTabs True, if the supergroup is a forum, which topics are shown in the same way as in channel direct messages groups

Implementation

final bool hasForumTabs;