isChannel property

bool isChannel
final

isChannel True, if the supergroup is a channel, which can have an unlimited number of subscribers, but only administrators can post there and see the list of subscribers

Implementation

final bool isChannel;