joinByRequest property
joinByRequest True, if all users directly joining the supergroup need to be approved by supergroup administrators
Implementation
final bool joinByRequest;
joinByRequest True, if all users directly joining the supergroup need to be approved by supergroup administrators
final bool joinByRequest;