restrictionInfo property
restrictionInfo Information about the restrictions that must be applied to the corresponding supergroup or channel chat; may be null if none
Implementation
final RestrictionInfo? restrictionInfo;
restrictionInfo Information about the restrictions that must be applied to the corresponding supergroup or channel chat; may be null if none
final RestrictionInfo? restrictionInfo;