showMessageSender property
showMessageSender True, if messages sent to the channel have information about the sender user. This field is only applicable to channels
Implementation
final bool showMessageSender;
showMessageSender True, if messages sent to the channel have information about the sender user. This field is only applicable to channels
final bool showMessageSender;