signMessages property
signMessages True, if messages sent to the channel contains name of the sender. This field is only applicable to channels
Implementation
final bool signMessages;
signMessages True, if messages sent to the channel contains name of the sender. This field is only applicable to channels
final bool signMessages;