SupergroupFullInfo class final

Contains full information about a supergroup or channel

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SupergroupFullInfo({ChatPhoto? photo, required int communityId, required String description, required int memberCount, required int administratorCount, required int restrictedCount, required int bannedCount, required int linkedChatId, required int directMessagesChatId, required int slowModeDelay, required double slowModeDelayExpiresIn, required bool canEnablePaidMessages, required bool canEnablePaidReaction, required bool canGetMembers, required bool hasHiddenMembers, required bool canHideMembers, required bool canSetStickerSet, required bool canSetLocation, required bool canGetStatistics, required bool canGetRevenueStatistics, required bool canGetStarRevenueStatistics, required bool canSendGift, required bool canToggleAggressiveAntiSpam, required bool isAllHistoryAvailable, required bool canHaveSponsoredMessages, required bool hasAggressiveAntiSpamEnabled, required bool hasPaidMediaAllowed, required bool hasPinnedStories, required int giftCount, required int myBoostCount, required int unrestrictBoostCount, required int outgoingPaidMessageStarCount, required int stickerSetId, required int customEmojiStickerSetId, ChatLocation? location, ChatInviteLink? inviteLink, required int guardBotUserId, required List<BotCommands> botCommands, BotVerification? botVerification, ProfileTab? mainProfileTab, required int upgradedFromBasicGroupId, required int upgradedFromMaxMessageId})

Properties

administratorCount int
administratorCount Number of privileged users in the supergroup or channel; 0 if unknown
final
bannedCount int
bannedCount Number of users banned from chat; 0 if unknown
final
botCommands List<BotCommands>
botCommands List of commands of bots in the group
final
botVerification BotVerification?
botVerification Information about verification status of the supergroup or the channel provided by a bot; may be null if none or unknown
final
canEnablePaidMessages bool
canEnablePaidMessages True, if paid messages can be enabled in the supergroup chat; for supergroup only
final
canEnablePaidReaction bool
canEnablePaidReaction True, if paid reaction can be enabled in the channel chat; for channels only
final
canGetMembers bool
canGetMembers True, if members of the chat can be retrieved via getSupergroupMembers or searchChatMembers
final
canGetRevenueStatistics bool
canGetRevenueStatistics True, if the supergroup or channel revenue statistics are available
final
canGetStarRevenueStatistics bool
canGetStarRevenueStatistics True, if the supergroup or channel Telegram Star revenue statistics are available
final
canGetStatistics bool
canGetStatistics True, if the supergroup or channel statistics are available
final
canHaveSponsoredMessages bool
canHaveSponsoredMessages True, if the chat can have sponsored messages. The value of this field is only available to the owner of the chat
final
canHideMembers bool
canHideMembers True, if non-administrators and non-bots can be hidden in responses to getSupergroupMembers and searchChatMembers for non-administrators
final
canSendGift bool
canSendGift True, if the user can send a gift to the supergroup or channel using sendGift or transferGift
final
canSetLocation bool
canSetLocation True, if the supergroup location can be changed
final
canSetStickerSet bool
canSetStickerSet True, if the supergroup sticker set can be changed
final
canToggleAggressiveAntiSpam bool
canToggleAggressiveAntiSpam True, if aggressive anti-spam checks can be enabled or disabled in the supergroup
final
communityId int
communityId Identifier of the community to which the corresponding chat was added
final
customEmojiStickerSetId int
customEmojiStickerSetId Identifier of the custom emoji sticker set that can be used in the supergroup without Telegram Premium subscription; 0 if none
final
description String
param_description Supergroup or channel description
final
directMessagesChatId int
directMessagesChatId Chat identifier of a direct messages group for the channel, or a channel, for which the supergroup is the designated direct messages group; 0 if none
final
giftCount int
giftCount Number of saved to profile gifts for channels without can_post_messages administrator right, otherwise, the total number of received gifts
final
guardBotUserId int
guardBotUserId User identifier of the guard bot in the group; for chat administrators only
final
hasAggressiveAntiSpamEnabled bool
hasAggressiveAntiSpamEnabled True, if aggressive anti-spam checks are enabled in the supergroup. The value of this field is only available to chat administrators
final
hashCode int
The hash code for this object.
no setteroverride
hasHiddenMembers bool
hasHiddenMembers True, if non-administrators can receive only administrators and bots using getSupergroupMembers or searchChatMembers
final
hasPaidMediaAllowed bool
hasPaidMediaAllowed True, if paid media can be sent and forwarded to the channel chat; for channels only
final
hasPinnedStories bool
hasPinnedStories True, if the supergroup or channel has pinned stories
final
inviteLink Primary invite link for the chat; may be null. For chat administrators with can_invite_users right only
final
isAllHistoryAvailable bool
isAllHistoryAvailable True, if new chat members will have access to old messages. In public, discussion, of forum groups and all channels, old messages are always available, so this option affects only private non-forum supergroups without a linked chat. The value of this field is only available to chat administrators
final
linkedChatId int
linkedChatId Chat identifier of a discussion group for the channel, or a channel, for which the supergroup is the designated discussion group; 0 if none or unknown
final
location ChatLocation?
location Location to which the supergroup is connected; may be null if none
final
mainProfileTab ProfileTab?
mainProfileTab The main tab chosen by the administrators of the channel; may be null if not chosen manually
final
memberCount int
memberCount Number of members in the supergroup or channel; 0 if unknown
final
myBoostCount int
myBoostCount Number of times the current user boosted the supergroup or channel
final
outgoingPaidMessageStarCount int
outgoingPaidMessageStarCount Number of Telegram Stars that must be paid by the current user for each sent message to the supergroup
final
photo ChatPhoto?
photo Chat photo; may be null if empty or unknown. If non-null, then it is the same photo as in chat.photo
final
restrictedCount int
restrictedCount Number of restricted users in the supergroup; 0 if unknown
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowModeDelay int
slowModeDelay Delay between consecutive sent messages for non-administrator supergroup members, in seconds
final
slowModeDelayExpiresIn double
slowModeDelayExpiresIn Time left before next message can be sent in the supergroup, in seconds. An updateSupergroupFullInfo update is not triggered when value of this field changes, but both new and old values are non-zero
final
stickerSetId int
stickerSetId Identifier of the supergroup sticker set that must be shown before user sticker sets; 0 if none
final
unrestrictBoostCount int
unrestrictBoostCount Number of times the supergroup must be boosted by a user to ignore slow mode and chat permission restrictions; 0 if unspecified
final
upgradedFromBasicGroupId int
upgradedFromBasicGroupId Identifier of the basic group from which supergroup was upgraded; 0 if none
final
upgradedFromMaxMessageId int
upgradedFromMaxMessageId Identifier of the last message in the basic group from which supergroup was upgraded; 0 if none
final

Methods

copyWith({ChatPhoto? photo, int? communityId, String? description, int? memberCount, int? administratorCount, int? restrictedCount, int? bannedCount, int? linkedChatId, int? directMessagesChatId, int? slowModeDelay, double? slowModeDelayExpiresIn, bool? canEnablePaidMessages, bool? canEnablePaidReaction, bool? canGetMembers, bool? hasHiddenMembers, bool? canHideMembers, bool? canSetStickerSet, bool? canSetLocation, bool? canGetStatistics, bool? canGetRevenueStatistics, bool? canGetStarRevenueStatistics, bool? canSendGift, bool? canToggleAggressiveAntiSpam, bool? isAllHistoryAvailable, bool? canHaveSponsoredMessages, bool? hasAggressiveAntiSpamEnabled, bool? hasPaidMediaAllowed, bool? hasPinnedStories, int? giftCount, int? myBoostCount, int? unrestrictBoostCount, int? outgoingPaidMessageStarCount, int? stickerSetId, int? customEmojiStickerSetId, ChatLocation? location, ChatInviteLink? inviteLink, int? guardBotUserId, List<BotCommands>? botCommands, BotVerification? botVerification, ProfileTab? mainProfileTab, int? upgradedFromBasicGroupId, int? upgradedFromMaxMessageId}) SupergroupFullInfo

Available on SupergroupFullInfo, provided by the SupergroupFullInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SupergroupFullInfo?

Constants

constructor → const String