canGetRevenueStatistics property
canGetRevenueStatistics True, if the supergroup or channel revenue statistics are available
Implementation
final bool canGetRevenueStatistics;
canGetRevenueStatistics True, if the supergroup or channel revenue statistics are available
final bool canGetRevenueStatistics;