canGetStarRevenueStatistics property
canGetStarRevenueStatistics True, if the supergroup or channel Telegram Star revenue statistics are available
Implementation
final bool canGetStarRevenueStatistics;
canGetStarRevenueStatistics True, if the supergroup or channel Telegram Star revenue statistics are available
final bool canGetStarRevenueStatistics;