canHaveSponsoredMessages property
canHaveSponsoredMessages True, if the chat can have sponsored messages. The value of this field is only available to the owner of the chat
Implementation
final bool canHaveSponsoredMessages;
canHaveSponsoredMessages True, if the chat can have sponsored messages. The value of this field is only available to the owner of the chat
final bool canHaveSponsoredMessages;