canSendGift property
canSendGift True, if the user can send a gift to the supergroup or channel using sendGift or transferGift
Implementation
final bool canSendGift;
canSendGift True, if the user can send a gift to the supergroup or channel using sendGift or transferGift
final bool canSendGift;