guardBotUserId property
guardBotUserId User identifier of the guard bot in the group; for chat administrators only
Implementation
final int guardBotUserId;
guardBotUserId User identifier of the guard bot in the group; for chat administrators only
final int guardBotUserId;