hasPaidMediaAllowed property
hasPaidMediaAllowed True, if paid media can be sent and forwarded to the channel chat; for channels only
Implementation
final bool hasPaidMediaAllowed;
hasPaidMediaAllowed True, if paid media can be sent and forwarded to the channel chat; for channels only
final bool hasPaidMediaAllowed;