outgoingPaidMessageStarCount property

int outgoingPaidMessageStarCount
final

outgoingPaidMessageStarCount Number of Telegram Stars that must be paid by the current user for each sent message to the supergroup

Implementation

final int outgoingPaidMessageStarCount;