unrestrictBoostCount property

int unrestrictBoostCount
final

unrestrictBoostCount Number of times the supergroup must be boosted by a user to ignore slow mode and chat permission restrictions; 0 if unspecified

Implementation

final int unrestrictBoostCount;