SynchronizeLanguagePack class final

Fetches the latest versions of all strings from a language pack in the current localization target from the server. This method doesn't need to be called explicitly for the current used/base language packs. Can be called before authorization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SynchronizeLanguagePack({required String languagePackId})

Properties

hashCode int
The hash code for this object.
no setteroverride
languagePackId String
languagePackId Language pack identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? languagePackId}) SynchronizeLanguagePack

Available on SynchronizeLanguagePack, provided by the SynchronizeLanguagePackExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String