TMeUrl class final

Represents a URL linking to an internal Telegram entity

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TMeUrl({required String url, TMeUrlType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TMeUrlType?
type Type of the URL
final
url String
url URL
final

Methods

copyWith({String? url, TMeUrlType? type}) TMeUrl

Available on TMeUrl, provided by the TMeUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TMeUrl?

Constants

constructor → const String