TMeUrlTypeChatInvite class final
A chat invite link
- Inheritance
-
- Object
- TdObject
- TMeUrlType
- TMeUrlTypeChatInvite
- Available extensions
- Annotations
-
- @immutable
Constructors
- TMeUrlTypeChatInvite({ChatInviteLinkInfo? info})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- info → ChatInviteLinkInfo?
-
info Information about the chat invite link
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatInviteLinkInfo? info}) → TMeUrlTypeChatInvite -
Available on TMeUrlTypeChatInvite, provided by the TMeUrlTypeChatInviteExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chatInvite(TMeUrlTypeChatInvite value), required TResult stickerSet(TMeUrlTypeStickerSet value), required TResult supergroup(TMeUrlTypeSupergroup value), required TResult user(TMeUrlTypeUser value)}) → TResult -
Available on TMeUrlType, provided by the TMeUrlTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chatInvite(TMeUrlTypeChatInvite value)?, TResult stickerSet(TMeUrlTypeStickerSet value)?, TResult supergroup(TMeUrlTypeSupergroup value)?, TResult user(TMeUrlTypeUser value)?, required TResult orElse()}) → TResult -
Available on TMeUrlType, provided by the TMeUrlTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TMeUrlTypeChatInvite? -
Inherited by:
TMeUrlTypeChatInvite
TMeUrlTypeStickerSet
TMeUrlTypeSupergroup
TMeUrlTypeUser
override
Constants
- constructor → const String