TMeUrlTypeUser class final

A URL linking to a user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TMeUrlTypeUser({required int userId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId Identifier of the user
final

Methods

copyWith({int? userId}) TMeUrlTypeUser

Available on TMeUrlTypeUser, provided by the TMeUrlTypeUserExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult chatInvite(TMeUrlTypeChatInvite value), required TResult stickerSet(TMeUrlTypeStickerSet value), required TResult supergroup(TMeUrlTypeSupergroup value), required TResult user(TMeUrlTypeUser value)}) → TResult

Available on TMeUrlType, provided by the TMeUrlTypeExtensions extension

maybeMap<TResult extends Object?>({TResult chatInvite(TMeUrlTypeChatInvite value)?, TResult stickerSet(TMeUrlTypeStickerSet value)?, TResult supergroup(TMeUrlTypeSupergroup value)?, TResult user(TMeUrlTypeUser value)?, required TResult orElse()}) → TResult

Available on TMeUrlType, provided by the TMeUrlTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String