TMeUrls class final

Contains a list of t.me URLs

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TMeUrls({required List<TMeUrl> urls})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urls List<TMeUrl>
urls List of URLs
final

Methods

copyWith({List<TMeUrl>? urls}) TMeUrls

Available on TMeUrls, provided by the TMeUrlsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TMeUrls?

Constants

constructor → const String