TargetChat class sealed
Describes the target chat to be opened
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chosen(TargetChatChosen value), required TResult current(TargetChatCurrent value), required TResult internalLink(TargetChatInternalLink value)}) → TResult -
Available on TargetChat, provided by the TargetChatExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chosen(TargetChatChosen value)?, TResult current(TargetChatCurrent value)?, TResult internalLink(TargetChatInternalLink value)?, required TResult orElse()}) → TResult -
Available on TargetChat, provided by the TargetChatExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TargetChat? - Inherited by: TargetChatChosen TargetChatCurrent TargetChatInternalLink
Constants
- constructor → const String