TdError class final

An object of this type can be returned on every function call, in case of an error

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TdError({required int code, required String message})

Properties

code → int
code Error code; subject to future changes. If the error code is 406, the error message must not be processed in any way and must not be displayed to the user
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
message Error message; subject to future changes
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? code, String? message}) → TdError

Available on TdError, provided by the TdErrorExtensions extension

getConstructor() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) → TdError?

Constants

constructor → const String