TdFunction class abstract
- Implementers
- AcceptCall
- AcceptOauthRequest
- AcceptTermsOfService
- ActivateStoryStealthMode
- AddBotMediaPreview
- AddChatFolderByInviteLink
- AddChatMember
- AddChatMembers
- AddChatToList
- AddChecklistTasks
- AddContact
- AddCustomServerLanguagePack
- AddFavoriteSticker
- AddFileToDownloads
- AddGiftCollectionGifts
- AddLocalMessage
- AddLoginPasskey
- AddLogMessage
- AddMessageReaction
- AddNetworkStatistics
- AddOffer
- AddPendingLiveStoryReaction
- AddPendingPaidMessageReaction
- AddPollOption
- AddProfileAudio
- AddProxy
- AddQuickReplyShortcutInlineQueryResultMessage
- AddQuickReplyShortcutMessage
- AddQuickReplyShortcutMessageAlbum
- AddRecentlyFoundChat
- AddRecentSticker
- AddSavedAnimation
- AddSavedNotificationSound
- AddStickerToSet
- AddStoryAlbumStories
- AddTextCompositionStyle
- AddWebBrowserSettingsException
- AllowBotToSendMessages
- AllowUnpaidMessagesFromUser
- AnswerCallbackQuery
- AnswerChatJoinRequestQuery
- AnswerCustomQuery
- AnswerGuestQuery
- AnswerInlineQuery
- AnswerPreCheckoutQuery
- AnswerShippingQuery
- AnswerWebAppQuery
- ApplyPremiumGiftCode
- ApproveSuggestedPost
- AssignStoreTransaction
- BanChatMember
- BanGroupCallParticipants
- BlockMessageSenderFromReplies
- BoostChat
- BuyGiftUpgrade
- CanBotSendMessages
- CancelDownloadFile
- CancelPasswordReset
- CancelPreliminaryUploadFile
- CancelRecoveryEmailAddressVerification
- CanPostStory
- CanPurchaseFromStore
- CanSendGift
- CanSendMessageToUser
- CanTransferOwnership
- ChangeImportedContacts
- ChangeStickerSet
- ChangeWebBrowserSettings
- CheckAuthenticationBotToken
- CheckAuthenticationCode
- CheckAuthenticationEmailCode
- CheckAuthenticationPasskey
- CheckAuthenticationPassword
- CheckAuthenticationPasswordRecoveryCode
- CheckAuthenticationPremiumPurchase
- CheckAuthenticationWebToken
- CheckBotUsername
- CheckChatFolderInviteLink
- CheckChatInviteLink
- CheckChatUsername
- CheckCreatedPublicChatsLimit
- CheckEmailAddressVerificationCode
- CheckLoginEmailAddressCode
- CheckOauthRequestMatchCode
- CheckPasswordRecoveryCode
- CheckPhoneNumberCode
- CheckPremiumGiftCode
- CheckQuickReplyShortcutName
- CheckRecoveryEmailAddressCode
- CheckStickerSetName
- CheckWebAppFileDownload
- CleanFileName
- ClearAllDraftMessages
- ClearAutosaveSettingsExceptions
- ClearImportedContacts
- ClearRecentEmojiStatuses
- ClearRecentlyFoundChats
- ClearRecentReactions
- ClearRecentStickers
- ClearSearchedForTags
- ClickAnimatedEmojiMessage
- ClickChatSponsoredMessage
- ClickPremiumSubscriptionButton
- ClickVideoMessageAdvertisement
- Close
- CloseChat
- CloseGiftAuction
- CloseSecretChat
- CloseStory
- CloseWebApp
- CommitPendingLiveStoryReactions
- CommitPendingPaidMessageReactions
- ComposeRichMessageWithAi
- ComposeTextWithAi
- ConfirmBusinessConnectedBot
- ConfirmQrCodeAuthentication
- ConfirmSession
- ConnectAffiliateProgram
- CraftGift
- CreateBasicGroupChat
- CreateBot
- CreateBusinessChatLink
- CreateCall
- CreateChatFolder
- CreateChatFolderInviteLink
- CreateChatInviteLink
- CreateChatSubscriptionInviteLink
- CreateForumTopic
- CreateGiftCollection
- CreateGroupCall
- CreateInvoiceLink
- CreateNewBasicGroupChat
- CreateNewSecretChat
- CreateNewStickerSet
- CreateNewSupergroupChat
- CreatePrivateChat
- CreateRichMessageWithAi
- CreateSecretChat
- CreateStoryAlbum
- CreateSupergroupChat
- CreateTemporaryPassword
- CreateTextCompositionStyle
- CreateVideoChat
- DeclineGroupCallInvitation
- DeclineOauthRequest
- DeclineSuggestedPost
- DecryptGroupCallData
- DeleteAccount
- DeleteAllCallMessages
- DeleteAllRecentMessageReactionsFromSender
- DeleteAllRevokedChatInviteLinks
- DeleteBotMediaPreviews
- DeleteBusinessChatLink
- DeleteBusinessConnectedBot
- DeleteBusinessMessages
- DeleteBusinessStory
- DeleteChat
- DeleteChatBackground
- DeleteChatFolder
- DeleteChatFolderInviteLink
- DeleteChatHistory
- DeleteChatMessagesByDate
- DeleteChatMessagesBySender
- DeleteChatReplyMarkup
- DeleteCommands
- DeleteDefaultBackground
- DeleteDirectMessagesChatTopicHistory
- DeleteDirectMessagesChatTopicMessagesByDate
- DeleteEphemeralMessage
- DeleteFile
- DeleteForumTopic
- DeleteGiftCollection
- DeleteGroupCallMessages
- DeleteGroupCallMessagesBySender
- DeleteLanguagePack
- DeleteMessageReactionsFromSender
- DeleteMessages
- DeletePassportElement
- DeletePollOption
- DeleteProfilePhoto
- DeleteQuickReplyShortcut
- DeleteQuickReplyShortcutMessages
- DeleteRevokedChatInviteLink
- DeleteSavedCredentials
- DeleteSavedMessagesTopicHistory
- DeleteSavedMessagesTopicMessagesByDate
- DeleteSavedOrderInfo
- DeleteStickerSet
- DeleteStory
- DeleteStoryAlbum
- DeleteTextCompositionStyle
- Destroy
- DisableAllSupergroupUsernames
- DisableProxy
- DiscardCall
- DisconnectAffiliateProgram
- DisconnectAllWebsites
- DisconnectWebsite
- DownloadFile
- DropGiftOriginalDetails
- EditBotMediaPreview
- EditBusinessChatLink
- EditBusinessMessageCaption
- EditBusinessMessageChecklist
- EditBusinessMessageLiveLocation
- EditBusinessMessageMedia
- EditBusinessMessageReplyMarkup
- EditBusinessMessageText
- EditBusinessStory
- EditChatFolder
- EditChatFolderInviteLink
- EditChatInviteLink
- EditChatSubscriptionInviteLink
- EditCustomLanguagePackInfo
- EditEphemeralMessage
- EditForumTopic
- EditInlineMessageCaption
- EditInlineMessageLiveLocation
- EditInlineMessageMedia
- EditInlineMessageReplyMarkup
- EditInlineMessageText
- EditMessageCaption
- EditMessageChecklist
- EditMessageLiveLocation
- EditMessageMedia
- EditMessageReplyMarkup
- EditMessageSchedulingState
- EditMessageText
- EditProxy
- EditQuickReplyMessage
- EditStarSubscription
- EditStory
- EditStoryCover
- EditTextCompositionStyle
- EditUserStarSubscription
- EnableProxy
- EncryptGroupCallData
- EndGroupCall
- EndGroupCallRecording
- EndGroupCallScreenSharing
- FinishFileGeneration
- FixRichMessageWithAi
- FixTextWithAi
- ForwardMessages
- GetAccountTtl
- GetActiveSessions
- GetAllPassportElements
- GetAllStickerEmojis
- GetAnimatedEmoji
- GetApplicationConfig
- GetApplicationDownloadLink
- GetArchiveChatListSettings
- GetArchivedStickerSets
- GetAttachedStickerSets
- GetAttachmentMenuBot
- GetAuthenticationPasskeyParameters
- GetAuthorizationState
- GetAutoDownloadSettingsPresets
- GetAutosaveSettings
- GetAvailableChatBoostSlots
- GetAvailableGifts
- GetBackgroundUrl
- GetBankCardInfo
- GetBasicGroup
- GetBasicGroupFullInfo
- GetBlockedMessageSenders
- GetBotInfoDescription
- GetBotInfoShortDescription
- GetBotMediaPreviewInfo
- GetBotMediaPreviews
- GetBotName
- GetBotSimilarBotCount
- GetBotSimilarBots
- GetBusinessAccountStarAmount
- GetBusinessChatLinkInfo
- GetBusinessChatLinks
- GetBusinessConnectedBot
- GetBusinessConnection
- GetBusinessFeatures
- GetCallbackQueryAnswer
- GetCallbackQueryMessage
- GetChat
- GetChatActiveStories
- GetChatAdministrators
- GetChatArchivedStories
- GetChatAvailableMessageSenders
- GetChatAvailablePaidMessageReactionSenders
- GetChatBoostFeatures
- GetChatBoostLevelFeatures
- GetChatBoostLink
- GetChatBoostLinkInfo
- GetChatBoosts
- GetChatBoostStatus
- GetChatEventLog
- GetChatFolder
- GetChatFolderChatCount
- GetChatFolderChatsToLeave
- GetChatFolderDefaultIconName
- GetChatFolderInviteLinks
- GetChatFolderNewChats
- GetChatHistory
- GetChatInviteLink
- GetChatInviteLinkCounts
- GetChatInviteLinkMembers
- GetChatInviteLinks
- GetChatJoinRequests
- GetChatListsToAddChat
- GetChatMember
- GetChatMessageByDate
- GetChatMessageCalendar
- GetChatMessageCount
- GetChatMessagePosition
- GetChatNotificationSettingsExceptions
- GetChatOwnerAfterLeaving
- GetChatPinnedMessage
- GetChatPostedToChatPageStories
- GetChatRevenueStatistics
- GetChatRevenueTransactions
- GetChatRevenueWithdrawalUrl
- GetChats
- GetChatScheduledMessages
- GetChatsForChatFolderInviteLink
- GetChatSimilarChatCount
- GetChatSimilarChats
- GetChatSparseMessagePositions
- GetChatSponsoredMessages
- GetChatStatistics
- GetChatsToPostStories
- GetChatStoryAlbums
- GetChatStoryInteractions
- GetCloseFriends
- GetCollectibleItemInfo
- GetCommands
- GetConnectedAffiliateProgram
- GetConnectedAffiliatePrograms
- GetConnectedWebsites
- GetContacts
- GetCountries
- GetCountry
- GetCountryCode
- GetCountryFlagEmoji
- GetCreatedPublicChats
- GetCurrentState
- GetCurrentWeather
- GetCustomEmojiReactionAnimations
- GetCustomEmojiStickers
- GetDatabaseStatistics
- GetDeepLinkInfo
- GetDefaultBackgroundCustomEmojiStickers
- GetDefaultChatEmojiStatuses
- GetDefaultChatPhotoCustomEmojiStickers
- GetDefaultEmojiStatuses
- GetDefaultMessageAutoDeleteTime
- GetDefaultProfilePhotoCustomEmojiStickers
- GetDirectMessagesChatTopic
- GetDirectMessagesChatTopicHistory
- GetDirectMessagesChatTopicMessageByDate
- GetDirectMessagesChatTopicRevenue
- GetDisallowedChatEmojiStatuses
- GetEmojiCategories
- GetEmojiReaction
- GetEmojiSuggestionsUrl
- GetExternalLink
- GetExternalLinkInfo
- GetFavoriteStickers
- GetFile
- GetFileDownloadedPrefixSize
- GetFileExtension
- GetFileMimeType
- GetForumTopic
- GetForumTopicDefaultIcons
- GetForumTopicHistory
- GetForumTopicLink
- GetForumTopics
- GetFullRichMessage
- GetGameHighScores
- GetGiftAuctionAcquiredGifts
- GetGiftAuctionState
- GetGiftChatThemes
- GetGiftCollections
- GetGiftsForCrafting
- GetGiftUpgradePreview
- GetGiveawayInfo
- GetGramRevenueStatistics
- GetGramWithdrawalUrl
- GetGreetingStickers
- GetGrossingWebAppBots
- GetGroupCall
- GetGroupCallParticipants
- GetGroupCallStreams
- GetGroupCallStreamSegment
- GetGroupsInCommon
- GetGuardBotWebAppUrl
- GetImportedContactCount
- GetInactiveSupergroupChats
- GetInlineGameHighScores
- GetInlineQueryResults
- GetInstalledBackgrounds
- GetInstalledStickerSets
- GetInternalLink
- GetInternalLinkType
- GetJsonString
- GetJsonValue
- GetKeywordEmojis
- GetLanguagePackInfo
- GetLanguagePackString
- GetLanguagePackStrings
- GetLinkPreview
- GetLinkWebBrowserType
- GetLiveStoryAvailableMessageSenders
- GetLiveStoryRtmpUrl
- GetLiveStoryStreamer
- GetLiveStoryTopDonors
- GetLocalizationTargetInfo
- GetLoginPasskeys
- GetLoginUrl
- GetLoginUrlInfo
- GetLogStream
- GetLogTags
- GetLogTagVerbosityLevel
- GetLogVerbosityLevel
- GetMainWebApp
- GetManagedBotAccessSettings
- GetManagedBotToken
- GetMapThumbnailFile
- GetMarkdownText
- GetMe
- GetMenuButton
- GetMessage
- GetMessageAddedReactions
- GetMessageAuthor
- GetMessageAvailableReactions
- GetMessageEffect
- GetMessageEmbeddingCode
- GetMessageFileType
- GetMessageImportConfirmationText
- GetMessageLink
- GetMessageLinkInfo
- GetMessageLocally
- GetMessageProperties
- GetMessagePublicForwards
- GetMessageReadDate
- GetMessages
- GetMessageStatistics
- GetMessageThread
- GetMessageThreadHistory
- GetMessageViewers
- GetNetworkStatistics
- GetNewChatPrivacySettings
- GetOauthLinkInfo
- GetOption
- GetOwnedBots
- GetOwnedStickerSets
- GetPaidMessageRevenue
- GetPasskeyParameters
- GetPassportAuthorizationForm
- GetPassportAuthorizationFormAvailableElements
- GetPassportElement
- GetPasswordState
- GetPaymentForm
- GetPaymentReceipt
- GetPersonalChatHistory
- GetPhoneNumberInfo
- GetPhoneNumberInfoSync
- GetPollOptionProperties
- GetPollVoters
- GetPollVoteStatistics
- GetPreferredCountryLanguage
- GetPremiumFeatures
- GetPremiumGiftPaymentOptions
- GetPremiumGiveawayPaymentOptions
- GetPremiumInfoSticker
- GetPremiumLimit
- GetPremiumState
- GetPremiumStickerExamples
- GetPremiumStickers
- GetPreparedInlineMessage
- GetPreparedKeyboardButton
- GetProxies
- GetPublicPostSearchLimits
- GetPushReceiverId
- GetReadDatePrivacySettings
- GetReceivedGift
- GetReceivedGifts
- GetRecentEmojiStatuses
- GetRecentInlineBots
- GetRecentlyOpenedChats
- GetRecentlyVisitedTMeUrls
- GetRecentStickers
- GetRecommendedChatFolders
- GetRecommendedChats
- GetRecoveryEmailAddress
- GetRemoteFile
- GetRepliedMessage
- GetSavedAnimations
- GetSavedMessagesTags
- GetSavedMessagesTopicHistory
- GetSavedMessagesTopicMessageByDate
- GetSavedNotificationSound
- GetSavedNotificationSounds
- GetSavedOrderInfo
- GetScopeNotificationSettings
- GetSearchedForTags
- GetSearchSponsoredChats
- GetSecretChat
- GetStakeDiceState
- GetStarAdAccountUrl
- GetStarGiftPaymentOptions
- GetStarGiveawayPaymentOptions
- GetStarPaymentOptions
- GetStarRevenueStatistics
- GetStarSubscriptions
- GetStarTransactions
- GetStarWithdrawalUrl
- GetStatisticalGraph
- GetStickerEmojis
- GetStickerOutline
- GetStickerOutlineSvgPath
- GetStickers
- GetStickerSet
- GetStickerSetName
- GetStorageStatistics
- GetStorageStatisticsFast
- GetStory
- GetStoryAlbumStories
- GetStoryAvailableReactions
- GetStoryInteractions
- GetStoryNotificationSettingsExceptions
- GetStoryPublicForwards
- GetStoryStatistics
- GetSuggestedFileName
- GetSuggestedStickerSetName
- GetSuitableDiscussionChats
- GetSuitablePersonalChats
- GetSupergroup
- GetSupergroupFullInfo
- GetSupergroupMembers
- GetSupportName
- GetSupportUser
- GetTemporaryPasswordState
- GetTextCompositionStyleExample
- GetTextEntities
- GetThemedChatEmojiStatuses
- GetThemedEmojiStatuses
- GetThemeParametersJsonString
- GetTimeZones
- GetTonTransactions
- GetTopChats
- GetTrendingStickerSets
- GetUpgradedGift
- GetUpgradedGiftEmojiStatuses
- GetUpgradedGiftsPromotionalAnimation
- GetUpgradedGiftValueInfo
- GetUpgradedGiftVariants
- GetUpgradedGiftWithdrawalUrl
- GetUser
- GetUserChatBoosts
- GetUserFullInfo
- GetUserLink
- GetUserPrivacySettingRules
- GetUserProfileAudios
- GetUserProfilePhotos
- GetUserSupportInfo
- GetVideoChatAvailableParticipants
- GetVideoChatInviteLink
- GetVideoChatRtmpUrl
- GetVideoMessageAdvertisements
- GetWebAppLinkUrl
- GetWebAppPlaceholder
- GetWebAppUrl
- GetWebPageInstantView
- GiftPremiumWithStars
- HideContactCloseBirthdays
- HideSuggestedAction
- ImportContacts
- ImportMessages
- IncreaseGiftAuctionBid
- InviteGroupCallParticipant
- InviteVideoChatParticipants
- IsLoginEmailAddressRequired
- IsProfileAudio
- JoinChat
- JoinChatByInviteLink
- JoinGroupCall
- JoinLiveStory
- JoinVideoChat
- LaunchPrepaidGiveaway
- LeaveChat
- LeaveGroupCall
- ListenToAudio
- LoadActiveStories
- LoadChats
- LoadDirectMessagesChatTopics
- LoadGroupCallParticipants
- LoadQuickReplyShortcutMessages
- LoadQuickReplyShortcuts
- LoadSavedMessagesTopics
- LogOut
- MarkChecklistTasksAsDone
- OpenBotSimilarBot
- OpenChat
- OpenChatSimilarChat
- OpenGiftAuction
- OpenMessageContent
- OpenSponsoredChat
- OpenStory
- OpenWebApp
- OptimizeStorage
- ParseMarkdown
- ParseTextEntities
- PinChatMessage
- PingProxy
- PlaceGiftAuctionBid
- PostStory
- PreliminaryUploadFile
- ProcessChatFolderNewChats
- ProcessChatHasProtectedContentDisableRequest
- ProcessChatJoinRequest
- ProcessChatJoinRequests
- ProcessGiftPurchaseOffer
- ProcessPushNotification
- RateSpeechRecognition
- ReadAllChatMentions
- ReadAllChatPollVotes
- ReadAllChatReactions
- ReadAllDirectMessagesChatTopicReactions
- ReadAllForumTopicMentions
- ReadAllForumTopicPollVotes
- ReadAllForumTopicReactions
- ReadBusinessMessage
- ReadChatList
- ReaddQuickReplyShortcutMessages
- ReadFilePart
- RecognizeSpeech
- RecoverAuthenticationPassword
- RecoverPassword
- RefundStarPayment
- RegisterDevice
- RegisterUser
- RemoveAllFilesFromDownloads
- RemoveAllWebBrowserSettingsExceptions
- RemoveBusinessConnectedBotFromChat
- RemoveChatActionBar
- RemoveContacts
- RemoveFavoriteSticker
- RemoveFileFromDownloads
- RemoveGiftCollectionGifts
- RemoveInstalledBackground
- RemoveLoginPasskey
- RemoveMessageReaction
- RemoveMessageSenderBotVerification
- RemoveNotification
- RemoveNotificationGroup
- RemovePendingLiveStoryReactions
- RemovePendingPaidMessageReactions
- RemoveProfileAudio
- RemoveProxy
- RemoveRecentHashtag
- RemoveRecentlyFoundChat
- RemoveRecentSticker
- RemoveSavedAnimation
- RemoveSavedNotificationSound
- RemoveSearchedForTag
- RemoveStickerFromSet
- RemoveStoryAlbumStories
- RemoveTextCompositionStyle
- RemoveTopChat
- RemoveWebBrowserSettingsException
- ReorderActiveUsernames
- ReorderBotActiveUsernames
- ReorderBotMediaPreviews
- ReorderChatFolders
- ReorderGiftCollectionGifts
- ReorderGiftCollections
- ReorderInstalledStickerSets
- ReorderQuickReplyShortcuts
- ReorderStoryAlbums
- ReorderStoryAlbumStories
- ReorderSupergroupActiveUsernames
- ReplaceLiveStoryRtmpUrl
- ReplacePrimaryChatInviteLink
- ReplaceStickerInSet
- ReplaceVideoChatRtmpUrl
- ReportAuthenticationCodeMissing
- ReportChat
- ReportChatPhoto
- ReportChatSponsoredMessage
- ReportMessageReactions
- ReportPhoneNumberCodeMissing
- ReportSponsoredChat
- ReportStory
- ReportSupergroupAntiSpamFalsePositive
- ReportSupergroupSpam
- ReportVideoMessageAdvertisement
- RequestAuthenticationPasswordRecovery
- RequestPasswordRecovery
- RequestQrCodeAuthentication
- ResendAuthenticationCode
- ResendEmailAddressVerificationCode
- ResendLoginEmailAddressCode
- ResendMessages
- ResendPhoneNumberCode
- ResendRecoveryEmailAddressCode
- ResetAllNotificationSettings
- ResetAuthenticationEmailAddress
- ResetInstalledBackgrounds
- ResetNetworkStatistics
- ResetPassword
- ReuseStarSubscription
- RevokeChatInviteLink
- RevokeGroupCallInviteLink
- SaveApplicationLogEvent
- SavePreparedInlineMessage
- SavePreparedKeyboardButton
- SearchAffiliatePrograms
- SearchBackground
- SearchCallMessages
- SearchChatAffiliateProgram
- SearchChatMembers
- SearchChatMessages
- SearchChatRecentLocationMessages
- SearchChats
- SearchChatsOnServer
- SearchContacts
- SearchEmojis
- SearchFileDownloads
- SearchGiftsForResale
- SearchHashtags
- SearchInstalledStickerSets
- SearchMessages
- SearchOutgoingDocumentMessages
- SearchPublicChat
- SearchPublicChats
- SearchPublicMessagesByTag
- SearchPublicPosts
- SearchPublicStoriesByLocation
- SearchPublicStoriesByTag
- SearchPublicStoriesByVenue
- SearchQuote
- SearchRecentlyFoundChats
- SearchSavedMessages
- SearchSecretMessages
- SearchStickers
- SearchStickerSet
- SearchStickerSets
- SearchStringsByPrefix
- SearchTextCompositionStyle
- SearchUserByPhoneNumber
- SearchUserByToken
- SearchWebApp
- SellGift
- SendAuthenticationFirebaseSms
- SendBotStartMessage
- SendBusinessMessage
- SendBusinessMessageAlbum
- SendCallDebugInformation
- SendCallLog
- SendCallRating
- SendCallSignalingData
- SendChatAction
- SendCustomRequest
- SendEmailAddressVerificationCode
- SendEphemeralMessage
- SendGift
- SendGiftPurchaseOffer
- SendGroupCallMessage
- SendInlineQueryResultMessage
- SendMessage
- SendMessageAlbum
- SendMessageViewMetrics
- SendPassportAuthorizationForm
- SendPaymentForm
- SendPhoneNumberCode
- SendPhoneNumberFirebaseSms
- SendQuickReplyShortcutMessages
- SendResoldGift
- SendRichMessageDraft
- SendTextMessageDraft
- SendWebAppCustomRequest
- SendWebAppData
- SetAccentColor
- SetAccountTtl
- SetAlarm
- SetApplicationVerificationToken
- SetArchiveChatListSettings
- SetAuthenticationEmailAddress
- SetAuthenticationPhoneNumber
- SetAuthenticationPremiumPurchaseTransaction
- SetAutoDownloadSettings
- SetAutosaveSettings
- SetBio
- SetBirthdate
- SetBotInfoDescription
- SetBotInfoShortDescription
- SetBotName
- SetBotProfilePhoto
- SetBotUpdatesStatus
- SetBusinessAccountBio
- SetBusinessAccountGiftSettings
- SetBusinessAccountName
- SetBusinessAccountProfilePhoto
- SetBusinessAccountUsername
- SetBusinessAwayMessageSettings
- SetBusinessConnectedBot
- SetBusinessGreetingMessageSettings
- SetBusinessLocation
- SetBusinessMessageIsPinned
- SetBusinessOpeningHours
- SetBusinessStartPage
- SetChatAccentColor
- SetChatActiveStoriesList
- SetChatAffiliateProgram
- SetChatAvailableReactions
- SetChatBackground
- SetChatClientData
- SetChatDescription
- SetChatDirectMessagesGroup
- SetChatDiscussionGroup
- SetChatDraftMessage
- SetChatEmojiStatus
- SetChatLocation
- SetChatMemberStatus
- SetChatMemberTag
- SetChatMessageAutoDeleteTime
- SetChatMessageSender
- SetChatNotificationSettings
- SetChatPaidMessageStarCount
- SetChatPermissions
- SetChatPhoto
- SetChatPinnedStories
- SetChatProfileAccentColor
- SetChatSlowModeDelay
- SetChatTheme
- SetChatTitle
- SetCloseFriends
- SetCommands
- SetCustomEmojiStickerSetThumbnail
- SetCustomLanguagePack
- SetCustomLanguagePackString
- SetDatabaseEncryptionKey
- SetDefaultBackground
- SetDefaultChannelAdministratorRights
- SetDefaultGroupAdministratorRights
- SetDefaultMessageAutoDeleteTime
- SetDefaultReactionType
- SetDirectMessagesChatTopicIsMarkedAsUnread
- SetEmojiStatus
- SetFileGenerationProgress
- SetForumTopicNotificationSettings
- SetGameScore
- SetGiftCollectionName
- SetGiftResalePrice
- SetGiftSettings
- SetGroupCallPaidMessageStarCount
- SetGroupCallParticipantIsSpeaking
- SetGroupCallParticipantVolumeLevel
- SetInactiveSessionTtl
- SetInlineGameScore
- SetLiveStoryMessageSender
- SetLoginEmailAddress
- SetLogStream
- SetLogTagVerbosityLevel
- SetLogVerbosityLevel
- SetMainProfileTab
- SetManagedBotAccessSettings
- SetMenuButton
- SetMessageFactCheck
- SetMessageReactions
- SetMessageSenderBlockList
- SetMessageSenderBotVerification
- SetName
- SetNetworkType
- SetNewChatPrivacySettings
- SetOption
- SetPaidMessageReactionType
- SetPassportElement
- SetPassportElementErrors
- SetPassword
- SetPersonalChat
- SetPinnedChats
- SetPinnedForumTopics
- SetPinnedGifts
- SetPinnedSavedMessagesTopics
- SetPollAnswer
- SetProfileAccentColor
- SetProfileAudioPosition
- SetProfilePhoto
- SetQuickReplyShortcutName
- SetReactionNotificationSettings
- SetReadDatePrivacySettings
- SetRecoveryEmailAddress
- SetSavedMessagesTagLabel
- SetScopeNotificationSettings
- SetStickerEmojis
- SetStickerKeywords
- SetStickerMaskPosition
- SetStickerPositionInSet
- SetStickerSetThumbnail
- SetStickerSetTitle
- SetStoryAlbumName
- SetStoryPrivacySettings
- SetStoryReaction
- SetSupergroupCustomEmojiStickerSet
- SetSupergroupMainProfileTab
- SetSupergroupStickerSet
- SetSupergroupUnrestrictBoostCount
- SetSupergroupUsername
- SetTdlibParameters
- SetUpgradedGiftColors
- SetUserEmojiStatus
- SetUsername
- SetUserNote
- SetUserPersonalProfilePhoto
- SetUserPrivacySettingRules
- SetUserSupportInfo
- SetVideoChatDefaultParticipant
- SetVideoChatTitle
- ShareChatWithBot
- SharePhoneNumber
- ShareUsersWithBot
- StartGroupCallRecording
- StartGroupCallScreenSharing
- StartLiveStory
- StartScheduledVideoChat
- StopBusinessPoll
- StopPoll
- SuggestUserBirthdate
- SuggestUserProfilePhoto
- SummarizeMessage
- SynchronizeLanguagePack
- TerminateAllOtherSessions
- TerminateSession
- TestCallBytes
- TestCallEmpty
- TestCallString
- TestCallVectorInt
- TestCallVectorIntObject
- TestCallVectorString
- TestCallVectorStringObject
- TestGetDifference
- TestNetwork
- TestProxy
- TestReturnError
- TestSquareInt
- TestUseUpdate
- ToggleAllDownloadsArePaused
- ToggleBotCanManageEmojiStatus
- ToggleBotIsAddedToAttachmentMenu
- ToggleBotUsernameIsActive
- ToggleBusinessConnectedBotChatIsPaused
- ToggleChatDefaultDisableNotification
- ToggleChatFolderTags
- ToggleChatGiftNotifications
- ToggleChatHasProtectedContent
- ToggleChatIsMarkedAsUnread
- ToggleChatIsPinned
- ToggleChatIsTranslatable
- ToggleChatViewAsTopics
- ToggleDirectMessagesChatTopicCanSendUnpaidMessages
- ToggleDownloadIsPaused
- ToggleForumTopicIsClosed
- ToggleForumTopicIsPinned
- ToggleGeneralForumTopicIsHidden
- ToggleGiftIsSaved
- ToggleGroupCallAreMessagesAllowed
- ToggleGroupCallIsMyVideoEnabled
- ToggleGroupCallIsMyVideoPaused
- ToggleGroupCallParticipantIsHandRaised
- ToggleGroupCallParticipantIsMuted
- ToggleGroupCallScreenSharingIsPaused
- ToggleHasSponsoredMessagesEnabled
- ToggleSavedMessagesTopicIsPinned
- ToggleSessionCanAcceptCalls
- ToggleSessionCanAcceptSecretChats
- ToggleStoryIsPostedToChatPage
- ToggleSupergroupCanHaveSponsoredMessages
- ToggleSupergroupHasAggressiveAntiSpamEnabled
- ToggleSupergroupHasAutomaticTranslation
- ToggleSupergroupHasHiddenMembers
- ToggleSupergroupIsAllHistoryAvailable
- ToggleSupergroupIsBroadcastGroup
- ToggleSupergroupIsForum
- ToggleSupergroupJoinByRequest
- ToggleSupergroupJoinToSendMessages
- ToggleSupergroupSignMessages
- ToggleSupergroupUsernameIsActive
- ToggleUsernameIsActive
- ToggleVideoChatEnabledStartNotification
- ToggleVideoChatMuteNewParticipants
- TransferBusinessAccountStars
- TransferChatOwnership
- TransferGift
- TranslateMessageRichMessage
- TranslateMessageText
- TranslateRichMessage
- TranslateText
- UnpinAllChatMessages
- UnpinAllDirectMessagesChatTopicMessages
- UnpinAllForumTopicMessages
- UnpinChatMessage
- UpgradeBasicGroupChatToSupergroupChat
- UpgradeGift
- UploadStickerFile
- ValidateOrderInfo
- ViewMessages
- ViewPremiumFeature
- ViewSponsoredChat
- ViewTrendingStickerSets
- ViewVideoMessageAdvertisement
- WriteGeneratedFilePart
Constructors
- TdFunction()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited