TdObject class abstract
- Implementers
- AccentColor
- AcceptedGiftTypes
- AccountInfo
- AccountTtl
- ActiveStoryState
- AddedProxies
- AddedProxy
- AddedReaction
- AddedReactions
- Address
- AdvertisementSponsor
- AffiliateInfo
- AffiliateProgramInfo
- AffiliateProgramParameters
- AffiliateProgramSortOrder
- AffiliateType
- AgeVerificationParameters
- AlternativeVideo
- AnimatedChatPhoto
- AnimatedEmoji
- Animation
- Animations
- ArchiveChatListSettings
- AttachmentMenuBot
- AttachmentMenuBotColor
- AttributeCraftPersistenceProbability
- AuctionBid
- AuctionRound
- AuctionState
- Audio
- Audios
- AuthenticationCodeInfo
- AuthenticationCodeType
- AuthorizationState
- AutoDownloadSettings
- AutoDownloadSettingsPresets
- AutosaveSettings
- AutosaveSettingsException
- AutosaveSettingsScope
- AvailableGift
- AvailableGifts
- AvailableReaction
- AvailableReactions
- Background
- BackgroundFill
- Backgrounds
- BackgroundType
- BankCardActionOpenUrl
- BankCardInfo
- BasicGroup
- BasicGroupFullInfo
- Birthdate
- BlockList
- BotAccessSettings
- BotCommand
- BotCommands
- BotCommandScope
- BotInfo
- BotMediaPreview
- BotMediaPreviewInfo
- BotMediaPreviews
- BotMenuButton
- BotVerification
- BotVerificationParameters
- BotWriteAccessAllowReason
- BuiltInTheme
- BusinessAwayMessageSchedule
- BusinessAwayMessageSettings
- BusinessBotManageBar
- BusinessBotRights
- BusinessChatLink
- BusinessChatLinkInfo
- BusinessChatLinks
- BusinessConnectedBot
- BusinessConnectedBotInfo
- BusinessConnection
- BusinessFeature
- BusinessFeaturePromotionAnimation
- BusinessFeatures
- BusinessGreetingMessageSettings
- BusinessInfo
- BusinessLocation
- BusinessMessage
- BusinessMessages
- BusinessOpeningHours
- BusinessOpeningHoursInterval
- BusinessRecipients
- BusinessStartPage
- ButtonStyle
- Call
- CallbackQueryAnswer
- CallbackQueryPayload
- CallDiscardReason
- CallId
- CallProblem
- CallProtocol
- CallServer
- CallServerType
- CallState
- CanPostStoryResult
- CanSendGiftResult
- CanSendMessageToUserResult
- CanTransferOwnershipResult
- Chat
- ChatAction
- ChatActionBar
- ChatActiveStories
- ChatAdministrator
- ChatAdministratorRights
- ChatAdministrators
- ChatAvailableReactions
- ChatBackground
- ChatBoost
- ChatBoostFeatures
- ChatBoostLevelFeatures
- ChatBoostLink
- ChatBoostLinkInfo
- ChatBoostSlot
- ChatBoostSlots
- ChatBoostSource
- ChatBoostStatus
- ChatEvent
- ChatEventAction
- ChatEventLogFilters
- ChatEvents
- ChatFolder
- ChatFolderIcon
- ChatFolderInfo
- ChatFolderInviteLink
- ChatFolderInviteLinkInfo
- ChatFolderInviteLinks
- ChatFolderName
- ChatInviteLink
- ChatInviteLinkCount
- ChatInviteLinkCounts
- ChatInviteLinkInfo
- ChatInviteLinkMember
- ChatInviteLinkMembers
- ChatInviteLinks
- ChatInviteLinkSubscriptionInfo
- ChatJoinRequest
- ChatJoinRequestResult
- ChatJoinRequests
- ChatJoinRequestsInfo
- ChatJoinResult
- ChatList
- ChatLists
- ChatLocation
- ChatMember
- ChatMembers
- ChatMembersFilter
- ChatMemberStatus
- ChatMessageSender
- ChatMessageSenders
- ChatNotificationSettings
- ChatPermissions
- ChatPhoto
- ChatPhotoInfo
- ChatPhotos
- ChatPhotoSticker
- ChatPhotoStickerType
- ChatPosition
- ChatRevenueAmount
- ChatRevenueStatistics
- ChatRevenueTransaction
- ChatRevenueTransactions
- ChatRevenueTransactionType
- Chats
- ChatSource
- ChatStatistics
- ChatStatisticsAdministratorActionsInfo
- ChatStatisticsInteractionInfo
- ChatStatisticsInviterInfo
- ChatStatisticsMessageSenderInfo
- ChatStatisticsObjectType
- ChatTheme
- ChatType
- CheckChatUsernameResult
- Checklist
- ChecklistTask
- CheckStickerSetNameResult
- CloseBirthdayUser
- ClosedVectorPath
- CollectibleItemInfo
- CollectibleItemType
- Community
- CommunityAdministratorRights
- CommunityMemberStatus
- CommunityPermissions
- ConnectedAffiliateProgram
- ConnectedAffiliatePrograms
- ConnectedWebsite
- ConnectedWebsites
- ConnectionState
- Contact
- Count
- Countries
- CountryInfo
- CraftGiftResult
- CreatedBasicGroupChat
- CurrentWeather
- CustomRequestResult
- Data
- DatabaseStatistics
- Date
- DatedFile
- DateRange
- DateTimeFormattingType
- DateTimePartPrecision
- DeepLinkInfo
- DeviceToken
- DiceStickers
- DiffEntity
- DiffEntityType
- DiffText
- DirectMessagesChatTopic
- Document
- DownloadedFileCounts
- DraftMessage
- DraftMessageContent
- EmailAddressAuthentication
- EmailAddressAuthenticationCodeInfo
- EmailAddressResetState
- EmojiCategories
- EmojiCategory
- EmojiCategorySource
- EmojiCategoryType
- EmojiChatTheme
- EmojiKeyword
- EmojiKeywords
- EmojiReaction
- Emojis
- EmojiStatus
- EmojiStatusCustomEmojis
- EmojiStatuses
- EmojiStatusType
- EncryptedCredentials
- EncryptedPassportElement
- FactCheck
- FailedToAddMember
- FailedToAddMembers
- File
- FileDownload
- FileDownloadedPrefixSize
- FileType
- FirebaseAuthenticationSettings
- FirebaseDeviceVerificationParameters
- FixedText
- FormattedText
- ForumTopic
- ForumTopicIcon
- ForumTopicInfo
- ForumTopics
- ForwardSource
- FoundAffiliateProgram
- FoundAffiliatePrograms
- FoundChatBoosts
- FoundChatMessages
- FoundFileDownloads
- FoundMessages
- FoundPosition
- FoundPositions
- FoundPublicPosts
- FoundStories
- FoundUsers
- FoundWebApp
- Game
- GameHighScore
- GameHighScores
- Gift
- GiftAuction
- GiftAuctionAcquiredGift
- GiftAuctionAcquiredGifts
- GiftAuctionState
- GiftBackground
- GiftChatTheme
- GiftChatThemes
- GiftCollection
- GiftCollections
- GiftForResale
- GiftForResaleOrder
- GiftPurchaseLimits
- GiftPurchaseOfferState
- GiftResaleParameters
- GiftResalePrice
- GiftResaleResult
- GiftSettings
- GiftsForCrafting
- GiftsForResale
- GiftUpgradePreview
- GiftUpgradePrice
- GiftUpgradeVariants
- GiveawayInfo
- GiveawayParameters
- GiveawayParticipantStatus
- GiveawayPrize
- GramRevenueStatistics
- GramRevenueStatus
- GroupCall
- GroupCallDataChannel
- GroupCallId
- GroupCallInfo
- GroupCallJoinParameters
- GroupCallMessage
- GroupCallMessageLevel
- GroupCallParticipant
- GroupCallParticipants
- GroupCallParticipantVideoInfo
- GroupCallRecentSpeaker
- GroupCallStream
- GroupCallStreams
- GroupCallVideoQuality
- GroupCallVideoSourceGroup
- Hashtags
- HttpUrl
- IdentityDocument
- ImportedContact
- ImportedContacts
- InlineKeyboardButton
- InlineKeyboardButtonType
- InlineMessageId
- InlineQueryResult
- InlineQueryResults
- InlineQueryResultsButton
- InlineQueryResultsButtonType
- InputAnimation
- InputAudio
- InputBackground
- InputBusinessChatLink
- InputBusinessStartPage
- InputCall
- InputChatPhoto
- InputChatTheme
- InputChecklist
- InputChecklistTask
- InputCredentials
- InputDocument
- InputFile
- InputGroupCall
- InputIdentityDocument
- InputInlineQueryResult
- InputInvoice
- InputMessageContent
- InputMessageReplyTo
- InputPageBlock
- InputPageBlockListItem
- InputPaidMedia
- InputPaidMediaType
- InputPassportElement
- InputPassportElementError
- InputPassportElementErrorSource
- InputPersonalDocument
- InputPhoto
- InputPollMedia
- InputPollOption
- InputPollType
- InputRichMessage
- InputRichMessageMedia
- InputSticker
- InputStoryArea
- InputStoryAreas
- InputStoryAreaType
- InputStoryContent
- InputSuggestedPostInfo
- InputTextQuote
- InputThumbnail
- InputVideo
- InputVideoNote
- InputVoiceNote
- InternalLinkType
- InviteGroupCallParticipantResult
- InviteLinkChatType
- Invoice
- JsonObjectMember
- JsonValue
- KeyboardButton
- KeyboardButtonSource
- KeyboardButtonType
- LabeledPricePart
- LanguagePackInfo
- LanguagePackString
- LanguagePackStrings
- LanguagePackStringValue
- LinkPreview
- LinkPreviewAlbumMedia
- LinkPreviewOptions
- LinkPreviewType
- LiveLocation
- LiveStoryDonors
- LocalFile
- LocalizationTargetInfo
- Location
- LocationAddress
- LoginUrlInfo
- LogStream
- LogTags
- LogVerbosityLevel
- MainWebApp
- MaskPoint
- MaskPosition
- Message
- MessageAutoDeleteTime
- MessageCalendar
- MessageCalendarDay
- MessageContent
- MessageCopyOptions
- MessageEffect
- MessageEffectType
- MessageFileType
- MessageForwardInfo
- MessageImportInfo
- MessageInteractionInfo
- MessageLink
- MessageLinkInfo
- MessageOrigin
- MessagePosition
- MessagePositions
- MessageProperties
- MessageReaction
- MessageReactions
- MessageReadDate
- MessageReplyInfo
- MessageReplyTo
- Messages
- MessageSchedulingState
- MessageSelfDestructType
- MessageSender
- MessageSenders
- MessageSendingState
- MessageSendOptions
- MessageSource
- MessageStatistics
- MessageThreadInfo
- MessageTopic
- MessageViewer
- MessageViewers
- Minithumbnail
- NetworkStatistics
- NetworkStatisticsEntry
- NetworkType
- NewChatPrivacySettings
- NewSticker
- Notification
- NotificationGroup
- NotificationGroupType
- NotificationSettingsScope
- NotificationSound
- NotificationSounds
- NotificationType
- OauthLinkInfo
- Ok
- OptionValue
- OrderInfo
- Outline
- PageBlock
- PageBlockCaption
- PageBlockHorizontalAlignment
- PageBlockListItem
- PageBlockRelatedArticle
- PageBlockTableCell
- PageBlockVerticalAlignment
- PaidMedia
- PaidReactionType
- PaidReactor
- Passkey
- Passkeys
- PassportAuthorizationForm
- PassportElement
- PassportElementError
- PassportElementErrorSource
- PassportElements
- PassportElementsWithErrors
- PassportElementType
- PassportRequiredElement
- PassportSuitableElement
- PasswordState
- PaymentForm
- PaymentFormType
- PaymentOption
- PaymentProvider
- PaymentReceipt
- PaymentReceiptType
- PaymentResult
- PersonalDetails
- PersonalDocument
- PhoneNumberAuthenticationSettings
- PhoneNumberCodeType
- PhoneNumberInfo
- Photo
- PhotoSize
- Point
- Poll
- PollMedia
- PollOption
- PollOptionProperties
- PollType
- PollVoter
- PollVoteRestrictionReason
- PollVoters
- PollVoteStatistics
- PremiumFeature
- PremiumFeaturePromotionAnimation
- PremiumFeatures
- PremiumGiftCodeInfo
- PremiumGiftPaymentOption
- PremiumGiftPaymentOptions
- PremiumGiveawayPaymentOption
- PremiumGiveawayPaymentOptions
- PremiumLimit
- PremiumLimitType
- PremiumPaymentOption
- PremiumSource
- PremiumState
- PremiumStatePaymentOption
- PremiumStoryFeature
- PrepaidGiveaway
- PreparedInlineMessage
- PreparedInlineMessageId
- ProductInfo
- ProfileAccentColor
- ProfileAccentColors
- ProfilePhoto
- ProfileTab
- Proxy
- ProxyType
- PublicChatType
- PublicForward
- PublicForwards
- PublicPostSearchLimits
- PushMessageContent
- PushReceiverId
- QuickReplyMessage
- QuickReplyMessages
- QuickReplyShortcut
- ReactionNotificationSettings
- ReactionNotificationSource
- ReactionType
- ReactionUnavailabilityReason
- ReadDatePrivacySettings
- ReceivedGift
- ReceivedGifts
- RecommendedChatFolder
- RecommendedChatFolders
- RecoveryEmailAddress
- RemoteFile
- ReplyMarkup
- ReportChatResult
- ReportOption
- ReportReason
- ReportSponsoredResult
- ReportStoryResult
- ResendCodeReason
- ResetPasswordResult
- RestrictionInfo
- RevenueWithdrawalState
- RichMessage
- RichMessageSource
- RichText
- RtmpUrl
- SavedCredentials
- SavedMessagesTag
- SavedMessagesTags
- SavedMessagesTopic
- SavedMessagesTopicType
- ScopeAutosaveSettings
- ScopeNotificationSettings
- SearchChatTypeFilter
- SearchMessagesChatTypeFilter
- SearchMessagesFilter
- Seconds
- SecretChat
- SecretChatState
- SentGift
- Session
- SessionDeviceType
- Sessions
- SessionType
- SettingsSection
- SharedChat
- SharedUser
- ShippingOption
- SpeechRecognitionResult
- SponsoredChat
- SponsoredChats
- SponsoredMessage
- SponsoredMessages
- StakeDiceState
- StarAmount
- StarCount
- StarGiveawayPaymentOption
- StarGiveawayPaymentOptions
- StarGiveawayWinnerOption
- StarPaymentOption
- StarPaymentOptions
- StarRevenueStatistics
- StarRevenueStatus
- StarSubscription
- StarSubscriptionPricing
- StarSubscriptions
- StarSubscriptionType
- StartLiveStoryResult
- StarTransaction
- StarTransactions
- StarTransactionType
- StatisticalGraph
- StatisticalValue
- Sticker
- StickerFormat
- StickerFullType
- Stickers
- StickerSet
- StickerSetInfo
- StickerSets
- StickerType
- StorageStatistics
- StorageStatisticsByChat
- StorageStatisticsByFileType
- StorageStatisticsFast
- StorePaymentPurpose
- StoreTransaction
- Stories
- Story
- StoryAlbum
- StoryAlbums
- StoryArea
- StoryAreaPosition
- StoryAreaType
- StoryContent
- StoryContentType
- StoryFullId
- StoryInfo
- StoryInteraction
- StoryInteractionInfo
- StoryInteractions
- StoryInteractionType
- StoryList
- StoryOrigin
- StoryPrivacySettings
- StoryRepostInfo
- StoryStatistics
- StoryVideo
- SuggestedAction
- SuggestedPostInfo
- SuggestedPostPrice
- SuggestedPostRefundReason
- SuggestedPostState
- Supergroup
- SupergroupFullInfo
- SupergroupMembersFilter
- TargetChat
- TargetChatTypes
- TdError
- TelegramPaymentPurpose
- TemporaryPasswordState
- TermsOfService
- TestBytes
- TestInt
- TestString
- TestVectorInt
- TestVectorIntObject
- TestVectorString
- TestVectorStringObject
- Text
- TextCompositionStyle
- TextCompositionStyleExample
- TextEntities
- TextEntity
- TextEntityType
- TextParseMode
- TextQuote
- ThemeParameters
- ThemeSettings
- Thumbnail
- ThumbnailFormat
- TimeZone
- TimeZones
- TMeUrl
- TMeUrls
- TMeUrlType
- TonTransaction
- TonTransactions
- TonTransactionType
- TopChatCategory
- TransactionDirection
- TrendingStickerSets
- UnconfirmedSession
- UnreadReaction
- Update
- Updates
- UpgradedGift
- UpgradedGiftAttributeId
- UpgradedGiftAttributeRarity
- UpgradedGiftBackdrop
- UpgradedGiftBackdropColors
- UpgradedGiftBackdropCount
- UpgradedGiftColors
- UpgradedGiftModel
- UpgradedGiftModelCount
- UpgradedGiftOrigin
- UpgradedGiftOriginalDetails
- UpgradedGiftSymbol
- UpgradedGiftSymbolCount
- UpgradedGiftValueInfo
- UpgradeGiftResult
- User
- UserAuctionBid
- UserFullInfo
- UserLink
- Usernames
- UserPrivacySetting
- UserPrivacySettingRule
- UserPrivacySettingRules
- UserRating
- Users
- UserStatus
- UserSupportInfo
- UserType
- ValidatedOrderInfo
- VectorPathCommand
- Venue
- VerificationStatus
- Video
- VideoChat
- VideoMessageAdvertisement
- VideoMessageAdvertisements
- VideoNote
- VideoStoryboard
- VoiceNote
- WebApp
- WebAppInfo
- WebAppOpenMode
- WebAppOpenParameters
- WebAppUrl
- WebBrowserSettings
- WebBrowserType
- WebDomainException
- WebPageInstantView
Constructors
- TdObject()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited