TelegramPaymentPurposePremiumGift class final

The user gifting Telegram Premium to another user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TelegramPaymentPurposePremiumGift({required String currency, required int amount, required int userId, required int monthCount, FormattedText? text})

Properties

amount int
amount Paid amount, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code of the payment currency, or "XTR" for payments in Telegram Stars
final
hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active for the user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text FormattedText?
text Text to show to the user receiving Telegram Premium; 0-getOption("gift_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed
final
userId int
userId Identifier of the user which will receive Telegram Premium
final

Methods

copyWith({String? currency, int? amount, int? userId, int? monthCount, FormattedText? text}) TelegramPaymentPurposePremiumGift

Available on TelegramPaymentPurposePremiumGift, provided by the TelegramPaymentPurposePremiumGiftExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftedStars(TelegramPaymentPurposeGiftedStars value), required TResult joinChat(TelegramPaymentPurposeJoinChat value), required TResult premiumGift(TelegramPaymentPurposePremiumGift value), required TResult premiumGiftCodes(TelegramPaymentPurposePremiumGiftCodes value), required TResult premiumGiveaway(TelegramPaymentPurposePremiumGiveaway value), required TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value), required TResult stars(TelegramPaymentPurposeStars value)}) → TResult

Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension

maybeMap<TResult extends Object?>({TResult giftedStars(TelegramPaymentPurposeGiftedStars value)?, TResult joinChat(TelegramPaymentPurposeJoinChat value)?, TResult premiumGift(TelegramPaymentPurposePremiumGift value)?, TResult premiumGiftCodes(TelegramPaymentPurposePremiumGiftCodes value)?, TResult premiumGiveaway(TelegramPaymentPurposePremiumGiveaway value)?, TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value)?, TResult stars(TelegramPaymentPurposeStars value)?, required TResult orElse()}) → TResult

Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String