TelegramPaymentPurposePremiumGiftCodes class final
The user boosting a chat by creating Telegram Premium gift codes for other users
- Inheritance
-
- Object
- TdObject
- TelegramPaymentPurpose
- TelegramPaymentPurposePremiumGiftCodes
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TelegramPaymentPurposePremiumGiftCodes({required int boostedChatId, required String currency, required int amount, required List<
int> userIds, required int monthCount, FormattedText? text})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- boostedChatId → int
-
boostedChatId Identifier of the supergroup or channel chat, which will
be automatically boosted by the users for duration of the Premium
subscription and which is administered by the user
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- monthCount → int
-
monthCount Number of months the Telegram Premium subscription will be
active for the users
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Text to show along with the gift codes;
0-getOption("gift_text_length_max") characters. Only Bold, Italic,
Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are
allowed
final
-
userIds
→ List<
int> -
userIds Identifiers of the users which can activate the gift codes
final
Methods
-
copyWith(
{int? boostedChatId, String? currency, int? amount, List< int> ? userIds, int? monthCount, FormattedText? text}) → TelegramPaymentPurposePremiumGiftCodes -
Available on TelegramPaymentPurposePremiumGiftCodes, provided by the TelegramPaymentPurposePremiumGiftCodesExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftedStars(TelegramPaymentPurposeGiftedStars value), required TResult joinChat(TelegramPaymentPurposeJoinChat value), required TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value), required TResult stars(TelegramPaymentPurposeStars value)}) → TResult -
Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftedStars(TelegramPaymentPurposeGiftedStars value)?, TResult joinChat(TelegramPaymentPurposeJoinChat value)?, TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value)?, TResult stars(TelegramPaymentPurposeStars value)?, required TResult orElse()}) → TResult -
Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TelegramPaymentPurposePremiumGiftCodes? -
Inherited by:
TelegramPaymentPurposeGiftedStars
TelegramPaymentPurposeJoinChat
TelegramPaymentPurposePremiumGift
TelegramPaymentPurposePremiumGiftCodes
TelegramPaymentPurposePremiumGiveaway
TelegramPaymentPurposeStarGiveaway
TelegramPaymentPurposeStars
override
Constants
- constructor → const String