boostedChatId property

int boostedChatId
final

boostedChatId Identifier of the supergroup or channel chat, which will be automatically boosted by the users for duration of the Premium subscription and which is administered by the user

Implementation

final int boostedChatId;