TelegramPaymentPurposePremiumGiveaway class final

The user creating a Telegram Premium giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TelegramPaymentPurposePremiumGiveaway({GiveawayParameters? parameters, required String currency, required int amount, required int winnerCount, required int monthCount})

Properties

amount int
amount Paid amount, in the smallest units of the currency
final
currency String
currency ISO 4217 currency code of the payment currency
final
hashCode int
The hash code for this object.
no setteroverride
monthCount int
monthCount Number of months the Telegram Premium subscription will be active for the users
final
parameters GiveawayParameters?
parameters Giveaway parameters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winnerCount int
winnerCount Number of users which will be able to activate the gift codes
final

Methods

copyWith({GiveawayParameters? parameters, String? currency, int? amount, int? winnerCount, int? monthCount}) TelegramPaymentPurposePremiumGiveaway

Available on TelegramPaymentPurposePremiumGiveaway, provided by the TelegramPaymentPurposePremiumGiveawayExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult giftedStars(TelegramPaymentPurposeGiftedStars value), required TResult joinChat(TelegramPaymentPurposeJoinChat value), required TResult premiumGift(TelegramPaymentPurposePremiumGift value), required TResult premiumGiftCodes(TelegramPaymentPurposePremiumGiftCodes value), required TResult premiumGiveaway(TelegramPaymentPurposePremiumGiveaway value), required TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value), required TResult stars(TelegramPaymentPurposeStars value)}) → TResult

Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension

maybeMap<TResult extends Object?>({TResult giftedStars(TelegramPaymentPurposeGiftedStars value)?, TResult joinChat(TelegramPaymentPurposeJoinChat value)?, TResult premiumGift(TelegramPaymentPurposePremiumGift value)?, TResult premiumGiftCodes(TelegramPaymentPurposePremiumGiftCodes value)?, TResult premiumGiveaway(TelegramPaymentPurposePremiumGiveaway value)?, TResult starGiveaway(TelegramPaymentPurposeStarGiveaway value)?, TResult stars(TelegramPaymentPurposeStars value)?, required TResult orElse()}) → TResult

Available on TelegramPaymentPurpose, provided by the TelegramPaymentPurposeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String