TestBytes class final

A simple object containing a sequence of bytes; for testing only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestBytes({required String value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
value Bytes
final

Methods

copyWith({String? value}) TestBytes

Available on TestBytes, provided by the TestBytesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TestBytes?

Constants

constructor → const String