TestCallString class final

Returns the received string; for testing only. This is an offline method. Can be called before authorization Returns TestString

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestCallString({required String x})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x String
x String to return
final

Methods

copyWith({String? x}) TestCallString

Available on TestCallString, provided by the TestCallStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String