TestCallVectorInt class final

Returns the received vector of numbers; for testing only. This is an offline method. Can be called before authorization Returns TestVectorInt

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestCallVectorInt({required List<int> x})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x List<int>
x Vector of numbers to return
final

Methods

copyWith({List<int>? x}) TestCallVectorInt

Available on TestCallVectorInt, provided by the TestCallVectorIntExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String