TestCallVectorIntObject class final
Returns the received vector of objects containing a number; for testing only. This is an offline method. Can be called before authorization Returns TestVectorIntObject
- Inheritance
-
- Object
- TdFunction
- TestCallVectorIntObject
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TestCallVectorIntObject({required List<
TestInt> x})
Properties
Methods
-
copyWith(
{List< TestInt> ? x}) → TestCallVectorIntObject -
Available on TestCallVectorIntObject, provided by the TestCallVectorIntObjectExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String