TestCallVectorString class final

Returns the received vector of strings; for testing only. This is an offline method. Can be called before authorization Returns TestVectorString

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestCallVectorString({required List<String> x})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x List<String>
x Vector of strings to return
final

Methods

copyWith({List<String>? x}) TestCallVectorString

Available on TestCallVectorString, provided by the TestCallVectorStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String