TestCallVectorStringObject class final
Returns the received vector of objects containing a string; for testing only. This is an offline method. Can be called before authorization Returns TestVectorStringObject
- Inheritance
-
- Object
- TdFunction
- TestCallVectorStringObject
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TestCallVectorStringObject({required List<
TestString> x})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
x
→ List<
TestString> -
x Vector of objects to return
final
Methods
-
copyWith(
{List< TestString> ? x}) → TestCallVectorStringObject -
Available on TestCallVectorStringObject, provided by the TestCallVectorStringObjectExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String