TestInt class final

A simple object containing a number; for testing only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestInt({required int value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
value Number
final

Methods

copyWith({int? value}) TestInt

Available on TestInt, provided by the TestIntExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TestInt?

Constants

constructor → const String