TestReturnError class final

Returns the specified error and ensures that the Error object is used; for testing only. Can be called synchronously Returns Error

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestReturnError({TdError? error})

Properties

error TdError?
error The error to be returned
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({TdError? error}) TestReturnError

Available on TestReturnError, provided by the TestReturnErrorExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String