TestSquareInt class final

Returns the squared received number; for testing only. This is an offline method. Can be called before authorization Returns TestInt

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestSquareInt({required int x})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x int
x Number to square
final

Methods

copyWith({int? x}) TestSquareInt

Available on TestSquareInt, provided by the TestSquareIntExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String