TestString class final

A simple object containing a string; for testing only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestString({required String value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
value String
final

Methods

copyWith({String? value}) TestString

Available on TestString, provided by the TestStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TestString?

Constants

constructor → const String