TestUseUpdate class final
Does nothing and ensures that the Update object is used; for testing only. This is an offline method. Can be called before authorization Returns Update
- Inheritance
-
- Object
- TdFunction
- TestUseUpdate
- Annotations
-
- @immutable
Constructors
- TestUseUpdate()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String