TestVectorIntObject class final

A simple object containing a vector of objects that hold a number; for testing only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestVectorIntObject({required List<TestInt> value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<TestInt>
value Vector of objects
final

Methods

copyWith({List<TestInt>? value}) TestVectorIntObject

Available on TestVectorIntObject, provided by the TestVectorIntObjectExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TestVectorIntObject?

Constants

constructor → const String