TestVectorString class final

A simple object containing a vector of strings; for testing only

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TestVectorString({required List<String> value})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value List<String>
value Vector of strings
final

Methods

copyWith({List<String>? value}) TestVectorString

Available on TestVectorString, provided by the TestVectorStringExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TestVectorString?

Constants

constructor → const String