TestVectorStringObject class final
A simple object containing a vector of objects that hold a string; for testing only
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TestVectorStringObject({required List<
TestString> value})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ List<
TestString> -
value Vector of objects
final
Methods
-
copyWith(
{List< TestString> ? value}) → TestVectorStringObject -
Available on TestVectorStringObject, provided by the TestVectorStringObjectExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TestVectorStringObject?
Constants
- constructor → const String