Text class final

Contains some text

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Text({required String text})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text Text
final

Methods

copyWith({String? text}) Text

Available on Text, provided by the TextExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Text?

Constants

constructor → const String