TextCompositionStyleExample class final

Contains an example of text composition style usage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TextCompositionStyleExample({FormattedText? sourceText, FormattedText? resultText})

Properties

hashCode int
The hash code for this object.
no setteroverride
resultText FormattedText?
resultText The text after the style was applied to the source text
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceText FormattedText?
sourceText Source text
final

Methods

copyWith({FormattedText? sourceText, FormattedText? resultText}) TextCompositionStyleExample

Available on TextCompositionStyleExample, provided by the TextCompositionStyleExampleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TextCompositionStyleExample?

Constants

constructor → const String