TextEntity class final

Represents a part of the text that needs to be formatted in some unusual way

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TextEntity({required int offset, required int length, TextEntityType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
length int
length Length of the entity, in UTF-16 code units
final
offset int
offset Offset of the entity, in UTF-16 code units
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TextEntityType?
type Type of the entity
final

Methods

copyWith({int? offset, int? length, TextEntityType? type}) TextEntity

Available on TextEntity, provided by the TextEntityExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TextEntity?

Constants

constructor → const String