mediaTimestamp property

int mediaTimestamp
final

mediaTimestamp Timestamp from which a video/audio/video note/voice note/story playing must start, in seconds. The media can be in the content or the link preview of the current message, or in the same places in the replied message

Implementation

final int mediaTimestamp;