TextEntityTypePhoneNumber class final
A phone number
- Inheritance
-
- Object
- TdObject
- TextEntityType
- TextEntityTypePhoneNumber
- Available extensions
- Annotations
-
- @immutable
Constructors
- TextEntityTypePhoneNumber()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bankCardNumber(TextEntityTypeBankCardNumber value), required TResult blockQuote(TextEntityTypeBlockQuote value), required TResult bold(TextEntityTypeBold value), required TResult botCommand(TextEntityTypeBotCommand value), required TResult cashtag(TextEntityTypeCashtag value), required TResult code(TextEntityTypeCode value), required TResult customEmoji(TextEntityTypeCustomEmoji value), required TResult dateTime(TextEntityTypeDateTime value), required TResult emailAddress(TextEntityTypeEmailAddress value), required TResult expandableBlockQuote(TextEntityTypeExpandableBlockQuote value), required TResult hashtag(TextEntityTypeHashtag value), required TResult italic(TextEntityTypeItalic value), required TResult mediaTimestamp(TextEntityTypeMediaTimestamp value), required TResult mention(TextEntityTypeMention value), required TResult mentionName(TextEntityTypeMentionName value), required TResult phoneNumber(TextEntityTypePhoneNumber value), required TResult pre(TextEntityTypePre value), required TResult preCode(TextEntityTypePreCode value), required TResult spoiler(TextEntityTypeSpoiler value), required TResult strikethrough(TextEntityTypeStrikethrough value), required TResult textUrl(TextEntityTypeTextUrl value), required TResult underline(TextEntityTypeUnderline value), required TResult url(TextEntityTypeUrl value)}) → TResult -
Available on TextEntityType, provided by the TextEntityTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bankCardNumber(TextEntityTypeBankCardNumber value)?, TResult blockQuote(TextEntityTypeBlockQuote value)?, TResult bold(TextEntityTypeBold value)?, TResult botCommand(TextEntityTypeBotCommand value)?, TResult cashtag(TextEntityTypeCashtag value)?, TResult code(TextEntityTypeCode value)?, TResult customEmoji(TextEntityTypeCustomEmoji value)?, TResult dateTime(TextEntityTypeDateTime value)?, TResult emailAddress(TextEntityTypeEmailAddress value)?, TResult expandableBlockQuote(TextEntityTypeExpandableBlockQuote value)?, TResult hashtag(TextEntityTypeHashtag value)?, TResult italic(TextEntityTypeItalic value)?, TResult mediaTimestamp(TextEntityTypeMediaTimestamp value)?, TResult mention(TextEntityTypeMention value)?, TResult mentionName(TextEntityTypeMentionName value)?, TResult phoneNumber(TextEntityTypePhoneNumber value)?, TResult pre(TextEntityTypePre value)?, TResult preCode(TextEntityTypePreCode value)?, TResult spoiler(TextEntityTypeSpoiler value)?, TResult strikethrough(TextEntityTypeStrikethrough value)?, TResult textUrl(TextEntityTypeTextUrl value)?, TResult underline(TextEntityTypeUnderline value)?, TResult url(TextEntityTypeUrl value)?, required TResult orElse()}) → TResult -
Available on TextEntityType, provided by the TextEntityTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TextEntityTypePhoneNumber? -
Inherited by:
TextEntityTypeBankCardNumber
TextEntityTypeBlockQuote
TextEntityTypeBold
TextEntityTypeBotCommand
TextEntityTypeCashtag
TextEntityTypeCode
TextEntityTypeCustomEmoji
TextEntityTypeDateTime
TextEntityTypeEmailAddress
TextEntityTypeExpandableBlockQuote
TextEntityTypeHashtag
TextEntityTypeItalic
TextEntityTypeMediaTimestamp
TextEntityTypeMention
TextEntityTypeMentionName
TextEntityTypePhoneNumber
TextEntityTypePre
TextEntityTypePreCode
TextEntityTypeSpoiler
TextEntityTypeStrikethrough
TextEntityTypeTextUrl
TextEntityTypeUnderline
TextEntityTypeUrl
override
Constants
- constructor → const String