TextParseModeMarkdown class final

The text uses Markdown-style formatting

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TextParseModeMarkdown({required int version})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version int
version Version of the parser: 0 or 1 - Telegram Bot API "Markdown" parse mode, 2 - Telegram Bot API "MarkdownV2" parse mode
final

Methods

copyWith({int? version}) TextParseModeMarkdown

Available on TextParseModeMarkdown, provided by the TextParseModeMarkdownExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult hTML(TextParseModeHTML value), required TResult markdown(TextParseModeMarkdown value)}) → TResult

Available on TextParseMode, provided by the TextParseModeExtensions extension

maybeMap<TResult extends Object?>({TResult hTML(TextParseModeHTML value)?, TResult markdown(TextParseModeMarkdown value)?, required TResult orElse()}) → TResult

Available on TextParseMode, provided by the TextParseModeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TextParseModeMarkdown?
Inherited by: TextParseModeHTML TextParseModeMarkdown
override

Constants

constructor → const String