bottomBarBackgroundColor property
bottomBarBackgroundColor A color of the bottom bar background in the RGB format
Implementation
final int bottomBarBackgroundColor;
bottomBarBackgroundColor A color of the bottom bar background in the RGB format
final int bottomBarBackgroundColor;