destructiveTextColor property
destructiveTextColor A color of the text for destructive actions in the RGB format
Implementation
final int destructiveTextColor;
destructiveTextColor A color of the text for destructive actions in the RGB format
final int destructiveTextColor;