headerBackgroundColor property
headerBackgroundColor A color of the header background in the RGB format
Implementation
final int headerBackgroundColor;
headerBackgroundColor A color of the header background in the RGB format
final int headerBackgroundColor;