secondaryBackgroundColor property
secondaryBackgroundColor A secondary color for the background in the RGB format
Implementation
final int secondaryBackgroundColor;
secondaryBackgroundColor A secondary color for the background in the RGB format
final int secondaryBackgroundColor;