sectionBackgroundColor property
sectionBackgroundColor A color of the section background in the RGB format
Implementation
final int sectionBackgroundColor;
sectionBackgroundColor A color of the section background in the RGB format
final int sectionBackgroundColor;