sectionHeaderTextColor property
sectionHeaderTextColor A color of text on the section headers in the RGB format
Implementation
final int sectionHeaderTextColor;
sectionHeaderTextColor A color of text on the section headers in the RGB format
final int sectionHeaderTextColor;