sectionSeparatorColor property
sectionSeparatorColor A color of the section separator in the RGB format
Implementation
final int sectionSeparatorColor;
sectionSeparatorColor A color of the section separator in the RGB format
final int sectionSeparatorColor;