ThumbnailFormat class sealed
Describes format of a thumbnail
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult gif(ThumbnailFormatGif value), required TResult jpeg(ThumbnailFormatJpeg value), required TResult mpeg4(ThumbnailFormatMpeg4 value), required TResult png(ThumbnailFormatPng value), required TResult tgs(ThumbnailFormatTgs value), required TResult webm(ThumbnailFormatWebm value), required TResult webp(ThumbnailFormatWebp value)}) → TResult -
Available on ThumbnailFormat, provided by the ThumbnailFormatExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult gif(ThumbnailFormatGif value)?, TResult jpeg(ThumbnailFormatJpeg value)?, TResult mpeg4(ThumbnailFormatMpeg4 value)?, TResult png(ThumbnailFormatPng value)?, TResult tgs(ThumbnailFormatTgs value)?, TResult webm(ThumbnailFormatWebm value)?, TResult webp(ThumbnailFormatWebp value)?, required TResult orElse()}) → TResult -
Available on ThumbnailFormat, provided by the ThumbnailFormatExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ThumbnailFormat? - Inherited by: ThumbnailFormatGif ThumbnailFormatJpeg ThumbnailFormatMpeg4 ThumbnailFormatPng ThumbnailFormatTgs ThumbnailFormatWebm ThumbnailFormatWebp
Constants
- constructor → const String