TimeZones class final

Contains a list of time zones

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TimeZones({required List<TimeZone> timeZones})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeZones List<TimeZone>
timeZones A list of time zones
final

Methods

copyWith({List<TimeZone>? timeZones}) TimeZones

Available on TimeZones, provided by the TimeZonesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TimeZones?

Constants

constructor → const String