ToggleAllDownloadsArePaused class final

Changes pause state of all files in the file download list Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleAllDownloadsArePaused({required bool arePaused})

Properties

arePaused bool
arePaused Pass true to pause all downloads; pass false to unpause them
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? arePaused}) ToggleAllDownloadsArePaused

Available on ToggleAllDownloadsArePaused, provided by the ToggleAllDownloadsArePausedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String