ToggleBotCanManageEmojiStatus class final

Toggles whether the bot can manage emoji status of the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleBotCanManageEmojiStatus({required int botUserId, required bool canManageEmojiStatus})

Properties

botUserId int
botUserId User identifier of the bot
final
canManageEmojiStatus bool
canManageEmojiStatus Pass true if the bot is allowed to change emoji status of the user; pass false otherwise
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, bool? canManageEmojiStatus}) ToggleBotCanManageEmojiStatus

Available on ToggleBotCanManageEmojiStatus, provided by the ToggleBotCanManageEmojiStatusExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String