canManageEmojiStatus property
canManageEmojiStatus Pass true if the bot is allowed to change emoji status of the user; pass false otherwise
Implementation
final bool canManageEmojiStatus;
canManageEmojiStatus Pass true if the bot is allowed to change emoji status of the user; pass false otherwise
final bool canManageEmojiStatus;