ToggleBusinessConnectedBotChatIsPaused class final
Pauses or resumes the connected business bot in a specific chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleBusinessConnectedBotChatIsPaused
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleBusinessConnectedBotChatIsPaused({required int chatId, required bool isPaused})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPaused → bool
-
isPaused Pass true to pause the connected bot in the chat; pass false to
resume the bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? isPaused}) → ToggleBusinessConnectedBotChatIsPaused -
Available on ToggleBusinessConnectedBotChatIsPaused, provided by the ToggleBusinessConnectedBotChatIsPausedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String