ToggleChatGiftNotifications class final

Toggles whether notifications for new gifts received by a channel chat are sent to the current user; requires can_post_messages administrator right in the chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleChatGiftNotifications({required int chatId, required bool areEnabled})

Properties

areEnabled bool
areEnabled Pass true to enable notifications about new gifts owned by the channel chat; pass false to disable the notifications
final
chatId int
chatId Identifier of the channel chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? areEnabled}) ToggleChatGiftNotifications

Available on ToggleChatGiftNotifications, provided by the ToggleChatGiftNotificationsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String