areEnabled property
areEnabled Pass true to enable notifications about new gifts owned by the channel chat; pass false to disable the notifications
Implementation
final bool areEnabled;
areEnabled Pass true to enable notifications about new gifts owned by the channel chat; pass false to disable the notifications
final bool areEnabled;