ToggleChatHasProtectedContent class final
Changes the ability of users to save, forward, or copy chat content. Requires owner privileges in basic groups, supergroups and channels. Requires Telegram Premium to enable protected content in private chats. Not available in Saved Messages and private chats with bots or support accounts Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleChatHasProtectedContent
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleChatHasProtectedContent({required int chatId, required bool hasProtectedContent})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasProtectedContent → bool
-
hasProtectedContent New value of has_protected_content
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? hasProtectedContent}) → ToggleChatHasProtectedContent -
Available on ToggleChatHasProtectedContent, provided by the ToggleChatHasProtectedContentExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String