ToggleChatIsMarkedAsUnread class final
Changes the marked as unread state of a chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleChatIsMarkedAsUnread
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleChatIsMarkedAsUnread({required int chatId, required bool isMarkedAsUnread})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isMarkedAsUnread → bool
-
isMarkedAsUnread New value of is_marked_as_unread
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? isMarkedAsUnread}) → ToggleChatIsMarkedAsUnread -
Available on ToggleChatIsMarkedAsUnread, provided by the ToggleChatIsMarkedAsUnreadExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String