ToggleChatIsPinned class final

Changes the pinned state of a chat. There can be up to getOption("pinned_chat_count_max")/getOption("pinned_archived_chat_count_max") pinned non-secret chats and the same number of secret chats in the main/archive chat list. The limit can be increased with Telegram Premium Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleChatIsPinned({ChatList? chatList, required int chatId, required bool isPinned})

Properties

chatId int
chatId Chat identifier
final
chatList ChatList?
chatList Chat list in which to change the pinned state of the chat
final
hashCode int
The hash code for this object.
no setteroverride
isPinned bool
isPinned Pass true to pin the chat; pass false to unpin it
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({ChatList? chatList, int? chatId, bool? isPinned}) ToggleChatIsPinned

Available on ToggleChatIsPinned, provided by the ToggleChatIsPinnedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String