ToggleChatIsTranslatable class final

Changes the translatable state of a chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleChatIsTranslatable({required int chatId, required bool isTranslatable})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
isTranslatable bool
isTranslatable New value of is_translatable
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? isTranslatable}) ToggleChatIsTranslatable

Available on ToggleChatIsTranslatable, provided by the ToggleChatIsTranslatableExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String