ToggleChatViewAsTopics class final

Changes the view_as_topics setting of a forum chat or Saved Messages Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleChatViewAsTopics({required int chatId, required bool viewAsTopics})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
viewAsTopics bool
viewAsTopics New value of view_as_topics
final

Methods

copyWith({int? chatId, bool? viewAsTopics}) ToggleChatViewAsTopics

Available on ToggleChatViewAsTopics, provided by the ToggleChatViewAsTopicsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String