ToggleDirectMessagesChatTopicCanSendUnpaidMessages class final

Allows to send unpaid messages to the given topic of the channel direct messages chat administered by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleDirectMessagesChatTopicCanSendUnpaidMessages({required int chatId, required int topicId, required bool canSendUnpaidMessages, required bool refundPayments})

Properties

canSendUnpaidMessages bool
canSendUnpaidMessages Pass true to allow unpaid messages; pass false to disallow unpaid messages
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
refundPayments bool
refundPayments Pass true to refund the user previously paid messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId int
topicId Identifier of the topic
final

Methods

copyWith({int? chatId, int? topicId, bool? canSendUnpaidMessages, bool? refundPayments}) ToggleDirectMessagesChatTopicCanSendUnpaidMessages

Available on ToggleDirectMessagesChatTopicCanSendUnpaidMessages, provided by the ToggleDirectMessagesChatTopicCanSendUnpaidMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String