ToggleDownloadIsPaused class final

Changes pause state of a file in the file download list Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleDownloadIsPaused({required int fileId, required bool isPaused})

Properties

fileId int
fileId Identifier of the downloaded file
final
hashCode int
The hash code for this object.
no setteroverride
isPaused bool
isPaused Pass true if the download is paused
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, bool? isPaused}) ToggleDownloadIsPaused

Available on ToggleDownloadIsPaused, provided by the ToggleDownloadIsPausedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String