ToggleForumTopicIsClosed class final

Toggles whether a topic is closed in a forum supergroup chat; requires can_manage_topics administrator right in the supergroup unless the user is creator of the topic Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleForumTopicIsClosed({required int chatId, required int forumTopicId, required bool isClosed})

Properties

chatId int
chatId Identifier of the chat
final
forumTopicId int
forumTopicId Forum topic identifier
final
hashCode int
The hash code for this object.
no setteroverride
isClosed bool
isClosed Pass true to close the topic; pass false to reopen it
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? forumTopicId, bool? isClosed}) ToggleForumTopicIsClosed

Available on ToggleForumTopicIsClosed, provided by the ToggleForumTopicIsClosedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String