ToggleGiftIsSaved class final

Toggles whether a gift is shown on the current user's or the channel's profile page; requires can_post_messages administrator right in the channel chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleGiftIsSaved({required String receivedGiftId, required bool isSaved})

Properties

hashCode int
The hash code for this object.
no setteroverride
isSaved bool
isSaved Pass true to display the gift on the user's or the channel's profile page; pass false to remove it from the profile page
final
receivedGiftId String
receivedGiftId Identifier of the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? receivedGiftId, bool? isSaved}) ToggleGiftIsSaved

Available on ToggleGiftIsSaved, provided by the ToggleGiftIsSavedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String