ToggleGroupCallAreMessagesAllowed class final

Toggles whether participants of a group call can send messages there. Requires groupCall.can_toggle_are_messages_allowed right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleGroupCallAreMessagesAllowed({required int groupCallId, required bool areMessagesAllowed})

Properties

areMessagesAllowed bool
areMessagesAllowed New value of the are_messages_allowed setting
final
groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? areMessagesAllowed}) ToggleGroupCallAreMessagesAllowed

Available on ToggleGroupCallAreMessagesAllowed, provided by the ToggleGroupCallAreMessagesAllowedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String