ToggleGroupCallParticipantIsMuted class final

Toggles whether a participant of an active group call is muted, unmuted, or allowed to unmute themselves; not supported for live stories Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleGroupCallParticipantIsMuted({required int groupCallId, MessageSender? participantId, required bool isMuted})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
isMuted bool
isMuted Pass true to mute the user; pass false to unmute them
final
participantId MessageSender?
participantId Participant identifier
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, MessageSender? participantId, bool? isMuted}) ToggleGroupCallParticipantIsMuted

Available on ToggleGroupCallParticipantIsMuted, provided by the ToggleGroupCallParticipantIsMutedExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String