ToggleGroupCallScreenSharingIsPaused class final
Pauses or unpauses screen sharing in a joined group call; not supported in live stories Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleGroupCallScreenSharingIsPaused
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleGroupCallScreenSharingIsPaused({required int groupCallId, required bool isPaused})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPaused → bool
-
isPaused Pass true to pause screen sharing; pass false to unpause it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, bool? isPaused}) → ToggleGroupCallScreenSharingIsPaused -
Available on ToggleGroupCallScreenSharingIsPaused, provided by the ToggleGroupCallScreenSharingIsPausedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String