ToggleHasSponsoredMessagesEnabled class final

Toggles whether the current user has sponsored messages enabled. The setting has no effect for users without Telegram Premium for which sponsored messages are always enabled Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleHasSponsoredMessagesEnabled({required bool hasSponsoredMessagesEnabled})

Properties

hashCode int
The hash code for this object.
no setteroverride
hasSponsoredMessagesEnabled bool
hasSponsoredMessagesEnabled Pass true to enable sponsored messages for the current user; false to disable them
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? hasSponsoredMessagesEnabled}) ToggleHasSponsoredMessagesEnabled

Available on ToggleHasSponsoredMessagesEnabled, provided by the ToggleHasSponsoredMessagesEnabledExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String