ToggleSavedMessagesTopicIsPinned class final
Changes the pinned state of a Saved Messages topic. There can be up to getOption("pinned_saved_messages_topic_count_max") pinned topics. The limit can be increased with Telegram Premium Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSavedMessagesTopicIsPinned
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSavedMessagesTopicIsPinned({required int savedMessagesTopicId, required bool isPinned})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPinned → bool
-
isPinned Pass true to pin the topic; pass false to unpin it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedMessagesTopicId → int
-
savedMessagesTopicId Identifier of Saved Messages topic to pin or unpin
final
Methods
-
copyWith(
{int? savedMessagesTopicId, bool? isPinned}) → ToggleSavedMessagesTopicIsPinned -
Available on ToggleSavedMessagesTopicIsPinned, provided by the ToggleSavedMessagesTopicIsPinnedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String