ToggleStoryIsPostedToChatPage class final

Toggles whether a story is accessible after expiration. Can be called only if story.can_toggle_is_posted_to_chat_page == true Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleStoryIsPostedToChatPage({required int storyPosterChatId, required int storyId, required bool isPostedToChatPage})

Properties

hashCode int
The hash code for this object.
no setteroverride
isPostedToChatPage bool
isPostedToChatPage Pass true to make the story accessible after expiration; pass false to make it private
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story
final
storyPosterChatId int
storyPosterChatId Identifier of the chat that posted the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId, bool? isPostedToChatPage}) ToggleStoryIsPostedToChatPage

Available on ToggleStoryIsPostedToChatPage, provided by the ToggleStoryIsPostedToChatPageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String