isPostedToChatPage property
isPostedToChatPage Pass true to make the story accessible after expiration; pass false to make it private
Implementation
final bool isPostedToChatPage;
isPostedToChatPage Pass true to make the story accessible after expiration; pass false to make it private
final bool isPostedToChatPage;