ToggleSupergroupCanHaveSponsoredMessages class final
Toggles whether sponsored messages are shown in the channel chat; requires owner privileges in the channel. The chat must have at least chatBoostFeatures.min_sponsored_message_disable_boost_level boost level to disable sponsored messages Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSupergroupCanHaveSponsoredMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSupergroupCanHaveSponsoredMessages({required int supergroupId, required bool canHaveSponsoredMessages})
Properties
- canHaveSponsoredMessages → bool
-
canHaveSponsoredMessages The new value of can_have_sponsored_messages
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId The identifier of the channel
final
Methods
-
copyWith(
{int? supergroupId, bool? canHaveSponsoredMessages}) → ToggleSupergroupCanHaveSponsoredMessages -
Available on ToggleSupergroupCanHaveSponsoredMessages, provided by the ToggleSupergroupCanHaveSponsoredMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String