ToggleSupergroupHasAggressiveAntiSpamEnabled class final
Toggles whether aggressive anti-spam checks are enabled in the supergroup. Can be called only if supergroupFullInfo.can_toggle_aggressive_anti_spam == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSupergroupHasAggressiveAntiSpamEnabled
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSupergroupHasAggressiveAntiSpamEnabled({required int supergroupId, required bool hasAggressiveAntiSpamEnabled})
Properties
- hasAggressiveAntiSpamEnabled → bool
-
hasAggressiveAntiSpamEnabled The new value of
has_aggressive_anti_spam_enabled
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId The identifier of the supergroup, which isn't a broadcast
group
final
Methods
-
copyWith(
{int? supergroupId, bool? hasAggressiveAntiSpamEnabled}) → ToggleSupergroupHasAggressiveAntiSpamEnabled -
Available on ToggleSupergroupHasAggressiveAntiSpamEnabled, provided by the ToggleSupergroupHasAggressiveAntiSpamEnabledExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String