ToggleSupergroupHasAutomaticTranslation class final

Toggles whether messages are automatically translated in the channel chat; requires can_change_info administrator right in the channel. The chat must have at least chatBoostFeatures.min_automatic_translation_boost_level boost level to enable automatic translation Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSupergroupHasAutomaticTranslation({required int supergroupId, required bool hasAutomaticTranslation})

Properties

hasAutomaticTranslation bool
hasAutomaticTranslation The new value of has_automatic_translation
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId The identifier of the channel
final

Methods

copyWith({int? supergroupId, bool? hasAutomaticTranslation}) ToggleSupergroupHasAutomaticTranslation

Available on ToggleSupergroupHasAutomaticTranslation, provided by the ToggleSupergroupHasAutomaticTranslationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String