ToggleSupergroupIsAllHistoryAvailable class final

Toggles whether the message history of a supergroup is available to new members; requires can_change_info member right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSupergroupIsAllHistoryAvailable({required int supergroupId, required bool isAllHistoryAvailable})

Properties

hashCode int
The hash code for this object.
no setteroverride
isAllHistoryAvailable bool
isAllHistoryAvailable The new value of is_all_history_available
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId The identifier of the supergroup
final

Methods

copyWith({int? supergroupId, bool? isAllHistoryAvailable}) ToggleSupergroupIsAllHistoryAvailable

Available on ToggleSupergroupIsAllHistoryAvailable, provided by the ToggleSupergroupIsAllHistoryAvailableExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String