ToggleSupergroupIsBroadcastGroup class final

Upgrades supergroup to a broadcast group; requires owner privileges in the supergroup Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSupergroupIsBroadcastGroup({required int supergroupId})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup
final

Methods

copyWith({int? supergroupId}) ToggleSupergroupIsBroadcastGroup

Available on ToggleSupergroupIsBroadcastGroup, provided by the ToggleSupergroupIsBroadcastGroupExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String