ToggleSupergroupIsForum class final
Toggles whether the supergroup is a forum; requires owner privileges in the supergroup. Discussion supergroups can't be converted to forums Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSupergroupIsForum
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSupergroupIsForum({required int supergroupId, required bool isForum, required bool hasForumTabs})
Properties
- hasForumTabs → bool
-
hasForumTabs New value of has_forum_tabs; ignored if is_forum is false
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isForum → bool
-
isForum New value of is_forum
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId Identifier of the supergroup
final
Methods
-
copyWith(
{int? supergroupId, bool? isForum, bool? hasForumTabs}) → ToggleSupergroupIsForum -
Available on ToggleSupergroupIsForum, provided by the ToggleSupergroupIsForumExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String