ToggleSupergroupJoinByRequest class final
Toggles whether all users directly joining the supergroup need to be approved by supergroup administrators; requires can_restrict_members administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSupergroupJoinByRequest
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSupergroupJoinByRequest({required int supergroupId, required bool joinByRequest, required int guardBotUserId, required bool applyToInviteLinks})
Properties
- applyToInviteLinks → bool
-
applyToInviteLinks Pass true to apply the change to the existing invite
links, including primary links
final
- guardBotUserId → int
-
guardBotUserId Identifier of the bot which will be the guard bot in the
group; pass 0 if none; ignored if join_by_request == false. The bot must
have administrator privileges and can_invite_users right in the supergroup
chat, and must have userTypeBot.is_guard == true
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- joinByRequest → bool
-
joinByRequest New value of join_by_request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId Identifier of the supergroup that isn't a broadcast group
and isn't a channel direct message group
final
Methods
-
copyWith(
{int? supergroupId, bool? joinByRequest, int? guardBotUserId, bool? applyToInviteLinks}) → ToggleSupergroupJoinByRequest -
Available on ToggleSupergroupJoinByRequest, provided by the ToggleSupergroupJoinByRequestExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String