applyToInviteLinks property
applyToInviteLinks Pass true to apply the change to the existing invite links, including primary links
Implementation
final bool applyToInviteLinks;
applyToInviteLinks Pass true to apply the change to the existing invite links, including primary links
final bool applyToInviteLinks;