ToggleSupergroupJoinToSendMessages class final

Toggles whether joining is mandatory to send messages to a discussion supergroup; requires can_restrict_members administrator right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSupergroupJoinToSendMessages({required int supergroupId, required bool joinToSendMessages})

Properties

hashCode int
The hash code for this object.
no setteroverride
joinToSendMessages bool
joinToSendMessages New value of join_to_send_messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup that isn't a broadcast group
final

Methods

copyWith({int? supergroupId, bool? joinToSendMessages}) ToggleSupergroupJoinToSendMessages

Available on ToggleSupergroupJoinToSendMessages, provided by the ToggleSupergroupJoinToSendMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String