ToggleVideoChatEnabledStartNotification class final

Toggles whether the current user will receive a notification when the video chat starts; for scheduled video chats only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleVideoChatEnabledStartNotification({required int groupCallId, required bool enabledStartNotification})

Properties

enabledStartNotification bool
enabledStartNotification New value of the enabled_start_notification setting
final
groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? enabledStartNotification}) ToggleVideoChatEnabledStartNotification

Available on ToggleVideoChatEnabledStartNotification, provided by the ToggleVideoChatEnabledStartNotificationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String