ToggleVideoChatMuteNewParticipants class final

Toggles whether new participants of a video chat can be unmuted only by administrators of the video chat. Requires groupCall.can_toggle_mute_new_participants right Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleVideoChatMuteNewParticipants({required int groupCallId, required bool muteNewParticipants})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
muteNewParticipants bool
muteNewParticipants New value of the mute_new_participants setting
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? groupCallId, bool? muteNewParticipants}) ToggleVideoChatMuteNewParticipants

Available on ToggleVideoChatMuteNewParticipants, provided by the ToggleVideoChatMuteNewParticipantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String