TonTransaction class final

Represents a transaction changing the amount of owned TON Grams

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TonTransaction({required String id, required int gramAmount, required bool isRefund, required int date, TonTransactionType? type})

Properties

date int
date Point in time (Unix timestamp) when the transaction was completed
final
gramAmount int
gramAmount The amount of added owned Grams, in the smallest units of the cryptocurrency; negative for outgoing transactions
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the transaction
final
isRefund bool
isRefund True, if the transaction is a refund of a previous transaction
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type TonTransactionType?
type Type of the transaction
final

Methods

copyWith({String? id, int? gramAmount, bool? isRefund, int? date, TonTransactionType? type}) TonTransaction

Available on TonTransaction, provided by the TonTransactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TonTransaction?

Constants

constructor → const String