TonTransactionTypeUpgradedGiftSale class final
The transaction is a sale of an upgraded gift
- Inheritance
-
- Object
- TdObject
- TonTransactionType
- TonTransactionTypeUpgradedGiftSale
- Available extensions
- Annotations
-
- @immutable
Constructors
- TonTransactionTypeUpgradedGiftSale({required int userId, UpgradedGift? gift, required int commissionPerMille, required int commissionGramAmount, required bool viaOffer})
Properties
- commissionGramAmount → int
-
commissionGramAmount The Gram amount that was received by the Telegram;
in the smallest units of the currency
final
- commissionPerMille → int
-
commissionPerMille The number of Grams received by the Telegram for each
1000 Grams received by the seller of the gift
final
- gift → UpgradedGift?
-
gift The gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user who bought the gift
final
- viaOffer → bool
-
viaOffer True, if the gift was sold through a purchase offer
final
Methods
-
copyWith(
{int? userId, UpgradedGift? gift, int? commissionPerMille, int? commissionGramAmount, bool? viaOffer}) → TonTransactionTypeUpgradedGiftSale -
Available on TonTransactionTypeUpgradedGiftSale, provided by the TonTransactionTypeUpgradedGiftSaleExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fragmentDeposit(TonTransactionTypeFragmentDeposit value), required TResult fragmentWithdrawal(TonTransactionTypeFragmentWithdrawal value), required TResult giftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer value), required TResult stakeDicePayout(TonTransactionTypeStakeDicePayout value), required TResult stakeDiceStake(TonTransactionTypeStakeDiceStake value), required TResult suggestedPostPayment(TonTransactionTypeSuggestedPostPayment value), required TResult unsupported(TonTransactionTypeUnsupported value), required TResult upgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase value), required TResult upgradedGiftSale(TonTransactionTypeUpgradedGiftSale value)}) → TResult -
Available on TonTransactionType, provided by the TonTransactionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fragmentDeposit(TonTransactionTypeFragmentDeposit value)?, TResult fragmentWithdrawal(TonTransactionTypeFragmentWithdrawal value)?, TResult giftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer value)?, TResult stakeDicePayout(TonTransactionTypeStakeDicePayout value)?, TResult stakeDiceStake(TonTransactionTypeStakeDiceStake value)?, TResult suggestedPostPayment(TonTransactionTypeSuggestedPostPayment value)?, TResult unsupported(TonTransactionTypeUnsupported value)?, TResult upgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase value)?, TResult upgradedGiftSale(TonTransactionTypeUpgradedGiftSale value)?, required TResult orElse()}) → TResult -
Available on TonTransactionType, provided by the TonTransactionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TonTransactionTypeUpgradedGiftSale? -
Inherited by:
TonTransactionTypeFragmentDeposit
TonTransactionTypeFragmentWithdrawal
TonTransactionTypeGiftPurchaseOffer
TonTransactionTypeStakeDicePayout
TonTransactionTypeStakeDiceStake
TonTransactionTypeSuggestedPostPayment
TonTransactionTypeUnsupported
TonTransactionTypeUpgradedGiftPurchase
TonTransactionTypeUpgradedGiftSale
override
Constants
- constructor → const String