TonTransactions class final
Represents a list of TON Gram transactions
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TonTransactions({required int gramAmount, required List<
TonTransaction> transactions, required String nextOffset})
Properties
- gramAmount → int
-
gramAmount The total amount of owned Grams, in the smallest units of the
cryptocurrency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transactions
→ List<
TonTransaction> -
transactions List of Gram transactions
final
Methods
-
copyWith(
{int? gramAmount, List< TonTransaction> ? transactions, String? nextOffset}) → TonTransactions -
Available on TonTransactions, provided by the TonTransactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TonTransactions?
Constants
- constructor → const String