TopChatCategoryCalls class final
A category containing frequently used chats used for calls
- Inheritance
-
- Object
- TdObject
- TopChatCategory
- TopChatCategoryCalls
- Available extensions
- Annotations
-
- @immutable
Constructors
- TopChatCategoryCalls()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bots(TopChatCategoryBots value), required TResult calls(TopChatCategoryCalls value), required TResult channels(TopChatCategoryChannels value), required TResult forwardChats(TopChatCategoryForwardChats value), required TResult groups(TopChatCategoryGroups value), required TResult guestBots(TopChatCategoryGuestBots value), required TResult inlineBots(TopChatCategoryInlineBots value), required TResult users(TopChatCategoryUsers value), required TResult webAppBots(TopChatCategoryWebAppBots value)}) → TResult -
Available on TopChatCategory, provided by the TopChatCategoryExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bots(TopChatCategoryBots value)?, TResult calls(TopChatCategoryCalls value)?, TResult channels(TopChatCategoryChannels value)?, TResult forwardChats(TopChatCategoryForwardChats value)?, TResult groups(TopChatCategoryGroups value)?, TResult guestBots(TopChatCategoryGuestBots value)?, TResult inlineBots(TopChatCategoryInlineBots value)?, TResult users(TopChatCategoryUsers value)?, TResult webAppBots(TopChatCategoryWebAppBots value)?, required TResult orElse()}) → TResult -
Available on TopChatCategory, provided by the TopChatCategoryExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String