TransactionDirectionOutgoing class final
The transaction is outgoing and decreases the amount of owned currency
- Inheritance
-
- Object
- TdObject
- TransactionDirection
- TransactionDirectionOutgoing
- Available extensions
- Annotations
-
- @immutable
Constructors
- TransactionDirectionOutgoing()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult incoming(TransactionDirectionIncoming value), required TResult outgoing(TransactionDirectionOutgoing value)}) → TResult -
Available on TransactionDirection, provided by the TransactionDirectionExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult incoming(TransactionDirectionIncoming value)?, TResult outgoing(TransactionDirectionOutgoing value)?, required TResult orElse()}) → TResult -
Available on TransactionDirection, provided by the TransactionDirectionExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TransactionDirectionOutgoing? -
Inherited by:
TransactionDirectionIncoming
TransactionDirectionOutgoing
override
Constants
- constructor → const String