TransferChatOwnership class final
Changes the owner of a chat; for basic groups, supergroups and channel chats only; requires owner privileges in the chat. Use the method canTransferOwnership to check whether the ownership can be transferred from the current session Returns Ok
- Inheritance
-
- Object
- TdFunction
- TransferChatOwnership
- Available extensions
- Annotations
-
- @immutable
Constructors
- TransferChatOwnership({required int chatId, required int userId, required String password})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- password → String
-
password The 2-step verification password of the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user to which transfer the ownership. The
ownership can't be transferred to a bot or to a deleted user
final
Methods
-
copyWith(
{int? chatId, int? userId, String? password}) → TransferChatOwnership -
Available on TransferChatOwnership, provided by the TransferChatOwnershipExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String