TransferGift class final

Sends an upgraded gift to another user or channel chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TransferGift({String? businessConnectionId, required String receivedGiftId, MessageSender? newOwnerId, required int starCount})

Properties

businessConnectionId String?
businessConnectionId Unique identifier of business connection on behalf of which to send the request; for bots only
final
hashCode int
The hash code for this object.
no setteroverride
newOwnerId MessageSender?
newOwnerId Identifier of the user or the channel chat that will receive the gift
final
receivedGiftId String
receivedGiftId Identifier of the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount required to pay for the transfer
final

Methods

copyWith({String? businessConnectionId, String? receivedGiftId, MessageSender? newOwnerId, int? starCount}) TransferGift

Available on TransferGift, provided by the TransferGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String