newOwnerId property
newOwnerId Identifier of the user or the channel chat that will receive the gift
Implementation
final MessageSender? newOwnerId;
newOwnerId Identifier of the user or the channel chat that will receive the gift
final MessageSender? newOwnerId;