TranslateMessageRichMessage class final

Extracts rich message of the given message and translates it to the given language Returns RichMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TranslateMessageRichMessage({required int chatId, required int messageId, required String toLanguageCode, required String tone})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLanguageCode String
toLanguageCode Language code of the language to which the message is translated. See translateText.to_language_code for the list of supported values
final
tone String
tone Tone of the translation; see translateText.tone for the list of supported values
final

Methods

copyWith({int? chatId, int? messageId, String? toLanguageCode, String? tone}) TranslateMessageRichMessage

Available on TranslateMessageRichMessage, provided by the TranslateMessageRichMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String