toLanguageCode property
toLanguageCode Language code of the language to which the message is translated. See translateText.to_language_code for the list of supported values
Implementation
final String toLanguageCode;
toLanguageCode Language code of the language to which the message is translated. See translateText.to_language_code for the list of supported values
final String toLanguageCode;