TrendingStickerSets class final

Represents a list of trending sticker sets

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TrendingStickerSets({required int totalCount, required List<StickerSetInfo> sets, required bool isPremium})

Properties

hashCode int
The hash code for this object.
no setteroverride
isPremium bool
isPremium True, if the list contains sticker sets with premium stickers
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sets List<StickerSetInfo>
sets List of trending sticker sets
final
totalCount int
totalCount Approximate total number of trending sticker sets
final

Methods

copyWith({int? totalCount, List<StickerSetInfo>? sets, bool? isPremium}) TrendingStickerSets

Available on TrendingStickerSets, provided by the TrendingStickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TrendingStickerSets?

Constants

constructor → const String