UnconfirmedSession class final

Contains information about an unconfirmed session

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UnconfirmedSession({SessionType? type, required int date, required String deviceModel, required String location})

Properties

date int
date Point in time (Unix timestamp) when the user has logged in or the business bot was connected
final
deviceModel String
deviceModel Model of the device that was used for the session creation, as provided by the application
final
hashCode int
The hash code for this object.
no setteroverride
location String
location A human-readable description of the location from which the session was created, based on the IP address
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SessionType?
type Session type
final

Methods

copyWith({SessionType? type, int? date, String? deviceModel, String? location}) UnconfirmedSession

Available on UnconfirmedSession, provided by the UnconfirmedSessionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UnconfirmedSession?

Constants

constructor → const String