deviceModel property
deviceModel Model of the device that was used for the session creation, as provided by the application
Implementation
final String deviceModel;
deviceModel Model of the device that was used for the session creation, as provided by the application
final String deviceModel;