UnpinAllDirectMessagesChatTopicMessages class final
Removes all pinned messages from the topic in a channel direct messages chat administered by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- UnpinAllDirectMessagesChatTopicMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- UnpinAllDirectMessagesChatTopicMessages({required int chatId, required int topicId})
Properties
Methods
-
copyWith(
{int? chatId, int? topicId}) → UnpinAllDirectMessagesChatTopicMessages -
Available on UnpinAllDirectMessagesChatTopicMessages, provided by the UnpinAllDirectMessagesChatTopicMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String