UnreadReaction class final

Contains information about an unread reaction to a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UnreadReaction({ReactionType? type, MessageSender? senderId, required bool isBig})

Properties

hashCode int
The hash code for this object.
no setteroverride
isBig bool
isBig True, if the reaction was added with a big animation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the sender, added the reaction
final
type ReactionType?
type Type of the reaction
final

Methods

copyWith({ReactionType? type, MessageSender? senderId, bool? isBig}) UnreadReaction

Available on UnreadReaction, provided by the UnreadReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UnreadReaction?

Constants

constructor → const String