availableAccentColorIds property
availableAccentColorIds The list of accent color identifiers, which can be set through setAccentColor and setChatAccentColor. The colors must be shown in the specified order
Implementation
final List<int> availableAccentColorIds;