reactionEffectIds property
reactionEffectIds The new list of available message effects from emoji reactions
Implementation
final List<int> reactionEffectIds;
reactionEffectIds The new list of available message effects from emoji reactions
final List<int> reactionEffectIds;