stickerEffectIds property
stickerEffectIds The new list of available message effects from Premium stickers
Implementation
final List<int> stickerEffectIds;
stickerEffectIds The new list of available message effects from Premium stickers
final List<int> stickerEffectIds;