backgroundCustomEmojiId property

int backgroundCustomEmojiId
final

backgroundCustomEmojiId The new identifier of a custom emoji to be shown on the reply header and link preview background; 0 if none

Implementation

final int backgroundCustomEmojiId;