profileBackgroundCustomEmojiId property
profileBackgroundCustomEmojiId The new identifier of a custom emoji to be shown on the profile background; 0 if none
Implementation
final int profileBackgroundCustomEmojiId;
profileBackgroundCustomEmojiId The new identifier of a custom emoji to be shown on the profile background; 0 if none
final int profileBackgroundCustomEmojiId;