topicId property
topicId Identifier of the specific topic in which the action was performed; may be null if none
Implementation
final MessageTopic? topicId;
topicId Identifier of the specific topic in which the action was performed; may be null if none
final MessageTopic? topicId;