queryId property

int queryId
final

queryId Identifier of the join request query as received in chatJoinResultGuardBotApprovalRequired. If the corresponding Web App is still open, then it must be closed

Implementation

final int queryId;