lastMessage property

Message? lastMessage
final

lastMessage The new last message in the chat; may be null if the last message became unknown. While the last message is unknown, new messages can be added to the chat without corresponding updateNewMessage update

Implementation

final Message? lastMessage;