replyMarkupMessage property

Message? replyMarkupMessage
final

replyMarkupMessage The message from which the reply markup must be used; may be null if there is no default reply markup in the chat

Implementation

final Message? replyMarkupMessage;