unreadPollVoteCount property
unreadPollVoteCount The number of messages with unread poll votes left in the chat
Implementation
final int unreadPollVoteCount;
unreadPollVoteCount The number of messages with unread poll votes left in the chat
final int unreadPollVoteCount;