destinationPath property

String destinationPath
final

destinationPath The path to a file that must be created and where the new file must be generated by the application. If the application has no access to the path, it can use writeGeneratedFilePart to generate the file

Implementation

final String destinationPath;