unreadPollVoteCount property
unreadPollVoteCount Number of messages with unread poll votes in the topic
Implementation
final int unreadPollVoteCount;
unreadPollVoteCount Number of messages with unread poll votes in the topic
final int unreadPollVoteCount;