levels property
levels New description of the levels in decreasing order of groupCallMessageLevel.min_star_count
Implementation
final List<GroupCallMessageLevel> levels;
levels New description of the levels in decreasing order of groupCallMessageLevel.min_star_count
final List<GroupCallMessageLevel> levels;