participantUserIds property

List<int> participantUserIds
final

participantUserIds New list of group call participant user identifiers. The identifiers may be invalid or the corresponding users may be unknown. The participants must be shown in the list of group call participants even if there is no information about them

Implementation

final List<int> participantUserIds;