generation property

int generation
final

generation The call state generation to which the emoji corresponds. If generation is different for two users, then their emoji may be also different

Implementation

final int generation;