unreadPollVoteCount property
unreadPollVoteCount The new number of messages with unread poll votes in the chat
Implementation
final int unreadPollVoteCount;
unreadPollVoteCount The new number of messages with unread poll votes in the chat
final int unreadPollVoteCount;