message property
message The message from the business account from which the query originated
Implementation
final BusinessMessage? message;
message The message from the business account from which the query originated
final BusinessMessage? message;