addedNotifications property
addedNotifications List of added group notifications, sorted by notification identifier
Implementation
final List<Notification> addedNotifications;
addedNotifications List of added group notifications, sorted by notification identifier
final List<Notification> addedNotifications;