removedNotificationIds property
removedNotificationIds Identifiers of removed group notifications, sorted by notification identifier
Implementation
final List<int> removedNotificationIds;
removedNotificationIds Identifiers of removed group notifications, sorted by notification identifier
final List<int> removedNotificationIds;