forumTopicId property
forumTopicId The forum topic identifier in which the message will be sent; 0 if none
Implementation
final int forumTopicId;
forumTopicId The forum topic identifier in which the message will be sent; 0 if none
final int forumTopicId;