optionPositions property
optionPositions 0-based identifiers of answer options, that were chosen by the user
Implementation
final List<int> optionPositions;
optionPositions 0-based identifiers of answer options, that were chosen by the user
final List<int> optionPositions;