messages property

List<QuickReplyMessage> messages
final

messages The new list of quick reply messages for the shortcut in order from the first to the last sent

Implementation

final List<QuickReplyMessage> messages;