botUserIds property
botUserIds List of user identifiers of the bots; the corresponding users may not be sent using updateUser updates and may not be accessible
Implementation
final List<int> botUserIds;
botUserIds List of user identifiers of the bots; the corresponding users may not be sent using updateUser updates and may not be accessible
final List<int> botUserIds;