UpgradeGift class final

Upgrades a regular gift Returns UpgradeGiftResult

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradeGift({String? businessConnectionId, required String receivedGiftId, required bool keepOriginalDetails, required int starCount})

Properties

businessConnectionId String?
businessConnectionId Unique identifier of business connection on behalf of which to send the request; for bots only
final
hashCode int
The hash code for this object.
no setteroverride
keepOriginalDetails bool
keepOriginalDetails Pass true to keep the original gift text, sender and receiver in the upgraded gift
final
receivedGiftId String
receivedGiftId Identifier of the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The Telegram Star amount required to pay for the upgrade. If the gift has prepaid_upgrade_star_count
final

Methods

copyWith({String? businessConnectionId, String? receivedGiftId, bool? keepOriginalDetails, int? starCount}) UpgradeGift

Available on UpgradeGift, provided by the UpgradeGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String