UpgradeGiftResult class final

Contains result of gift upgrading

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradeGiftResult({UpgradedGift? gift, required String receivedGiftId, required bool isSaved, required bool canBeTransferred, required int transferStarCount, required int dropOriginalDetailsStarCount, required int nextTransferDate, required int nextResaleDate, required int exportDate})

Properties

canBeTransferred bool
canBeTransferred True, if the gift can be transferred to another owner
final
dropOriginalDetailsStarCount int
dropOriginalDetailsStarCount Number of Telegram Stars that must be paid to drop original details of the upgraded gift; 0 if not available
final
exportDate int
exportDate Point in time (Unix timestamp) when the gift can be transferred to the TON blockchain as an NFT; can be in the past
final
gift UpgradedGift?
gift The upgraded gift
final
hashCode int
The hash code for this object.
no setteroverride
isSaved bool
isSaved True, if the gift is displayed on the user's or the channel's profile page
final
nextResaleDate int
nextResaleDate Point in time (Unix timestamp) when the gift can be resold to another user; can be in the past; 0 if the gift can't be resold; only for the receiver of the gift
final
nextTransferDate int
nextTransferDate Point in time (Unix timestamp) when the gift can be transferred to another owner; can be in the past; 0 if the gift can be transferred immediately or transfer isn't possible
final
receivedGiftId String
receivedGiftId Unique identifier of the received gift for the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transferStarCount int
transferStarCount Number of Telegram Stars that must be paid to transfer the upgraded gift
final

Methods

copyWith({UpgradedGift? gift, String? receivedGiftId, bool? isSaved, bool? canBeTransferred, int? transferStarCount, int? dropOriginalDetailsStarCount, int? nextTransferDate, int? nextResaleDate, int? exportDate}) UpgradeGiftResult

Available on UpgradeGiftResult, provided by the UpgradeGiftResultExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradeGiftResult?

Constants

constructor → const String