craftProbabilityPerMille property
craftProbabilityPerMille Probability that the gift adds to the chance of successful crafting of a new gift; 0 if the gift can't be used for crafting
Implementation
final int craftProbabilityPerMille;
craftProbabilityPerMille Probability that the gift adds to the chance of successful crafting of a new gift; 0 if the gift can't be used for crafting
final int craftProbabilityPerMille;