maxUpgradedCount property
maxUpgradedCount The maximum number of gifts that can be upgraded from the same gift
Implementation
final int maxUpgradedCount;
maxUpgradedCount The maximum number of gifts that can be upgraded from the same gift
final int maxUpgradedCount;