ownerId property
ownerId Identifier of the user or the chat that owns the upgraded gift; may be null if none or unknown
Implementation
final MessageSender? ownerId;
ownerId Identifier of the user or the chat that owns the upgraded gift; may be null if none or unknown
final MessageSender? ownerId;