totalUpgradedCount property
totalUpgradedCount Total number of gifts that were upgraded from the same gift
Implementation
final int totalUpgradedCount;
totalUpgradedCount Total number of gifts that were upgraded from the same gift
final int totalUpgradedCount;