usedThemeChatId property
usedThemeChatId Identifier of the chat for which the gift is used to set a theme; 0 if none or the gift isn't owned by the current user
Implementation
final int usedThemeChatId;
usedThemeChatId Identifier of the chat for which the gift is used to set a theme; 0 if none or the gift isn't owned by the current user
final int usedThemeChatId;