valueCurrency property
valueCurrency ISO 4217 currency code of the currency in which value of the gift is represented; may be empty if unavailable
Implementation
final String valueCurrency;
valueCurrency ISO 4217 currency code of the currency in which value of the gift is represented; may be empty if unavailable
final String valueCurrency;