UpgradedGiftAttributeIdBackdrop class final

Identifier of a gift backdrop

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftAttributeIdBackdrop({required int backdropId})

Properties

backdropId int
backdropId Identifier of the backdrop
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? backdropId}) UpgradedGiftAttributeIdBackdrop

Available on UpgradedGiftAttributeIdBackdrop, provided by the UpgradedGiftAttributeIdBackdropExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult backdrop(UpgradedGiftAttributeIdBackdrop value), required TResult model(UpgradedGiftAttributeIdModel value), required TResult symbol(UpgradedGiftAttributeIdSymbol value)}) → TResult

Available on UpgradedGiftAttributeId, provided by the UpgradedGiftAttributeIdExtensions extension

maybeMap<TResult extends Object?>({TResult backdrop(UpgradedGiftAttributeIdBackdrop value)?, TResult model(UpgradedGiftAttributeIdModel value)?, TResult symbol(UpgradedGiftAttributeIdSymbol value)?, required TResult orElse()}) → TResult

Available on UpgradedGiftAttributeId, provided by the UpgradedGiftAttributeIdExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String