UpgradedGiftAttributeRarityLegendary class final
The attribute is legendary
- Inheritance
-
- Object
- TdObject
- UpgradedGiftAttributeRarity
- UpgradedGiftAttributeRarityLegendary
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult epic(UpgradedGiftAttributeRarityEpic value), required TResult legendary(UpgradedGiftAttributeRarityLegendary value), required TResult perMille(UpgradedGiftAttributeRarityPerMille value), required TResult rare(UpgradedGiftAttributeRarityRare value), required TResult uncommon(UpgradedGiftAttributeRarityUncommon value)}) → TResult -
Available on UpgradedGiftAttributeRarity, provided by the UpgradedGiftAttributeRarityExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult epic(UpgradedGiftAttributeRarityEpic value)?, TResult legendary(UpgradedGiftAttributeRarityLegendary value)?, TResult perMille(UpgradedGiftAttributeRarityPerMille value)?, TResult rare(UpgradedGiftAttributeRarityRare value)?, TResult uncommon(UpgradedGiftAttributeRarityUncommon value)?, required TResult orElse()}) → TResult -
Available on UpgradedGiftAttributeRarity, provided by the UpgradedGiftAttributeRarityExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String