UpgradedGiftBackdrop class final

Describes a backdrop of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftBackdrop({required int id, required String name, UpgradedGiftBackdropColors? colors, UpgradedGiftAttributeRarity? rarity})

Properties

colors UpgradedGiftBackdropColors?
colors Colors of the backdrop
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the backdrop
final
name String
name Name of the backdrop
final
rarity UpgradedGiftAttributeRarity?
rarity The rarity of the backdrop
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? id, String? name, UpgradedGiftBackdropColors? colors, UpgradedGiftAttributeRarity? rarity}) UpgradedGiftBackdrop

Available on UpgradedGiftBackdrop, provided by the UpgradedGiftBackdropExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftBackdrop?

Constants

constructor → const String