UpgradedGiftBackdropColors class final

Describes colors of a backdrop of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftBackdropColors({required int centerColor, required int edgeColor, required int symbolColor, required int textColor})

Properties

centerColor int
centerColor A color in the center of the backdrop in the RGB format
final
edgeColor int
edgeColor A color on the edges of the backdrop in the RGB format
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbolColor int
symbolColor A color to be applied for the symbol in the RGB format
final
textColor int
textColor A color for the text on the backdrop in the RGB format
final

Methods

copyWith({int? centerColor, int? edgeColor, int? symbolColor, int? textColor}) UpgradedGiftBackdropColors

Available on UpgradedGiftBackdropColors, provided by the UpgradedGiftBackdropColorsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftBackdropColors?

Constants

constructor → const String