UpgradedGiftBackdropCount class final

Describes a backdrop of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftBackdropCount({UpgradedGiftBackdrop? backdrop, required int totalCount})

Properties

backdrop UpgradedGiftBackdrop?
backdrop The backdrop
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of gifts with the symbol
final

Methods

copyWith({UpgradedGiftBackdrop? backdrop, int? totalCount}) UpgradedGiftBackdropCount

Available on UpgradedGiftBackdropCount, provided by the UpgradedGiftBackdropCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftBackdropCount?

Constants

constructor → const String