lightThemeAccentColor property
lightThemeAccentColor Accent color to use in light themes in RGB format
Implementation
final int lightThemeAccentColor;
lightThemeAccentColor Accent color to use in light themes in RGB format
final int lightThemeAccentColor;