modelCustomEmojiId property
modelCustomEmojiId Custom emoji identifier of the model of the upgraded gift
Implementation
final int modelCustomEmojiId;
modelCustomEmojiId Custom emoji identifier of the model of the upgraded gift
final int modelCustomEmojiId;