UpgradedGiftModel class final

Describes a model of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftModel({required String name, Sticker? sticker, UpgradedGiftAttributeRarity? rarity, required bool isCrafted})

Properties

hashCode int
The hash code for this object.
no setteroverride
isCrafted bool
isCrafted True, if the model can be obtained only through gift crafting
final
name String
name Name of the model
final
rarity UpgradedGiftAttributeRarity?
rarity The rarity of the model
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker Sticker?
sticker The sticker representing the upgraded gift
final

Methods

copyWith({String? name, Sticker? sticker, UpgradedGiftAttributeRarity? rarity, bool? isCrafted}) UpgradedGiftModel

Available on UpgradedGiftModel, provided by the UpgradedGiftModelExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftModel?

Constants

constructor → const String