UpgradedGiftOriginResale class final
The gift was bought from another user
- Inheritance
-
- Object
- TdObject
- UpgradedGiftOrigin
- UpgradedGiftOriginResale
- Available extensions
- Annotations
-
- @immutable
Constructors
- UpgradedGiftOriginResale({GiftResalePrice? price})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- price → GiftResalePrice?
-
price Price paid for the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{GiftResalePrice? price}) → UpgradedGiftOriginResale -
Available on UpgradedGiftOriginResale, provided by the UpgradedGiftOriginResaleExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult blockchain(UpgradedGiftOriginBlockchain value), required TResult craft(UpgradedGiftOriginCraft value), required TResult offer(UpgradedGiftOriginOffer value), required TResult prepaidUpgrade(UpgradedGiftOriginPrepaidUpgrade value), required TResult resale(UpgradedGiftOriginResale value), required TResult transfer(UpgradedGiftOriginTransfer value), required TResult upgrade(UpgradedGiftOriginUpgrade value)}) → TResult -
Available on UpgradedGiftOrigin, provided by the UpgradedGiftOriginExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult blockchain(UpgradedGiftOriginBlockchain value)?, TResult craft(UpgradedGiftOriginCraft value)?, TResult offer(UpgradedGiftOriginOffer value)?, TResult prepaidUpgrade(UpgradedGiftOriginPrepaidUpgrade value)?, TResult resale(UpgradedGiftOriginResale value)?, TResult transfer(UpgradedGiftOriginTransfer value)?, TResult upgrade(UpgradedGiftOriginUpgrade value)?, required TResult orElse()}) → TResult -
Available on UpgradedGiftOrigin, provided by the UpgradedGiftOriginExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String