giftMessageId property
giftMessageId Identifier of the message with the regular gift that was upgraded; may be 0 or an identifier of a deleted message
Implementation
final int giftMessageId;
giftMessageId Identifier of the message with the regular gift that was upgraded; may be 0 or an identifier of a deleted message
final int giftMessageId;