UpgradedGiftOriginalDetails class final

Describes the original details about the gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftOriginalDetails({MessageSender? senderId, MessageSender? receiverId, FormattedText? text, required int date})

Properties

date int
date Point in time (Unix timestamp) when the gift was sent
final
hashCode int
The hash code for this object.
no setteroverride
receiverId MessageSender?
receiverId Identifier of the user or the chat that received the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderId MessageSender?
senderId Identifier of the user or the chat that sent the gift; may be null if the gift was private
final
text FormattedText?
text Message added to the gift
final

Methods

copyWith({MessageSender? senderId, MessageSender? receiverId, FormattedText? text, int? date}) UpgradedGiftOriginalDetails

Available on UpgradedGiftOriginalDetails, provided by the UpgradedGiftOriginalDetailsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftOriginalDetails?

Constants

constructor → const String