senderId property
senderId Identifier of the user or the chat that sent the gift; may be null if the gift was private
Implementation
final MessageSender? senderId;
senderId Identifier of the user or the chat that sent the gift; may be null if the gift was private
final MessageSender? senderId;