UpgradedGiftSymbol class final

Describes a symbol shown on the pattern of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftSymbol({required String name, Sticker? sticker, UpgradedGiftAttributeRarity? rarity})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the symbol
final
rarity UpgradedGiftAttributeRarity?
rarity The rarity of the symbol
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker Sticker?
sticker The sticker representing the symbol
final

Methods

copyWith({String? name, Sticker? sticker, UpgradedGiftAttributeRarity? rarity}) UpgradedGiftSymbol

Available on UpgradedGiftSymbol, provided by the UpgradedGiftSymbolExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftSymbol?

Constants

constructor → const String