UpgradedGiftSymbolCount class final

Describes a symbol shown on the pattern of an upgraded gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UpgradedGiftSymbolCount({UpgradedGiftSymbol? symbol, required int totalCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol UpgradedGiftSymbol?
symbol The symbol
final
totalCount int
totalCount Total number of gifts with the symbol
final

Methods

copyWith({UpgradedGiftSymbol? symbol, int? totalCount}) UpgradedGiftSymbolCount

Available on UpgradedGiftSymbolCount, provided by the UpgradedGiftSymbolCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UpgradedGiftSymbolCount?

Constants

constructor → const String