fragmentUrl property
fragmentUrl The HTTPS link to the Fragment for the gift; may be empty if there are no such gifts being sold on Fragment
Implementation
final String fragmentUrl;
fragmentUrl The HTTPS link to the Fragment for the gift; may be empty if there are no such gifts being sold on Fragment
final String fragmentUrl;