UploadStickerFile class final

Uploads a file with a sticker; returns the uploaded file Returns File

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UploadStickerFile({required int userId, StickerFormat? stickerFormat, InputFile? sticker})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sticker InputFile?
sticker File to upload; must fit in a 512x512 square. For WEBP stickers the file must be in WEBP or PNG format, which will be converted to WEBP server-side. See https://core.telegram.org/animated_stickers#technical-requirements for technical requirements
final
stickerFormat StickerFormat?
stickerFormat Sticker format
final
userId int
userId Sticker file owner; ignored for regular users
final

Methods

copyWith({int? userId, StickerFormat? stickerFormat, InputFile? sticker}) UploadStickerFile

Available on UploadStickerFile, provided by the UploadStickerFileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String