accentColorId property
accentColorId Identifier of the accent color for name, and backgrounds of profile photo, reply header, and link preview
Implementation
final int accentColorId;
accentColorId Identifier of the accent color for name, and backgrounds of profile photo, reply header, and link preview
final int accentColorId;