activeStoryState property
activeStoryState State of active stories of the user; may be null if the user has no active stories
Implementation
final ActiveStoryState? activeStoryState;
activeStoryState State of active stories of the user; may be null if the user has no active stories
final ActiveStoryState? activeStoryState;