backgroundCustomEmojiId property
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the reply header and link preview background; 0 if none
Implementation
final int backgroundCustomEmojiId;
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the reply header and link preview background; 0 if none
final int backgroundCustomEmojiId;