restrictionInfo property
restrictionInfo Information about restrictions that must be applied to the corresponding private chat; may be null if none
Implementation
final RestrictionInfo? restrictionInfo;
restrictionInfo Information about restrictions that must be applied to the corresponding private chat; may be null if none
final RestrictionInfo? restrictionInfo;