upgradedGiftColors property
upgradedGiftColors Color scheme based on an upgraded gift to be used for the user instead of accent_color_id and background_custom_emoji_id; may be null if none
Implementation
final UpgradedGiftColors? upgradedGiftColors;
upgradedGiftColors Color scheme based on an upgraded gift to be used for the user instead of accent_color_id and background_custom_emoji_id; may be null if none
final UpgradedGiftColors? upgradedGiftColors;