UserAuctionBid class final

Describes a bid of the current user in an auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserAuctionBid({required int starCount, required int bidDate, required int nextBidStarCount, MessageSender? ownerId, required bool wasReturned})

Properties

bidDate int
bidDate Point in time (Unix timestamp) when the bid was made
final
hashCode int
The hash code for this object.
no setteroverride
nextBidStarCount int
nextBidStarCount The minimum number of Telegram Stars that can be put for the next bid
final
ownerId MessageSender?
ownerId Identifier of the user or the chat that will receive the auctioned item. If the auction is opened in context of another user or chat, then a warning is supposed to be shown to the current user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars that were put in the bid
final
wasReturned bool
wasReturned True, if the bid was returned to the user, because it was outbid and can't win anymore
final

Methods

copyWith({int? starCount, int? bidDate, int? nextBidStarCount, MessageSender? ownerId, bool? wasReturned}) UserAuctionBid

Available on UserAuctionBid, provided by the UserAuctionBidExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserAuctionBid?

Constants

constructor → const String