nextBidStarCount property
nextBidStarCount The minimum number of Telegram Stars that can be put for the next bid
Implementation
final int nextBidStarCount;
nextBidStarCount The minimum number of Telegram Stars that can be put for the next bid
final int nextBidStarCount;