wasReturned property
wasReturned True, if the bid was returned to the user, because it was outbid and can't win anymore
Implementation
final bool wasReturned;
wasReturned True, if the bid was returned to the user, because it was outbid and can't win anymore
final bool wasReturned;