communityId property
communityId Identifier of the community to which chat with the bot was added; for bots only
Implementation
final int? communityId;
communityId Identifier of the community to which chat with the bot was added; for bots only
final int? communityId;