hasPostedToProfileStories property
hasPostedToProfileStories True, if the user has posted to profile stories
Implementation
final bool hasPostedToProfileStories;
hasPostedToProfileStories True, if the user has posted to profile stories
final bool hasPostedToProfileStories;