hasSponsoredMessagesEnabled property
hasSponsoredMessagesEnabled True, if the user always enabled sponsored messages; known only for the current user
Implementation
final bool hasSponsoredMessagesEnabled;
hasSponsoredMessagesEnabled True, if the user always enabled sponsored messages; known only for the current user
final bool hasSponsoredMessagesEnabled;