incomingPaidMessageStarCount property

int incomingPaidMessageStarCount
final

incomingPaidMessageStarCount Number of Telegram Stars that must be paid by the user for each sent message to the current user

Implementation

final int incomingPaidMessageStarCount;