pendingRatingDate property

int pendingRatingDate
final

pendingRatingDate Unix timestamp when rating of the user will change to pending_rating; 0 if the user isn't the current user or there are no pending rating changes

Implementation

final int pendingRatingDate;