setChatBackground property
setChatBackground True, if the user set chat background for both chat users and it wasn't reverted yet
Implementation
final bool setChatBackground;
setChatBackground True, if the user set chat background for both chat users and it wasn't reverted yet
final bool setChatBackground;