UserPrivacySettingRuleAllowChatMembers class final
A rule to allow all members of certain specified basic groups and supergroups to doing something
- Inheritance
-
- Object
- TdObject
- UserPrivacySettingRule
- UserPrivacySettingRuleAllowChatMembers
- Available extensions
- Annotations
-
- @immutable
Constructors
-
UserPrivacySettingRuleAllowChatMembers({required List<
int> chatIds})
Properties
Methods
-
copyWith(
{List< int> ? chatIds}) → UserPrivacySettingRuleAllowChatMembers -
Available on UserPrivacySettingRuleAllowChatMembers, provided by the UserPrivacySettingRuleAllowChatMembersExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult allowAll(UserPrivacySettingRuleAllowAll value), required TResult allowBots(UserPrivacySettingRuleAllowBots value), required TResult allowChatMembers(UserPrivacySettingRuleAllowChatMembers value), required TResult allowContacts(UserPrivacySettingRuleAllowContacts value), required TResult allowPremiumUsers(UserPrivacySettingRuleAllowPremiumUsers value), required TResult allowUsers(UserPrivacySettingRuleAllowUsers value), required TResult restrictAll(UserPrivacySettingRuleRestrictAll value), required TResult restrictBots(UserPrivacySettingRuleRestrictBots value), required TResult restrictChatMembers(UserPrivacySettingRuleRestrictChatMembers value), required TResult restrictContacts(UserPrivacySettingRuleRestrictContacts value), required TResult restrictUsers(UserPrivacySettingRuleRestrictUsers value)}) → TResult -
Available on UserPrivacySettingRule, provided by the UserPrivacySettingRuleExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult allowAll(UserPrivacySettingRuleAllowAll value)?, TResult allowBots(UserPrivacySettingRuleAllowBots value)?, TResult allowChatMembers(UserPrivacySettingRuleAllowChatMembers value)?, TResult allowContacts(UserPrivacySettingRuleAllowContacts value)?, TResult allowPremiumUsers(UserPrivacySettingRuleAllowPremiumUsers value)?, TResult allowUsers(UserPrivacySettingRuleAllowUsers value)?, TResult restrictAll(UserPrivacySettingRuleRestrictAll value)?, TResult restrictBots(UserPrivacySettingRuleRestrictBots value)?, TResult restrictChatMembers(UserPrivacySettingRuleRestrictChatMembers value)?, TResult restrictContacts(UserPrivacySettingRuleRestrictContacts value)?, TResult restrictUsers(UserPrivacySettingRuleRestrictUsers value)?, required TResult orElse()}) → TResult -
Available on UserPrivacySettingRule, provided by the UserPrivacySettingRuleExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UserPrivacySettingRuleAllowChatMembers? -
Inherited by:
UserPrivacySettingRuleAllowAll
UserPrivacySettingRuleAllowBots
UserPrivacySettingRuleAllowChatMembers
UserPrivacySettingRuleAllowContacts
UserPrivacySettingRuleAllowPremiumUsers
UserPrivacySettingRuleAllowUsers
UserPrivacySettingRuleRestrictAll
UserPrivacySettingRuleRestrictBots
UserPrivacySettingRuleRestrictChatMembers
UserPrivacySettingRuleRestrictContacts
UserPrivacySettingRuleRestrictUsers
override
Constants
- constructor → const String