UserPrivacySettingRuleRestrictChatMembers class final

A rule to restrict all members of specified basic groups and supergroups from doing something

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserPrivacySettingRuleRestrictChatMembers({required List<int> chatIds})

Properties

chatIds List<int>
chatIds The chat identifiers, total number of chats in all rules must not exceed 20
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<int>? chatIds}) UserPrivacySettingRuleRestrictChatMembers

Available on UserPrivacySettingRuleRestrictChatMembers, provided by the UserPrivacySettingRuleRestrictChatMembersExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult allowAll(UserPrivacySettingRuleAllowAll value), required TResult allowBots(UserPrivacySettingRuleAllowBots value), required TResult allowChatMembers(UserPrivacySettingRuleAllowChatMembers value), required TResult allowContacts(UserPrivacySettingRuleAllowContacts value), required TResult allowPremiumUsers(UserPrivacySettingRuleAllowPremiumUsers value), required TResult allowUsers(UserPrivacySettingRuleAllowUsers value), required TResult restrictAll(UserPrivacySettingRuleRestrictAll value), required TResult restrictBots(UserPrivacySettingRuleRestrictBots value), required TResult restrictChatMembers(UserPrivacySettingRuleRestrictChatMembers value), required TResult restrictContacts(UserPrivacySettingRuleRestrictContacts value), required TResult restrictUsers(UserPrivacySettingRuleRestrictUsers value)}) → TResult

Available on UserPrivacySettingRule, provided by the UserPrivacySettingRuleExtensions extension

maybeMap<TResult extends Object?>({TResult allowAll(UserPrivacySettingRuleAllowAll value)?, TResult allowBots(UserPrivacySettingRuleAllowBots value)?, TResult allowChatMembers(UserPrivacySettingRuleAllowChatMembers value)?, TResult allowContacts(UserPrivacySettingRuleAllowContacts value)?, TResult allowPremiumUsers(UserPrivacySettingRuleAllowPremiumUsers value)?, TResult allowUsers(UserPrivacySettingRuleAllowUsers value)?, TResult restrictAll(UserPrivacySettingRuleRestrictAll value)?, TResult restrictBots(UserPrivacySettingRuleRestrictBots value)?, TResult restrictChatMembers(UserPrivacySettingRuleRestrictChatMembers value)?, TResult restrictContacts(UserPrivacySettingRuleRestrictContacts value)?, TResult restrictUsers(UserPrivacySettingRuleRestrictUsers value)?, required TResult orElse()}) → TResult

Available on UserPrivacySettingRule, provided by the UserPrivacySettingRuleExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String