UserPrivacySettingRules class final

A list of privacy rules. Rules are matched in the specified order. The first matched rule defines the privacy setting for a given user. If no rule matches, the action is not allowed

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserPrivacySettingRules({required List<UserPrivacySettingRule> rules})

Properties

hashCode int
The hash code for this object.
no setteroverride
rules List<UserPrivacySettingRule>
rules A list of rules
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<UserPrivacySettingRule>? rules}) UserPrivacySettingRules

Available on UserPrivacySettingRules, provided by the UserPrivacySettingRulesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserPrivacySettingRules?

Constants

constructor → const String