UserRating class final

Contains description of user rating

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserRating({required int level, required bool isMaximumLevelReached, required int rating, required int currentLevelRating, required int nextLevelRating})

Properties

currentLevelRating int
currentLevelRating The rating required for the current level
final
hashCode int
The hash code for this object.
no setteroverride
isMaximumLevelReached bool
isMaximumLevelReached True, if the maximum level is reached
final
level int
level The level of the user; may be negative
final
nextLevelRating int
nextLevelRating The rating required for the next level; 0 if the maximum level is reached
final
rating int
rating Numerical value of the rating
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? level, bool? isMaximumLevelReached, int? rating, int? currentLevelRating, int? nextLevelRating}) UserRating

Available on UserRating, provided by the UserRatingExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserRating?

Constants

constructor → const String