UserStatusLastMonth class final

The user is offline, but was online last month

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserStatusLastMonth({required bool byMyPrivacySettings})

Properties

byMyPrivacySettings bool
byMyPrivacySettings Exact user's status is hidden because the current user enabled userPrivacySettingShowStatus privacy setting for the user and has no Telegram Premium
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? byMyPrivacySettings}) UserStatusLastMonth

Available on UserStatusLastMonth, provided by the UserStatusLastMonthExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult empty(UserStatusEmpty value), required TResult lastMonth(UserStatusLastMonth value), required TResult lastWeek(UserStatusLastWeek value), required TResult offline(UserStatusOffline value), required TResult online(UserStatusOnline value), required TResult recently(UserStatusRecently value)}) → TResult

Available on UserStatus, provided by the UserStatusExtensions extension

maybeMap<TResult extends Object?>({TResult empty(UserStatusEmpty value)?, TResult lastMonth(UserStatusLastMonth value)?, TResult lastWeek(UserStatusLastWeek value)?, TResult offline(UserStatusOffline value)?, TResult online(UserStatusOnline value)?, TResult recently(UserStatusRecently value)?, required TResult orElse()}) → TResult

Available on UserStatus, provided by the UserStatusExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String