byMyPrivacySettings property

bool byMyPrivacySettings
final

byMyPrivacySettings Exact user's status is hidden because the current user enabled userPrivacySettingShowStatus privacy setting for the user and has no Telegram Premium

Implementation

final bool byMyPrivacySettings;