UserStatusOnline class final

The user is online

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserStatusOnline({required int expires})

Properties

expires int
expires Point in time (Unix timestamp) when the user's online status will expire
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? expires}) UserStatusOnline

Available on UserStatusOnline, provided by the UserStatusOnlineExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult empty(UserStatusEmpty value), required TResult lastMonth(UserStatusLastMonth value), required TResult lastWeek(UserStatusLastWeek value), required TResult offline(UserStatusOffline value), required TResult online(UserStatusOnline value), required TResult recently(UserStatusRecently value)}) → TResult

Available on UserStatus, provided by the UserStatusExtensions extension

maybeMap<TResult extends Object?>({TResult empty(UserStatusEmpty value)?, TResult lastMonth(UserStatusLastMonth value)?, TResult lastWeek(UserStatusLastWeek value)?, TResult offline(UserStatusOffline value)?, TResult online(UserStatusOnline value)?, TResult recently(UserStatusRecently value)?, required TResult orElse()}) → TResult

Available on UserStatus, provided by the UserStatusExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String