UserSupportInfo class final

Contains custom information about the user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserSupportInfo({FormattedText? message, required String author, required int date})

Properties

author String
author Information author
final
date int
date Information change date
final
hashCode int
The hash code for this object.
no setteroverride
message FormattedText?
message Information message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({FormattedText? message, String? author, int? date}) UserSupportInfo

Available on UserSupportInfo, provided by the UserSupportInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserSupportInfo?

Constants

constructor → const String