UserType class sealed

Represents the type of user. The following types are possible: regular users, deleted users and bots

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult bot(UserTypeBot value), required TResult deleted(UserTypeDeleted value), required TResult regular(UserTypeRegular value), required TResult unknown(UserTypeUnknown value)}) → TResult

Available on UserType, provided by the UserTypeExtensions extension

maybeMap<TResult extends Object?>({TResult bot(UserTypeBot value)?, TResult deleted(UserTypeDeleted value)?, TResult regular(UserTypeRegular value)?, TResult unknown(UserTypeUnknown value)?, required TResult orElse()}) → TResult

Available on UserType, provided by the UserTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserType?
Inherited by: UserTypeBot UserTypeDeleted UserTypeRegular UserTypeUnknown

Constants

constructor → const String