UserTypeBot class final

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

UserTypeBot({required bool canBeEdited, required bool canJoinGroups, required bool canReadAllGroupMessages, required bool hasMainWebApp, required bool hasTopics, required bool allowsUsersToCreateTopics, required bool canManageBots, required bool isInline, required String inlineQueryPlaceholder, required bool supportsGuestQueries, required bool isGuard, required bool needLocation, required bool canConnectToBusiness, required bool canBeAddedToAttachmentMenu, required int activeUserCount})

Properties

activeUserCount int
activeUserCount The number of recently active users of the bot
final
allowsUsersToCreateTopics bool
allowsUsersToCreateTopics True, if users can create and delete topics in the chat with the bot
final
canBeAddedToAttachmentMenu bool
canBeAddedToAttachmentMenu True, if the bot can be added to attachment or side menu
final
canBeEdited bool
canBeEdited True, if the bot is owned by the current user and can be edited using the methods toggleBotUsernameIsActive, reorderBotActiveUsernames, setBotProfilePhoto, setBotName, setBotInfoDescription, and setBotInfoShortDescription
final
canConnectToBusiness bool
canConnectToBusiness True, if the bot supports connection to user accounts for chat automation
final
canJoinGroups bool
canJoinGroups True, if the bot can be invited to basic group and supergroup chats
final
canManageBots bool
canManageBots True, if the bot can manage other bots
final
canReadAllGroupMessages bool
canReadAllGroupMessages True, if the bot can read all messages in basic group or supergroup chats and not just those addressed to the bot. In private and channel chats a bot can always read all messages
final
hashCode int
The hash code for this object.
no setteroverride
hasMainWebApp bool
hasMainWebApp True, if the bot has the main Web App
final
hasTopics bool
hasTopics True, if the bot has topics
final
inlineQueryPlaceholder String
inlineQueryPlaceholder Placeholder for inline queries (displayed on the application input field)
final
isGuard bool
isGuard True, if the bot can be set as a guard bot in supergroup chats
final
isInline bool
isInline True, if the bot supports inline queries
final
needLocation bool
needLocation True, if the location of the user is expected to be sent with every inline query to this bot
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsGuestQueries bool
supportsGuestQueries True, if the bot can be queried by username from any non-secret chat
final

Methods

copyWith({bool? canBeEdited, bool? canJoinGroups, bool? canReadAllGroupMessages, bool? hasMainWebApp, bool? hasTopics, bool? allowsUsersToCreateTopics, bool? canManageBots, bool? isInline, String? inlineQueryPlaceholder, bool? supportsGuestQueries, bool? isGuard, bool? needLocation, bool? canConnectToBusiness, bool? canBeAddedToAttachmentMenu, int? activeUserCount}) UserTypeBot

Available on UserTypeBot, provided by the UserTypeBotExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult bot(UserTypeBot value), required TResult deleted(UserTypeDeleted value), required TResult regular(UserTypeRegular value), required TResult unknown(UserTypeUnknown value)}) → TResult

Available on UserType, provided by the UserTypeExtensions extension

maybeMap<TResult extends Object?>({TResult bot(UserTypeBot value)?, TResult deleted(UserTypeDeleted value)?, TResult regular(UserTypeRegular value)?, TResult unknown(UserTypeUnknown value)?, required TResult orElse()}) → TResult

Available on UserType, provided by the UserTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) UserTypeBot?
Inherited by: UserTypeBot UserTypeDeleted UserTypeRegular UserTypeUnknown
override

Constants

constructor → const String