allowsUsersToCreateTopics property
allowsUsersToCreateTopics True, if users can create and delete topics in the chat with the bot
Implementation
final bool allowsUsersToCreateTopics;
allowsUsersToCreateTopics True, if users can create and delete topics in the chat with the bot
final bool allowsUsersToCreateTopics;