canBeAddedToAttachmentMenu property
canBeAddedToAttachmentMenu True, if the bot can be added to attachment or side menu
Implementation
final bool canBeAddedToAttachmentMenu;
canBeAddedToAttachmentMenu True, if the bot can be added to attachment or side menu
final bool canBeAddedToAttachmentMenu;