supportsGuestQueries property
supportsGuestQueries True, if the bot can be queried by username from any non-secret chat
Implementation
final bool supportsGuestQueries;
supportsGuestQueries True, if the bot can be queried by username from any non-secret chat
final bool supportsGuestQueries;