Users class final

Represents a list of users

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Users({required int totalCount, required List<int> userIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of users found
final
userIds List<int>
userIds A list of user identifiers
final

Methods

copyWith({int? totalCount, List<int>? userIds}) Users

Available on Users, provided by the UsersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Users?

Constants

constructor → const String