ValidateOrderInfo class final

Validates the order information provided by a user and returns the available shipping options for a flexible invoice Returns ValidatedOrderInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ValidateOrderInfo({InputInvoice? inputInvoice, OrderInfo? orderInfo, required bool allowSave})

Properties

allowSave bool
allowSave Pass true to save the order information
final
hashCode int
The hash code for this object.
no setteroverride
inputInvoice InputInvoice?
inputInvoice The invoice
final
orderInfo OrderInfo?
orderInfo The order information, provided by the user; pass null if empty
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputInvoice? inputInvoice, OrderInfo? orderInfo, bool? allowSave}) ValidateOrderInfo

Available on ValidateOrderInfo, provided by the ValidateOrderInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String