ValidatedOrderInfo class final
Contains a temporary identifier of validated order information, which is stored for one hour, and the available shipping options
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ValidatedOrderInfo({required String orderInfoId, required List<
ShippingOption> shippingOptions})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- orderInfoId → String
-
orderInfoId Temporary identifier of the order information
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shippingOptions
→ List<
ShippingOption> -
shippingOptions Available shipping options
final
Methods
-
copyWith(
{String? orderInfoId, List< ShippingOption> ? shippingOptions}) → ValidatedOrderInfo -
Available on ValidatedOrderInfo, provided by the ValidatedOrderInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ValidatedOrderInfo?
Constants
- constructor → const String