VectorPathCommandCubicBezierCurve class final

A cubic B

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

VectorPathCommandCubicBezierCurve({Point? startControlPoint, Point? endControlPoint, Point? endPoint})

Properties

endControlPoint Point?
final
endPoint Point?
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startControlPoint Point?
final

Methods

copyWith({Point? startControlPoint, Point? endControlPoint, Point? endPoint}) VectorPathCommandCubicBezierCurve

Available on VectorPathCommandCubicBezierCurve, provided by the VectorPathCommandCubicBezierCurveExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult cubicBezierCurve(VectorPathCommandCubicBezierCurve value), required TResult line(VectorPathCommandLine value)}) → TResult

Available on VectorPathCommand, provided by the VectorPathCommandExtensions extension

maybeMap<TResult extends Object?>({TResult cubicBezierCurve(VectorPathCommandCubicBezierCurve value)?, TResult line(VectorPathCommandLine value)?, required TResult orElse()}) → TResult

Available on VectorPathCommand, provided by the VectorPathCommandExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String