VectorPathCommandLine class final

A straight line to a given point

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

VectorPathCommandLine({Point? endPoint})

Properties

endPoint Point?
endPoint The end point of the straight line
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Point? endPoint}) VectorPathCommandLine

Available on VectorPathCommandLine, provided by the VectorPathCommandLineExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult cubicBezierCurve(VectorPathCommandCubicBezierCurve value), required TResult line(VectorPathCommandLine value)}) → TResult

Available on VectorPathCommand, provided by the VectorPathCommandExtensions extension

maybeMap<TResult extends Object?>({TResult cubicBezierCurve(VectorPathCommandCubicBezierCurve value)?, TResult line(VectorPathCommandLine value)?, required TResult orElse()}) → TResult

Available on VectorPathCommand, provided by the VectorPathCommandExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) VectorPathCommandLine?
Inherited by: VectorPathCommandCubicBezierCurve VectorPathCommandLine
override

Constants

constructor → const String