canBeReported property
canBeReported True, if the advertisement can be reported to Telegram moderators through reportVideoMessageAdvertisement
Implementation
final bool canBeReported;
canBeReported True, if the advertisement can be reported to Telegram moderators through reportVideoMessageAdvertisement
final bool canBeReported;