VideoNote class final
Describes a video note. The video must be equal in width and height, cropped to a circle, and stored in MPEG4 format
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- VideoNote({required int duration, required String waveform, required int length, Minithumbnail? minithumbnail, Thumbnail? thumbnail, SpeechRecognitionResult? speechRecognitionResult, File? video})
Properties
- duration → int
-
duration Duration of the video, in seconds; as defined by the sender
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Video width and height; as defined by the sender
final
- minithumbnail → Minithumbnail?
-
minithumbnail Video minithumbnail; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speechRecognitionResult → SpeechRecognitionResult?
-
speechRecognitionResult Result of speech recognition in the video note;
may be null
final
- thumbnail → Thumbnail?
-
thumbnail Video thumbnail in JPEG format; as defined by the sender; may
be null
final
- video → File?
-
video File containing the video
final
- waveform → String
-
waveform A waveform representation of the video note's audio in 5-bit
format; may be empty if unknown
final
Methods
-
copyWith(
{int? duration, String? waveform, int? length, Minithumbnail? minithumbnail, Thumbnail? thumbnail, SpeechRecognitionResult? speechRecognitionResult, File? video}) → VideoNote -
Available on VideoNote, provided by the VideoNoteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String