VideoStoryboard class final

Describes a storyboard for a video

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

VideoStoryboard({File? storyboardFile, required int width, required int height, File? mapFile})

Properties

hashCode int
The hash code for this object.
no setteroverride
height int
height Height of a tile
final
mapFile File?
mapFile File that describes mapping of position in the video to a tile in the JPEG file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyboardFile File?
storyboardFile A JPEG file that contains tiled previews of video
final
width int
width Width of a tile
final

Methods

copyWith({File? storyboardFile, int? width, int? height, File? mapFile}) VideoStoryboard

Available on VideoStoryboard, provided by the VideoStoryboardExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) VideoStoryboard?

Constants

constructor → const String