ViewMessages class final
Informs TDLib that messages are being viewed by the user. Sponsored messages must be marked as viewed only when the entire text of the message is shown on the screen (excluding the button). Many useful activities depend on whether the messages are currently being viewed or not (e.g., marking messages as read, incrementing a view counter, updating a view counter, removing deleted messages in supergroups and channels) Returns Ok
- Inheritance
-
- Object
- TdFunction
- ViewMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ViewMessages({required int chatId, required List<
int> messageIds, MessageSource? source, required bool forceRead})
Properties
- chatId → int
-
chatId Chat identifier
final
- forceRead → bool
-
forceRead Pass true to mark as read the specified messages even if the
chat is closed
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messageIds
→ List<
int> -
messageIds The identifiers of the messages being viewed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → MessageSource?
-
source Source of the message view; pass null to guess the source based
on chat open state
final
Methods
-
copyWith(
{int? chatId, List< int> ? messageIds, MessageSource? source, bool? forceRead}) → ViewMessages -
Available on ViewMessages, provided by the ViewMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String