ViewPremiumFeature class final

Informs TDLib that the user viewed detailed information about a Premium feature on the Premium features screen Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ViewPremiumFeature({PremiumFeature? feature})

Properties

feature PremiumFeature?
feature The viewed premium feature
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PremiumFeature? feature}) ViewPremiumFeature

Available on ViewPremiumFeature, provided by the ViewPremiumFeatureExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String