ViewTrendingStickerSets class final

Informs the server that some trending sticker sets have been viewed by the user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ViewTrendingStickerSets({required List<int> stickerSetIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerSetIds List<int>
stickerSetIds Identifiers of viewed trending sticker sets
final

Methods

copyWith({List<int>? stickerSetIds}) ViewTrendingStickerSets

Available on ViewTrendingStickerSets, provided by the ViewTrendingStickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String