ViewVideoMessageAdvertisement class final

Informs TDLib that the user viewed a video message advertisement Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ViewVideoMessageAdvertisement({required int advertisementUniqueId})

Properties

advertisementUniqueId int
advertisementUniqueId Unique identifier of the advertisement
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? advertisementUniqueId}) ViewVideoMessageAdvertisement

Available on ViewVideoMessageAdvertisement, provided by the ViewVideoMessageAdvertisementExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String