WebApp class final

Describes a Web App. Use getInternalLink with internalLinkTypeWebApp to share the Web App

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebApp({required String shortName, required String title, required String description, Photo? photo, Animation? animation})

Properties

animation Animation?
animation Web App animation; may be null
final
description String
param_description Web App description
final
hashCode int
The hash code for this object.
no setteroverride
photo Photo?
photo Web App photo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortName String
shortName Web App short name
final
title String
title Web App title
final

Methods

copyWith({String? shortName, String? title, String? description, Photo? photo, Animation? animation}) WebApp

Available on WebApp, provided by the WebAppExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebApp?

Constants

constructor → const String