WebAppInfo class final

Contains information about a Web App

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebAppInfo({required int launchId, WebAppUrl? url})

Properties

hashCode int
The hash code for this object.
no setteroverride
launchId int
launchId Unique identifier for the Web App launch
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url WebAppUrl?
url The Web App URL to open in a web view
final

Methods

copyWith({int? launchId, WebAppUrl? url}) WebAppInfo

Available on WebAppInfo, provided by the WebAppInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebAppInfo?

Constants

constructor → const String