WebAppOpenModeFullScreen class final

The Web App is opened in the full-screen mode

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebAppOpenModeFullScreen()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult compact(WebAppOpenModeCompact value), required TResult fullScreen(WebAppOpenModeFullScreen value), required TResult fullSize(WebAppOpenModeFullSize value)}) → TResult

Available on WebAppOpenMode, provided by the WebAppOpenModeExtensions extension

maybeMap<TResult extends Object?>({TResult compact(WebAppOpenModeCompact value)?, TResult fullScreen(WebAppOpenModeFullScreen value)?, TResult fullSize(WebAppOpenModeFullSize value)?, required TResult orElse()}) → TResult

Available on WebAppOpenMode, provided by the WebAppOpenModeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String