mode property
mode The mode in which the Web App is opened; pass null to open in webAppOpenModeFullSize
Implementation
final WebAppOpenMode? mode;
mode The mode in which the Web App is opened; pass null to open in webAppOpenModeFullSize
final WebAppOpenMode? mode;