WebAppUrl class final

Contains information about a Web App URL

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebAppUrl({required String url, required bool requireSameOrigin})

Properties

hashCode int
The hash code for this object.
no setteroverride
requireSameOrigin bool
requireSameOrigin True, if events from the Web App must be accepted only from the same origin as the URL
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The Web App URL to open in a web view
final

Methods

copyWith({String? url, bool? requireSameOrigin}) WebAppUrl

Available on WebAppUrl, provided by the WebAppUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebAppUrl?

Constants

constructor → const String