WebBrowserSettings class final

Describes web browser settings

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebBrowserSettings({required bool openExternalBrowser, required List<WebDomainException> externalExceptions, required List<WebDomainException> inAppExceptions, required bool displayCloseButton})

Properties

displayCloseButton bool
displayCloseButton True, if a close button must be shown in the in-app browser; for Android app only
final
externalExceptions List<WebDomainException>
externalExceptions The list of websites which must always be opened in an external browser
final
hashCode int
The hash code for this object.
no setteroverride
inAppExceptions List<WebDomainException>
inAppExceptions The list of websites which must always be opened in the in-app browser
final
openExternalBrowser bool
openExternalBrowser True, if links are opened in an external browser by default
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? openExternalBrowser, List<WebDomainException>? externalExceptions, List<WebDomainException>? inAppExceptions, bool? displayCloseButton}) WebBrowserSettings

Available on WebBrowserSettings, provided by the WebBrowserSettingsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebBrowserSettings?

Constants

constructor → const String