externalExceptions property
externalExceptions The list of websites which must always be opened in an external browser
Implementation
final List<WebDomainException> externalExceptions;
externalExceptions The list of websites which must always be opened in an external browser
final List<WebDomainException> externalExceptions;