inAppExceptions property
inAppExceptions The list of websites which must always be opened in the in-app browser
Implementation
final List<WebDomainException> inAppExceptions;
inAppExceptions The list of websites which must always be opened in the in-app browser
final List<WebDomainException> inAppExceptions;