WebBrowserTypeExternal class final

An external web browser

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebBrowserTypeExternal()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult external(WebBrowserTypeExternal value), required TResult inApp(WebBrowserTypeInApp value)}) → TResult

Available on WebBrowserType, provided by the WebBrowserTypeExtensions extension

maybeMap<TResult extends Object?>({TResult external(WebBrowserTypeExternal value)?, TResult inApp(WebBrowserTypeInApp value)?, required TResult orElse()}) → TResult

Available on WebBrowserType, provided by the WebBrowserTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebBrowserTypeExternal?
Inherited by: WebBrowserTypeExternal WebBrowserTypeInApp
override

Constants

constructor → const String