WebDomainException class final

Describes an exception for built-in browser usage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WebDomainException({required String url, required String domain, required String title, required int faviconCustomEmojiId})

Properties

domain String
domain Domain of the URL. All URLs on the domain and subdomains of the domain are subject to the exception
final
faviconCustomEmojiId int
faviconCustomEmojiId Identifier of the custom emoji with favicon of the website; may be 0 if unknown, in which case the first letter of the domain must be used
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
title Title of the website
final
url String
url URL for which the exception is done
final

Methods

copyWith({String? url, String? domain, String? title, int? faviconCustomEmojiId}) WebDomainException

Available on WebDomainException, provided by the WebDomainExceptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) WebDomainException?

Constants

constructor → const String