faviconCustomEmojiId property
faviconCustomEmojiId Identifier of the custom emoji with favicon of the website; may be 0 if unknown, in which case the first letter of the domain must be used
Implementation
final int faviconCustomEmojiId;
faviconCustomEmojiId Identifier of the custom emoji with favicon of the website; may be 0 if unknown, in which case the first letter of the domain must be used
final int faviconCustomEmojiId;