WriteGeneratedFilePart class final

Writes a part of a generated file. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct write to the destination file Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

WriteGeneratedFilePart({required int generationId, required int offset, required String data})

Properties

data String
data The data to write
final
generationId int
generationId The identifier of the generation process
final
hashCode int
The hash code for this object.
no setteroverride
offset int
offset The offset from which to write the data to the file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? generationId, int? offset, String? data}) WriteGeneratedFilePart

Available on WriteGeneratedFilePart, provided by the WriteGeneratedFilePartExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String