AcceptCall class final
Accepts an incoming call Returns Ok
- Inheritance
-
- Object
- TdFunction
- AcceptCall
- Available extensions
- Annotations
-
- @immutable
Constructors
- AcceptCall({required int callId, CallProtocol? protocol})
Properties
- callId → int
-
callId Call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- protocol → CallProtocol?
-
protocol The call protocols supported by the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? callId, CallProtocol? protocol}) → AcceptCall -
Available on AcceptCall, provided by the AcceptCallExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String