AcceptedGiftTypes class final
Describes gift types that are accepted by a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AcceptedGiftTypes({required bool unlimitedGifts, required bool limitedGifts, required bool upgradedGifts, required bool giftsFromChannels, })
Properties
- giftsFromChannels → bool
-
giftsFromChannels True, if gifts from channels are accepted subject to
other restrictions
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limitedGifts → bool
-
limitedGifts True, if limited regular gifts are accepted
final
-
premiumSubscription True, if Telegram Premium subscription is accepted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unlimitedGifts → bool
-
unlimitedGifts True, if unlimited regular gifts are accepted
final
- upgradedGifts → bool
-
upgradedGifts True, if upgraded gifts and regular gifts that can be
upgraded for free are accepted
final
Methods
-
copyWith(
{bool? unlimitedGifts, bool? limitedGifts, bool? upgradedGifts, bool? giftsFromChannels, }) → AcceptedGiftTypes -
Available on AcceptedGiftTypes, provided by the AcceptedGiftTypesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AcceptedGiftTypes?
Constants
- constructor → const String