AccountTtl class final
Contains information about the period of inactivity after which the current user's account will automatically be deleted
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AccountTtl({required int days})
Properties
Methods
-
copyWith(
{int? days}) → AccountTtl -
Available on AccountTtl, provided by the AccountTtlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AccountTtl?
Constants
- constructor → const String