AddChatMember class final
Adds a new member to a chat; requires can_invite_users member right. Members can't be added to private or secret chats. Returns information about members that weren't added Returns FailedToAddMembers
- Inheritance
-
- Object
- TdFunction
- AddChatMember
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddChatMember({required int chatId, required int userId, required int forwardLimit})
Properties
- chatId → int
-
chatId Chat identifier
final
- forwardLimit → int
-
forwardLimit The number of earlier messages from the chat to be
forwarded to the new member; up to 100. Ignored for supergroups and
channels, or if the added user is a bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user
final
Methods
-
copyWith(
{int? chatId, int? userId, int? forwardLimit}) → AddChatMember -
Available on AddChatMember, provided by the AddChatMemberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String