AddChecklistTasks class final

Adds tasks to a checklist in a message Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddChecklistTasks({required int chatId, required int messageId, required List<InputChecklistTask> tasks})

Properties

chatId int
chatId Identifier of the chat with the message
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message containing the checklist. Use messageProperties.can_add_tasks to check whether the tasks can be added
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks List<InputChecklistTask>
tasks List of added tasks
final

Methods

copyWith({int? chatId, int? messageId, List<InputChecklistTask>? tasks}) AddChecklistTasks

Available on AddChecklistTasks, provided by the AddChecklistTasksExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String