AddFavoriteSticker class final
Adds a new sticker to the list of favorite stickers. The new sticker is added to the top of the list. If the sticker was already in the list, it is removed from the list first. Only stickers belonging to a sticker set or in WEBP or WEBM format can be added to this list. Emoji stickers can't be added to favorite stickers Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddFavoriteSticker
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddFavoriteSticker({InputFile? sticker})
Properties
Methods
-
copyWith(
{InputFile? sticker}) → AddFavoriteSticker -
Available on AddFavoriteSticker, provided by the AddFavoriteStickerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String