AddLoginPasskey class final

Adds a passkey allowed to be used for the login by the current user and returns the added passkey. Call getPasskeyParameters to get parameters for creating of the passkey Returns Passkey

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddLoginPasskey({required String clientData, required String attestationObject})

Properties

attestationObject String
attestationObject Passkey attestation object
final
clientData String
clientData JSON-encoded client data
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? clientData, String? attestationObject}) AddLoginPasskey

Available on AddLoginPasskey, provided by the AddLoginPasskeyExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String