AddMessageReaction class final
Adds a reaction or a tag to a message. Use getMessageAvailableReactions to receive the list of available reactions for the message Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddMessageReaction
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddMessageReaction({required int chatId, required int messageId, ReactionType? reactionType, required bool isBig, required bool updateRecentReactions})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isBig → bool
-
isBig Pass true if the reaction is added with a big animation
final
- messageId → int
-
messageId Identifier of the message
final
- reactionType → ReactionType?
-
reactionType Type of the reaction to add. Use
addPendingPaidMessageReaction instead to add the paid reaction
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateRecentReactions → bool
-
updateRecentReactions Pass true if the reaction needs to be added to
recent reactions; tags are never added to the list of recent reactions
final
Methods
-
copyWith(
{int? chatId, int? messageId, ReactionType? reactionType, bool? isBig, bool? updateRecentReactions}) → AddMessageReaction -
Available on AddMessageReaction, provided by the AddMessageReactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String