AddOffer class final
Sends a suggested post based on a previously sent message in a channel direct messages chat. Can be also used to suggest price or time change for an existing suggested post. Returns the sent message Returns Message
- Inheritance
-
- Object
- TdFunction
- AddOffer
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddOffer({required int chatId, required int messageId, MessageSendOptions? options})
Properties
- chatId → int
-
chatId Identifier of the channel direct messages chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message in the chat which will be sent as
suggested post. Use messageProperties.can_add_offer to check whether an
offer can be added or messageProperties.can_edit_suggested_post_info to
check whether price or time of sending of the post can be changed
final
- options → MessageSendOptions?
-
options Options to be used to send the message. New information about
the suggested post must always be specified
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, MessageSendOptions? options}) → AddOffer -
Available on AddOffer, provided by the AddOfferExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String