AddPendingLiveStoryReaction class final
Adds pending paid reaction in a live story group call. Can't be used in live stories posted by the current user. Call commitPendingLiveStoryReactions or removePendingLiveStoryReactions to actually send all pending reactions when the undo timer is over or abort the sending Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddPendingLiveStoryReaction
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddPendingLiveStoryReaction({required int groupCallId, required int starCount})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount Number of Telegram Stars to be used for the reaction. The
total number of pending paid reactions must not exceed
getOption("paid_group_call_message_star_count_max")
final
Methods
-
copyWith(
{int? groupCallId, int? starCount}) → AddPendingLiveStoryReaction -
Available on AddPendingLiveStoryReaction, provided by the AddPendingLiveStoryReactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String