AddPendingPaidMessageReaction class final
Adds the paid message reaction to a message. Use getMessageAvailableReactions to check whether the reaction is available for the message Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddPendingPaidMessageReaction
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddPendingPaidMessageReaction({required int chatId, required int messageId, required int starCount, PaidReactionType? type})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount Number of Telegram Stars to be used for the reaction. The
total number of pending paid reactions must not exceed
getOption("paid_reaction_star_count_max")
final
- type → PaidReactionType?
-
type Type of the paid reaction; pass null if the user didn't choose
reaction type explicitly, for example, the reaction is set from the
message bubble
final
Methods
-
copyWith(
{int? chatId, int? messageId, int? starCount, PaidReactionType? type}) → AddPendingPaidMessageReaction -
Available on AddPendingPaidMessageReaction, provided by the AddPendingPaidMessageReactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String