AddPollOption class final

Adds an option to a poll Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AddPollOption({required int chatId, required int messageId, InputPollOption? option})

Properties

chatId int
chatId Identifier of the chat to which the poll belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message containing the poll. Use messagePoll.can_add_option to check whether an option can be added
final
option InputPollOption?
option The new option
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, InputPollOption? option}) AddPollOption

Available on AddPollOption, provided by the AddPollOptionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String