AddRecentlyFoundChat class final
Adds a chat to the list of recently found chats. The chat is added to the beginning of the list. If the chat is already in the list, it will be removed from the list first Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddRecentlyFoundChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddRecentlyFoundChat({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → AddRecentlyFoundChat -
Available on AddRecentlyFoundChat, provided by the AddRecentlyFoundChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String