AddSavedAnimation class final
Manually adds a new animation to the list of saved animations. The new animation is added to the beginning of the list. If the animation was already in the list, it is removed first. Only non-secret video animations with MIME type "video/mp4" can be added to the list Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddSavedAnimation
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddSavedAnimation({InputFile? animation})
Properties
- animation → InputFile?
-
animation The animation file to be added. Only animations known to the
server (i.e., successfully sent via a message) can be added to the list
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputFile? animation}) → AddSavedAnimation -
Available on AddSavedAnimation, provided by the AddSavedAnimationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String