AddSavedNotificationSound class final
Adds a new notification sound to the list of saved notification sounds. The new notification sound is added to the top of the list. If it is already in the list, its position isn't changed Returns NotificationSound
- Inheritance
-
- Object
- TdFunction
- AddSavedNotificationSound
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddSavedNotificationSound({InputFile? sound})
Properties
Methods
-
copyWith(
{InputFile? sound}) → AddSavedNotificationSound -
Available on AddSavedNotificationSound, provided by the AddSavedNotificationSoundExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String