AddStickerToSet class final
Adds a new sticker to a set Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddStickerToSet
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddStickerToSet({required int userId, required String name, NewSticker? sticker})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Sticker set name. The sticker set must be owned by the current
user, and contain less than 200 stickers for custom emoji sticker sets and
less than 120 otherwise
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → NewSticker?
-
sticker Sticker to add to the set
final
- userId → int
-
userId Sticker set owner; ignored for regular users
final
Methods
-
copyWith(
{int? userId, String? name, NewSticker? sticker}) → AddStickerToSet -
Available on AddStickerToSet, provided by the AddStickerToSetExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String