AddTextCompositionStyle class final
Adds a custom text composition style to the list of used by the user styles. May return an error with a message "TONES_SAVED_TOO_MANY" if the maximum number of added custom styles getOption("added_text_composition_style_count_max") has been reached Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddTextCompositionStyle
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddTextCompositionStyle({required String name})
Properties
Methods
-
copyWith(
{String? name}) → AddTextCompositionStyle -
Available on AddTextCompositionStyle, provided by the AddTextCompositionStyleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String