AddWebBrowserSettingsException class final
Adds a special handling for the opening of the specified URL Returns Ok
- Inheritance
-
- Object
- TdFunction
- AddWebBrowserSettingsException
- Available extensions
- Annotations
-
- @immutable
Constructors
- AddWebBrowserSettingsException({required bool openExternalBrowser, required String url})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- openExternalBrowser → bool
-
openExternalBrowser Pass true if the specified website must be opened in
an external browser; pass false to open it in the in-app browser. There
can be at most 100 exceptions in each list of the exceptions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url URL of the website
final
Methods
-
copyWith(
{bool? openExternalBrowser, String? url}) → AddWebBrowserSettingsException -
Available on AddWebBrowserSettingsException, provided by the AddWebBrowserSettingsExceptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String