AffiliateProgramParameters class final
Describes parameters of an affiliate program
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AffiliateProgramParameters({required int commissionPerMille, required int monthCount})
Properties
- commissionPerMille → int
-
commissionPerMille The number of Telegram Stars received by the
affiliate for each 1000 Telegram Stars received by the program owner;
getOption("affiliate_program_commission_per_mille_min")-getOption("affiliate_program_commission_per_mille_max")
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- monthCount → int
-
monthCount Number of months the program will be active; 0-36. If 0, then
the program is eternal
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? commissionPerMille, int? monthCount}) → AffiliateProgramParameters -
Available on AffiliateProgramParameters, provided by the AffiliateProgramParametersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AffiliateProgramParameters?
Constants
- constructor → const String