AlternativeVideo class final
Describes an alternative re-encoded quality of a video file
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- codec → String
-
codec Codec used for video file encoding, for example, "h264", "h265",
"av1", or "av01"
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Video height
final
- hlsFile → File?
-
hlsFile HLS file describing the video
final
- id → int
-
id Unique identifier of the alternative video, which is used in the HLS
file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- video → File?
-
video File containing the video
final
- width → int
-
width Video width
final
Methods
-
copyWith(
{int? id, int? width, int? height, String? codec, File? hlsFile, File? video}) → AlternativeVideo -
Available on AlternativeVideo, provided by the AlternativeVideoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AlternativeVideo?
Constants
- constructor → const String