AnimatedChatPhoto class final
Animated variant of a chat photo in MPEG4 format
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AnimatedChatPhoto({required int length, File? file, required double mainFrameTimestamp})
Properties
- file → File?
-
file Information about the animation file
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Animation width and height
final
- mainFrameTimestamp → double
-
mainFrameTimestamp Timestamp of the frame, used as a static chat photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? length, File? file, double? mainFrameTimestamp}) → AnimatedChatPhoto -
Available on AnimatedChatPhoto, provided by the AnimatedChatPhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AnimatedChatPhoto?
Constants
- constructor → const String