Animations class final
Represents a list of animations
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Animations({required List<
Animation> animations})
Properties
-
animations
→ List<
Animation> -
animations List of animations
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< Animation> ? animations}) → Animations -
Available on Animations, provided by the AnimationsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → Animations?
Constants
- constructor → const String