AnswerChatJoinRequestQuery class final
Sets the result of a chat join query; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- AnswerChatJoinRequestQuery
- Available extensions
- Annotations
-
- @immutable
Constructors
- AnswerChatJoinRequestQuery({required int queryId, ChatJoinRequestResult? result, required String url})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- queryId → int
-
queryId Identifier of the query
final
- result → ChatJoinRequestResult?
-
result The result
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url URL of the Web App to open
final
Methods
-
copyWith(
{int? queryId, ChatJoinRequestResult? result, String? url}) → AnswerChatJoinRequestQuery -
Available on AnswerChatJoinRequestQuery, provided by the AnswerChatJoinRequestQueryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String