AnswerGuestQuery class final
Sets the result of a guest query; for bots only Returns InlineMessageId
- Inheritance
-
- Object
- TdFunction
- AnswerGuestQuery
- Available extensions
- Annotations
-
- @immutable
Constructors
- AnswerGuestQuery({required int guestQueryId, InputInlineQueryResult? result})
Properties
- guestQueryId → int
-
guestQueryId Identifier of the guest query
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- result → InputInlineQueryResult?
-
result The result of the query
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? guestQueryId, InputInlineQueryResult? result}) → AnswerGuestQuery -
Available on AnswerGuestQuery, provided by the AnswerGuestQueryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String