AnswerInlineQuery class final
Sets the result of an inline query; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- AnswerInlineQuery
- Available extensions
- Annotations
-
- @immutable
Constructors
-
AnswerInlineQuery({required int inlineQueryId, required bool isPersonal, InlineQueryResultsButton? button, required List<
InputInlineQueryResult> results, required int cacheTime, required String nextOffset})
Properties
-
button Button to be shown above inline query results; pass null if none
final
- cacheTime → int
-
cacheTime Allowed time to cache the results of the query, in seconds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inlineQueryId → int
-
inlineQueryId Identifier of the inline query
final
- isPersonal → bool
-
isPersonal Pass true if results may be cached and returned only for the
user who sent the query. By default, results may be returned to any user
who sends the same query
final
- nextOffset → String
-
nextOffset Offset for the next inline query; pass an empty string if
there are no more results
final
-
results
→ List<
InputInlineQueryResult> -
results The results of the query
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? inlineQueryId, bool? isPersonal, InlineQueryResultsButton? button, List< InputInlineQueryResult> ? results, int? cacheTime, String? nextOffset}) → AnswerInlineQuery -
Available on AnswerInlineQuery, provided by the AnswerInlineQueryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String