ApproveSuggestedPost class final
Approves a suggested post in a channel direct messages chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- ApproveSuggestedPost
- Available extensions
- Annotations
-
- @immutable
Constructors
- ApproveSuggestedPost({required int chatId, required int messageId, required int sendDate})
Properties
- chatId → int
-
chatId Chat identifier of the channel direct messages chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message with the suggested post. Use
messageProperties.can_be_approved to check whether the suggested post can
be approved
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendDate → int
-
sendDate Point in time (Unix timestamp) when the post is expected to be
published; pass 0 if the date has already been chosen. If specified, then
the date must be in the future, but at most
getOption("suggested_post_send_delay_max") seconds in the future
final
Methods
-
copyWith(
{int? chatId, int? messageId, int? sendDate}) → ApproveSuggestedPost -
Available on ApproveSuggestedPost, provided by the ApproveSuggestedPostExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String