AssignStoreTransaction class final

Informs server about an in-store purchase. For official applications only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AssignStoreTransaction({StoreTransaction? transaction, StorePaymentPurpose? purpose})

Properties

hashCode int
The hash code for this object.
no setteroverride
purpose StorePaymentPurpose?
purpose Transaction purpose
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transaction StoreTransaction?
transaction Information about the transaction
final

Methods

copyWith({StoreTransaction? transaction, StorePaymentPurpose? purpose}) AssignStoreTransaction

Available on AssignStoreTransaction, provided by the AssignStoreTransactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String