AttachmentMenuBotColor class final
Describes a color to highlight a bot added to attachment menu
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AttachmentMenuBotColor({required int lightColor, required int darkColor})
Properties
- darkColor → int
-
darkColor Color in the RGB format for dark themes
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lightColor → int
-
lightColor Color in the RGB format for light themes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? lightColor, int? darkColor}) → AttachmentMenuBotColor -
Available on AttachmentMenuBotColor, provided by the AttachmentMenuBotColorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AttachmentMenuBotColor?
Constants
- constructor → const String