AuctionRound class final
Describes a round of an auction
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AuctionRound({required int number, required int duration, required int extendTime, required int topWinnerCount})
Properties
- duration → int
-
duration Duration of the round, in seconds
final
- extendTime → int
-
extendTime The number of seconds for which the round will be extended if
there are changes in the top winners
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- number → int
-
number 1-based number of the round
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topWinnerCount → int
-
topWinnerCount The number of top winners who trigger round extension if
changed
final
Methods
-
copyWith(
{int? number, int? duration, int? extendTime, int? topWinnerCount}) → AuctionRound -
Available on AuctionRound, provided by the AuctionRoundExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AuctionRound?
Constants
- constructor → const String