Audio class final
Describes an audio file. Audio is usually in MP3 or M4A format
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- albumCoverMinithumbnail → Minithumbnail?
-
albumCoverMinithumbnail The minithumbnail of the album cover; may be
null
final
- albumCoverThumbnail → Thumbnail?
-
albumCoverThumbnail The thumbnail of the album cover in JPEG format; as
defined by the sender. The full size thumbnail is expected to be extracted
from the downloaded audio file; may be null
final
- audio → File?
-
audio File containing the audio
final
- duration → int
-
duration Duration of the audio, in seconds; as defined by the sender
final
-
externalAlbumCovers
→ List<
Thumbnail> -
externalAlbumCovers Album cover variants to use if the downloaded audio
file contains no album cover. Provided thumbnail dimensions are
approximate
final
- fileName → String
-
fileName Original name of the file; as defined by the sender
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mimeType → String
-
mimeType The MIME type of the file; as defined by the sender
final
- performer → String
-
performer Performer of the audio; as defined by the sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Title of the audio; as defined by the sender
final
Methods
-
copyWith(
{int? duration, String? title, String? performer, String? fileName, String? mimeType, Minithumbnail? albumCoverMinithumbnail, Thumbnail? albumCoverThumbnail, List< Thumbnail> ? externalAlbumCovers, File? audio}) → Audio -
Available on Audio, provided by the AudioExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String