AuthenticationCodeInfo class final

Information about the authentication code that was sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AuthenticationCodeInfo({required String phoneNumber, AuthenticationCodeType? type, AuthenticationCodeType? nextType, required int timeout})

Properties

hashCode int
The hash code for this object.
no setteroverride
nextType AuthenticationCodeType?
nextType The way the next code will be sent to the user; may be null
final
phoneNumber String
phoneNumber A phone number that is being authenticated
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int
timeout Timeout before the code can be re-sent, in seconds
final
type AuthenticationCodeType?
type The way the code was sent to the user
final

Methods

copyWith({String? phoneNumber, AuthenticationCodeType? type, AuthenticationCodeType? nextType, int? timeout}) AuthenticationCodeInfo

Available on AuthenticationCodeInfo, provided by the AuthenticationCodeInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AuthenticationCodeInfo?

Constants

constructor → const String