AuthenticationCodeTypeFirebaseIos class final
A digit-only authentication code is delivered via Firebase Authentication to the official iOS application
- Inheritance
-
- Object
- TdObject
- AuthenticationCodeType
- AuthenticationCodeTypeFirebaseIos
- Available extensions
- Annotations
-
- @immutable
Constructors
- AuthenticationCodeTypeFirebaseIos({required String receipt, required int pushTimeout, required int length})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Length of the code
final
- pushTimeout → int
-
pushTimeout Time after the next authentication method is expected to be
used if verification push notification isn't received, in seconds
final
- receipt → String
-
receipt Receipt of successful application token validation to compare
with receipt from push notification
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? receipt, int? pushTimeout, int? length}) → AuthenticationCodeTypeFirebaseIos -
Available on AuthenticationCodeTypeFirebaseIos, provided by the AuthenticationCodeTypeFirebaseIosExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult call(AuthenticationCodeTypeCall value), required TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value), required TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value), required TResult flashCall(AuthenticationCodeTypeFlashCall value), required TResult fragment(AuthenticationCodeTypeFragment value), required TResult missedCall(AuthenticationCodeTypeMissedCall value), required TResult sms(AuthenticationCodeTypeSms value), required TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value), required TResult smsWord(AuthenticationCodeTypeSmsWord value), required TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult call(AuthenticationCodeTypeCall value)?, TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value)?, TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value)?, TResult flashCall(AuthenticationCodeTypeFlashCall value)?, TResult fragment(AuthenticationCodeTypeFragment value)?, TResult missedCall(AuthenticationCodeTypeMissedCall value)?, TResult sms(AuthenticationCodeTypeSms value)?, TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value)?, TResult smsWord(AuthenticationCodeTypeSmsWord value)?, TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)?, required TResult orElse()}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AuthenticationCodeTypeFirebaseIos? -
Inherited by:
AuthenticationCodeTypeCall
AuthenticationCodeTypeFirebaseAndroid
AuthenticationCodeTypeFirebaseIos
AuthenticationCodeTypeFlashCall
AuthenticationCodeTypeFragment
AuthenticationCodeTypeMissedCall
AuthenticationCodeTypeSms
AuthenticationCodeTypeSmsPhrase
AuthenticationCodeTypeSmsWord
AuthenticationCodeTypeTelegramMessage
override
Constants
- constructor → const String