AuthenticationCodeTypeMissedCall class final
An authentication code is delivered by an immediately canceled call to the specified phone number. The last digits of the phone number that calls are the code that must be entered manually by the user
- Inheritance
-
- Object
- TdObject
- AuthenticationCodeType
- AuthenticationCodeTypeMissedCall
- Available extensions
- Annotations
-
- @immutable
Constructors
- AuthenticationCodeTypeMissedCall({required String phoneNumberPrefix, required int length})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Number of digits in the code, excluding the prefix
final
- phoneNumberPrefix → String
-
phoneNumberPrefix Prefix of the phone number from which the call will be
made
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? phoneNumberPrefix, int? length}) → AuthenticationCodeTypeMissedCall -
Available on AuthenticationCodeTypeMissedCall, provided by the AuthenticationCodeTypeMissedCallExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult call(AuthenticationCodeTypeCall value), required TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value), required TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value), required TResult flashCall(AuthenticationCodeTypeFlashCall value), required TResult fragment(AuthenticationCodeTypeFragment value), required TResult missedCall(AuthenticationCodeTypeMissedCall value), required TResult sms(AuthenticationCodeTypeSms value), required TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value), required TResult smsWord(AuthenticationCodeTypeSmsWord value), required TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult call(AuthenticationCodeTypeCall value)?, TResult firebaseAndroid(AuthenticationCodeTypeFirebaseAndroid value)?, TResult firebaseIos(AuthenticationCodeTypeFirebaseIos value)?, TResult flashCall(AuthenticationCodeTypeFlashCall value)?, TResult fragment(AuthenticationCodeTypeFragment value)?, TResult missedCall(AuthenticationCodeTypeMissedCall value)?, TResult sms(AuthenticationCodeTypeSms value)?, TResult smsPhrase(AuthenticationCodeTypeSmsPhrase value)?, TResult smsWord(AuthenticationCodeTypeSmsWord value)?, TResult telegramMessage(AuthenticationCodeTypeTelegramMessage value)?, required TResult orElse()}) → TResult -
Available on AuthenticationCodeType, provided by the AuthenticationCodeTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AuthenticationCodeTypeMissedCall? -
Inherited by:
AuthenticationCodeTypeCall
AuthenticationCodeTypeFirebaseAndroid
AuthenticationCodeTypeFirebaseIos
AuthenticationCodeTypeFlashCall
AuthenticationCodeTypeFragment
AuthenticationCodeTypeMissedCall
AuthenticationCodeTypeSms
AuthenticationCodeTypeSmsPhrase
AuthenticationCodeTypeSmsWord
AuthenticationCodeTypeTelegramMessage
override
Constants
- constructor → const String