AutosaveSettings class final
Describes autosave settings
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
AutosaveSettings({ScopeAutosaveSettings? privateChatSettings, ScopeAutosaveSettings? groupSettings, ScopeAutosaveSettings? channelSettings, required List<
AutosaveSettingsException> exceptions})
Properties
- channelSettings → ScopeAutosaveSettings?
-
channelSettings Default autosave settings for channel chats
final
-
exceptions
→ List<
AutosaveSettingsException> -
exceptions Autosave settings for specific chats
final
- groupSettings → ScopeAutosaveSettings?
-
groupSettings Default autosave settings for basic group and supergroup
chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- privateChatSettings → ScopeAutosaveSettings?
-
privateChatSettings Default autosave settings for private chats
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ScopeAutosaveSettings? privateChatSettings, ScopeAutosaveSettings? groupSettings, ScopeAutosaveSettings? channelSettings, List< AutosaveSettingsException> ? exceptions}) → AutosaveSettings -
Available on AutosaveSettings, provided by the AutosaveSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AutosaveSettings?
Constants
- constructor → const String