AutosaveSettingsException class final
Contains autosave settings for a chat, which overrides default settings for the corresponding scope
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AutosaveSettingsException({required int chatId, ScopeAutosaveSettings? settings})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → ScopeAutosaveSettings?
-
settings Autosave settings for the chat
final
Methods
-
copyWith(
{int? chatId, ScopeAutosaveSettings? settings}) → AutosaveSettingsException -
Available on AutosaveSettingsException, provided by the AutosaveSettingsExceptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AutosaveSettingsException?
Constants
- constructor → const String