AvailableGift class final
Describes a gift that is available for purchase
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- AvailableGift({Gift? gift, required int resaleCount, required int minResaleStarCount, required String title})
Properties
- gift → Gift?
-
gift The gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- minResaleStarCount → int
-
minResaleStarCount The minimum price for the gifts available for resale
in Telegram Star equivalent; 0 if there are no such gifts
final
- resaleCount → int
-
resaleCount Number of gifts that are available for resale
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title The title of the upgraded gift; empty if the gift isn't available
for resale
final
Methods
-
copyWith(
{Gift? gift, int? resaleCount, int? minResaleStarCount, String? title}) → AvailableGift -
Available on AvailableGift, provided by the AvailableGiftExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → AvailableGift?
Constants
- constructor → const String