AvailableGifts class final

Contains a list of gifts that can be sent to another user or channel chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

AvailableGifts({required List<AvailableGift> gifts})

Properties

gifts List<AvailableGift>
gifts The list of gifts
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<AvailableGift>? gifts}) AvailableGifts

Available on AvailableGifts, provided by the AvailableGiftsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) AvailableGifts?

Constants

constructor → const String