BackgroundFillGradient class final
Describes a gradient fill of a background
- Inheritance
-
- Object
- TdObject
- BackgroundFill
- BackgroundFillGradient
- Available extensions
- Annotations
-
- @immutable
Constructors
- BackgroundFillGradient({required int topColor, required int bottomColor, required int rotationAngle})
Properties
- bottomColor → int
-
bottomColor A bottom color of the background in the RGB format
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- rotationAngle → int
-
rotationAngle Clockwise rotation angle of the gradient, in degrees;
0-359. Must always be divisible by 45
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topColor → int
-
topColor A top color of the background in the RGB format
final
Methods
-
copyWith(
{int? topColor, int? bottomColor, int? rotationAngle}) → BackgroundFillGradient -
Available on BackgroundFillGradient, provided by the BackgroundFillGradientExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult freeformGradient(BackgroundFillFreeformGradient value), required TResult gradient(BackgroundFillGradient value), required TResult solid(BackgroundFillSolid value)}) → TResult -
Available on BackgroundFill, provided by the BackgroundFillExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult freeformGradient(BackgroundFillFreeformGradient value)?, TResult gradient(BackgroundFillGradient value)?, TResult solid(BackgroundFillSolid value)?, required TResult orElse()}) → TResult -
Available on BackgroundFill, provided by the BackgroundFillExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BackgroundFillGradient? -
Inherited by:
BackgroundFillFreeformGradient
BackgroundFillGradient
BackgroundFillSolid
override
Constants
- constructor → const String