BackgroundTypeFill class final
A filled background
- Inheritance
-
- Object
- TdObject
- BackgroundType
- BackgroundTypeFill
- Available extensions
- Annotations
-
- @immutable
Constructors
- BackgroundTypeFill({BackgroundFill? fill})
Properties
- fill → BackgroundFill?
-
fill The background fill
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BackgroundFill? fill}) → BackgroundTypeFill -
Available on BackgroundTypeFill, provided by the BackgroundTypeFillExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chatTheme(BackgroundTypeChatTheme value), required TResult fill(BackgroundTypeFill value), required TResult pattern(BackgroundTypePattern value), required TResult wallpaper(BackgroundTypeWallpaper value)}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chatTheme(BackgroundTypeChatTheme value)?, TResult fill(BackgroundTypeFill value)?, TResult pattern(BackgroundTypePattern value)?, TResult wallpaper(BackgroundTypeWallpaper value)?, required TResult orElse()}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BackgroundTypeFill? -
Inherited by:
BackgroundTypeChatTheme
BackgroundTypeFill
BackgroundTypePattern
BackgroundTypeWallpaper
override
Constants
- constructor → const String