BackgroundTypePattern class final
A PNG or TGV (gzipped subset of SVG with MIME type "application/x-tgwallpattern") pattern to be combined with the background fill chosen by the user
- Inheritance
-
- Object
- TdObject
- BackgroundType
- BackgroundTypePattern
- Available extensions
- Annotations
-
- @immutable
Constructors
- BackgroundTypePattern({BackgroundFill? fill, required int intensity, required bool isInverted, required bool isMoving})
Properties
- fill → BackgroundFill?
-
fill Fill of the background
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- intensity → int
-
intensity Intensity of the pattern when it is shown above the filled
background; 0-100
final
- isInverted → bool
-
isInverted True, if the background fill must be applied only to the
pattern itself. All other pixels are black in this case. For dark themes
only
final
- isMoving → bool
-
isMoving True, if the background needs to be slightly moved when device
is tilted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BackgroundFill? fill, int? intensity, bool? isInverted, bool? isMoving}) → BackgroundTypePattern -
Available on BackgroundTypePattern, provided by the BackgroundTypePatternExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chatTheme(BackgroundTypeChatTheme value), required TResult fill(BackgroundTypeFill value), required TResult pattern(BackgroundTypePattern value), required TResult wallpaper(BackgroundTypeWallpaper value)}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chatTheme(BackgroundTypeChatTheme value)?, TResult fill(BackgroundTypeFill value)?, TResult pattern(BackgroundTypePattern value)?, TResult wallpaper(BackgroundTypeWallpaper value)?, required TResult orElse()}) → TResult -
Available on BackgroundType, provided by the BackgroundTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BackgroundTypePattern? -
Inherited by:
BackgroundTypeChatTheme
BackgroundTypeFill
BackgroundTypePattern
BackgroundTypeWallpaper
override
Constants
- constructor → const String