BasicGroup class final

Represents a basic group of 0-200 users (must be upgraded to a supergroup to accommodate more than 200 users)

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BasicGroup({required int id, required int memberCount, ChatMemberStatus? status, required bool isActive, required int upgradedToSupergroupId})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Group identifier
final
isActive bool
isActive True, if the group is active
final
memberCount int
memberCount Number of members in the group
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ChatMemberStatus?
status Status of the current user in the group
final
upgradedToSupergroupId int
upgradedToSupergroupId Identifier of the supergroup to which this group was upgraded; 0 if none
final

Methods

copyWith({int? id, int? memberCount, ChatMemberStatus? status, bool? isActive, int? upgradedToSupergroupId}) BasicGroup

Available on BasicGroup, provided by the BasicGroupExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BasicGroup?

Constants

constructor → const String