Birthdate class final

Represents a birthdate of a user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Birthdate({required int day, required int month, required int year})

Properties

day int
day Day of the month; 1-31
final
hashCode int
The hash code for this object.
no setteroverride
month int
month Month of the year; 1-12
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
year int
year Birth year; 0 if unknown
final

Methods

copyWith({int? day, int? month, int? year}) Birthdate

Available on Birthdate, provided by the BirthdateExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Birthdate?

Constants

constructor → const String