BotAccessSettings class final
Describes users that have access to a bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BotAccessSettings({required bool isRestricted, required List<
int> addedUserIds})
Properties
-
addedUserIds
→ List<
int> -
addedUserIds Identifiers of the users who can use the bot additionally
to the owner of the bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRestricted → bool
-
isRestricted True, if access to the bot is restricted to its owner and
selected users
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isRestricted, List< int> ? addedUserIds}) → BotAccessSettings -
Available on BotAccessSettings, provided by the BotAccessSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BotAccessSettings?
Constants
- constructor → const String