BotCommand class final
Represents a command supported by a bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BotCommand({required String command, required String description, required bool isEphemeral})
Properties
- command → String
-
command Text of the bot command
final
- description → String
-
param_description Description of the bot command
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isEphemeral → bool
-
isEphemeral True, if the command must send an ephemeral message instead
of a regular one
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? command, String? description, bool? isEphemeral}) → BotCommand -
Available on BotCommand, provided by the BotCommandExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BotCommand?
Constants
- constructor → const String