BotInfo class final
Contains information about a bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BotInfo({required String shortDescription, required String description, Photo? photo, Animation? animation, required int managerBotUserId, required List<
BotCommand> commands, required String privacyPolicyUrl, ChatAdministratorRights? defaultGroupAdministratorRights, ChatAdministratorRights? defaultChannelAdministratorRights, AffiliateProgramInfo? affiliateProgram, required int webAppBackgroundLightColor, required int webAppBackgroundDarkColor, required int webAppHeaderLightColor, required int webAppHeaderDarkColor, BotVerificationParameters? verificationParameters, required bool canGetRevenueStatistics, required bool canManageEmojiStatus, required bool hasMediaPreviews, InternalLinkType? editCommandsLink, InternalLinkType? editDescriptionLink, InternalLinkType? editDescriptionMediaLink, InternalLinkType? editSettingsLink})
Properties
- affiliateProgram → AffiliateProgramInfo?
-
affiliateProgram Information about the affiliate program of the bot; may
be null if none
final
- animation → Animation?
-
animation Animation shown in the chat with the bot if the chat is empty;
may be null
final
- canGetRevenueStatistics → bool
-
canGetRevenueStatistics True, if the bot's revenue statistics are
available to the current user
final
- canManageEmojiStatus → bool
-
canManageEmojiStatus True, if the bot can manage emoji status of the
current user
final
-
commands
→ List<
BotCommand> -
commands List of the bot commands
final
- defaultChannelAdministratorRights → ChatAdministratorRights?
-
defaultChannelAdministratorRights Default administrator rights for
adding the bot to channels; may be null
final
- defaultGroupAdministratorRights → ChatAdministratorRights?
-
defaultGroupAdministratorRights Default administrator rights for adding
the bot to basic group and supergroup chats; may be null
final
- description → String
-
param_description The text shown in the chat with the bot if the chat is
empty
final
- editCommandsLink → InternalLinkType?
-
editCommandsLink The internal link, which can be used to edit bot
commands; may be null
final
- editDescriptionLink → InternalLinkType?
-
editDescriptionLink The internal link, which can be used to edit bot
description; may be null
final
- editDescriptionMediaLink → InternalLinkType?
-
editDescriptionMediaLink The internal link, which can be used to edit
the photo or animation shown in the chat with the bot if the chat is
empty; may be null
final
- editSettingsLink → InternalLinkType?
-
editSettingsLink The internal link, which can be used to edit bot
settings; may be null
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasMediaPreviews → bool
-
hasMediaPreviews True, if the bot has media previews
final
- managerBotUserId → int
-
managerBotUserId Identifier of the bot, which manages the bot; 0 if none
or unknown; for owner of the bot only
final
-
menuButton Information about a button to show instead of the bot
commands menu button; may be null if ordinary bot commands menu must be
shown
final
- photo → Photo?
-
photo Photo shown in the chat with the bot if the chat is empty; may be
null
final
- privacyPolicyUrl → String
-
privacyPolicyUrl The HTTP link to the privacy policy of the bot. If
empty, then /privacy command must be used if supported by the bot. If the
command isn't supported, then https://telegram.org/privacy-tpa must be
opened
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDescription → String
-
shortDescription The text that is shown on the bot's profile page and is
sent together with the link when users share the bot
final
- verificationParameters → BotVerificationParameters?
-
verificationParameters Parameters of the verification that can be
provided by the bot; may be null if none or the current user isn't the
owner of the bot
final
- webAppBackgroundDarkColor → int
-
webAppBackgroundDarkColor Default dark background color for bot Web
Apps; -1 if not specified
final
- webAppBackgroundLightColor → int
-
webAppBackgroundLightColor Default light background color for bot Web
Apps; -1 if not specified
final
- webAppHeaderDarkColor → int
-
webAppHeaderDarkColor Default dark header color for bot Web Apps; -1 if
not specified
final
- webAppHeaderLightColor → int
-
webAppHeaderLightColor Default light header color for bot Web Apps; -1
if not specified
final
Methods
-
copyWith(
{String? shortDescription, String? description, Photo? photo, Animation? animation, int? managerBotUserId, List< BotCommand> ? commands, String? privacyPolicyUrl, ChatAdministratorRights? defaultGroupAdministratorRights, ChatAdministratorRights? defaultChannelAdministratorRights, AffiliateProgramInfo? affiliateProgram, int? webAppBackgroundLightColor, int? webAppBackgroundDarkColor, int? webAppHeaderLightColor, int? webAppHeaderDarkColor, BotVerificationParameters? verificationParameters, bool? canGetRevenueStatistics, bool? canManageEmojiStatus, bool? hasMediaPreviews, InternalLinkType? editCommandsLink, InternalLinkType? editDescriptionLink, InternalLinkType? editDescriptionMediaLink, InternalLinkType? editSettingsLink}) → BotInfo -
Available on BotInfo, provided by the BotInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String