BotMediaPreview class final
Describes media previews of a bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BotMediaPreview({required int date, StoryContent? content})
Properties
- content → StoryContent?
-
content Content of the preview; may only be of the types
storyContentPhoto, storyContentVideo, or storyContentUnsupported
final
- date → int
-
date Point in time (Unix timestamp) when the preview was added or
changed last time
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? date, StoryContent? content}) → BotMediaPreview -
Available on BotMediaPreview, provided by the BotMediaPreviewExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BotMediaPreview?
Constants
- constructor → const String