BotMenuButton class final
Describes a button to be shown instead of bot commands menu button
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BotMenuButton({required String text, required String url})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
text Text of the button
final
- url → String
-
url URL of a Web App to open when the button is pressed. If the link is
of the type internalLinkTypeWebApp, then it must be processed accordingly.
Otherwise, the link must be passed to openWebApp
final
Methods
-
copyWith(
{String? text, String? url}) → BotMenuButton -
Available on BotMenuButton, provided by the BotMenuButtonExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BotMenuButton?
Constants
- constructor → const String