BusinessAwayMessageSettings class final
Describes settings for messages that are automatically sent by a Telegram Business account when it is away
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessAwayMessageSettings({required int shortcutId, BusinessRecipients? recipients, BusinessAwayMessageSchedule? schedule, required bool offlineOnly})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- offlineOnly → bool
-
offlineOnly True, if the messages must not be sent if the account was
online in the last 10 minutes
final
- recipients → BusinessRecipients?
-
recipients Chosen recipients of the away messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule → BusinessAwayMessageSchedule?
-
schedule Settings used to check whether the current user is away
final
- shortcutId → int
-
shortcutId Unique quick reply shortcut identifier for the away messages
final
Methods
-
copyWith(
{int? shortcutId, BusinessRecipients? recipients, BusinessAwayMessageSchedule? schedule, bool? offlineOnly}) → BusinessAwayMessageSettings -
Available on BusinessAwayMessageSettings, provided by the BusinessAwayMessageSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessAwayMessageSettings?
Constants
- constructor → const String