BusinessBotManageBar class final
Contains information about a business bot that manages the chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessBotManageBar({required int botUserId, required String manageUrl, required bool isBotPaused, required bool canBotReply})
Properties
- botUserId → int
-
botUserId User identifier of the bot
final
- canBotReply → bool
-
canBotReply True, if the bot can reply
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isBotPaused → bool
-
isBotPaused True, if the bot is paused. Use
toggleBusinessConnectedBotChatIsPaused to change the value of the field
final
- manageUrl → String
-
manageUrl URL to be opened to manage the bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? manageUrl, bool? isBotPaused, bool? canBotReply}) → BusinessBotManageBar -
Available on BusinessBotManageBar, provided by the BusinessBotManageBarExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessBotManageBar?
Constants
- constructor → const String