BusinessBotRights class final
Describes rights of a business bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessBotRights({required bool canReply, required bool canReadMessages, required bool canDeleteSentMessages, required bool canDeleteAllMessages, required bool canEditName, required bool canEditBio, required bool canEditProfilePhoto, required bool canEditUsername, required bool canViewGiftsAndStars, required bool canSellGifts, required bool canChangeGiftSettings, required bool canTransferAndUpgradeGifts, required bool canTransferStars, required bool canManageStories})
Properties
- canChangeGiftSettings → bool
-
canChangeGiftSettings True, if the bot can change gift receiving
settings of the business account
final
- canDeleteAllMessages → bool
-
canDeleteAllMessages True, if the bot can delete any message
final
- canDeleteSentMessages → bool
-
canDeleteSentMessages True, if the bot can delete sent messages
final
- canEditBio → bool
-
canEditBio True, if the bot can edit bio of the business account
final
- canEditName → bool
-
canEditName True, if the bot can edit name of the business account
final
- canEditProfilePhoto → bool
-
canEditProfilePhoto True, if the bot can edit profile photo of the
business account
final
- canEditUsername → bool
-
canEditUsername True, if the bot can edit username of the business
account
final
- canManageStories → bool
-
canManageStories True, if the bot can post, edit and delete stories
final
- canReadMessages → bool
-
canReadMessages True, if the bot can mark incoming private messages as
read
final
- canReply → bool
-
canReply True, if the bot can send and edit messages in the private
chats that had incoming messages in the last 24 hours
final
- canSellGifts → bool
-
canSellGifts True, if the bot can sell regular gifts received by the
business account
final
- canTransferAndUpgradeGifts → bool
-
canTransferAndUpgradeGifts True, if the bot can transfer and upgrade
gifts received by the business account
final
- canTransferStars → bool
-
canTransferStars True, if the bot can transfer Telegram Stars received
by the business account to account of the bot, or use them to upgrade and
transfer gifts
final
- canViewGiftsAndStars → bool
-
canViewGiftsAndStars True, if the bot can view gifts and Telegram Star
amount owned by the business account
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canReply, bool? canReadMessages, bool? canDeleteSentMessages, bool? canDeleteAllMessages, bool? canEditName, bool? canEditBio, bool? canEditProfilePhoto, bool? canEditUsername, bool? canViewGiftsAndStars, bool? canSellGifts, bool? canChangeGiftSettings, bool? canTransferAndUpgradeGifts, bool? canTransferStars, bool? canManageStories}) → BusinessBotRights -
Available on BusinessBotRights, provided by the BusinessBotRightsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessBotRights?
Constants
- constructor → const String