BusinessChatLinks class final
Contains a list of business chat links created by the user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
BusinessChatLinks({required List<
BusinessChatLink> links})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
links
→ List<
BusinessChatLink> -
links List of links
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< BusinessChatLink> ? links}) → BusinessChatLinks -
Available on BusinessChatLinks, provided by the BusinessChatLinksExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessChatLinks?
Constants
- constructor → const String