deviceModel property
deviceModel Model of the device that was used for the bot connection, as provided by the application; may be empty if unknown
Implementation
final String deviceModel;
deviceModel Model of the device that was used for the bot connection, as provided by the application; may be empty if unknown
final String deviceModel;