BusinessConnection class final
Describes a connection of the bot with a business account
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessConnection({required String id, required int userId, required int userChatId, required int date, BusinessBotRights? rights, required bool isEnabled})
Properties
- date → int
-
date Point in time (Unix timestamp) when the connection was established
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique identifier of the connection
final
- isEnabled → bool
-
isEnabled True, if the connection is enabled; false otherwise
final
- rights → BusinessBotRights?
-
rights Rights of the bot; may be null if the connection was disabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userChatId → int
-
userChatId Chat identifier of the private chat with the user
final
- userId → int
-
userId Identifier of the business user who created the connection
final
Methods
-
copyWith(
{String? id, int? userId, int? userChatId, int? date, BusinessBotRights? rights, bool? isEnabled}) → BusinessConnection -
Available on BusinessConnection, provided by the BusinessConnectionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessConnection?
Constants
- constructor → const String