BusinessLocation class final

Represents a location of a business

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

BusinessLocation({Location? location, required String address})

Properties

address String
address Location address; 1-96 characters
final
hashCode int
The hash code for this object.
no setteroverride
location Location?
location The location; may be null if not specified
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Location? location, String? address}) BusinessLocation

Available on BusinessLocation, provided by the BusinessLocationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) BusinessLocation?

Constants

constructor → const String