BusinessOpeningHoursInterval class final
Describes an interval of time when the business is open
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- BusinessOpeningHoursInterval({required int startMinute, required int endMinute})
Properties
- endMinute → int
-
endMinute The minute's sequence number in a week, starting on Monday,
marking the end of the time interval during which the business is open;
1-82460
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startMinute → int
-
startMinute The minute's sequence number in a week, starting on Monday,
marking the start of the time interval during which the business is open;
0-72460
final
Methods
-
copyWith(
{int? startMinute, int? endMinute}) → BusinessOpeningHoursInterval -
Available on BusinessOpeningHoursInterval, provided by the BusinessOpeningHoursIntervalExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → BusinessOpeningHoursInterval?
Constants
- constructor → const String