Call class final
Describes a call
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Call identifier, not persistent
final
- isOutgoing → bool
-
isOutgoing True, if the call is outgoing
final
- isVideo → bool
-
isVideo True, if the call is a video call
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CallState?
-
state Call state
final
- uniqueId → int
-
uniqueId Persistent unique call identifier; 0 if isn't assigned yet by
the server
final
- userId → int
-
userId User identifier of the other call participant
final
Methods
-
copyWith(
{int? id, int? uniqueId, int? userId, bool? isOutgoing, bool? isVideo, CallState? state}) → Call -
Available on Call, provided by the CallExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String