CallStatePending class final
The call is pending, waiting to be accepted by a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- CallStatePending({required bool isCreated, required bool isReceived})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCreated → bool
-
isCreated True, if the call has already been created by the server
final
- isReceived → bool
-
isReceived True, if the call has already been received by the other
party
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isCreated, bool? isReceived}) → CallStatePending -
Available on CallStatePending, provided by the CallStatePendingExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult discarded(CallStateDiscarded value), required TResult error(CallStateError value), required TResult exchangingKeys(CallStateExchangingKeys value), required TResult hangingUp(CallStateHangingUp value), required TResult pending(CallStatePending value), required TResult ready(CallStateReady value)}) → TResult -
Available on CallState, provided by the CallStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult discarded(CallStateDiscarded value)?, TResult error(CallStateError value)?, TResult exchangingKeys(CallStateExchangingKeys value)?, TResult hangingUp(CallStateHangingUp value)?, TResult pending(CallStatePending value)?, TResult ready(CallStateReady value)?, required TResult orElse()}) → TResult -
Available on CallState, provided by the CallStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CallStatePending? -
Inherited by:
CallStateDiscarded
CallStateError
CallStateExchangingKeys
CallStateHangingUp
CallStatePending
CallStateReady
override
Constants
- constructor → const String