CallbackQueryAnswer class final
Contains a bot's answer to a callback query
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- CallbackQueryAnswer({required String text, required bool showAlert, required String url})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showAlert → bool
-
showAlert True, if an alert must be shown to the user instead of a toast
notification
final
- text → String
-
text Text of the answer
final
- url → String
-
url URL to be opened
final
Methods
-
copyWith(
{String? text, bool? showAlert, String? url}) → CallbackQueryAnswer -
Available on CallbackQueryAnswer, provided by the CallbackQueryAnswerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CallbackQueryAnswer?
Constants
- constructor → const String