CanBotSendMessages class final
Checks whether the specified bot can send messages to the user. Returns a 404 error if can't and the access can be granted by call to allowBotToSendMessages Returns Ok
- Inheritance
-
- Object
- TdFunction
- CanBotSendMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanBotSendMessages({required int botUserId})
Properties
Methods
-
copyWith(
{int? botUserId}) → CanBotSendMessages -
Available on CanBotSendMessages, provided by the CanBotSendMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String