CanPostStory class final
Checks whether the current user can post a story on behalf of a chat; requires can_post_stories administrator right for supergroup and channel chats Returns CanPostStoryResult
- Inheritance
-
- Object
- TdFunction
- CanPostStory
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanPostStory({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → CanPostStory -
Available on CanPostStory, provided by the CanPostStoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String