CanPurchaseFromStore class final
Checks whether an in-store purchase is possible. Must be called before any in-store purchase. For official applications only Returns Ok
- Inheritance
-
- Object
- TdFunction
- CanPurchaseFromStore
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanPurchaseFromStore({StorePaymentPurpose? purpose})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- purpose → StorePaymentPurpose?
-
purpose Transaction purpose
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{StorePaymentPurpose? purpose}) → CanPurchaseFromStore -
Available on CanPurchaseFromStore, provided by the CanPurchaseFromStoreExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String