CanSendMessageToUser class final
Checks whether the current user can message another user or try to create a chat with them Returns CanSendMessageToUserResult
- Inheritance
-
- Object
- TdFunction
- CanSendMessageToUser
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanSendMessageToUser({required int userId, required bool onlyLocal})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyLocal → bool
-
onlyLocal Pass true to get only locally available information without
sending network requests
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the other user
final
Methods
-
copyWith(
{int? userId, bool? onlyLocal}) → CanSendMessageToUser -
Available on CanSendMessageToUser, provided by the CanSendMessageToUserExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String