CanTransferOwnershipResultPasswordTooFresh class final
The 2-step verification was enabled recently, user needs to wait
- Inheritance
-
- Object
- TdObject
- CanTransferOwnershipResult
- CanTransferOwnershipResultPasswordTooFresh
- Available extensions
- Annotations
-
- @immutable
Constructors
- CanTransferOwnershipResultPasswordTooFresh({required int retryAfter})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- retryAfter → int
-
retryAfter Time left before the session can be used to transfer
ownership of a chat, in seconds
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? retryAfter}) → CanTransferOwnershipResultPasswordTooFresh -
Available on CanTransferOwnershipResultPasswordTooFresh, provided by the CanTransferOwnershipResultPasswordTooFreshExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ok(CanTransferOwnershipResultOk value), required TResult passwordNeeded(CanTransferOwnershipResultPasswordNeeded value), required TResult passwordTooFresh(CanTransferOwnershipResultPasswordTooFresh value), required TResult sessionTooFresh(CanTransferOwnershipResultSessionTooFresh value)}) → TResult -
Available on CanTransferOwnershipResult, provided by the CanTransferOwnershipResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ok(CanTransferOwnershipResultOk value)?, TResult passwordNeeded(CanTransferOwnershipResultPasswordNeeded value)?, TResult passwordTooFresh(CanTransferOwnershipResultPasswordTooFresh value)?, TResult sessionTooFresh(CanTransferOwnershipResultSessionTooFresh value)?, required TResult orElse()}) → TResult -
Available on CanTransferOwnershipResult, provided by the CanTransferOwnershipResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String