viewAsTopics property
viewAsTopics True, if the chat is a forum supergroup that must be shown in the "View as topics" mode, or Saved Messages chat that must be shown in the "View as chats"
Implementation
final bool viewAsTopics;
viewAsTopics True, if the chat is a forum supergroup that must be shown in the "View as topics" mode, or Saved Messages chat that must be shown in the "View as chats"
final bool viewAsTopics;