ChatAdministrator class final
Contains information about a chat administrator
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatAdministrator({required int userId, required String customTitle, required bool isOwner, required bool canBeEdited})
Properties
- canBeEdited → bool
-
canBeEdited True, if the current user can edit the administrator
privileges for the administrator
final
- customTitle → String
-
customTitle Custom title of the administrator
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isOwner → bool
-
isOwner True, if the user is the owner of the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier of the administrator
final
Methods
-
copyWith(
{int? userId, String? customTitle, bool? isOwner, bool? canBeEdited}) → ChatAdministrator -
Available on ChatAdministrator, provided by the ChatAdministratorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatAdministrator?
Constants
- constructor → const String