ChatAdministratorRights class final
Describes rights of the administrator
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatAdministratorRights({required bool canManageChat, required bool canChangeInfo, required bool canPostMessages, required bool canEditMessages, required bool canDeleteMessages, required bool canInviteUsers, required bool canRestrictMembers, required bool canPinMessages, required bool canManageTopics, required bool canPromoteMembers, required bool canManageVideoChats, required bool canPostStories, required bool canEditStories, required bool canDeleteStories, required bool canManageDirectMessages, required bool canManageTags, required bool isAnonymous})
Properties
- canChangeInfo → bool
-
canChangeInfo True, if the administrator can change the chat title,
photo, and other settings
final
- canDeleteMessages → bool
-
canDeleteMessages True, if the administrator can delete messages of
other users
final
- canDeleteStories → bool
-
canDeleteStories True, if the administrator can delete stories posted by
other users; applicable to supergroups and channels only
final
- canEditMessages → bool
-
canEditMessages True, if the administrator can edit messages of other
users and pin messages; applicable to channels only
final
- canEditStories → bool
-
canEditStories True, if the administrator can edit stories posted by
other users, post stories to the chat page, pin chat stories, and access
story archive; applicable to supergroups and channels only
final
- canInviteUsers → bool
-
canInviteUsers True, if the administrator can invite new users to the
chat
final
- canManageChat → bool
-
canManageChat True, if the administrator can access the chat event log,
get boost list, see hidden supergroup and channel members, report
supergroup spam messages, ignore slow mode, and send messages to the chat
without paying Telegram Stars. Implied by any other privilege; applicable
to supergroups and channels only
final
- canManageDirectMessages → bool
-
canManageDirectMessages True, if the administrator can answer to channel
direct messages; applicable to channels only
final
- canManageTags → bool
-
canManageTags True, if the administrator can change tags of other users;
applicable to basic groups and supergroups only
final
- canManageTopics → bool
-
canManageTopics True, if the administrator can create, rename, close,
reopen, hide, and unhide forum topics; applicable to forum supergroups
only
final
- canManageVideoChats → bool
-
canManageVideoChats True, if the administrator can manage video chats
final
- canPinMessages → bool
-
canPinMessages True, if the administrator can pin messages; applicable
to basic groups and supergroups only
final
- canPostMessages → bool
-
canPostMessages True, if the administrator can create channel posts,
approve suggested channel posts, or view channel statistics; applicable to
channels only
final
- canPostStories → bool
-
canPostStories True, if the administrator can create new chat stories,
or edit and delete posted stories; applicable to supergroups and channels
only
final
- canPromoteMembers → bool
-
canPromoteMembers True, if the administrator can add new administrators
with a subset of their own privileges or demote administrators that were
directly or indirectly promoted by them; applicable to supergroups and
channels only
final
- canRestrictMembers → bool
-
canRestrictMembers True, if the administrator can restrict, ban, or
unban chat members or view supergroup statistics
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAnonymous → bool
-
isAnonymous True, if the administrator isn't shown in the chat member
list and sends messages anonymously; applicable to supergroups only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canManageChat, bool? canChangeInfo, bool? canPostMessages, bool? canEditMessages, bool? canDeleteMessages, bool? canInviteUsers, bool? canRestrictMembers, bool? canPinMessages, bool? canManageTopics, bool? canPromoteMembers, bool? canManageVideoChats, bool? canPostStories, bool? canEditStories, bool? canDeleteStories, bool? canManageDirectMessages, bool? canManageTags, bool? isAnonymous}) → ChatAdministratorRights -
Available on ChatAdministratorRights, provided by the ChatAdministratorRightsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatAdministratorRights?
Constants
- constructor → const String