ChatAvailableReactionsSome class final
Only specific reactions are available in the chat
- Inheritance
-
- Object
- TdObject
- ChatAvailableReactions
- ChatAvailableReactionsSome
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatAvailableReactionsSome({required List<
ReactionType> reactions, required int maxReactionCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxReactionCount → int
-
maxReactionCount The maximum allowed number of reactions per message;
1-11
final
-
reactions
→ List<
ReactionType> -
reactions The list of reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ReactionType> ? reactions, int? maxReactionCount}) → ChatAvailableReactionsSome -
Available on ChatAvailableReactionsSome, provided by the ChatAvailableReactionsSomeExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult all(ChatAvailableReactionsAll value), required TResult some(ChatAvailableReactionsSome value)}) → TResult -
Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult all(ChatAvailableReactionsAll value)?, TResult some(ChatAvailableReactionsSome value)?, required TResult orElse()}) → TResult -
Available on ChatAvailableReactions, provided by the ChatAvailableReactionsExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatAvailableReactionsSome? -
Inherited by:
ChatAvailableReactionsAll
ChatAvailableReactionsSome
override
Constants
- constructor → const String