ChatBoost class final

Describes a boost applied to a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatBoost({required String id, required int count, ChatBoostSource? source, required int startDate, required int expirationDate})

Properties

count int
count The number of identical boosts applied
final
expirationDate int
expirationDate Point in time (Unix timestamp) when the boost will expire
final
hashCode int
The hash code for this object.
no setteroverride
id String
id Unique identifier of the boost
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source ChatBoostSource?
source Source of the boost
final
startDate int
startDate Point in time (Unix timestamp) when the chat was boosted
final

Methods

copyWith({String? id, int? count, ChatBoostSource? source, int? startDate, int? expirationDate}) ChatBoost

Available on ChatBoost, provided by the ChatBoostExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatBoost?

Constants

constructor → const String