ChatBoostStatus class final
Describes current boost status of a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
appliedSlotIds
→ List<
int> -
appliedSlotIds Identifiers of boost slots of the current user applied to
the chat
final
- boostCount → int
-
boostCount The number of boosts received by the chat
final
- boostUrl → String
-
boostUrl An HTTP URL, which can be used to boost the chat
final
- currentLevelBoostCount → int
-
currentLevelBoostCount The number of boosts added to reach the current
level
final
- giftCodeBoostCount → int
-
giftCodeBoostCount The number of boosts received by the chat from
created Telegram Premium gift codes and giveaways; always 0 if the current
user isn't an administrator in the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- level → int
-
level Current boost level of the chat
final
- nextLevelBoostCount → int
-
nextLevelBoostCount The number of boosts needed to reach the next level;
0 if the next level isn't available
final
-
premiumMemberCount Approximate number of Telegram Premium subscribers
joined the chat; always 0 if the current user isn't an administrator in
the chat
final
-
premiumMemberPercentage A percentage of Telegram Premium subscribers
joined the chat; always 0 if the current user isn't an administrator in
the chat
final
-
prepaidGiveaways
→ List<
PrepaidGiveaway> -
prepaidGiveaways The list of prepaid giveaways available for the chat;
only for chat administrators
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? boostUrl, List< int> ? appliedSlotIds, int? level, int? giftCodeBoostCount, int? boostCount, int? currentLevelBoostCount, int? nextLevelBoostCount, List<PrepaidGiveaway> ? prepaidGiveaways}) → ChatBoostStatus -
Available on ChatBoostStatus, provided by the ChatBoostStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatBoostStatus?
Constants
- constructor → const String