ChatFolder class final
Represents a folder for user chats
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatFolder({ChatFolderName? name, ChatFolderIcon? icon, required int colorId, required List<
int> pinnedChatIds, required List<int> includedChatIds, required List<int> excludedChatIds, required bool excludeMuted, required bool excludeRead, required bool excludeArchived, required bool includeContacts, required bool includeNonContacts, required bool includeBots, required bool includeGroups, required bool includeChannels})
Properties
- colorId → int
-
colorId The identifier of the chosen color for the chat folder icon;
from -1 to 6. If -1, then color is disabled. Can't be changed if folder
tags are disabled or the current user doesn't have Telegram Premium
subscription
final
- excludeArchived → bool
-
excludeArchived True, if archived chats need to be excluded
final
-
excludedChatIds
→ List<
int> -
excludedChatIds The chat identifiers of always excluded chats in the
folder. There can be up to getOption("chat_folder_chosen_chat_count_max")
always excluded non-secret chats and the same number of secret chats, but
the limit can be increased with Telegram Premium
final
- excludeMuted → bool
-
excludeMuted True, if muted chats need to be excluded
final
- excludeRead → bool
-
excludeRead True, if read chats need to be excluded
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → ChatFolderIcon?
-
icon The chosen icon for the chat folder; may be null. If null, use
getChatFolderDefaultIconName to get default icon name for the folder
final
- includeBots → bool
-
includeBots True, if bots need to be included
final
- includeChannels → bool
-
includeChannels True, if channels need to be included
final
- includeContacts → bool
-
includeContacts True, if contacts need to be included
final
-
includedChatIds
→ List<
int> -
includedChatIds The chat identifiers of always included chats in the
folder. There can be up to getOption("chat_folder_chosen_chat_count_max")
pinned and always included non-secret chats and the same number of secret
chats, but the limit can be increased with Telegram Premium
final
- includeGroups → bool
-
includeGroups True, if basic groups and supergroups need to be included
final
- includeNonContacts → bool
-
includeNonContacts True, if non-contact users need to be included
final
-
isShareable True, if at least one link has been created for the folder
final
- name → ChatFolderName?
-
name The name of the folder
final
-
pinnedChatIds
→ List<
int> -
pinnedChatIds The chat identifiers of pinned chats in the folder. There
can be up to getOption("chat_folder_chosen_chat_count_max") pinned and
always included non-secret chats and the same number of secret chats, but
the limit can be increased with Telegram Premium
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolderName? name, ChatFolderIcon? icon, int? colorId, List< int> ? pinnedChatIds, List<int> ? includedChatIds, List<int> ? excludedChatIds, bool? excludeMuted, bool? excludeRead, bool? excludeArchived, bool? includeContacts, bool? includeNonContacts, bool? includeBots, bool? includeGroups, bool? includeChannels}) → ChatFolder -
Available on ChatFolder, provided by the ChatFolderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatFolder?
Constants
- constructor → const String