ChatFolderIcon class final
Represents an icon for a chat folder
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatFolderIcon({required String name})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name The chosen icon name for short folder representation; one of "All",
"Unread", "Unmuted", "Bots", "Channels", "Groups", "Private", "Custom",
"Setup", "Cat", "Crown", "Favorite", "Flower", "Game", "Home", "Love",
"Mask", "Party", "Sport", "Study", "Trade", "Travel", "Work", "Airplane",
"Book", "Light", "Like", "Money", "Note", "Palette"
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? name}) → ChatFolderIcon -
Available on ChatFolderIcon, provided by the ChatFolderIconExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatFolderIcon?
Constants
- constructor → const String