ChatFolderInviteLinkInfo class final
Contains information about an invite link to a chat folder
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatFolderInviteLinkInfo({ChatFolderInfo? chatFolderInfo, required List<
int> missingChatIds, required List<int> addedChatIds})
Properties
-
addedChatIds
→ List<
int> -
addedChatIds Identifiers of the chats from the link, which are added to
the folder already
final
- chatFolderInfo → ChatFolderInfo?
-
chatFolderInfo Basic information about the chat folder; chat folder
identifier will be 0 if the user didn't have the chat folder yet
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
missingChatIds
→ List<
int> -
missingChatIds Identifiers of the chats from the link, which aren't
added to the folder yet
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolderInfo? chatFolderInfo, List< int> ? missingChatIds, List<int> ? addedChatIds}) → ChatFolderInviteLinkInfo -
Available on ChatFolderInviteLinkInfo, provided by the ChatFolderInviteLinkInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatFolderInviteLinkInfo?
Constants
- constructor → const String