ChatInviteLinkCount class final
Describes a chat administrator with a number of active and revoked chat invite links
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatInviteLinkCount({required int userId, required int inviteLinkCount, required int revokedInviteLinkCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLinkCount → int
-
inviteLinkCount Number of active invite links
final
- revokedInviteLinkCount → int
-
revokedInviteLinkCount Number of revoked invite links
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Administrator's user identifier
final
Methods
-
copyWith(
{int? userId, int? inviteLinkCount, int? revokedInviteLinkCount}) → ChatInviteLinkCount -
Available on ChatInviteLinkCount, provided by the ChatInviteLinkCountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatInviteLinkCount?
Constants
- constructor → const String