ChatInviteLinkMember class final
Describes a chat member joined a chat via an invite link
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatInviteLinkMember({required int userId, required int joinedChatDate, required bool viaChatFolderInviteLink, required int approverUserId})
Properties
- approverUserId → int
-
approverUserId User identifier of the chat administrator, approved user
join request
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- joinedChatDate → int
-
joinedChatDate Point in time (Unix timestamp) when the user joined the
chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
- viaChatFolderInviteLink → bool
-
viaChatFolderInviteLink True, if the user has joined the chat using an
invite link for a chat folder
final
Methods
-
copyWith(
{int? userId, int? joinedChatDate, bool? viaChatFolderInviteLink, int? approverUserId}) → ChatInviteLinkMember -
Available on ChatInviteLinkMember, provided by the ChatInviteLinkMemberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatInviteLinkMember?
Constants
- constructor → const String