ChatJoinRequests class final
Contains a list of requests to join a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ChatJoinRequests({required int totalCount, required List<
ChatJoinRequest> requests})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
requests
→ List<
ChatJoinRequest> -
requests List of the requests
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Approximate total number of requests found
final
Methods
-
copyWith(
{int? totalCount, List< ChatJoinRequest> ? requests}) → ChatJoinRequests -
Available on ChatJoinRequests, provided by the ChatJoinRequestsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatJoinRequests?
Constants
- constructor → const String