ChatJoinResultGuardBotApprovalRequired class final
An approval from a guard bot through a Web App is required to join the chat
- Inheritance
-
- Object
- TdObject
- ChatJoinResult
- ChatJoinResultGuardBotApprovalRequired
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatJoinResultGuardBotApprovalRequired({required int botUserId, required int queryId})
Properties
- botUserId → int
-
botUserId Identifier of the guard bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- queryId → int
-
queryId Unique identifier of the join request, which will be used in
getGuardBotWebAppUrl and updateChatJoinResult
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, int? queryId}) → ChatJoinResultGuardBotApprovalRequired -
Available on ChatJoinResultGuardBotApprovalRequired, provided by the ChatJoinResultGuardBotApprovalRequiredExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult declined(ChatJoinResultDeclined value), required TResult guardBotApprovalRequired(ChatJoinResultGuardBotApprovalRequired value), required TResult requestSent(ChatJoinResultRequestSent value), required TResult success(ChatJoinResultSuccess value)}) → TResult -
Available on ChatJoinResult, provided by the ChatJoinResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult declined(ChatJoinResultDeclined value)?, TResult guardBotApprovalRequired(ChatJoinResultGuardBotApprovalRequired value)?, TResult requestSent(ChatJoinResultRequestSent value)?, TResult success(ChatJoinResultSuccess value)?, required TResult orElse()}) → TResult -
Available on ChatJoinResult, provided by the ChatJoinResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatJoinResultGuardBotApprovalRequired? -
Inherited by:
ChatJoinResultDeclined
ChatJoinResultGuardBotApprovalRequired
ChatJoinResultRequestSent
ChatJoinResultSuccess
override
Constants
- constructor → const String