ChatMessageSender class final
Represents a message sender, which can be used to send messages in a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatMessageSender({MessageSender? sender, required bool needsPremium})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- needsPremium → bool
-
needsPremium True, if Telegram Premium is needed to use the message
sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → MessageSender?
-
sender The message sender
final
Methods
-
copyWith(
{MessageSender? sender, bool? needsPremium}) → ChatMessageSender -
Available on ChatMessageSender, provided by the ChatMessageSenderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatMessageSender?
Constants
- constructor → const String