ChatNotificationSettings class final
Contains information about notification settings for a chat or a forum topic
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatNotificationSettings({required bool useDefaultMuteFor, required int muteFor, required bool useDefaultSound, required int soundId, required bool useDefaultShowPreview, required bool showPreview, required bool useDefaultMuteStories, required bool muteStories, required bool useDefaultStorySound, required int storySoundId, required bool useDefaultShowStoryPoster, required bool showStoryPoster, required bool useDefaultDisablePinnedMessageNotifications, required bool disablePinnedMessageNotifications, required bool useDefaultDisableMentionNotifications, required bool disableMentionNotifications})
Properties
- disableMentionNotifications → bool
-
disableMentionNotifications If true, notifications for messages with
mentions will be created as for an ordinary unread message
final
- disablePinnedMessageNotifications → bool
-
disablePinnedMessageNotifications If true, notifications for incoming
pinned messages will be created as for an ordinary unread message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- muteFor → int
-
muteFor Time left before notifications will be unmuted, in seconds
final
- muteStories → bool
-
muteStories True, if story notifications are disabled for the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPreview → bool
-
showPreview True, if message content must be displayed in notifications
final
- showStoryPoster → bool
-
showStoryPoster True, if the chat that posted a story must be displayed
in notifications
final
- soundId → int
-
soundId Identifier of the notification sound to be played for messages;
0 if sound is disabled
final
- storySoundId → int
-
storySoundId Identifier of the notification sound to be played for
stories; 0 if sound is disabled
final
- useDefaultDisableMentionNotifications → bool
-
useDefaultDisableMentionNotifications If true, the value for the
relevant type of chat or the forum chat is used instead of
disable_mention_notifications
final
- useDefaultDisablePinnedMessageNotifications → bool
-
useDefaultDisablePinnedMessageNotifications If true, the value for the
relevant type of chat or the forum chat is used instead of
disable_pinned_message_notifications
final
- useDefaultMuteFor → bool
-
useDefaultMuteFor If true, the value for the relevant type of chat or
the forum chat is used instead of mute_for
final
- useDefaultMuteStories → bool
-
useDefaultMuteStories If true, the value for the relevant type of chat
is used instead of mute_stories
final
- useDefaultShowPreview → bool
-
useDefaultShowPreview If true, the value for the relevant type of chat
or the forum chat is used instead of show_preview
final
- useDefaultShowStoryPoster → bool
-
useDefaultShowStoryPoster If true, the value for the relevant type of
chat is used instead of show_story_poster
final
- useDefaultSound → bool
-
useDefaultSound If true, the value for the relevant type of chat or the
forum chat is used instead of sound_id
final
- useDefaultStorySound → bool
-
useDefaultStorySound If true, the value for the relevant type of chat is
used instead of story_sound_id
final
Methods
-
copyWith(
{bool? useDefaultMuteFor, int? muteFor, bool? useDefaultSound, int? soundId, bool? useDefaultShowPreview, bool? showPreview, bool? useDefaultMuteStories, bool? muteStories, bool? useDefaultStorySound, int? storySoundId, bool? useDefaultShowStoryPoster, bool? showStoryPoster, bool? useDefaultDisablePinnedMessageNotifications, bool? disablePinnedMessageNotifications, bool? useDefaultDisableMentionNotifications, bool? disableMentionNotifications}) → ChatNotificationSettings -
Available on ChatNotificationSettings, provided by the ChatNotificationSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatNotificationSettings?
Constants
- constructor → const String