useDefaultDisablePinnedMessageNotifications property
useDefaultDisablePinnedMessageNotifications If true, the value for the relevant type of chat or the forum chat is used instead of disable_pinned_message_notifications
Implementation
final bool useDefaultDisablePinnedMessageNotifications;