useDefaultShowPreview property
useDefaultShowPreview If true, the value for the relevant type of chat or the forum chat is used instead of show_preview
Implementation
final bool useDefaultShowPreview;
useDefaultShowPreview If true, the value for the relevant type of chat or the forum chat is used instead of show_preview
final bool useDefaultShowPreview;