ChatPermissions class final
Describes actions that a user is allowed to take in a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatPermissions({required bool canSendBasicMessages, required bool canSendAudios, required bool canSendDocuments, required bool canSendPhotos, required bool canSendVideos, required bool canSendVideoNotes, required bool canSendVoiceNotes, required bool canSendPolls, required bool canSendOtherMessages, required bool canAddLinkPreviews, required bool canReactToMessages, required bool canEditTag, required bool canChangeInfo, required bool canInviteUsers, required bool canPinMessages, required bool canCreateTopics})
Properties
- canAddLinkPreviews → bool
-
canAddLinkPreviews True, if the user may add a link preview to their
messages
final
- canChangeInfo → bool
-
canChangeInfo True, if the user can change the chat title, photo, and
other settings
final
- canCreateTopics → bool
-
canCreateTopics True, if the user can create topics
final
- canEditTag → bool
-
canEditTag True, if the user may change the tag of self
final
- canInviteUsers → bool
-
canInviteUsers True, if the user can invite new users to the chat
final
- canPinMessages → bool
-
canPinMessages True, if the user can pin messages
final
- canReactToMessages → bool
-
canReactToMessages True, if the user can react to messages
final
- canSendAudios → bool
-
canSendAudios True, if the user can send music files
final
- canSendBasicMessages → bool
-
canSendBasicMessages True, if the user can send text messages, rich
messages, contacts, giveaways, giveaway winners, invoices, locations, and
venues
final
- canSendDocuments → bool
-
canSendDocuments True, if the user can send documents
final
- canSendOtherMessages → bool
-
canSendOtherMessages True, if the user can send animations, games,
stickers, and dice and use inline bots
final
- canSendPhotos → bool
-
canSendPhotos True, if the user can send photos
final
- canSendPolls → bool
-
canSendPolls True, if the user can send polls and checklists
final
- canSendVideoNotes → bool
-
canSendVideoNotes True, if the user can send video notes
final
- canSendVideos → bool
-
canSendVideos True, if the user can send videos
final
- canSendVoiceNotes → bool
-
canSendVoiceNotes True, if the user can send voice notes
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canSendBasicMessages, bool? canSendAudios, bool? canSendDocuments, bool? canSendPhotos, bool? canSendVideos, bool? canSendVideoNotes, bool? canSendVoiceNotes, bool? canSendPolls, bool? canSendOtherMessages, bool? canAddLinkPreviews, bool? canReactToMessages, bool? canEditTag, bool? canChangeInfo, bool? canInviteUsers, bool? canPinMessages, bool? canCreateTopics}) → ChatPermissions -
Available on ChatPermissions, provided by the ChatPermissionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatPermissions?
Constants
- constructor → const String