ChatPhotoSticker class final
Information about the sticker, which was used to create the chat photo. The sticker is shown at the center of the photo and occupies at most 67% of it
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatPhotoSticker({ChatPhotoStickerType? type, BackgroundFill? backgroundFill})
Properties
- backgroundFill → BackgroundFill?
-
backgroundFill The fill to be used as background for the sticker;
rotation angle in backgroundFillGradient isn't supported
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChatPhotoStickerType?
-
type Type of the sticker
final
Methods
-
copyWith(
{ChatPhotoStickerType? type, BackgroundFill? backgroundFill}) → ChatPhotoSticker -
Available on ChatPhotoSticker, provided by the ChatPhotoStickerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatPhotoSticker?
Constants
- constructor → const String