ChatPhotoStickerTypeCustomEmoji class final
Information about the custom emoji, which was used to create the chat photo
- Inheritance
-
- Object
- TdObject
- ChatPhotoStickerType
- ChatPhotoStickerTypeCustomEmoji
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatPhotoStickerTypeCustomEmoji({required int customEmojiId})
Properties
- customEmojiId → int
-
customEmojiId Identifier of the custom emoji
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? customEmojiId}) → ChatPhotoStickerTypeCustomEmoji -
Available on ChatPhotoStickerTypeCustomEmoji, provided by the ChatPhotoStickerTypeCustomEmojiExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult customEmoji(ChatPhotoStickerTypeCustomEmoji value), required TResult regularOrMask(ChatPhotoStickerTypeRegularOrMask value)}) → TResult -
Available on ChatPhotoStickerType, provided by the ChatPhotoStickerTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult customEmoji(ChatPhotoStickerTypeCustomEmoji value)?, TResult regularOrMask(ChatPhotoStickerTypeRegularOrMask value)?, required TResult orElse()}) → TResult -
Available on ChatPhotoStickerType, provided by the ChatPhotoStickerTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatPhotoStickerTypeCustomEmoji? -
Inherited by:
ChatPhotoStickerTypeCustomEmoji
ChatPhotoStickerTypeRegularOrMask
override
Constants
- constructor → const String