ChatPosition class final
Describes a position of a chat in a chat list
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatPosition({ChatList? list, required int order, required bool isPinned, ChatSource? source})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPinned → bool
-
isPinned True, if the chat is pinned in the chat list
final
- list → ChatList?
-
list The chat list
final
- order → int
-
order A parameter used to determine order of the chat in the chat list.
Chats must be sorted by the pair (order, chat.id) in descending order
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ChatSource?
-
source Source of the chat in the chat list; may be null
final
Methods
-
copyWith(
{ChatList? list, int? order, bool? isPinned, ChatSource? source}) → ChatPosition -
Available on ChatPosition, provided by the ChatPositionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatPosition?
Constants
- constructor → const String