ChatRevenueAmount class final

Contains information about revenue earned from sponsored messages in a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatRevenueAmount({required String cryptocurrency, required int totalAmount, required int balanceAmount, required int availableAmount, required bool withdrawalEnabled})

Properties

availableAmount int
availableAmount Amount of the cryptocurrency available for withdrawal, in the smallest units of the cryptocurrency
final
balanceAmount int
balanceAmount Amount of the cryptocurrency that isn't withdrawn yet, in the smallest units of the cryptocurrency
final
cryptocurrency String
cryptocurrency Cryptocurrency in which revenue is calculated
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAmount int
totalAmount Total amount of the cryptocurrency earned, in the smallest units of the cryptocurrency
final
withdrawalEnabled bool
withdrawalEnabled True, if Telegram Stars can be withdrawn now or later
final

Methods

copyWith({String? cryptocurrency, int? totalAmount, int? balanceAmount, int? availableAmount, bool? withdrawalEnabled}) ChatRevenueAmount

Available on ChatRevenueAmount, provided by the ChatRevenueAmountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatRevenueAmount?

Constants

constructor → const String