ChatRevenueTransaction class final

Contains a chat revenue transactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ChatRevenueTransaction({required String cryptocurrency, required int cryptocurrencyAmount, ChatRevenueTransactionType? type})

Properties

cryptocurrency String
cryptocurrency Cryptocurrency in which revenue is calculated
final
cryptocurrencyAmount int
cryptocurrencyAmount The withdrawn amount, in the smallest units of the cryptocurrency
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ChatRevenueTransactionType?
type Type of the transaction
final

Methods

copyWith({String? cryptocurrency, int? cryptocurrencyAmount, ChatRevenueTransactionType? type}) ChatRevenueTransaction

Available on ChatRevenueTransaction, provided by the ChatRevenueTransactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatRevenueTransaction?

Constants

constructor → const String