ChatRevenueTransactionTypeSponsoredMessageEarnings class final
Describes earnings from sponsored messages in a chat in some time frame
- Inheritance
-
- Object
- TdObject
- ChatRevenueTransactionType
- ChatRevenueTransactionTypeSponsoredMessageEarnings
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatRevenueTransactionTypeSponsoredMessageEarnings({required int startDate, required int endDate})
Properties
- endDate → int
-
endDate Point in time (Unix timestamp) when the earnings ended
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → int
-
startDate Point in time (Unix timestamp) when the earnings started
final
Methods
-
copyWith(
{int? startDate, int? endDate}) → ChatRevenueTransactionTypeSponsoredMessageEarnings -
Available on ChatRevenueTransactionTypeSponsoredMessageEarnings, provided by the ChatRevenueTransactionTypeSponsoredMessageEarningsExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fragmentRefund(ChatRevenueTransactionTypeFragmentRefund value), required TResult fragmentWithdrawal(ChatRevenueTransactionTypeFragmentWithdrawal value), required TResult sponsoredMessageEarnings(ChatRevenueTransactionTypeSponsoredMessageEarnings value), required TResult suggestedPostEarnings(ChatRevenueTransactionTypeSuggestedPostEarnings value), required TResult unsupported(ChatRevenueTransactionTypeUnsupported value)}) → TResult -
Available on ChatRevenueTransactionType, provided by the ChatRevenueTransactionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fragmentRefund(ChatRevenueTransactionTypeFragmentRefund value)?, TResult fragmentWithdrawal(ChatRevenueTransactionTypeFragmentWithdrawal value)?, TResult sponsoredMessageEarnings(ChatRevenueTransactionTypeSponsoredMessageEarnings value)?, TResult suggestedPostEarnings(ChatRevenueTransactionTypeSuggestedPostEarnings value)?, TResult unsupported(ChatRevenueTransactionTypeUnsupported value)?, required TResult orElse()}) → TResult -
Available on ChatRevenueTransactionType, provided by the ChatRevenueTransactionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatRevenueTransactionTypeSponsoredMessageEarnings? -
Inherited by:
ChatRevenueTransactionTypeFragmentRefund
ChatRevenueTransactionTypeFragmentWithdrawal
ChatRevenueTransactionTypeSponsoredMessageEarnings
ChatRevenueTransactionTypeSuggestedPostEarnings
ChatRevenueTransactionTypeUnsupported
override
Constants
- constructor → const String