ChatSource class sealed

Describes a reason why an external chat is shown in a chat list

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult mtprotoProxy(ChatSourceMtprotoProxy value), required TResult publicServiceAnnouncement(ChatSourcePublicServiceAnnouncement value)}) → TResult

Available on ChatSource, provided by the ChatSourceExtensions extension

maybeMap<TResult extends Object?>({TResult mtprotoProxy(ChatSourceMtprotoProxy value)?, TResult publicServiceAnnouncement(ChatSourcePublicServiceAnnouncement value)?, required TResult orElse()}) → TResult

Available on ChatSource, provided by the ChatSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ChatSource?
Inherited by: ChatSourceMtprotoProxy ChatSourcePublicServiceAnnouncement

Constants

constructor → const String