ChatStatisticsAdministratorActionsInfo class final
Contains statistics about administrator actions done by a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatStatisticsAdministratorActionsInfo({required int userId, required int deletedMessageCount, required int bannedUserCount, required int restrictedUserCount})
Properties
- bannedUserCount → int
-
bannedUserCount Number of users banned by the administrator
final
- deletedMessageCount → int
-
deletedMessageCount Number of messages deleted by the administrator
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- restrictedUserCount → int
-
restrictedUserCount Number of users restricted by the administrator
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Administrator user identifier
final
Methods
-
copyWith(
{int? userId, int? deletedMessageCount, int? bannedUserCount, int? restrictedUserCount}) → ChatStatisticsAdministratorActionsInfo -
Available on ChatStatisticsAdministratorActionsInfo, provided by the ChatStatisticsAdministratorActionsInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatStatisticsAdministratorActionsInfo?
Constants
- constructor → const String