ChatStatisticsInviterInfo class final
Contains statistics about number of new members invited by a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ChatStatisticsInviterInfo({required int userId, required int addedMemberCount})
Properties
- addedMemberCount → int
-
addedMemberCount Number of new members invited by the user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, int? addedMemberCount}) → ChatStatisticsInviterInfo -
Available on ChatStatisticsInviterInfo, provided by the ChatStatisticsInviterInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ChatStatisticsInviterInfo?
Constants
- constructor → const String