CheckAuthenticationEmailCode class final

Checks the authentication of an email address. Works only when the current authorization state is authorizationStateWaitEmailCode Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Properties

code EmailAddressAuthentication?
code Email address authentication to check
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({EmailAddressAuthentication? code}) CheckAuthenticationEmailCode

Available on CheckAuthenticationEmailCode, provided by the CheckAuthenticationEmailCodeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String