CheckAuthenticationPasskey class final
Checks a passkey to log in to the corresponding account. Call getAuthenticationPasskeyParameters to get parameters for the passkey. Works only when the current authorization state is authorizationStateWaitPhoneNumber or authorizationStateWaitOtherDeviceConfirmation, or if there is no pending authentication query and the current authorization state is authorizationStateWaitPremiumPurchase, authorizationStateWaitEmailAddress, authorizationStateWaitEmailCode, authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationPasskey
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- authenticatorData → String
-
authenticatorData Authenticator data of the application that created the
credential
final
- clientData → String
-
clientData JSON-encoded client data
final
- credentialId → String
-
credentialId Base64url-encoded identifier of the credential
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String
-
signature Cryptographic signature of the credential
final
- userHandle → String
-
userHandle User handle of the passkey
final
Methods
-
copyWith(
{String? credentialId, String? clientData, String? authenticatorData, String? signature, String? userHandle}) → CheckAuthenticationPasskey -
Available on CheckAuthenticationPasskey, provided by the CheckAuthenticationPasskeyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String