CheckAuthenticationPassword class final
Checks the 2-step verification password for correctness. Works only when the current authorization state is authorizationStateWaitPassword Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationPassword
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckAuthenticationPassword({required String password})
Properties
Methods
-
copyWith(
{String? password}) → CheckAuthenticationPassword -
Available on CheckAuthenticationPassword, provided by the CheckAuthenticationPasswordExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String