CheckAuthenticationPremiumPurchase class final
Checks whether an in-store purchase of Telegram Premium is possible before authorization. Works only when the current authorization state is authorizationStateWaitPremiumPurchase Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckAuthenticationPremiumPurchase
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckAuthenticationPremiumPurchase({required String currency, required int amount})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
premiumDayCount The number of days for which the Telegram Premium
subscription will be granted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? currency, int? amount}) → CheckAuthenticationPremiumPurchase -
Available on CheckAuthenticationPremiumPurchase, provided by the CheckAuthenticationPremiumPurchaseExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String