CheckChatUsername class final
Checks whether a username can be set for a chat Returns CheckChatUsernameResult
- Inheritance
-
- Object
- TdFunction
- CheckChatUsername
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckChatUsername({required int chatId, required String username})
Properties
- chatId → int
-
chatId Chat identifier; must be identifier of a supergroup chat, or a
channel chat, or a private chat with self, or 0 if the chat is being
created
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → String
-
username Username to be checked
final
Methods
-
copyWith(
{int? chatId, String? username}) → CheckChatUsername -
Available on CheckChatUsername, provided by the CheckChatUsernameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String