CheckCreatedPublicChatsLimit class final
Checks whether the maximum number of owned public chats has been reached. Returns corresponding error if the limit was reached. The limit can be increased with Telegram Premium Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckCreatedPublicChatsLimit
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PublicChatType?
-
type Type of the public chats, for which to check the limit
final
Methods
-
copyWith(
{PublicChatType? type}) → CheckCreatedPublicChatsLimit -
Available on CheckCreatedPublicChatsLimit, provided by the CheckCreatedPublicChatsLimitExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String