CheckOauthRequestMatchCode class final
Checks a match-code for an OAuth authorization request. If fails, then the authorization request has failed. Otherwise, authorization confirmation dialog must be shown and the link must be processed using acceptOauthRequest or declineOauthRequest Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckOauthRequestMatchCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckOauthRequestMatchCode({required String url, required String matchCode})
Properties
Methods
-
copyWith(
{String? url, String? matchCode}) → CheckOauthRequestMatchCode -
Available on CheckOauthRequestMatchCode, provided by the CheckOauthRequestMatchCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String