CheckWebAppFileDownload class final
Checks whether a file can be downloaded and saved locally by Web App request Returns Ok
- Inheritance
-
- Object
- TdFunction
- CheckWebAppFileDownload
- Available extensions
- Annotations
-
- @immutable
Constructors
- CheckWebAppFileDownload({required int botUserId, required String fileName, required String url})
Properties
- botUserId → int
-
botUserId Identifier of the bot, providing the Web App
final
- fileName → String
-
fileName Name of the file
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url URL of the file
final
Methods
-
copyWith(
{int? botUserId, String? fileName, String? url}) → CheckWebAppFileDownload -
Available on CheckWebAppFileDownload, provided by the CheckWebAppFileDownloadExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String