Checklist class final
Describes a checklist
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Checklist({FormattedText? title, required List<
ChecklistTask> tasks, required bool othersCanAddTasks, required bool canAddTasks, required bool othersCanMarkTasksAsDone, required bool canMarkTasksAsDone})
Properties
- canAddTasks → bool
-
canAddTasks True, if the current user can add tasks to the list if they
have Telegram Premium subscription
final
- canMarkTasksAsDone → bool
-
canMarkTasksAsDone True, if the current user can mark tasks as done or
not done if they have Telegram Premium subscription
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- othersCanAddTasks → bool
-
othersCanAddTasks True, if users other than creator of the list can add
tasks to the list
final
- othersCanMarkTasksAsDone → bool
-
othersCanMarkTasksAsDone True, if users other than creator of the list
can mark tasks as done or not done. If true, then the checklist is called
"group checklist"
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tasks
→ List<
ChecklistTask> -
tasks List of tasks in the checklist
final
- title → FormattedText?
-
title Title of the checklist; may contain only Bold, Italic, Underline,
Strikethrough, Spoiler, CustomEmoji, and DateTime entities
final
Methods
-
copyWith(
{FormattedText? title, List< ChecklistTask> ? tasks, bool? othersCanAddTasks, bool? canAddTasks, bool? othersCanMarkTasksAsDone, bool? canMarkTasksAsDone}) → Checklist -
Available on Checklist, provided by the ChecklistExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String