canMarkTasksAsDone property

bool canMarkTasksAsDone
final

canMarkTasksAsDone True, if the current user can mark tasks as done or not done if they have Telegram Premium subscription

Implementation

final bool canMarkTasksAsDone;