othersCanMarkTasksAsDone property
othersCanMarkTasksAsDone True, if users other than creator of the list can mark tasks as done or not done. If true, then the checklist is called "group checklist"
Implementation
final bool othersCanMarkTasksAsDone;
othersCanMarkTasksAsDone True, if users other than creator of the list can mark tasks as done or not done. If true, then the checklist is called "group checklist"
final bool othersCanMarkTasksAsDone;