ClearAllDraftMessages class final
Clears message drafts in all chats Returns Ok
- Inheritance
-
- Object
- TdFunction
- ClearAllDraftMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- ClearAllDraftMessages({required bool excludeSecretChats})
Properties
- excludeSecretChats → bool
-
excludeSecretChats Pass true to keep local message drafts in secret
chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? excludeSecretChats}) → ClearAllDraftMessages -
Available on ClearAllDraftMessages, provided by the ClearAllDraftMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String