ClickAnimatedEmojiMessage class final
Informs TDLib that a message with an animated emoji was clicked by the user. Returns a big animated sticker to be played or a 404 error if usual animation needs to be played Returns Sticker
- Inheritance
-
- Object
- TdFunction
- ClickAnimatedEmojiMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- ClickAnimatedEmojiMessage({required int chatId, required int messageId})
Properties
Methods
-
copyWith(
{int? chatId, int? messageId}) → ClickAnimatedEmojiMessage -
Available on ClickAnimatedEmojiMessage, provided by the ClickAnimatedEmojiMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String