ClickChatSponsoredMessage class final
Informs TDLib that the user opened the sponsored chat via the button, the name, the chat photo, a mention in the sponsored message text, or the media in the sponsored message Returns Ok
- Inheritance
-
- Object
- TdFunction
- ClickChatSponsoredMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- ClickChatSponsoredMessage({required int chatId, required int messageId, required bool isMediaClick, required bool fromFullscreen})
Properties
- chatId → int
-
chatId Chat identifier of the sponsored message
final
- fromFullscreen → bool
-
fromFullscreen Pass true if the user expanded the video from the
sponsored message fullscreen before the click
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isMediaClick → bool
-
isMediaClick Pass true if the media was clicked in the sponsored message
final
- messageId → int
-
messageId Identifier of the sponsored message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, bool? isMediaClick, bool? fromFullscreen}) → ClickChatSponsoredMessage -
Available on ClickChatSponsoredMessage, provided by the ClickChatSponsoredMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String