fromFullscreen property
fromFullscreen Pass true if the user expanded the video from the sponsored message fullscreen before the click
Implementation
final bool fromFullscreen;
fromFullscreen Pass true if the user expanded the video from the sponsored message fullscreen before the click
final bool fromFullscreen;