CloseBirthdayUser class final
Describes a user who had or will have a birthday soon
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- CloseBirthdayUser({required int userId, Birthdate? birthdate})
Properties
Methods
-
copyWith(
{int? userId, Birthdate? birthdate}) → CloseBirthdayUser -
Available on CloseBirthdayUser, provided by the CloseBirthdayUserExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CloseBirthdayUser?
Constants
- constructor → const String