CloseChat class final
Informs TDLib that the chat is closed by the user. Many useful activities depend on the chat being opened or closed Returns Ok
- Inheritance
-
- Object
- TdFunction
- CloseChat
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{int? chatId}) → CloseChat -
Available on CloseChat, provided by the CloseChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String