ClosedVectorPath class final
Represents a closed vector path. The path begins at the end point of the last command. The coordinate system origin is in the upper-left corner
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ClosedVectorPath({required List<
VectorPathCommand> commands})
Properties
-
commands
→ List<
VectorPathCommand> -
commands List of vector path commands
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< VectorPathCommand> ? commands}) → ClosedVectorPath -
Available on ClosedVectorPath, provided by the ClosedVectorPathExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ClosedVectorPath?
Constants
- constructor → const String