Community class final
Represents a community consisting of supergroup chats, channel chats and chats with bots
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- Community({required int id, required bool haveAccess, required String name, ChatPhotoInfo? photo, required int date, CommunityMemberStatus? status, CommunityPermissions? permissions})
Properties
- date → int
-
date Point in time (Unix timestamp) when the community was joined, or
the point in time when the community was created, in case the user is not
a member of any chat in the community
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- haveAccess → bool
-
haveAccess If false, the community is inaccessible, and the only
information known about the community is inside this class. Identifier of
the community can't be passed to any method
final
- id → int
-
id Community identifier
final
- name → String
-
name Community name
final
- permissions → CommunityPermissions?
-
permissions Actions that non-administrator community members are allowed
to take in the community
final
- photo → ChatPhotoInfo?
-
photo Community photo; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → CommunityMemberStatus?
-
status Status of the current user in the community
final
Methods
-
copyWith(
{int? id, bool? haveAccess, String? name, ChatPhotoInfo? photo, int? date, CommunityMemberStatus? status, CommunityPermissions? permissions}) → Community -
Available on Community, provided by the CommunityExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String