CommunityAdministratorRights class final
Describes rights of the administrator in a community
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- canBanMembers → bool
-
canBanMembers True, if the administrator can ban, or unban community
members
final
- canChangeInfo → bool
-
canChangeInfo True, if the administrator can change the community name,
photo, and other settings
final
- canEditChatList → bool
-
canEditChatList True, if the user can change the chats added to the
community
final
- canManageCommunity → bool
-
canManageCommunity True, if the user is an administrator. Implied by any
other privilege
final
- canPromoteMembers → bool
-
canPromoteMembers True, if the administrator can add new administrators
with a subset of their own privileges or demote administrators that were
directly or indirectly promoted by them
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canManageCommunity, bool? canChangeInfo, bool? canEditChatList, bool? canPromoteMembers, bool? canBanMembers}) → CommunityAdministratorRights -
Available on CommunityAdministratorRights, provided by the CommunityAdministratorRightsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CommunityAdministratorRights?
Constants
- constructor → const String