ComposeTextWithAi class final

Changes text using an AI model; must not be used in secret chats. May return an error with a message "AICOMPOSE_FLOOD_PREMIUM" if Telegram Premium is required to send further requests Returns FormattedText

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ComposeTextWithAi({FormattedText? text, required String translateToLanguageCode, required String styleName, required bool addEmojis})

Properties

addEmojis bool
addEmojis Pass true to add emoji to the text
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleName String
styleName Name of the style of the resulted text; handle updateTextCompositionStyles to get the list of supported styles; pass an empty string to keep the current style of the text
final
text FormattedText?
text The original text
final
translateToLanguageCode String
translateToLanguageCode Pass a language code to which the text will be translated; pass an empty string if translation isn't needed. See translateText.to_language_code for the list of supported values
final

Methods

copyWith({FormattedText? text, String? translateToLanguageCode, String? styleName, bool? addEmojis}) ComposeTextWithAi

Available on ComposeTextWithAi, provided by the ComposeTextWithAiExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String