ConnectAffiliateProgram class final
Connects an affiliate program to the given affiliate. Returns information about the connected affiliate program Returns ConnectedAffiliateProgram
- Inheritance
-
- Object
- TdFunction
- ConnectAffiliateProgram
- Available extensions
- Annotations
-
- @immutable
Constructors
- ConnectAffiliateProgram({AffiliateType? affiliate, required int botUserId})
Properties
- affiliate → AffiliateType?
-
affiliate The affiliate to which the affiliate program will be connected
final
- botUserId → int
-
botUserId Identifier of the bot, which affiliate program is connected
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{AffiliateType? affiliate, int? botUserId}) → ConnectAffiliateProgram -
Available on ConnectAffiliateProgram, provided by the ConnectAffiliateProgramExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String