ConnectedAffiliatePrograms class final
Represents a list of affiliate programs that were connected to an affiliate
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ConnectedAffiliatePrograms({required int totalCount, required List<
ConnectedAffiliateProgram> programs, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
-
programs
→ List<
ConnectedAffiliateProgram> -
programs The list of connected affiliate programs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount The total number of affiliate programs that were connected to
the affiliate
final
Methods
-
copyWith(
{int? totalCount, List< ConnectedAffiliateProgram> ? programs, String? nextOffset}) → ConnectedAffiliatePrograms -
Available on ConnectedAffiliatePrograms, provided by the ConnectedAffiliateProgramsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ConnectedAffiliatePrograms?
Constants
- constructor → const String