ConnectedWebsite class final
Contains information about one website the current user is logged in with Telegram
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- botUserId → int
-
botUserId User identifier of a bot linked with the website
final
- browser → String
-
browser The version of a browser used to log in
final
- domainName → String
-
domainName The domain name of the website
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Website identifier
final
- ipAddress → String
-
ipAddress IP address from which the user was logged in, in
human-readable format
final
- lastActiveDate → int
-
lastActiveDate Point in time (Unix timestamp) when obtained
authorization was last used
final
- location → String
-
location Human-readable description of a country and a region from which
the user was logged in, based on the IP address
final
- logInDate → int
-
logInDate Point in time (Unix timestamp) when the user was logged in
final
- platform → String
-
platform Operating system the browser is running on
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, String? domainName, int? botUserId, String? browser, String? platform, int? logInDate, int? lastActiveDate, String? ipAddress, String? location}) → ConnectedWebsite -
Available on ConnectedWebsite, provided by the ConnectedWebsiteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ConnectedWebsite?
Constants
- constructor → const String