ConnectedWebsites class final
Contains a list of websites the current user is logged in with Telegram
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ConnectedWebsites({required List<
ConnectedWebsite> websites})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
websites
→ List<
ConnectedWebsite> -
websites List of connected websites
final
Methods
-
copyWith(
{List< ConnectedWebsite> ? websites}) → ConnectedWebsites -
Available on ConnectedWebsites, provided by the ConnectedWebsitesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ConnectedWebsites?
Constants
- constructor → const String