Contact class final
Describes a contact of a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- firstName → String
-
firstName First name of the user; 1-64 characters
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastName → String
-
lastName Last name of the user; 0-64 characters
final
- phoneNumber → String
-
phoneNumber Phone number of the user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user, if known; 0 otherwise
final
- vcard → String
-
vcard Additional data about the user in a form of vCard; 0-2048 bytes in
length
final
Methods
-
copyWith(
{String? phoneNumber, String? firstName, String? lastName, String? vcard, int? userId}) → Contact -
Available on Contact, provided by the ContactExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String