CraftGiftResultTooEarly class final
Crafting isn't possible because one of the gifts can't be used for crafting yet
- Inheritance
-
- Object
- TdObject
- CraftGiftResult
- CraftGiftResultTooEarly
- Available extensions
- Annotations
-
- @immutable
Constructors
- CraftGiftResultTooEarly({required int retryAfter})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- retryAfter → int
-
retryAfter Time left before the gift can be used for crafting
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? retryAfter}) → CraftGiftResultTooEarly -
Available on CraftGiftResultTooEarly, provided by the CraftGiftResultTooEarlyExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fail(CraftGiftResultFail value), required TResult invalidGift(CraftGiftResultInvalidGift value), required TResult success(CraftGiftResultSuccess value), required TResult tooEarly(CraftGiftResultTooEarly value)}) → TResult -
Available on CraftGiftResult, provided by the CraftGiftResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fail(CraftGiftResultFail value)?, TResult invalidGift(CraftGiftResultInvalidGift value)?, TResult success(CraftGiftResultSuccess value)?, TResult tooEarly(CraftGiftResultTooEarly value)?, required TResult orElse()}) → TResult -
Available on CraftGiftResult, provided by the CraftGiftResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → CraftGiftResultTooEarly? -
Inherited by:
CraftGiftResultFail
CraftGiftResultInvalidGift
CraftGiftResultSuccess
CraftGiftResultTooEarly
override
Constants
- constructor → const String