CreateBasicGroupChat class final
Returns an existing chat corresponding to a known basic group Returns Chat
- Inheritance
-
- Object
- TdFunction
- CreateBasicGroupChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreateBasicGroupChat({required int basicGroupId, required bool force})
Properties
- basicGroupId → int
-
basicGroupId Basic group identifier
final
- force → bool
-
force Pass true to create the chat without a network request. In this
case all information about the chat except its type, title and photo can
be incorrect
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? basicGroupId, bool? force}) → CreateBasicGroupChat -
Available on CreateBasicGroupChat, provided by the CreateBasicGroupChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String