CreateCall class final
Creates a new call Returns CallId
- Inheritance
-
- Object
- TdFunction
- CreateCall
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreateCall({required int userId, CallProtocol? protocol, required bool isVideo})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isVideo → bool
-
isVideo Pass true to create a video call
final
- protocol → CallProtocol?
-
protocol The call protocols supported by the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user to be called
final
Methods
-
copyWith(
{int? userId, CallProtocol? protocol, bool? isVideo}) → CreateCall -
Available on CreateCall, provided by the CreateCallExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String