CreateChatFolder class final
Creates new chat folder. Returns information about the created chat folder. There can be up to getOption("chat_folder_count_max") chat folders, but the limit can be increased with Telegram Premium Returns ChatFolderInfo
- Inheritance
-
- Object
- TdFunction
- CreateChatFolder
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreateChatFolder({ChatFolder? folder})
Properties
- folder → ChatFolder?
-
folder The new chat folder
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolder? folder}) → CreateChatFolder -
Available on CreateChatFolder, provided by the CreateChatFolderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String