CreateChatFolderInviteLink class final
Creates a new invite link for a chat folder. A link can be created for a chat folder if it has only pinned and included chats Returns ChatFolderInviteLink
- Inheritance
-
- Object
- TdFunction
- CreateChatFolderInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
-
CreateChatFolderInviteLink({required int chatFolderId, required String name, required List<
int> chatIds})
Properties
- chatFolderId → int
-
chatFolderId Chat folder identifier
final
-
chatIds
→ List<
int> -
chatIds Identifiers of chats to be accessible by the invite link. Use
getChatsForChatFolderInviteLink to get suitable chats. Basic groups will
be automatically converted to supergroups before link creation
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the link; 0-32 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId, String? name, List< int> ? chatIds}) → CreateChatFolderInviteLink -
Available on CreateChatFolderInviteLink, provided by the CreateChatFolderInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String