CreateChatSubscriptionInviteLink class final
Creates a new subscription invite link for a channel chat. Requires can_invite_users right in the chat Returns ChatInviteLink
- Inheritance
-
- Object
- TdFunction
- CreateChatSubscriptionInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- CreateChatSubscriptionInviteLink({required int chatId, required String name, StarSubscriptionPricing? subscriptionPricing})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Invite link name; 0-32 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionPricing → StarSubscriptionPricing?
-
subscriptionPricing Information about subscription plan that will be
applied to the users joining the chat via the link. Subscription period
must be 2592000 in production environment, and 60 or 300 if Telegram test
environment is used
final
Methods
-
copyWith(
{int? chatId, String? name, StarSubscriptionPricing? subscriptionPricing}) → CreateChatSubscriptionInviteLink -
Available on CreateChatSubscriptionInviteLink, provided by the CreateChatSubscriptionInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String