CreateForumTopic class final

Creates a topic in a forum supergroup chat or a chat with a bot with topics; requires can_manage_topics administrator or can_create_topics member right in the supergroup Returns ForumTopicInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateForumTopic({required int chatId, required String name, required bool isNameImplicit, ForumTopicIcon? icon})

Properties

chatId int
chatId Identifier of the chat
final
hashCode int
The hash code for this object.
no setteroverride
icon ForumTopicIcon?
icon Icon of the topic. Icon color must be one of 0x6FB9F0, 0xFFD67E, 0xCB86DB, 0x8EEE98, 0xFF93B2, or 0xFB6F5F. Telegram Premium users can use any custom emoji as topic icon, other users can use only a custom emoji returned by getForumTopicDefaultIcons
final
isNameImplicit bool
isNameImplicit Pass true if the name of the topic wasn't entered explicitly; for chats with bots only
final
name String
name Name of the topic; 1-128 characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, String? name, bool? isNameImplicit, ForumTopicIcon? icon}) CreateForumTopic

Available on CreateForumTopic, provided by the CreateForumTopicExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String