CreateGiftCollection class final
Creates a collection from gifts on the current user's or a channel's profile page; requires can_post_messages administrator right in the channel chat. An owner can have up to getOption("gift_collection_count_max") gift collections. The new collection will be added to the end of the gift collection list of the owner. Returns the created collection Returns GiftCollection
- Inheritance
-
- Object
- TdFunction
- CreateGiftCollection
- Available extensions
- Annotations
-
- @immutable
Constructors
-
CreateGiftCollection({MessageSender? ownerId, required String name, required List<
String> receivedGiftIds})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the collection; 1-12 characters
final
- ownerId → MessageSender?
-
ownerId Identifier of the user or the channel chat that received the
gifts
final
-
receivedGiftIds
→ List<
String> -
receivedGiftIds Identifier of the gifts to add to the collection;
0-getOption("gift_collection_size_max") identifiers
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageSender? ownerId, String? name, List< String> ? receivedGiftIds}) → CreateGiftCollection -
Available on CreateGiftCollection, provided by the CreateGiftCollectionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String