CreateStoryAlbum class final
Creates an album of stories; requires can_edit_stories administrator right for supergroup and channel chats Returns StoryAlbum
- Inheritance
-
- Object
- TdFunction
- CreateStoryAlbum
- Available extensions
- Annotations
-
- @immutable
Constructors
-
CreateStoryAlbum({required int storyPosterChatId, required String name, required List<
int> storyIds})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the album; 1-12 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storyIds
→ List<
int> -
storyIds Identifiers of stories to add to the album;
0-getOption("story_album_size_max") identifiers
final
- storyPosterChatId → int
-
storyPosterChatId Identifier of the chat that posted the stories
final
Methods
-
copyWith(
{int? storyPosterChatId, String? name, List< int> ? storyIds}) → CreateStoryAlbum -
Available on CreateStoryAlbum, provided by the CreateStoryAlbumExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String