CreateVideoChat class final

Creates a video chat (a group call bound to a chat); for basic groups, supergroups and channels only; requires can_manage_video_chats administrator right Returns GroupCallId

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

CreateVideoChat({required int chatId, required String title, required int startDate, required bool isRtmpStream})

Properties

chatId int
chatId Identifier of a chat in which the video chat will be created
final
hashCode int
The hash code for this object.
no setteroverride
isRtmpStream bool
isRtmpStream Pass true to create an RTMP stream instead of an ordinary video chat
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate int
startDate Point in time (Unix timestamp) when the group call is expected to be started by an administrator; 0 to start the video chat immediately. The date must be at least 10 seconds and at most 8 days in the future
final
title String
title Group call title; if empty, chat title will be used
final

Methods

copyWith({int? chatId, String? title, int? startDate, bool? isRtmpStream}) CreateVideoChat

Available on CreateVideoChat, provided by the CreateVideoChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String