DateRange class final
Represents a date range
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Properties
- endDate → int
-
endDate Point in time (Unix timestamp) at which the date range ends
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate → int
-
startDate Point in time (Unix timestamp) at which the date range begins
final
Methods
-
copyWith(
{int? startDate, int? endDate}) → DateRange -
Available on DateRange, provided by the DateRangeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String