DeclineSuggestedPost class final
Declines a suggested post in a channel direct messages chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeclineSuggestedPost
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeclineSuggestedPost({required int chatId, required int messageId, required String comment})
Properties
- chatId → int
-
chatId Chat identifier of the channel direct messages chat
final
- comment → String
-
comment Comment for the creator of the suggested post; 0-128 characters
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message with the suggested post. Use
messageProperties.can_be_declined to check whether the suggested post can
be declined
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, String? comment}) → DeclineSuggestedPost -
Available on DeclineSuggestedPost, provided by the DeclineSuggestedPostExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String