DeleteAllRevokedChatInviteLinks class final
Deletes all revoked chat invite links created by a given chat administrator. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteAllRevokedChatInviteLinks
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteAllRevokedChatInviteLinks({required int chatId, required int creatorUserId})
Properties
- chatId → int
-
chatId Chat identifier
final
- creatorUserId → int
-
creatorUserId User identifier of a chat administrator, which links will
be deleted. Must be an identifier of the current user for non-owner
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? creatorUserId}) → DeleteAllRevokedChatInviteLinks -
Available on DeleteAllRevokedChatInviteLinks, provided by the DeleteAllRevokedChatInviteLinksExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String