DeleteBotMediaPreviews class final
Deletes media previews from the list of media previews of a bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteBotMediaPreviews
- Available extensions
- Annotations
-
- @immutable
Constructors
-
DeleteBotMediaPreviews({required int botUserId, required String languageCode, required List<
int> fileIds})
Properties
- botUserId → int
-
botUserId Identifier of the target bot. The bot must be owned and must
have the main Web App
final
-
fileIds
→ List<
int> -
fileIds File identifiers of the media to delete
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode Language code of the media previews to delete
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, List< int> ? fileIds}) → DeleteBotMediaPreviews -
Available on DeleteBotMediaPreviews, provided by the DeleteBotMediaPreviewsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String