DeleteBusinessMessages class final
Deletes messages on behalf of a business account; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteBusinessMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
-
DeleteBusinessMessages({required String businessConnectionId, required List<
int> messageIds})
Properties
- businessConnectionId → String
-
businessConnectionId Unique identifier of business connection through
which the messages were received
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messageIds
→ List<
int> -
messageIds Identifier of the messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId, List< int> ? messageIds}) → DeleteBusinessMessages -
Available on DeleteBusinessMessages, provided by the DeleteBusinessMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String