DeleteChat class final
Deletes a chat along with all messages in the corresponding chat for all chat members. For group chats this will release the usernames and remove all members. Use the field chat.can_be_deleted_for_all_users to find whether the method can be applied to the chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteChat({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → DeleteChat -
Available on DeleteChat, provided by the DeleteChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String