DeleteChatBackground class final
Deletes background in a specific chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteChatBackground
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteChatBackground({required int chatId, required bool restorePrevious})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- restorePrevious → bool
-
restorePrevious Pass true to restore previously set background. Can be
used only in private and secret chats with non-deleted users if
userFullInfo.set_chat_background == true. Supposed to be used from
messageChatSetBackground messages with the currently set background that
was set for both sides by the other user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? restorePrevious}) → DeleteChatBackground -
Available on DeleteChatBackground, provided by the DeleteChatBackgroundExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String