DeleteChatMessagesByDate class final
Deletes all messages between the specified dates in a chat. Supported only for private chats and basic groups. Messages sent in the last 30 seconds will not be deleted Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteChatMessagesByDate
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteChatMessagesByDate({required int chatId, required int minDate, required int maxDate, required bool revoke})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxDate → int
-
maxDate The maximum date of the messages to delete
final
- minDate → int
-
minDate The minimum date of the messages to delete
final
- revoke → bool
-
revoke Pass true to delete chat messages for all users; private chats
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? minDate, int? maxDate, bool? revoke}) → DeleteChatMessagesByDate -
Available on DeleteChatMessagesByDate, provided by the DeleteChatMessagesByDateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String