DeleteDirectMessagesChatTopicHistory class final

Deletes all messages in the topic in a channel direct messages chat administered by the current user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteDirectMessagesChatTopicHistory({required int chatId, required int topicId})

Properties

chatId int
chatId Chat identifier of the channel direct messages chat
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId int
topicId Identifier of the topic which messages will be deleted
final

Methods

copyWith({int? chatId, int? topicId}) DeleteDirectMessagesChatTopicHistory

Available on DeleteDirectMessagesChatTopicHistory, provided by the DeleteDirectMessagesChatTopicHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String