DeleteDirectMessagesChatTopicMessagesByDate class final
Deletes all messages between the specified dates in the topic in a channel direct messages chat administered by the current user. Messages sent in the last 30 seconds will not be deleted Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteDirectMessagesChatTopicMessagesByDate
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteDirectMessagesChatTopicMessagesByDate({required int chatId, required int topicId, required int minDate, required int maxDate})
Properties
- chatId → int
-
chatId Chat identifier of the channel direct messages chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxDate → int
-
maxDate The maximum date of the messages to delete
final
- minDate → int
-
minDate The minimum date of the messages to delete
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → int
-
topicId Identifier of the topic which messages will be deleted
final
Methods
-
copyWith(
{int? chatId, int? topicId, int? minDate, int? maxDate}) → DeleteDirectMessagesChatTopicMessagesByDate -
Available on DeleteDirectMessagesChatTopicMessagesByDate, provided by the DeleteDirectMessagesChatTopicMessagesByDateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String