DeleteEphemeralMessage class final
Deletes an ephemeral message; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteEphemeralMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteEphemeralMessage({required int chatId, required int receiverUserId, required int ephemeralMessageId})
Properties
- chatId → int
-
chatId Chat identifier
final
- ephemeralMessageId → int
-
ephemeralMessageId Identifiers of the message to be deleted
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- receiverUserId → int
-
receiverUserId Identifier of the user who received the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? receiverUserId, int? ephemeralMessageId}) → DeleteEphemeralMessage -
Available on DeleteEphemeralMessage, provided by the DeleteEphemeralMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String