DeleteGiftCollection class final

Deletes a gift collection. If the collection is owned by a channel chat, then requires can_post_messages administrator right in the channel chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

DeleteGiftCollection({MessageSender? ownerId, required int collectionId})

Properties

collectionId int
collectionId Identifier of the gift collection
final
hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that owns the collection
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId, int? collectionId}) DeleteGiftCollection

Available on DeleteGiftCollection, provided by the DeleteGiftCollectionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String