DeleteGroupCallMessages class final
Deletes messages in a group call; for live story calls only. Requires groupCallMessage.can_be_deleted right Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteGroupCallMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
-
DeleteGroupCallMessages({required int groupCallId, required List<
int> messageIds, required bool reportSpam})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messageIds
→ List<
int> -
messageIds Identifiers of the messages to be deleted
final
- reportSpam → bool
-
reportSpam Pass true to report the messages as spam
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, List< int> ? messageIds, bool? reportSpam}) → DeleteGroupCallMessages -
Available on DeleteGroupCallMessages, provided by the DeleteGroupCallMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String