DeleteLanguagePack class final
Deletes all information about a language pack in the current localization target. The language pack which is currently in use (including base language pack) or is being synchronized can't be deleted. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteLanguagePack
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteLanguagePack({required String languagePackId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languagePackId → String
-
languagePackId Identifier of the language pack to delete
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languagePackId}) → DeleteLanguagePack -
Available on DeleteLanguagePack, provided by the DeleteLanguagePackExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String