DeleteMessageReactionsFromSender class final
Deletes all reactions added by the specified sender on a message Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteMessageReactionsFromSender
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteMessageReactionsFromSender({required int chatId, required int messageId, MessageSender? senderId})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message containing the reactions. Use
messageProperties.can_delete_reactions to check whether the method can be
used for a message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the sender of reactions to delete
final
Methods
-
copyWith(
{int? chatId, int? messageId, MessageSender? senderId}) → DeleteMessageReactionsFromSender -
Available on DeleteMessageReactionsFromSender, provided by the DeleteMessageReactionsFromSenderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String