DeletePollOption class final
Deletes an option from a poll Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeletePollOption
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeletePollOption({required int chatId, required int messageId, required String optionId})
Properties
- chatId → int
-
chatId Identifier of the chat to which the poll belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message containing the poll
final
- optionId → String
-
optionId Unique identifier of the option. Use
pollOptionProperties.can_be_deleted to check whether the option can be
deleted by the user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, String? optionId}) → DeletePollOption -
Available on DeletePollOption, provided by the DeletePollOptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String