DeleteProfilePhoto class final
Deletes a profile photo Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteProfilePhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteProfilePhoto({required int profilePhotoId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- profilePhotoId → int
-
profilePhotoId Identifier of the profile photo to delete
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? profilePhotoId}) → DeleteProfilePhoto -
Available on DeleteProfilePhoto, provided by the DeleteProfilePhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String