DeleteStoryAlbum class final
Deletes a story album. If the album is owned by a supergroup or a channel chat, then requires can_edit_stories administrator right in the chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- DeleteStoryAlbum
- Available extensions
- Annotations
-
- @immutable
Constructors
- DeleteStoryAlbum({required int chatId, required int storyAlbumId})
Properties
- chatId → int
-
chatId Identifier of the chat that owns the stories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyAlbumId → int
-
storyAlbumId Identifier of the story album
final
Methods
-
copyWith(
{int? chatId, int? storyAlbumId}) → DeleteStoryAlbum -
Available on DeleteStoryAlbum, provided by the DeleteStoryAlbumExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String