DirectMessagesChatTopic class final
Contains information about a topic in a channel direct messages chat administered by the current user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- DirectMessagesChatTopic({required int chatId, required int id, MessageSender? senderId, required int order, required bool canSendUnpaidMessages, required bool isMarkedAsUnread, required int unreadCount, required int lastReadInboxMessageId, required int lastReadOutboxMessageId, required int unreadReactionCount, Message? lastMessage, DraftMessage? draftMessage})
Properties
- canSendUnpaidMessages → bool
-
canSendUnpaidMessages True, if the other party can send unpaid messages
even if the chat has paid messages enabled
final
- chatId → int
-
chatId Identifier of the chat to which the topic belongs
final
- draftMessage → DraftMessage?
-
draftMessage A draft of a message in the topic; may be null if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique topic identifier
final
- isMarkedAsUnread → bool
-
isMarkedAsUnread True, if the topic is marked as unread
final
- lastMessage → Message?
-
lastMessage Last message in the topic; may be null if none or unknown
final
- lastReadInboxMessageId → int
-
lastReadInboxMessageId Identifier of the last read incoming message
final
- lastReadOutboxMessageId → int
-
lastReadOutboxMessageId Identifier of the last read outgoing message
final
- order → int
-
order A parameter used to determine order of the topic in the topic
list. Topics must be sorted by the order in descending order
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the user or chat that sends the messages to the
topic
final
- unreadCount → int
-
unreadCount Number of unread messages in the chat
final
- unreadReactionCount → int
-
unreadReactionCount Number of messages with unread reactions in the chat
final
Methods
-
copyWith(
{int? chatId, int? id, MessageSender? senderId, int? order, bool? canSendUnpaidMessages, bool? isMarkedAsUnread, int? unreadCount, int? lastReadInboxMessageId, int? lastReadOutboxMessageId, int? unreadReactionCount, Message? lastMessage, DraftMessage? draftMessage}) → DirectMessagesChatTopic -
Available on DirectMessagesChatTopic, provided by the DirectMessagesChatTopicExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DirectMessagesChatTopic?
Constants
- constructor → const String