DisableAllSupergroupUsernames class final
Disables all active non-editable usernames of a supergroup or channel, requires owner privileges in the supergroup or channel Returns Ok
- Inheritance
-
- Object
- TdFunction
- DisableAllSupergroupUsernames
- Available extensions
- Annotations
-
- @immutable
Constructors
- DisableAllSupergroupUsernames({required int supergroupId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supergroupId → int
-
supergroupId Identifier of the supergroup or channel
final
Methods
-
copyWith(
{int? supergroupId}) → DisableAllSupergroupUsernames -
Available on DisableAllSupergroupUsernames, provided by the DisableAllSupergroupUsernamesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String