Document class final
Describes a document of any type
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- document → File?
-
document File containing the document
final
- fileName → String
-
fileName Original name of the file; as defined by the sender
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mimeType → String
-
mimeType MIME type of the file; as defined by the sender
final
- minithumbnail → Minithumbnail?
-
minithumbnail Document minithumbnail; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → Thumbnail?
-
thumbnail Document thumbnail in JPEG or PNG format (PNG will be used
only for background patterns); as defined by the sender; may be null
final
Methods
-
copyWith(
{String? fileName, String? mimeType, Minithumbnail? minithumbnail, Thumbnail? thumbnail, File? document}) → Document -
Available on Document, provided by the DocumentExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String