DraftMessage class final
Contains information about a message draft
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- DraftMessage({InputMessageReplyTo? replyTo, required int date, DraftMessageContent? content, required int effectId, InputSuggestedPostInfo? suggestedPostInfo})
Properties
- content → DraftMessageContent?
-
content Content of the message draft
final
- date → int
-
date Point in time (Unix timestamp) when the draft was created
final
- effectId → int
-
effectId Identifier of the effect to apply to the message when it is
sent; 0 if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message to be replied;
inputMessageReplyToStory is unsupported; may be null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestedPostInfo → InputSuggestedPostInfo?
-
suggestedPostInfo Information about the suggested post; may be null if
none
final
Methods
-
copyWith(
{InputMessageReplyTo? replyTo, int? date, DraftMessageContent? content, int? effectId, InputSuggestedPostInfo? suggestedPostInfo}) → DraftMessage -
Available on DraftMessage, provided by the DraftMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DraftMessage?
Constants
- constructor → const String