DraftMessageContentVideoNote class final
A video note message draft
- Inheritance
-
- Object
- TdObject
- DraftMessageContent
- DraftMessageContentVideoNote
- Available extensions
- Annotations
-
- @immutable
Constructors
- DraftMessageContentVideoNote({required String filePath, required int duration, required int length, MessageSelfDestructType? selfDestructType})
Properties
- duration → int
-
duration Duration of the video, in seconds; 0-60
final
- filePath → String
-
filePath Path to the file with the video note
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Video width and height; must be positive and not greater than 640
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfDestructType → MessageSelfDestructType?
-
selfDestructType Video note self-destruct type; may be null if none;
pass null if none; private chats only
final
Methods
-
copyWith(
{String? filePath, int? duration, int? length, MessageSelfDestructType? selfDestructType}) → DraftMessageContentVideoNote -
Available on DraftMessageContentVideoNote, provided by the DraftMessageContentVideoNoteExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult richMessage(DraftMessageContentRichMessage value), required TResult text(DraftMessageContentText value), required TResult videoNote(DraftMessageContentVideoNote value), required TResult voiceNote(DraftMessageContentVoiceNote value)}) → TResult -
Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult richMessage(DraftMessageContentRichMessage value)?, TResult text(DraftMessageContentText value)?, TResult videoNote(DraftMessageContentVideoNote value)?, TResult voiceNote(DraftMessageContentVoiceNote value)?, required TResult orElse()}) → TResult -
Available on DraftMessageContent, provided by the DraftMessageContentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → DraftMessageContentVideoNote? -
Inherited by:
DraftMessageContentRichMessage
DraftMessageContentText
DraftMessageContentVideoNote
DraftMessageContentVoiceNote
override
Constants
- constructor → const String