EditBusinessStory class final

Changes a story posted by the bot on behalf of a business account; for bots only Returns Story

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditBusinessStory({required int storyPosterChatId, required int storyId, InputStoryContent? content, InputStoryAreas? areas, FormattedText? caption, StoryPrivacySettings? privacySettings})

Properties

areas InputStoryAreas?
areas New clickable rectangle areas to be shown on the story media
final
caption FormattedText?
caption New story caption
final
content InputStoryContent?
content New content of the story
final
hashCode int
The hash code for this object.
no setteroverride
privacySettings StoryPrivacySettings?
privacySettings The new privacy settings for the story
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story to edit
final
storyPosterChatId int
storyPosterChatId Identifier of the chat that posted the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId, InputStoryContent? content, InputStoryAreas? areas, FormattedText? caption, StoryPrivacySettings? privacySettings}) EditBusinessStory

Available on EditBusinessStory, provided by the EditBusinessStoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String