EditChatFolder class final
Edits existing chat folder. Returns information about the edited chat folder Returns ChatFolderInfo
- Inheritance
-
- Object
- TdFunction
- EditChatFolder
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditChatFolder({required int chatFolderId, ChatFolder? folder})
Properties
- chatFolderId → int
-
chatFolderId Chat folder identifier
final
- folder → ChatFolder?
-
folder The edited chat folder
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId, ChatFolder? folder}) → EditChatFolder -
Available on EditChatFolder, provided by the EditChatFolderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String