EditChatInviteLink class final
Edits a non-primary invite link for a chat. Available in basic groups, supergroups, and channels. If the link creates a subscription, then expiration_date, member_limit and creates_join_request must not be used. Requires administrator privileges and can_invite_users right in the chat for own links and owner privileges for other links Returns ChatInviteLink
- Inheritance
-
- Object
- TdFunction
- EditChatInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Chat identifier
final
- createsJoinRequest → bool
-
createsJoinRequest Pass true if users joining the chat via the link need
to be approved by chat administrators. In this case, member_limit must be
0
final
- expirationDate → int
-
expirationDate Point in time (Unix timestamp) when the link will expire;
pass 0 if never
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Invite link to be edited
final
- memberLimit → int
-
memberLimit The maximum number of chat members that can join the chat
via the link simultaneously; 0-99999; pass 0 if not limited
final
- name → String
-
name Invite link name; 0-32 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? inviteLink, String? name, int? expirationDate, int? memberLimit, bool? createsJoinRequest}) → EditChatInviteLink -
Available on EditChatInviteLink, provided by the EditChatInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String