EditChatSubscriptionInviteLink class final
Edits a subscription invite link for a channel chat. Requires can_invite_users right in the chat for own links and owner privileges for other links Returns ChatInviteLink
- Inheritance
-
- Object
- TdFunction
- EditChatSubscriptionInviteLink
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditChatSubscriptionInviteLink({required int chatId, required String inviteLink, required String name})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Invite link to be edited
final
- name → String
-
name Invite link name; 0-32 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? inviteLink, String? name}) → EditChatSubscriptionInviteLink -
Available on EditChatSubscriptionInviteLink, provided by the EditChatSubscriptionInviteLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String