EditEphemeralMessage class final
Edits the text, caption or reply markup of an ephemeral message sent by the bot; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- EditEphemeralMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditEphemeralMessage({required int chatId, required int receiverUserId, required int ephemeralMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- chatId → int
-
chatId The chat the message belongs to
final
- ephemeralMessageId → int
-
ephemeralMessageId Identifier of the ephemeral message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inputMessageContent → InputMessageContent?
-
inputMessageContent New content of the message; pass null to edit only
reply markup. Must be one of the following types: inputMessageText,
inputMessageAnimation, inputMessageAudio, inputMessageDocument,
inputMessagePhoto, inputMessageSticker, inputMessageVideo,
inputMessageVideoNote, inputMessageVoiceNote
final
- receiverUserId → int
-
receiverUserId Identifier of the user who received the message
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? receiverUserId, int? ephemeralMessageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditEphemeralMessage -
Available on EditEphemeralMessage, provided by the EditEphemeralMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String