EditInlineMessageLiveLocation class final
Edits the content of a live location in an inline message sent via a bot; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- EditInlineMessageLiveLocation
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditInlineMessageLiveLocation({required String inlineMessageId, ReplyMarkup? replyMarkup, LiveLocation? location})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inlineMessageId → String
-
inlineMessageId Inline message identifier
final
- location → LiveLocation?
-
location New live location of the message; pass null to stop sharing the
live location. If the new live_period isn't set to 0x7FFFFFFF, then it
must not exceed the current live_period by more than a day, and the live
location expiration date must remain in the next 90 days
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? inlineMessageId, ReplyMarkup? replyMarkup, LiveLocation? location}) → EditInlineMessageLiveLocation -
Available on EditInlineMessageLiveLocation, provided by the EditInlineMessageLiveLocationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String