EditMessageLiveLocation class final
Edits the message content of a live location. Messages can be edited for a limited period of time specified in the live location. Returns the edited message after the edit is completed on the server side Returns Message
- Inheritance
-
- Object
- TdFunction
- EditMessageLiveLocation
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditMessageLiveLocation({required int chatId, required int messageId, ReplyMarkup? replyMarkup, LiveLocation? location})
Properties
- chatId → int
-
chatId The chat the message belongs to
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → LiveLocation?
-
location New live location of the message; pass null to stop sharing the
live location. If the new live_period isn't set to 0x7FFFFFFF, then it
must not exceed the current live_period by more than a day, and the live
location expiration date must remain in the next 90 days
final
- messageId → int
-
messageId Identifier of the message. Use messageProperties.can_be_edited
to check whether the message can be edited
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none; for bots
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, ReplyMarkup? replyMarkup, LiveLocation? location}) → EditMessageLiveLocation -
Available on EditMessageLiveLocation, provided by the EditMessageLiveLocationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String