EditMessageText class final
Edits the text of a message (or a text of a game message). Returns the edited message after the edit is completed on the server side Returns Message
- Inheritance
-
- Object
- TdFunction
- EditMessageText
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditMessageText({required int chatId, required int messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- chatId → int
-
chatId The chat the message belongs to
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inputMessageContent → InputMessageContent?
-
inputMessageContent New text content of the message. Must be of type
inputMessageText or inputMessageRichMessage
final
- messageId → int
-
messageId Identifier of the message. Use messageProperties.can_be_edited
to check whether the message can be edited
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none; for bots
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → EditMessageText -
Available on EditMessageText, provided by the EditMessageTextExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String