EditProxy class final
Edits an existing proxy server for network requests. Can be called before authorization Returns AddedProxy
- Inheritance
-
- Object
- TdFunction
- EditProxy
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- comment → String
-
comment New comment for the proxy
final
- enable → bool
-
enable Pass true to immediately enable the proxy
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- proxy → Proxy?
-
proxy The new information about the proxy
final
- proxyId → int
-
proxyId Proxy identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? proxyId, Proxy? proxy, bool? enable, String? comment}) → EditProxy -
Available on EditProxy, provided by the EditProxyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String