EditStory class final
Changes content and caption of a story. Can be called only if story.can_be_edited == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- EditStory
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditStory({required int storyPosterChatId, required int storyId, InputStoryContent? content, InputStoryAreas? areas, FormattedText? caption})
Properties
- areas → InputStoryAreas?
-
areas New clickable rectangle areas to be shown on the story media; pass
null to keep the current areas. Areas can't be edited if story content
isn't changed
final
- caption → FormattedText?
-
caption New story caption; pass null to keep the current caption
final
- content → InputStoryContent?
-
content New content of the story; pass null to keep the current content
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId Identifier of the story to edit
final
- storyPosterChatId → int
-
storyPosterChatId Identifier of the chat that posted the story
final
Methods
-
copyWith(
{int? storyPosterChatId, int? storyId, InputStoryContent? content, InputStoryAreas? areas, FormattedText? caption}) → EditStory -
Available on EditStory, provided by the EditStoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String