EditStoryCover class final

Changes cover of a video story. Can be called only if story.can_be_edited == true and the story isn't being edited now Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditStoryCover({required int storyPosterChatId, required int storyId, required double coverFrameTimestamp})

Properties

coverFrameTimestamp double
coverFrameTimestamp New timestamp of the frame, which will be used as video thumbnail
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Identifier of the story to edit
final
storyPosterChatId int
storyPosterChatId Identifier of the chat that posted the story
final

Methods

copyWith({int? storyPosterChatId, int? storyId, double? coverFrameTimestamp}) EditStoryCover

Available on EditStoryCover, provided by the EditStoryCoverExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String