EditTextCompositionStyle class final

Edits a custom text composition style that was created by the current user Returns TextCompositionStyle

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EditTextCompositionStyle({required String name, required String title, required int customEmojiId, required String prompt, required bool showCreator})

Properties

customEmojiId int
customEmojiId Identifier of the custom emoji corresponding to the style
final
hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the style
final
prompt String
prompt Prompt that will be used for text composition; 1-getOption("text_composition_style_prompt_length_max") characters
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCreator bool
showCreator Pass true if the current user must be shown as the creator of the style
final
title String
title Title of the style; 1-getOption("text_composition_style_title_length_max") characters
final

Methods

copyWith({String? name, String? title, int? customEmojiId, String? prompt, bool? showCreator}) EditTextCompositionStyle

Available on EditTextCompositionStyle, provided by the EditTextCompositionStyleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String