EditUserStarSubscription class final
Cancels or re-enables Telegram Star subscription for a user; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- EditUserStarSubscription
- Available extensions
- Annotations
-
- @immutable
Constructors
- EditUserStarSubscription({required int userId, required String telegramPaymentChargeId, required bool isCanceled})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCanceled → bool
-
isCanceled Pass true to cancel the subscription; pass false to allow the
user to enable it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telegramPaymentChargeId → String
-
telegramPaymentChargeId Telegram payment identifier of the subscription
final
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, String? telegramPaymentChargeId, bool? isCanceled}) → EditUserStarSubscription -
Available on EditUserStarSubscription, provided by the EditUserStarSubscriptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String