EmailAddressAuthentication class sealed
Contains authentication data for an email address
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult appleId(EmailAddressAuthenticationAppleId value), required TResult code(EmailAddressAuthenticationCode value), required TResult googleId(EmailAddressAuthenticationGoogleId value)}) → TResult -
Available on EmailAddressAuthentication, provided by the EmailAddressAuthenticationExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult appleId(EmailAddressAuthenticationAppleId value)?, TResult code(EmailAddressAuthenticationCode value)?, TResult googleId(EmailAddressAuthenticationGoogleId value)?, required TResult orElse()}) → TResult -
Available on EmailAddressAuthentication, provided by the EmailAddressAuthenticationExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmailAddressAuthentication? - Inherited by: EmailAddressAuthenticationAppleId EmailAddressAuthenticationCode EmailAddressAuthenticationGoogleId
Constants
- constructor → const String