EmojiCategories class final
Represents a list of emoji categories
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
EmojiCategories({required List<
EmojiCategory> categories})
Properties
-
categories
→ List<
EmojiCategory> -
categories List of categories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< EmojiCategory> ? categories}) → EmojiCategories -
Available on EmojiCategories, provided by the EmojiCategoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiCategories?
Constants
- constructor → const String