EmojiCategory class final
Describes an emoji category
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- EmojiCategory({required String name, Sticker? icon, EmojiCategorySource? source, required bool isGreeting})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- icon → Sticker?
-
icon Custom emoji sticker, which represents icon of the category
final
- isGreeting → bool
-
isGreeting True, if the category must be shown first when choosing a
sticker for the start page
final
- name → String
-
name Name of the category
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → EmojiCategorySource?
-
source Source of stickers for the emoji category
final
Methods
-
copyWith(
{String? name, Sticker? icon, EmojiCategorySource? source, bool? isGreeting}) → EmojiCategory -
Available on EmojiCategory, provided by the EmojiCategoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiCategory?
Constants
- constructor → const String