EmojiKeywords class final

Represents a list of emojis with their keywords

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiKeywords({required List<EmojiKeyword> emojiKeywords})

Properties

emojiKeywords List<EmojiKeyword>
emojiKeywords List of emojis with their keywords
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<EmojiKeyword>? emojiKeywords}) EmojiKeywords

Available on EmojiKeywords, provided by the EmojiKeywordsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiKeywords?

Constants

constructor → const String