EmojiStatus class final
Describes an emoji to be shown instead of the Telegram Premium badge
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- EmojiStatus({EmojiStatusType? type, required int expirationDate})
Properties
- expirationDate → int
-
expirationDate Point in time (Unix timestamp) when the status will
expire; 0 if never
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → EmojiStatusType?
-
type Type of the emoji status
final
Methods
-
copyWith(
{EmojiStatusType? type, int? expirationDate}) → EmojiStatus -
Available on EmojiStatus, provided by the EmojiStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiStatus?
Constants
- constructor → const String