EmojiStatusCustomEmojis class final
Contains a list of custom emoji identifiers for emoji statuses
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
EmojiStatusCustomEmojis({required List<
int> customEmojiIds})
Properties
-
customEmojiIds
→ List<
int> -
customEmojiIds The list of custom emoji identifiers
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< int> ? customEmojiIds}) → EmojiStatusCustomEmojis -
Available on EmojiStatusCustomEmojis, provided by the EmojiStatusCustomEmojisExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiStatusCustomEmojis?
Constants
- constructor → const String