EmojiStatusTypeCustomEmoji class final

A custom emoji set as emoji status

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

EmojiStatusTypeCustomEmoji({required int customEmojiId})

Properties

customEmojiId int
customEmojiId Identifier of the custom emoji in stickerFormatTgs format
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? customEmojiId}) EmojiStatusTypeCustomEmoji

Available on EmojiStatusTypeCustomEmoji, provided by the EmojiStatusTypeCustomEmojiExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(EmojiStatusTypeCustomEmoji value), required TResult upgradedGift(EmojiStatusTypeUpgradedGift value)}) → TResult

Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(EmojiStatusTypeCustomEmoji value)?, TResult upgradedGift(EmojiStatusTypeUpgradedGift value)?, required TResult orElse()}) → TResult

Available on EmojiStatusType, provided by the EmojiStatusTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) EmojiStatusTypeCustomEmoji?
Inherited by: EmojiStatusTypeCustomEmoji EmojiStatusTypeUpgradedGift
override

Constants

constructor → const String