EmojiStatuses class final
Contains a list of emoji statuses
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
EmojiStatuses({required List<
EmojiStatus> emojiStatuses})
Properties
-
emojiStatuses
→ List<
EmojiStatus> -
emojiStatuses The list of emoji statuses identifiers
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< EmojiStatus> ? emojiStatuses}) → EmojiStatuses -
Available on EmojiStatuses, provided by the EmojiStatusesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EmojiStatuses?
Constants
- constructor → const String