EncryptedPassportElement class final
Contains information about an encrypted Telegram Passport element; for bots only
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- data → String
-
data Encrypted JSON-encoded data about the user
final
-
files
→ List<
DatedFile> -
files List of attached files
final
- frontSide → DatedFile?
-
frontSide The front side of an identity document
final
- hash → String
-
hash Hash of the entire element
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- reverseSide → DatedFile?
-
reverseSide The reverse side of an identity document; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfie → DatedFile?
-
selfie Selfie with the document; may be null
final
-
translation
→ List<
DatedFile> -
translation List of files containing a certified English translation of
the document
final
- type → PassportElementType?
-
type Type of Telegram Passport element
final
- value → String
-
value Unencrypted data, phone number or email address
final
Methods
-
copyWith(
{PassportElementType? type, String? data, DatedFile? frontSide, DatedFile? reverseSide, DatedFile? selfie, List< DatedFile> ? translation, List<DatedFile> ? files, String? value, String? hash}) → EncryptedPassportElement -
Available on EncryptedPassportElement, provided by the EncryptedPassportElementExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → EncryptedPassportElement?
Constants
- constructor → const String