FactCheck class final
Describes a fact-check added to the message by an independent checker
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- FactCheck({FormattedText? text, required String countryCode})
Properties
- countryCode → String
-
countryCode A two-letter ISO 3166-1 alpha-2 country code of the country
for which the fact-check is shown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Text of the fact-check
final
Methods
-
copyWith(
{FormattedText? text, String? countryCode}) → FactCheck -
Available on FactCheck, provided by the FactCheckExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String