FailedToAddMember class final
Contains information about a user who has failed to be added to a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- FailedToAddMember({required int userId, })
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
premiumRequiredToSendMessages True, if subscription to Telegram Premium
is required to send the user chat invite link
final
-
premiumWouldAllowInvite True, if subscription to Telegram Premium would
have allowed to add the user to the chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, }) → FailedToAddMember -
Available on FailedToAddMember, provided by the FailedToAddMemberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FailedToAddMember?
Constants
- constructor → const String