File class final

Represents a file

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

File({required int id, required int size, required int expectedSize, LocalFile? local, RemoteFile? remote})

Properties

expectedSize int
expectedSize Approximate file size in bytes in case the exact file size is unknown. Can be used to show download/upload progress
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique file identifier
final
local LocalFile?
local Information about the local copy of the file
final
remote RemoteFile?
remote Information about the remote copy of the file
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
size File size, in bytes; 0 if unknown
final

Methods

copyWith({int? id, int? size, int? expectedSize, LocalFile? local, RemoteFile? remote}) File

Available on File, provided by the FileExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) File?

Constants

constructor → const String