FirebaseAuthenticationSettingsIos class final
Settings for Firebase Authentication in the official iOS application
- Inheritance
-
- Object
- TdObject
- FirebaseAuthenticationSettings
- FirebaseAuthenticationSettingsIos
- Available extensions
- Annotations
-
- @immutable
Constructors
- FirebaseAuthenticationSettingsIos({required String deviceToken, required bool isAppSandbox})
Properties
- deviceToken → String
-
deviceToken Device token from Apple Push Notification service
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAppSandbox → bool
-
isAppSandbox True, if App Sandbox is enabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? deviceToken, bool? isAppSandbox}) → FirebaseAuthenticationSettingsIos -
Available on FirebaseAuthenticationSettingsIos, provided by the FirebaseAuthenticationSettingsIosExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult android(FirebaseAuthenticationSettingsAndroid value), required TResult ios(FirebaseAuthenticationSettingsIos value)}) → TResult -
Available on FirebaseAuthenticationSettings, provided by the FirebaseAuthenticationSettingsExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult android(FirebaseAuthenticationSettingsAndroid value)?, TResult ios(FirebaseAuthenticationSettingsIos value)?, required TResult orElse()}) → TResult -
Available on FirebaseAuthenticationSettings, provided by the FirebaseAuthenticationSettingsExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FirebaseAuthenticationSettingsIos? -
Inherited by:
FirebaseAuthenticationSettingsAndroid
FirebaseAuthenticationSettingsIos
override
Constants
- constructor → const String