FixRichMessageWithAi class final
Fixes a rich message using an AI model. May return an error with a message "AICOMPOSE_FLOOD_PREMIUM" if Telegram Premium is required to send further requests Returns RichMessage
- Inheritance
-
- Object
- TdFunction
- FixRichMessageWithAi
- Available extensions
- Annotations
-
- @immutable
Constructors
- FixRichMessageWithAi({InputRichMessage? message})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → InputRichMessage?
-
message The original message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputRichMessage? message}) → FixRichMessageWithAi -
Available on FixRichMessageWithAi, provided by the FixRichMessageWithAiExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String