FixTextWithAi class final
Fixes text using an AI model; must not be used in secret chats. May return an error with a message "AICOMPOSE_FLOOD_PREMIUM" if Telegram Premium is required to send further requests Returns FixedText
- Inheritance
-
- Object
- TdFunction
- FixTextWithAi
- Available extensions
- Annotations
-
- @immutable
Constructors
- FixTextWithAi({FormattedText? text})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text The original text
final
Methods
-
copyWith(
{FormattedText? text}) → FixTextWithAi -
Available on FixTextWithAi, provided by the FixTextWithAiExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String