FixedText class final
A text fixed using fixTextWithAi
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- FixedText({FormattedText? text, DiffText? diffText})
Properties
- diffText → DiffText?
-
diffText Changes made to the original text
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text The resulting text
final
Methods
-
copyWith(
{FormattedText? text, DiffText? diffText}) → FixedText -
Available on FixedText, provided by the FixedTextExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String