FormattedText class final
A text with some entities
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
FormattedText({required String text, required List<
TextEntity> entities})
Properties
-
entities
→ List<
TextEntity> -
entities Entities contained in the text. Entities can be nested, but
must not mutually intersect with each other. Pre, Code, PreCode, and
DateTime entities can't contain other entities. BlockQuote entities can't
contain other BlockQuote entities. Bold, Italic, Underline, Strikethrough,
and Spoiler entities can contain and can be part of any other entities.
All other entities can't contain each other
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
text The text
final
Methods
-
copyWith(
{String? text, List< TextEntity> ? entities}) → FormattedText -
Available on FormattedText, provided by the FormattedTextExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FormattedText?
Constants
- constructor → const String