ForumTopics class final
Describes a list of forum topics
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ForumTopics({required int totalCount, required List<
ForumTopic> topics, required int nextOffsetDate, required int nextOffsetMessageId, required int nextOffsetForumTopicId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffsetDate → int
-
nextOffsetDate Offset date for the next getForumTopics request
final
- nextOffsetForumTopicId → int
-
nextOffsetForumTopicId Offset forum topic identifier for the next
getForumTopics request
final
- nextOffsetMessageId → int
-
nextOffsetMessageId Offset message identifier for the next
getForumTopics request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topics
→ List<
ForumTopic> -
topics List of forum topics
final
- totalCount → int
-
totalCount Approximate total number of forum topics found
final
Methods
-
copyWith(
{int? totalCount, List< ForumTopic> ? topics, int? nextOffsetDate, int? nextOffsetMessageId, int? nextOffsetForumTopicId}) → ForumTopics -
Available on ForumTopics, provided by the ForumTopicsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ForumTopics?
Constants
- constructor → const String