ForwardMessages class final
Forwards previously sent messages. Returns the forwarded messages in the same order as the message identifiers passed in message_ids. If a message can't be forwarded, null will be returned instead of the message Returns Messages
- Inheritance
-
- Object
- TdFunction
- ForwardMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ForwardMessages({required int chatId, MessageTopic? topicId, required int fromChatId, required List<
int> messageIds, MessageSendOptions? options, required bool sendCopy, required bool removeCaption})
Properties
- chatId → int
-
chatId Identifier of the chat to which to forward messages
final
- fromChatId → int
-
fromChatId Identifier of the chat from which to forward messages
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messageIds
→ List<
int> -
messageIds Identifiers of the messages to forward. Message identifiers
must be in a strictly increasing order. At most 100 messages can be
forwarded simultaneously. A message can be forwarded only if
messageProperties.can_be_forwarded
final
- options → MessageSendOptions?
-
options Options to be used to send the messages; pass null to use
default options
final
- removeCaption → bool
-
removeCaption Pass true to remove media captions of message copies.
Ignored if send_copy is false
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendCopy → bool
-
sendCopy Pass true to copy content of the messages without reference to
the original sender. Always true if the messages are forwarded to a secret
chat or are local. Use messageProperties.can_be_copied and
messageProperties.can_be_copied_to_secret_chat to check whether the
message is suitable
final
- topicId → MessageTopic?
-
topicId Topic in which the messages will be forwarded; message threads
aren't supported; pass null if none
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, int? fromChatId, List< int> ? messageIds, MessageSendOptions? options, bool? sendCopy, bool? removeCaption}) → ForwardMessages -
Available on ForwardMessages, provided by the ForwardMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String