FoundAffiliatePrograms class final
Represents a list of found affiliate programs
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
FoundAffiliatePrograms({required int totalCount, required List<
FoundAffiliateProgram> programs, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
-
programs
→ List<
FoundAffiliateProgram> -
programs The list of affiliate programs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount The total number of found affiliate programs
final
Methods
-
copyWith(
{int? totalCount, List< FoundAffiliateProgram> ? programs, String? nextOffset}) → FoundAffiliatePrograms -
Available on FoundAffiliatePrograms, provided by the FoundAffiliateProgramsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FoundAffiliatePrograms?
Constants
- constructor → const String