FoundChatBoosts class final

Contains a list of boosts applied to a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundChatBoosts({required int totalCount, required List<ChatBoost> boosts, required String nextOffset})

Properties

boosts List<ChatBoost>
boosts List of boosts
final
hashCode int
The hash code for this object.
no setteroverride
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of boosts applied to the chat
final

Methods

copyWith({int? totalCount, List<ChatBoost>? boosts, String? nextOffset}) FoundChatBoosts

Available on FoundChatBoosts, provided by the FoundChatBoostsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundChatBoosts?

Constants

constructor → const String