FoundMessages class final

Contains a list of messages found by a search

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

FoundMessages({required int totalCount, required List<Message> messages, required String nextOffset})

Properties

hashCode int
The hash code for this object.
no setteroverride
messages List<Message>
messages List of messages
final
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Approximate total number of messages found; -1 if unknown
final

Methods

copyWith({int? totalCount, List<Message>? messages, String? nextOffset}) FoundMessages

Available on FoundMessages, provided by the FoundMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) FoundMessages?

Constants

constructor → const String