FoundPublicPosts class final
Contains a list of messages found by a public post search
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
FoundPublicPosts({required List<
Message> messages, required String nextOffset, PublicPostSearchLimits? searchLimits, required bool areLimitsExceeded})
Properties
- areLimitsExceeded → bool
-
areLimitsExceeded True, if the query has failed because search limits
are exceeded. In this case search_limits.daily_free_query_count will be
equal to 0
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messages
→ List<
Message> -
messages List of found public posts
final
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchLimits → PublicPostSearchLimits?
-
searchLimits Updated public post search limits after the query; repeated
requests with the same query will be free; may be null if they didn't
change
final
Methods
-
copyWith(
{List< Message> ? messages, String? nextOffset, PublicPostSearchLimits? searchLimits, bool? areLimitsExceeded}) → FoundPublicPosts -
Available on FoundPublicPosts, provided by the FoundPublicPostsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FoundPublicPosts?
Constants
- constructor → const String