FoundStories class final
Contains a list of stories found by a search
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
FoundStories({required int totalCount, required List<
Story> stories, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stories
→ List<
Story> -
stories List of stories
final
- totalCount → int
-
totalCount Approximate total number of stories found
final
Methods
-
copyWith(
{int? totalCount, List< Story> ? stories, String? nextOffset}) → FoundStories -
Available on FoundStories, provided by the FoundStoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FoundStories?
Constants
- constructor → const String