FoundUsers class final
Represents a list of found users
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
FoundUsers({required List<
int> userIds, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
int> -
userIds Identifiers of the found users
final
Methods
-
copyWith(
{List< int> ? userIds, String? nextOffset}) → FoundUsers -
Available on FoundUsers, provided by the FoundUsersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → FoundUsers?
Constants
- constructor → const String