Game class final
Describes a game. Use getInternalLink with internalLinkTypeGame to share the game
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- animation → Animation?
-
animation Game animation; may be null
final
- description → String
-
param_description Game description
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique game identifier
final
- photo → Photo?
-
photo Game photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortName → String
-
shortName Game short name
final
- text → FormattedText?
-
text Game text, usually containing scoreboards for a game
final
- title → String
-
title Game title
final
Methods
-
copyWith(
{int? id, String? shortName, String? title, FormattedText? text, String? description, Photo? photo, Animation? animation}) → Game -
Available on Game, provided by the GameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String