GameHighScore class final
Contains one row of the game high score table
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GameHighScore({required int position, required int userId, required int score})
Properties
Methods
-
copyWith(
{int? position, int? userId, int? score}) → GameHighScore -
Available on GameHighScore, provided by the GameHighScoreExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GameHighScore?
Constants
- constructor → const String