GameHighScores class final
Contains a list of game high scores
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GameHighScores({required List<
GameHighScore> scores})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scores
→ List<
GameHighScore> -
scores A list of game high scores
final
Methods
-
copyWith(
{List< GameHighScore> ? scores}) → GameHighScores -
Available on GameHighScores, provided by the GameHighScoresExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GameHighScores?
Constants
- constructor → const String