GetAllStickerEmojis class final
Returns unique emoji that correspond to stickers to be found by the getStickers(sticker_type, query, 1000000, chat_id) Returns Emojis
- Inheritance
-
- Object
- TdFunction
- GetAllStickerEmojis
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetAllStickerEmojis({StickerType? stickerType, required String query, required int chatId, required bool returnOnlyMainEmoji})
Properties
- chatId → int
-
chatId Chat identifier for which to find stickers
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- query → String
-
query Search query
final
- returnOnlyMainEmoji → bool
-
returnOnlyMainEmoji Pass true if only main emoji for each found sticker
must be included in the result
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the stickers to search for
final
Methods
-
copyWith(
{StickerType? stickerType, String? query, int? chatId, bool? returnOnlyMainEmoji}) → GetAllStickerEmojis -
Available on GetAllStickerEmojis, provided by the GetAllStickerEmojisExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String