returnOnlyMainEmoji property
returnOnlyMainEmoji Pass true if only main emoji for each found sticker must be included in the result
Implementation
final bool returnOnlyMainEmoji;
returnOnlyMainEmoji Pass true if only main emoji for each found sticker must be included in the result
final bool returnOnlyMainEmoji;