GetArchivedStickerSets class final
Returns a list of archived sticker sets Returns StickerSets
- Inheritance
-
- Object
- TdFunction
- GetArchivedStickerSets
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetArchivedStickerSets({StickerType? stickerType, required int offsetStickerSetId, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of sticker sets to return; up to 100
final
- offsetStickerSetId → int
-
offsetStickerSetId Identifier of the sticker set from which to return
the result; use 0 to get results from the beginning
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the sticker sets to return
final
Methods
-
copyWith(
{StickerType? stickerType, int? offsetStickerSetId, int? limit}) → GetArchivedStickerSets -
Available on GetArchivedStickerSets, provided by the GetArchivedStickerSetsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String