GetAttachedStickerSets class final
Returns a list of sticker sets attached to a file, including regular, mask, and emoji sticker sets. Currently, only animations, photos, and videos can have attached sticker sets Returns StickerSets
- Inheritance
-
- Object
- TdFunction
- GetAttachedStickerSets
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetAttachedStickerSets({required int fileId})
Properties
Methods
-
copyWith(
{int? fileId}) → GetAttachedStickerSets -
Available on GetAttachedStickerSets, provided by the GetAttachedStickerSetsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String