GetBasicGroupFullInfo class final
Returns full information about a basic group by its identifier Returns BasicGroupFullInfo
- Inheritance
-
- Object
- TdFunction
- GetBasicGroupFullInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetBasicGroupFullInfo({required int basicGroupId})
Properties
- basicGroupId → int
-
basicGroupId Basic group identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? basicGroupId}) → GetBasicGroupFullInfo -
Available on GetBasicGroupFullInfo, provided by the GetBasicGroupFullInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String