GetBotMediaPreviews class final

Returns the list of media previews of a bot Returns BotMediaPreviews

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBotMediaPreviews({required int botUserId})

Properties

botUserId int
botUserId Identifier of the target bot. The bot must have the main Web App
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId}) GetBotMediaPreviews

Available on GetBotMediaPreviews, provided by the GetBotMediaPreviewsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String