GetBotSimilarBotCount class final

Returns approximate number of bots similar to the given bot Returns Count

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetBotSimilarBotCount({required int botUserId, required bool returnLocal})

Properties

botUserId int
botUserId User identifier of the target bot
final
hashCode int
The hash code for this object.
no setteroverride
returnLocal bool
returnLocal Pass true to get the number of bots without sending network requests, or -1 if the number of bots is unknown locally
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? botUserId, bool? returnLocal}) GetBotSimilarBotCount

Available on GetBotSimilarBotCount, provided by the GetBotSimilarBotCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String