GetChatAvailablePaidMessageReactionSenders class final
Returns the list of message sender identifiers, which can be used to send a paid reaction in a chat Returns MessageSenders
- Inheritance
-
- Object
- TdFunction
- GetChatAvailablePaidMessageReactionSenders
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatAvailablePaidMessageReactionSenders({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetChatAvailablePaidMessageReactionSenders -
Available on GetChatAvailablePaidMessageReactionSenders, provided by the GetChatAvailablePaidMessageReactionSendersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String