GetChatBoostFeatures class final

Returns the list of features available for different chat boost levels. This is an offline method Returns ChatBoostFeatures

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatBoostFeatures({required bool isChannel})

Properties

hashCode int
The hash code for this object.
no setteroverride
isChannel bool
isChannel Pass true to get the list of features for channels; pass false to get the list of features for supergroups
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isChannel}) GetChatBoostFeatures

Available on GetChatBoostFeatures, provided by the GetChatBoostFeaturesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String