GetChatFolder class final

Returns information about a chat folder by its identifier Returns ChatFolder

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatFolder({required int chatFolderId})

Properties

chatFolderId int
chatFolderId Chat folder identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId}) GetChatFolder

Available on GetChatFolder, provided by the GetChatFolderExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String