GetChatFolderChatCount class final
Returns approximate number of chats in a being created chat folder. Main and archive chat lists must be fully preloaded for this function to work correctly Returns Count
- Inheritance
-
- Object
- TdFunction
- GetChatFolderChatCount
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatFolderChatCount({ChatFolder? folder})
Properties
- folder → ChatFolder?
-
folder The new chat folder
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolder? folder}) → GetChatFolderChatCount -
Available on GetChatFolderChatCount, provided by the GetChatFolderChatCountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String