GetChatFolderChatsToLeave class final
Returns identifiers of pinned or always included chats from a chat folder, which are suggested to be left when the chat folder is deleted Returns Chats
- Inheritance
-
- Object
- TdFunction
- GetChatFolderChatsToLeave
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatFolderChatsToLeave({required int chatFolderId})
Properties
- chatFolderId → int
-
chatFolderId Chat folder identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatFolderId}) → GetChatFolderChatsToLeave -
Available on GetChatFolderChatsToLeave, provided by the GetChatFolderChatsToLeaveExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String