GetChatFolderNewChats class final

Returns new chats added to a shareable chat folder by its owner. The method must be called at most once in getOption("chat_folder_new_chats_update_period") for the given chat folder Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatFolderNewChats({required int chatFolderId})

Properties

chatFolderId int
chatFolderId Chat folder identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatFolderId}) GetChatFolderNewChats

Available on GetChatFolderNewChats, provided by the GetChatFolderNewChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String