onlyWithExpiredSubscription property
onlyWithExpiredSubscription Pass true if the link is a subscription link and only members with expired subscription must be returned
Implementation
final bool onlyWithExpiredSubscription;
onlyWithExpiredSubscription Pass true if the link is a subscription link and only members with expired subscription must be returned
final bool onlyWithExpiredSubscription;