GetChatJoinRequests class final
Returns pending join requests in a chat Returns ChatJoinRequests
- Inheritance
-
- Object
- TdFunction
- GetChatJoinRequests
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatJoinRequests({required int chatId, required String inviteLink, required String query, ChatJoinRequest? offsetRequest, required int limit})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteLink → String
-
inviteLink Invite link for which to return join requests. If empty, all
join requests will be returned. Requires administrator privileges and
can_invite_users right in the chat for own links and owner privileges for
other links
final
- limit → int
-
limit The maximum number of requests to join the chat to return
final
- offsetRequest → ChatJoinRequest?
-
offsetRequest A chat join request from which to return next requests;
pass null to get results from the beginning
final
- query → String
-
query A query to search for in the first names, last names and usernames
of the users to return
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? inviteLink, String? query, ChatJoinRequest? offsetRequest, int? limit}) → GetChatJoinRequests -
Available on GetChatJoinRequests, provided by the GetChatJoinRequestsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String