GetChatMessageByDate class final
Returns the last message sent in a chat no later than the specified date. Returns a 404 error if such message doesn't exist Returns Message
- Inheritance
-
- Object
- TdFunction
- GetChatMessageByDate
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatMessageByDate({required int chatId, required int date})
Properties
Methods
-
copyWith(
{int? chatId, int? date}) → GetChatMessageByDate -
Available on GetChatMessageByDate, provided by the GetChatMessageByDateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String