GetChatMessageCount class final
Returns approximate number of messages of the specified type in the chat or its topic Returns Count
- Inheritance
-
- Object
- TdFunction
- GetChatMessageCount
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatMessageCount({required int chatId, MessageTopic? topicId, SearchMessagesFilter? filter, required bool returnLocal})
Properties
- chatId → int
-
chatId Identifier of the chat in which to count messages
final
- filter → SearchMessagesFilter?
-
filter Filter for message content; searchMessagesFilterEmpty is
unsupported in this function
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- returnLocal → bool
-
returnLocal Pass true to get the number of messages without sending
network requests, or -1 if the number of messages is unknown locally
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Pass topic identifier to get number of messages only in specific
topic; pass null to get number of messages in all topics; message threads
aren't supported
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, SearchMessagesFilter? filter, bool? returnLocal}) → GetChatMessageCount -
Available on GetChatMessageCount, provided by the GetChatMessageCountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String