GetChatRevenueTransactions class final
Returns the list of revenue transactions for a chat. Currently, this method can be used only for channels if supergroupFullInfo.can_get_revenue_statistics == true or bots if userFullInfo.bot_info.can_get_revenue_statistics == true Returns ChatRevenueTransactions
- Inheritance
-
- Object
- TdFunction
- GetChatRevenueTransactions
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatRevenueTransactions({required int chatId, required String offset, required int limit})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of transactions to be returned; up to 100
final
- offset → String
-
offset Offset of the first transaction to return as received from the
previous request; use empty string to get the first chunk of results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? offset, int? limit}) → GetChatRevenueTransactions -
Available on GetChatRevenueTransactions, provided by the GetChatRevenueTransactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String