GetChatRevenueWithdrawalUrl class final
Returns a URL for chat revenue withdrawal; requires owner privileges in the channel chat or the bot. Currently, this method can be used only if getOption("can_withdraw_chat_revenue") for channels with supergroupFullInfo.can_get_revenue_statistics == true or bots with userFullInfo.bot_info.can_get_revenue_statistics == true Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetChatRevenueWithdrawalUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatRevenueWithdrawalUrl({required int chatId, required String password})
Properties
Methods
-
copyWith(
{int? chatId, String? password}) → GetChatRevenueWithdrawalUrl -
Available on GetChatRevenueWithdrawalUrl, provided by the GetChatRevenueWithdrawalUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String