GetChatSimilarChatCount class final

Returns approximate number of chats similar to the given chat Returns Count

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetChatSimilarChatCount({required int chatId, required bool returnLocal})

Properties

chatId int
chatId Identifier of the target chat; must be an identifier of a channel chat
final
hashCode int
The hash code for this object.
no setteroverride
returnLocal bool
returnLocal Pass true to get the number of chats without sending network requests, or -1 if the number of chats is unknown locally
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, bool? returnLocal}) GetChatSimilarChatCount

Available on GetChatSimilarChatCount, provided by the GetChatSimilarChatCountExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String