GetChatSimilarChats class final
Returns a list of chats similar to the given chat Returns Chats
- Inheritance
-
- Object
- TdFunction
- GetChatSimilarChats
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatSimilarChats({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → GetChatSimilarChats -
Available on GetChatSimilarChats, provided by the GetChatSimilarChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String