GetChatStatistics class final
Returns detailed statistics about a chat. Currently, this method can be used only for supergroups and channels. Can be used only if supergroupFullInfo.can_get_statistics == true Returns ChatStatistics
- Inheritance
-
- Object
- TdFunction
- GetChatStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetChatStatistics({required int chatId, required bool isDark})
Properties
Methods
-
copyWith(
{int? chatId, bool? isDark}) → GetChatStatistics -
Available on GetChatStatistics, provided by the GetChatStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String