GetCreatedPublicChats class final

Returns a list of public chats of the specified type, owned by the user Returns Chats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetCreatedPublicChats({PublicChatType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PublicChatType?
type Type of the public chats to return
final

Methods

copyWith({PublicChatType? type}) GetCreatedPublicChats

Available on GetCreatedPublicChats, provided by the GetCreatedPublicChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String