GetCurrentWeather class final
Returns the current weather in the given location Returns CurrentWeather
- Inheritance
-
- Object
- TdFunction
- GetCurrentWeather
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetCurrentWeather({Location? location})
Properties
Methods
-
copyWith(
{Location? location}) → GetCurrentWeather -
Available on GetCurrentWeather, provided by the GetCurrentWeatherExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String