GetDirectMessagesChatTopicRevenue class final
Returns the total number of Telegram Stars received by the channel chat for direct messages from the given topic Returns StarCount
- Inheritance
-
- Object
- TdFunction
- GetDirectMessagesChatTopicRevenue
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetDirectMessagesChatTopicRevenue({required int chatId, required int topicId})
Properties
- chatId → int
-
chatId Chat identifier of the channel direct messages chat administered
by the current user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → int
-
topicId Identifier of the topic
final
Methods
-
copyWith(
{int? chatId, int? topicId}) → GetDirectMessagesChatTopicRevenue -
Available on GetDirectMessagesChatTopicRevenue, provided by the GetDirectMessagesChatTopicRevenueExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String