GetEmojiCategories class final
Returns available emoji categories Returns EmojiCategories
- Inheritance
-
- Object
- TdFunction
- GetEmojiCategories
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetEmojiCategories({EmojiCategoryType? type})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → EmojiCategoryType?
-
type Type of emoji categories to return; pass null to get default emoji
categories
final
Methods
-
copyWith(
{EmojiCategoryType? type}) → GetEmojiCategories -
Available on GetEmojiCategories, provided by the GetEmojiCategoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String