GetEmojiReaction class final
Returns information about an emoji reaction. Returns a 404 error if the reaction is not found Returns EmojiReaction
- Inheritance
-
- Object
- TdFunction
- GetEmojiReaction
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetEmojiReaction({required String emoji})
Properties
Methods
-
copyWith(
{String? emoji}) → GetEmojiReaction -
Available on GetEmojiReaction, provided by the GetEmojiReactionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String