GetEmojiSuggestionsUrl class final
Returns an HTTP URL which can be used to automatically log in to the translation platform and suggest new emoji replacements. The URL will be valid for 30 seconds after generation Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetEmojiSuggestionsUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetEmojiSuggestionsUrl({required String languageCode})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode Language code for which the emoji replacements will be
suggested
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languageCode}) → GetEmojiSuggestionsUrl -
Available on GetEmojiSuggestionsUrl, provided by the GetEmojiSuggestionsUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String