GetExternalLinkInfo class final
Returns information about an action to be done when the current user clicks an external link. Don't use this method for links from secret chats if link preview is disabled in secret chats, and use directly getLinkWebBrowserType Returns LoginUrlInfo
- Inheritance
-
- Object
- TdFunction
- GetExternalLinkInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetExternalLinkInfo({required String link})
Properties
Methods
-
copyWith(
{String? link}) → GetExternalLinkInfo -
Available on GetExternalLinkInfo, provided by the GetExternalLinkInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String