GetFileDownloadedPrefixSize class final

Returns file downloaded prefix size from a given offset, in bytes Returns FileDownloadedPrefixSize

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetFileDownloadedPrefixSize({required int fileId, required int offset})

Properties

fileId int
fileId Identifier of the file
final
hashCode int
The hash code for this object.
no setteroverride
offset int
offset Offset from which downloaded prefix size needs to be calculated
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? fileId, int? offset}) GetFileDownloadedPrefixSize

Available on GetFileDownloadedPrefixSize, provided by the GetFileDownloadedPrefixSizeExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String