GetForumTopics class final
Returns found forum topics in a forum supergroup chat or a chat with a bot with topics. This is a temporary method for getting information about topic list from the server Returns ForumTopics
- Inheritance
-
- Object
- TdFunction
- GetForumTopics
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Identifier of the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of forum topics to be returned; up to 100. For
optimal performance, the number of returned forum topics is chosen by
TDLib and can be smaller than the specified limit
final
- offsetDate → int
-
offsetDate The date starting from which the results need to be fetched.
Use 0 or any date in the future to get results from the last topic
final
- offsetForumTopicId → int
-
offsetForumTopicId The forum topic identifier of the last found topic,
or 0 for the first request
final
- offsetMessageId → int
-
offsetMessageId The message identifier of the last message in the last
found topic, or 0 for the first request
final
- query → String
-
query Query to search for in the forum topic's name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, String? query, int? offsetDate, int? offsetMessageId, int? offsetForumTopicId, int? limit}) → GetForumTopics -
Available on GetForumTopics, provided by the GetForumTopicsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String