GetGiftAuctionAcquiredGifts class final
Returns the gifts that were acquired by the current user on a gift auction Returns GiftAuctionAcquiredGifts
- Inheritance
-
- Object
- TdFunction
- GetGiftAuctionAcquiredGifts
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGiftAuctionAcquiredGifts({required int giftId})
Properties
Methods
-
copyWith(
{int? giftId}) → GetGiftAuctionAcquiredGifts -
Available on GetGiftAuctionAcquiredGifts, provided by the GetGiftAuctionAcquiredGiftsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String