GetGiftCollections class final

Returns collections of gifts owned by the given user or chat Returns GiftCollections

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGiftCollections({MessageSender? ownerId})

Properties

hashCode int
The hash code for this object.
no setteroverride
ownerId MessageSender?
ownerId Identifier of the user or the channel chat that received the gifts
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({MessageSender? ownerId}) GetGiftCollections

Available on GetGiftCollections, provided by the GetGiftCollectionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String