GetGramRevenueStatistics class final

Returns detailed TON Gram revenue statistics of the current user Returns GramRevenueStatistics

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetGramRevenueStatistics({required bool isDark})

Properties

hashCode int
The hash code for this object.
no setteroverride
isDark bool
isDark Pass true if a dark theme is used by the application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isDark}) GetGramRevenueStatistics

Available on GetGramRevenueStatistics, provided by the GetGramRevenueStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String