GetGramWithdrawalUrl class final
Returns a URL for TON Gram withdrawal from the current user's account. The user must have at least 10 Grams to withdraw and can withdraw up to 100000 Grams in one transaction Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetGramWithdrawalUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGramWithdrawalUrl({required String password})
Properties
Methods
-
copyWith(
{String? password}) → GetGramWithdrawalUrl -
Available on GetGramWithdrawalUrl, provided by the GetGramWithdrawalUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String