GetGrossingWebAppBots class final
Returns the most grossing Web App bots Returns FoundUsers
- Inheritance
-
- Object
- TdFunction
- GetGrossingWebAppBots
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGrossingWebAppBots({required String offset, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of bots to be returned; up to 100
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? offset, int? limit}) → GetGrossingWebAppBots -
Available on GetGrossingWebAppBots, provided by the GetGrossingWebAppBotsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String