GetGroupCallParticipants class final
Returns information about participants of a non-joined group call that is not bound to a chat Returns GroupCallParticipants
- Inheritance
-
- Object
- TdFunction
- GetGroupCallParticipants
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGroupCallParticipants({InputGroupCall? inputGroupCall, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inputGroupCall → InputGroupCall?
-
inputGroupCall The group call which participants will be returned
final
- limit → int
-
limit The maximum number of participants to return; must be positive
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputGroupCall? inputGroupCall, int? limit}) → GetGroupCallParticipants -
Available on GetGroupCallParticipants, provided by the GetGroupCallParticipantsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String