GetGroupsInCommon class final
Returns a list of common group chats with a given user. Chats are sorted by their type and creation date Returns Chats
- Inheritance
-
- Object
- TdFunction
- GetGroupsInCommon
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGroupsInCommon({required int userId, required int offsetChatId, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of chats to be returned; up to 100
final
- offsetChatId → int
-
offsetChatId Chat identifier starting from which to return chats; use 0
for the first request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId User identifier
final
Methods
-
copyWith(
{int? userId, int? offsetChatId, int? limit}) → GetGroupsInCommon -
Available on GetGroupsInCommon, provided by the GetGroupsInCommonExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String