GetGuardBotWebAppUrl class final
Returns an HTTPS URL of a Web App of a guard bot to open after receiving chatJoinResultGuardBotApprovalRequired Returns WebAppUrl
- Inheritance
-
- Object
- TdFunction
- GetGuardBotWebAppUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetGuardBotWebAppUrl({required int queryId, WebAppOpenParameters? parameters})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- parameters → WebAppOpenParameters?
-
parameters Parameters to use to open the Web App
final
- queryId → int
-
queryId Unique identifier of the join request as received in
chatJoinResultGuardBotApprovalRequired
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? queryId, WebAppOpenParameters? parameters}) → GetGuardBotWebAppUrl -
Available on GetGuardBotWebAppUrl, provided by the GetGuardBotWebAppUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String