GetLanguagePackInfo class final
Returns information about a language pack. Returned language pack identifier may be different from a provided one. Can be called before authorization Returns LanguagePackInfo
- Inheritance
-
- Object
- TdFunction
- GetLanguagePackInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetLanguagePackInfo({required String languagePackId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languagePackId → String
-
languagePackId Language pack identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languagePackId}) → GetLanguagePackInfo -
Available on GetLanguagePackInfo, provided by the GetLanguagePackInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String