GetLinkPreview class final
Returns a link preview by the text of a message. Do not call this function too often. Returns a 404 error if the text has no link preview Returns LinkPreview
- Inheritance
-
- Object
- TdFunction
- GetLinkPreview
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetLinkPreview({FormattedText? text, LinkPreviewOptions? linkPreviewOptions})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- linkPreviewOptions → LinkPreviewOptions?
-
linkPreviewOptions Options to be used for generation of the link
preview; pass null to use default link preview options
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Message text with formatting
final
Methods
-
copyWith(
{FormattedText? text, LinkPreviewOptions? linkPreviewOptions}) → GetLinkPreview -
Available on GetLinkPreview, provided by the GetLinkPreviewExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String