GetMenuButton class final
Returns menu button set by the bot for the given user; for bots only Returns BotMenuButton
- Inheritance
-
- Object
- TdFunction
- GetMenuButton
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMenuButton({required int userId})
Properties
Methods
-
copyWith(
{int? userId}) → GetMenuButton -
Available on GetMenuButton, provided by the GetMenuButtonExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String