GetMessageAuthor class final
Returns information about actual author of a message sent on behalf of a channel. The method can be called if messageProperties.can_get_author == true Returns User
- Inheritance
-
- Object
- TdFunction
- GetMessageAuthor
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMessageAuthor({required int chatId, required int messageId})
Properties
Methods
-
copyWith(
{int? chatId, int? messageId}) → GetMessageAuthor -
Available on GetMessageAuthor, provided by the GetMessageAuthorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String