GetMessageAvailableReactions class final

Returns reactions, which can be added to a message. The list can change after updateActiveEmojiReactions, updateChatAvailableReactions for the chat, or updateMessageInteractionInfo for the message Returns AvailableReactions

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageAvailableReactions({required int chatId, required int messageId, required int rowSize})

Properties

chatId int
chatId Identifier of the chat to which the message belongs
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message
final
rowSize int
rowSize Number of reaction per row, 5-25
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId, int? rowSize}) GetMessageAvailableReactions

Available on GetMessageAvailableReactions, provided by the GetMessageAvailableReactionsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String