GetMessageEffect class final

Returns information about a message effect. Returns a 404 error if the effect is not found Returns MessageEffect

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageEffect({required int effectId})

Properties

effectId int
effectId Unique identifier of the effect
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? effectId}) GetMessageEffect

Available on GetMessageEffect, provided by the GetMessageEffectExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String