GetMessageEmbeddingCode class final
Returns an HTML code for embedding the message. Available only if messageProperties.can_get_embedding_code Returns Text
- Inheritance
-
- Object
- TdFunction
- GetMessageEmbeddingCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetMessageEmbeddingCode({required int chatId, required int messageId, required bool forAlbum})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- forAlbum → bool
-
forAlbum Pass true to return an HTML code for embedding of the whole
media album
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, bool? forAlbum}) → GetMessageEmbeddingCode -
Available on GetMessageEmbeddingCode, provided by the GetMessageEmbeddingCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String