GetMessageLink class final
Returns an HTTPS link to a message in a chat. Available only if messageProperties.can_get_link, or if messageProperties.can_get_media_timestamp_links and a media timestamp link is generated. This is an offline method Returns MessageLink
- Inheritance
-
- Object
- TdFunction
- GetMessageLink
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- checklistTaskId → int
-
checklistTaskId If not 0, identifier of the checklist task in the
message to be linked
final
- forAlbum → bool
-
forAlbum Pass true to create a link for the whole media album
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inMessageThread → bool
-
inMessageThread Pass true to create a link to the message as a channel
post comment, in a message thread, or a forum topic
final
- mediaTimestamp → int
-
mediaTimestamp If not 0, timestamp from which the video/audio/video
note/voice note/story playing must start, in seconds. The media can be in
the message content or in its link preview
final
- messageId → int
-
messageId Identifier of the message
final
- pollOptionId → String
-
pollOptionId If not empty, identifier of the poll option in the message
to be linked
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, int? mediaTimestamp, int? checklistTaskId, String? pollOptionId, bool? forAlbum, bool? inMessageThread}) → GetMessageLink -
Available on GetMessageLink, provided by the GetMessageLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String