GetMessageLocally class final

Returns information about a message, if it is available without sending network request. Returns a 404 error if message isn't available locally. This is an offline method Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetMessageLocally({required int chatId, required int messageId})

Properties

chatId int
chatId Identifier of the chat the message belongs to
final
hashCode int
The hash code for this object.
no setteroverride
messageId int
messageId Identifier of the message to get
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? messageId}) GetMessageLocally

Available on GetMessageLocally, provided by the GetMessageLocallyExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String