GetNetworkStatistics class final
Returns network data usage statistics. Can be called before authorization Returns NetworkStatistics
- Inheritance
-
- Object
- TdFunction
- GetNetworkStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetNetworkStatistics({required bool onlyCurrent})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyCurrent → bool
-
onlyCurrent Pass true to get statistics only for the current library
launch
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? onlyCurrent}) → GetNetworkStatistics -
Available on GetNetworkStatistics, provided by the GetNetworkStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String