GetOauthLinkInfo class final
Returns information about an OAuth deep link. Use checkOauthRequestMatchCode, acceptOauthRequest or declineOauthRequest to process the link Returns OauthLinkInfo
- Inheritance
-
- Object
- TdFunction
- GetOauthLinkInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetOauthLinkInfo({required String url, required String inAppOrigin})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- inAppOrigin → String
-
inAppOrigin Origin of the OAuth request if the request was received from
the in-app browser; pass an empty string otherwise
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url URL of the link
final
Methods
-
copyWith(
{String? url, String? inAppOrigin}) → GetOauthLinkInfo -
Available on GetOauthLinkInfo, provided by the GetOauthLinkInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String