GetOwnedStickerSets class final
Returns sticker sets owned by the current user Returns StickerSets
- Inheritance
-
- Object
- TdFunction
- GetOwnedStickerSets
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetOwnedStickerSets({required int offsetStickerSetId, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of sticker sets to be returned; must be
positive and can't be greater than 100. For optimal performance, the
number of returned objects is chosen by TDLib and can be smaller than the
specified limit
final
- offsetStickerSetId → int
-
offsetStickerSetId Identifier of the sticker set from which to return
owned sticker sets; use 0 to get results from the beginning
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? offsetStickerSetId, int? limit}) → GetOwnedStickerSets -
Available on GetOwnedStickerSets, provided by the GetOwnedStickerSetsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String