GetPhoneNumberInfoSync class final
Returns information about a phone number by its prefix synchronously. getCountries must be called at least once after changing localization to the specified language if properly localized country information is expected. Can be called synchronously Returns PhoneNumberInfo
- Inheritance
-
- Object
- TdFunction
- GetPhoneNumberInfoSync
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetPhoneNumberInfoSync({required String languageCode, required String phoneNumberPrefix})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode A two-letter ISO 639-1 language code for country
information localization
final
- phoneNumberPrefix → String
-
phoneNumberPrefix The phone number prefix
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languageCode, String? phoneNumberPrefix}) → GetPhoneNumberInfoSync -
Available on GetPhoneNumberInfoSync, provided by the GetPhoneNumberInfoSyncExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String