GetPollOptionProperties class final
Returns properties of a poll option. This is an offline method Returns PollOptionProperties
- Inheritance
-
- Object
- TdFunction
- GetPollOptionProperties
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetPollOptionProperties({required int chatId, required int messageId, required String pollOptionId})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- pollOptionId → String
-
pollOptionId Unique identifier of the answer option, which properties
will be returned
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, String? pollOptionId}) → GetPollOptionProperties -
Available on GetPollOptionProperties, provided by the GetPollOptionPropertiesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String