GetPollVoteStatistics class final
Returns statistics of poll votes in a poll Returns PollVoteStatistics
- Inheritance
-
- Object
- TdFunction
- GetPollVoteStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetPollVoteStatistics({required int chatId, required int messageId, required bool isDark})
Properties
- chatId → int
-
chatId Identifier of the chat to which the poll belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isDark → bool
-
isDark Pass true if a dark theme is used by the application
final
- messageId → int
-
messageId Identifier of the message containing the poll. Use
messageProperties.can_get_poll_vote_statistics to check whether the method
can be used for a message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, bool? isDark}) → GetPollVoteStatistics -
Available on GetPollVoteStatistics, provided by the GetPollVoteStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String