GetPushReceiverId class final
Returns a globally unique push notification subscription identifier for identification of an account, which has received a push notification. Can be called synchronously Returns PushReceiverId
- Inheritance
-
- Object
- TdFunction
- GetPushReceiverId
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetPushReceiverId({required String payload})
Properties
Methods
-
copyWith(
{String? payload}) → GetPushReceiverId -
Available on GetPushReceiverId, provided by the GetPushReceiverIdExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String