GetReceivedGifts class final
Returns gifts received by the given user or chat Returns ReceivedGifts
- Inheritance
-
- Object
- TdFunction
- GetReceivedGifts
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetReceivedGifts({String? businessConnectionId, MessageSender? ownerId, required int collectionId, required bool excludeUnsaved, required bool excludeSaved, required bool excludeUnlimited, required bool excludeUpgradable, required bool excludeNonUpgradable, required bool excludeUpgraded, required bool excludeWithoutColors, required bool excludeHosted, required bool sortByPrice, required String offset, required int limit})
Properties
- businessConnectionId → String?
-
businessConnectionId Unique identifier of business connection on behalf
of which to send the request; for bots only
final
- collectionId → int
-
collectionId Pass collection identifier to get gifts only from the
specified collection; pass 0 to get gifts regardless of collections
final
- excludeHosted → bool
-
excludeHosted Pass true to exclude gifts that are just hosted and are
not owned by the owner
final
- excludeNonUpgradable → bool
-
excludeNonUpgradable Pass true to exclude gifts that can be purchased
limited number of times and can't be upgraded
final
- excludeSaved → bool
-
excludeSaved Pass true to exclude gifts that are saved to the chat's
profile page. Always false for gifts received by other users and channel
chats without can_post_messages administrator right
final
- excludeUnlimited → bool
-
excludeUnlimited Pass true to exclude gifts that can be purchased
unlimited number of times
final
- excludeUnsaved → bool
-
excludeUnsaved Pass true to exclude gifts that aren't saved to the
chat's profile page. Always true for gifts received by other users and
channel chats without can_post_messages administrator right
final
- excludeUpgradable → bool
-
excludeUpgradable Pass true to exclude gifts that can be purchased
limited number of times and can be upgraded
final
- excludeUpgraded → bool
-
excludeUpgraded Pass true to exclude upgraded gifts
final
- excludeWithoutColors → bool
-
excludeWithoutColors Pass true to exclude gifts that can't be used in
setUpgradedGiftColors
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of gifts to be returned; must be positive and
can't be greater than 100. For optimal performance, the number of returned
objects is chosen by TDLib and can be smaller than the specified limit
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- ownerId → MessageSender?
-
ownerId Identifier of the gift receiver
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortByPrice → bool
-
sortByPrice Pass true to sort results by gift price instead of send date
final
Methods
-
copyWith(
{String? businessConnectionId, MessageSender? ownerId, int? collectionId, bool? excludeUnsaved, bool? excludeSaved, bool? excludeUnlimited, bool? excludeUpgradable, bool? excludeNonUpgradable, bool? excludeUpgraded, bool? excludeWithoutColors, bool? excludeHosted, bool? sortByPrice, String? offset, int? limit}) → GetReceivedGifts -
Available on GetReceivedGifts, provided by the GetReceivedGiftsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String