excludeUpgradable property
excludeUpgradable Pass true to exclude gifts that can be purchased limited number of times and can be upgraded
Implementation
final bool excludeUpgradable;
excludeUpgradable Pass true to exclude gifts that can be purchased limited number of times and can be upgraded
final bool excludeUpgradable;