GetRemoteFile class final
Returns information about a file by its remote identifier. This is an offline method. Can be used to register a URL as a file for further uploading, or sending as a message. Even if the request succeeds, the file can be used only if it is still accessible to the user. For example, if the file is from a message, then the message must be not deleted and accessible to the user. If the file database is disabled, then the corresponding object with the file must be preloaded by the application Returns File
- Inheritance
-
- Object
- TdFunction
- GetRemoteFile
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetRemoteFile({required String remoteFileId, FileType? fileType})
Properties
- fileType → FileType?
-
fileType File type; pass null if unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- remoteFileId → String
-
remoteFileId Remote identifier of the file to get
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? remoteFileId, FileType? fileType}) → GetRemoteFile -
Available on GetRemoteFile, provided by the GetRemoteFileExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String