GetSavedMessagesTopicHistory class final

Returns messages in a Saved Messages topic. The messages are returned in reverse chronological order (i.e., in order of decreasing message_id) Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSavedMessagesTopicHistory({required int savedMessagesTopicId, required int fromMessageId, required int offset, required int limit})

Properties

fromMessageId int
fromMessageId Identifier of the message starting from which messages must be fetched; use 0 to get results from the last message
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned; must be positive and can't be greater than 100. If the offset is negative, then the limit must be greater than or equal to -offset. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit
final
offset int
offset Specify 0 to get results from exactly the message from_message_id or a negative number from -99 to -1 to get additionally -offset newer messages
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicId int
savedMessagesTopicId Identifier of Saved Messages topic which messages will be fetched
final

Methods

copyWith({int? savedMessagesTopicId, int? fromMessageId, int? offset, int? limit}) GetSavedMessagesTopicHistory

Available on GetSavedMessagesTopicHistory, provided by the GetSavedMessagesTopicHistoryExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String