GetSearchSponsoredChats class final
Returns sponsored chats to be shown in the search results Returns SponsoredChats
- Inheritance
-
- Object
- TdFunction
- GetSearchSponsoredChats
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetSearchSponsoredChats({required String query})
Properties
Methods
-
copyWith(
{String? query}) → GetSearchSponsoredChats -
Available on GetSearchSponsoredChats, provided by the GetSearchSponsoredChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String