GetSearchSponsoredChats class final

Returns sponsored chats to be shown in the search results Returns SponsoredChats

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetSearchSponsoredChats({required String query})

Properties

hashCode int
The hash code for this object.
no setteroverride
query String
query Query the user searches for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? query}) GetSearchSponsoredChats

Available on GetSearchSponsoredChats, provided by the GetSearchSponsoredChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String