GetStarAdAccountUrl class final
Returns a URL for a Telegram Ad platform account that can be used to set up advertisements for the chat paid in the owned Telegram Stars Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetStarAdAccountUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStarAdAccountUrl({MessageSender? ownerId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- ownerId → MessageSender?
-
ownerId Identifier of the owner of the Telegram Stars; can be identifier
of an owned bot, or identifier of an owned channel chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageSender? ownerId}) → GetStarAdAccountUrl -
Available on GetStarAdAccountUrl, provided by the GetStarAdAccountUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String