GetStarSubscriptions class final
Returns the list of Telegram Star subscriptions for the current user Returns StarSubscriptions
- Inheritance
-
- Object
- TdFunction
- GetStarSubscriptions
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStarSubscriptions({required bool onlyExpiring, required String offset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- offset → String
-
offset Offset of the first subscription to return as received from the
previous request; use empty string to get the first chunk of results
final
- onlyExpiring → bool
-
onlyExpiring Pass true to receive only expiring subscriptions for which
there aren't enough Telegram Stars to extend
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? onlyExpiring, String? offset}) → GetStarSubscriptions -
Available on GetStarSubscriptions, provided by the GetStarSubscriptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String