GetStickerEmojis class final
Returns emoji corresponding to a sticker. The list is only for informational purposes, because a sticker is always sent with a fixed emoji from the corresponding Sticker object Returns Emojis
- Inheritance
-
- Object
- TdFunction
- GetStickerEmojis
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStickerEmojis({InputFile? sticker})
Properties
Methods
-
copyWith(
{InputFile? sticker}) → GetStickerEmojis -
Available on GetStickerEmojis, provided by the GetStickerEmojisExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String