GetStorageStatistics class final
Returns storage usage statistics. Can be called before authorization Returns StorageStatistics
- Inheritance
-
- Object
- TdFunction
- GetStorageStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStorageStatistics({required int chatLimit})
Properties
- chatLimit → int
-
chatLimit The maximum number of chats with the largest storage usage for
which separate statistics need to be returned. All other chats will be
grouped in entries with chat_id == 0. If the chat info database is not
used, the chat_limit is ignored and is always set to 0
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatLimit}) → GetStorageStatistics -
Available on GetStorageStatistics, provided by the GetStorageStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String