GetStory class final
Returns a story Returns Story
- Inheritance
-
- Object
- TdFunction
- GetStory
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyLocal → bool
-
onlyLocal Pass true to get only locally available information without
sending network requests
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId Story identifier
final
- storyPosterChatId → int
-
storyPosterChatId Identifier of the chat that posted the story
final
Methods
-
copyWith(
{int? storyPosterChatId, int? storyId, bool? onlyLocal}) → GetStory -
Available on GetStory, provided by the GetStoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String