GetStoryAlbumStories class final
Returns the list of stories added to the given story album. For optimal performance, the number of returned stories is chosen by TDLib Returns Stories
- Inheritance
-
- Object
- TdFunction
- GetStoryAlbumStories
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStoryAlbumStories({required int chatId, required int storyAlbumId, required int offset, required int limit})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of stories to be returned. For optimal
performance, the number of returned stories is chosen by TDLib and can be
smaller than the specified limit
final
- offset → int
-
offset Offset of the first entry to return; use 0 to get results from
the first album story
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyAlbumId → int
-
storyAlbumId Story album identifier
final
Methods
-
copyWith(
{int? chatId, int? storyAlbumId, int? offset, int? limit}) → GetStoryAlbumStories -
Available on GetStoryAlbumStories, provided by the GetStoryAlbumStoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String