GetStoryAvailableReactions class final
Returns reactions, which can be chosen for a story Returns AvailableReactions
- Inheritance
-
- Object
- TdFunction
- GetStoryAvailableReactions
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStoryAvailableReactions({required int rowSize})
Properties
Methods
-
copyWith(
{int? rowSize}) → GetStoryAvailableReactions -
Available on GetStoryAvailableReactions, provided by the GetStoryAvailableReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String