GetStoryPublicForwards class final
Returns forwards of a story as a message to public chats and reposts by public channels. Can be used only if the story is posted on behalf of the current user or story.can_get_statistics == true. For optimal performance, the number of returned messages and stories is chosen by TDLib Returns PublicForwards
- Inheritance
-
- Object
- TdFunction
- GetStoryPublicForwards
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStoryPublicForwards({required int storyPosterChatId, required int storyId, required String offset, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of messages and stories to be returned; must be
positive and can't be greater than 100. For optimal performance, the
number of returned objects is chosen by TDLib and can be smaller than the
specified limit
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId The identifier of the story
final
- storyPosterChatId → int
-
storyPosterChatId The identifier of the poster of the story
final
Methods
-
copyWith(
{int? storyPosterChatId, int? storyId, String? offset, int? limit}) → GetStoryPublicForwards -
Available on GetStoryPublicForwards, provided by the GetStoryPublicForwardsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String