GetStoryStatistics class final
Returns detailed statistics about a story. Can be used only if story.can_get_statistics == true Returns StoryStatistics
- Inheritance
-
- Object
- TdFunction
- GetStoryStatistics
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetStoryStatistics({required int chatId, required int storyId, required bool isDark})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isDark → bool
-
isDark Pass true if a dark theme is used by the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId Story identifier
final
Methods
-
copyWith(
{int? chatId, int? storyId, bool? isDark}) → GetStoryStatistics -
Available on GetStoryStatistics, provided by the GetStoryStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String