GetTextEntities class final

Returns all entities (mentions, hashtags, cashtags, bot commands, bank card numbers, URLs, and email addresses) found in the text. Can be called synchronously Returns TextEntities

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetTextEntities({required String text})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
text The text in which to look for entities
final

Methods

copyWith({String? text}) GetTextEntities

Available on GetTextEntities, provided by the GetTextEntitiesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String