GetTopChats class final
Returns a list of frequently used chats Returns Chats
- Inheritance
-
- Object
- TdFunction
- GetTopChats
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetTopChats({TopChatCategory? category, required int limit})
Properties
- category → TopChatCategory?
-
category Category of chats to be returned
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of chats to be returned; up to 30
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{TopChatCategory? category, int? limit}) → GetTopChats -
Available on GetTopChats, provided by the GetTopChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String