GetUpgradedGiftValueInfo class final
Returns information about value of an upgraded gift by its name Returns UpgradedGiftValueInfo
- Inheritance
-
- Object
- TdFunction
- GetUpgradedGiftValueInfo
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetUpgradedGiftValueInfo({required String name})
Properties
Methods
-
copyWith(
{String? name}) → GetUpgradedGiftValueInfo -
Available on GetUpgradedGiftValueInfo, provided by the GetUpgradedGiftValueInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String