GetUpgradedGiftWithdrawalUrl class final
Returns a URL for upgraded gift withdrawal in the TON blockchain as an NFT; requires owner privileges for gifts owned by a chat Returns HttpUrl
- Inheritance
-
- Object
- TdFunction
- GetUpgradedGiftWithdrawalUrl
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetUpgradedGiftWithdrawalUrl({required String receivedGiftId, required String password})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- password → String
-
password The 2-step verification password of the current user
final
- receivedGiftId → String
-
receivedGiftId Identifier of the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? receivedGiftId, String? password}) → GetUpgradedGiftWithdrawalUrl -
Available on GetUpgradedGiftWithdrawalUrl, provided by the GetUpgradedGiftWithdrawalUrlExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String