GetWebAppLinkUrl class final

Returns an HTTPS URL of a Web App to open after a link of the type internalLinkTypeWebApp is clicked Returns WebAppUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetWebAppLinkUrl({required int chatId, required int botUserId, required String webAppShortName, required String startParameter, required bool allowWriteAccess, WebAppOpenParameters? parameters})

Properties

allowWriteAccess bool
allowWriteAccess Pass true if the current user allowed the bot to send them messages
final
botUserId int
botUserId Identifier of the target bot
final
chatId int
chatId Identifier of the chat in which the link was clicked; pass 0 if none
final
hashCode int
The hash code for this object.
no setteroverride
parameters WebAppOpenParameters?
parameters Parameters to use to open the Web App
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startParameter String
startParameter Start parameter from internalLinkTypeWebApp
final
webAppShortName String
webAppShortName Short name of the Web App
final

Methods

copyWith({int? chatId, int? botUserId, String? webAppShortName, String? startParameter, bool? allowWriteAccess, WebAppOpenParameters? parameters}) GetWebAppLinkUrl

Available on GetWebAppLinkUrl, provided by the GetWebAppLinkUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String