GetWebAppPlaceholder class final
Returns a default placeholder for Web Apps of a bot. This is an offline method. Returns a 404 error if the placeholder isn't known Returns Outline
- Inheritance
-
- Object
- TdFunction
- GetWebAppPlaceholder
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetWebAppPlaceholder({required int botUserId})
Properties
Methods
-
copyWith(
{int? botUserId}) → GetWebAppPlaceholder -
Available on GetWebAppPlaceholder, provided by the GetWebAppPlaceholderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String