GetWebAppUrl class final

Returns an HTTPS URL of a Web App to open from the side menu, a keyboardButtonTypeWebApp button, or an inlineQueryResultsButtonTypeWebApp button Returns WebAppUrl

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GetWebAppUrl({required int botUserId, required String url, WebAppOpenParameters? parameters})

Properties

botUserId int
botUserId Identifier of the target bot. If the bot is restricted for the current user, then show an error instead of calling the method
final
hashCode int
The hash code for this object.
no setteroverride
parameters WebAppOpenParameters?
parameters Parameters to use to open the Web App
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
url The URL from a keyboardButtonTypeWebApp button, inlineQueryResultsButtonTypeWebApp button, or an empty string when the bot is opened from the side menu
final

Methods

copyWith({int? botUserId, String? url, WebAppOpenParameters? parameters}) GetWebAppUrl

Available on GetWebAppUrl, provided by the GetWebAppUrlExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String