GetWebPageInstantView class final
Returns an instant view version of a web page if available. This is an offline method if only_local is true. Returns a 404 error if the web page has no instant view page Returns WebPageInstantView
- Inheritance
-
- Object
- TdFunction
- GetWebPageInstantView
- Available extensions
- Annotations
-
- @immutable
Constructors
- GetWebPageInstantView({required String url, required bool onlyLocal})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyLocal → bool
-
onlyLocal Pass true to get only locally available information without
sending network requests
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url The web page URL
final
Methods
-
copyWith(
{String? url, bool? onlyLocal}) → GetWebPageInstantView -
Available on GetWebPageInstantView, provided by the GetWebPageInstantViewExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String