GiftAuctionAcquiredGift class final

Represents a gift that was acquired by the current user on an auction

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftAuctionAcquiredGift({MessageSender? receiverId, required int date, required int starCount, required int auctionRoundNumber, required int auctionRoundPosition, required int uniqueGiftNumber, FormattedText? text, required bool isPrivate})

Properties

auctionRoundNumber int
auctionRoundNumber Identifier of the auction round in which the gift was acquired
final
auctionRoundPosition int
auctionRoundPosition Position of the user in the round among all auction participants
final
date int
date Point in time (Unix timestamp) when the gift was acquired
final
hashCode int
The hash code for this object.
no setteroverride
isPrivate bool
isPrivate True, if the sender and gift text are shown only to the gift receiver; otherwise, everyone will be able to see them
final
receiverId MessageSender?
receiverId Receiver of the gift
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount The number of Telegram Stars that were paid for the gift
final
text FormattedText?
text Message added to the gift
final
uniqueGiftNumber int
uniqueGiftNumber Unique number of the gift among gifts upgraded from the same gift after upgrade; 0 if yet unassigned
final

Methods

copyWith({MessageSender? receiverId, int? date, int? starCount, int? auctionRoundNumber, int? auctionRoundPosition, int? uniqueGiftNumber, FormattedText? text, bool? isPrivate}) GiftAuctionAcquiredGift

Available on GiftAuctionAcquiredGift, provided by the GiftAuctionAcquiredGiftExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftAuctionAcquiredGift?

Constants

constructor → const String