GiftForResale class final
Describes a gift available for resale
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiftForResale({UpgradedGift? gift, required String receivedGiftId})
Properties
- gift → UpgradedGift?
-
gift The gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- receivedGiftId → String
-
receivedGiftId Unique identifier of the received gift for the current
user; only for the gifts owned by the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{UpgradedGift? gift, String? receivedGiftId}) → GiftForResale -
Available on GiftForResale, provided by the GiftForResaleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftForResale?
Constants
- constructor → const String