receivedGiftId property

String receivedGiftId
final

receivedGiftId Unique identifier of the received gift for the current user; only for the gifts owned by the current user

Implementation

final String receivedGiftId;