GiftPurchaseLimits class final
Describes the maximum number of times that a specific gift can be purchased
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiftPurchaseLimits({required int totalCount, required int remainingCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- remainingCount → int
-
remainingCount Number of remaining times the gift can be purchased
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount The maximum number of times the gifts can be purchased
final
Methods
-
copyWith(
{int? totalCount, int? remainingCount}) → GiftPurchaseLimits -
Available on GiftPurchaseLimits, provided by the GiftPurchaseLimitsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftPurchaseLimits?
Constants
- constructor → const String