GiftResaleResult class sealed
Describes result of sending a resold gift
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ok(GiftResaleResultOk value), required TResult priceIncreased(GiftResaleResultPriceIncreased value)}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ok(GiftResaleResultOk value)?, TResult priceIncreased(GiftResaleResultPriceIncreased value)?, required TResult orElse()}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftResaleResult? - Inherited by: GiftResaleResultOk GiftResaleResultPriceIncreased
Constants
- constructor → const String