GiftResaleResultPriceIncreased class final
Operation has failed, because price has increased. If the price has decreased, then the buying will succeed anyway
- Inheritance
-
- Object
- TdObject
- GiftResaleResult
- GiftResaleResultPriceIncreased
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- price → GiftResalePrice?
-
price New price for the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{GiftResalePrice? price}) → GiftResaleResultPriceIncreased -
Available on GiftResaleResultPriceIncreased, provided by the GiftResaleResultPriceIncreasedExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ok(GiftResaleResultOk value), required TResult priceIncreased(GiftResaleResultPriceIncreased value)}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ok(GiftResaleResultOk value)?, TResult priceIncreased(GiftResaleResultPriceIncreased value)?, required TResult orElse()}) → TResult -
Available on GiftResaleResult, provided by the GiftResaleResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftResaleResultPriceIncreased? -
Inherited by:
GiftResaleResultOk
GiftResaleResultPriceIncreased
override
Constants
- constructor → const String