GiftSettings class final
Contains settings for gift receiving for a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiftSettings({required bool showGiftButton, AcceptedGiftTypes? acceptedGiftTypes})
Properties
- acceptedGiftTypes → AcceptedGiftTypes?
-
acceptedGiftTypes Types of gifts accepted by the user; for Telegram
Premium users only
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showGiftButton → bool
-
showGiftButton True, if a button for sending a gift to the user or by
the user must always be shown in the input field
final
Methods
-
copyWith(
{bool? showGiftButton, AcceptedGiftTypes? acceptedGiftTypes}) → GiftSettings -
Available on GiftSettings, provided by the GiftSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftSettings?
Constants
- constructor → const String