GiftUpgradePrice class final
Describes a price required to pay to upgrade a gift
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiftUpgradePrice({required int date, required int starCount})
Properties
- date → int
-
date Point in time (Unix timestamp) when the price will be in effect
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount The Telegram Star amount required to pay to upgrade the gift
final
Methods
-
copyWith(
{int? date, int? starCount}) → GiftUpgradePrice -
Available on GiftUpgradePrice, provided by the GiftUpgradePriceExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftUpgradePrice?
Constants
- constructor → const String