GiftUpgradeVariants class final

Contains all possible variants of upgraded gifts for the given regular gift

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiftUpgradeVariants({required List<UpgradedGiftModel> models, required List<UpgradedGiftSymbol> symbols, required List<UpgradedGiftBackdrop> backdrops})

Properties

backdrops List<UpgradedGiftBackdrop>
backdrops Backdrops that can be chosen for the gift after upgrade
final
hashCode int
The hash code for this object.
no setteroverride
models List<UpgradedGiftModel>
models Models that can be chosen for the gift after upgrade
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbols List<UpgradedGiftSymbol>
symbols Symbols that can be chosen for the gift after upgrade
final

Methods

copyWith({List<UpgradedGiftModel>? models, List<UpgradedGiftSymbol>? symbols, List<UpgradedGiftBackdrop>? backdrops}) GiftUpgradeVariants

Available on GiftUpgradeVariants, provided by the GiftUpgradeVariantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiftUpgradeVariants?

Constants

constructor → const String