GiftsForCrafting class final
Represents a list of gifts received by a user or a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GiftsForCrafting({required int totalCount, required List<
ReceivedGift> gifts, required List<AttributeCraftPersistenceProbability> attributePersistenceProbabilities, required String nextOffset})
Properties
-
attributePersistenceProbabilities
→ List<
AttributeCraftPersistenceProbability> -
attributePersistenceProbabilities The 4 objects that describe
probabilities of the crafted gift to have the backdrop or symbol of one of
the original gifts for the cases when 1, 2, 3 or 4 gifts are used in the
craft correspondingly
final
-
gifts
→ List<
ReceivedGift> -
gifts The list of gifts
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount The total number of received gifts
final
Methods
-
copyWith(
{int? totalCount, List< ReceivedGift> ? gifts, List<AttributeCraftPersistenceProbability> ? attributePersistenceProbabilities, String? nextOffset}) → GiftsForCrafting -
Available on GiftsForCrafting, provided by the GiftsForCraftingExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftsForCrafting?
Constants
- constructor → const String