GiftsForResale class final
Describes gifts available for resale
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GiftsForResale({required int totalCount, required List<
GiftForResale> gifts, required List<UpgradedGiftModelCount> models, required List<UpgradedGiftSymbolCount> symbols, required List<UpgradedGiftBackdropCount> backdrops, required String nextOffset})
Properties
-
backdrops
→ List<
UpgradedGiftBackdropCount> -
backdrops Available backdrops; for searchGiftsForResale requests without
offset and attributes only
final
-
gifts
→ List<
GiftForResale> -
gifts The gifts
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
models
→ List<
UpgradedGiftModelCount> -
models Available models; for searchGiftsForResale requests without
offset and attributes only
final
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
symbols
→ List<
UpgradedGiftSymbolCount> -
symbols Available symbols; for searchGiftsForResale requests without
offset and attributes only
final
- totalCount → int
-
totalCount Total number of gifts found
final
Methods
-
copyWith(
{int? totalCount, List< GiftForResale> ? gifts, List<UpgradedGiftModelCount> ? models, List<UpgradedGiftSymbolCount> ? symbols, List<UpgradedGiftBackdropCount> ? backdrops, String? nextOffset}) → GiftsForResale -
Available on GiftsForResale, provided by the GiftsForResaleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiftsForResale?
Constants
- constructor → const String