GiveawayInfo class sealed
Contains information about a giveaway
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult completed(GiveawayInfoCompleted value), required TResult ongoing(GiveawayInfoOngoing value)}) → TResult -
Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult completed(GiveawayInfoCompleted value)?, TResult ongoing(GiveawayInfoOngoing value)?, required TResult orElse()}) → TResult -
Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiveawayInfo? - Inherited by: GiveawayInfoCompleted GiveawayInfoOngoing
Constants
- constructor → const String