GiveawayInfoCompleted class final
Describes a completed giveaway
- Inheritance
-
- Object
- TdObject
- GiveawayInfo
- GiveawayInfoCompleted
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- activationCount → int
-
activationCount Number of winners, which activated their gift codes; for
Telegram Premium giveaways only
final
- actualWinnersSelectionDate → int
-
actualWinnersSelectionDate Point in time (Unix timestamp) when the
winners were selected. May be bigger than winners selection date specified
in parameters of the giveaway
final
- creationDate → int
-
creationDate Point in time (Unix timestamp) when the giveaway was
created
final
- giftCode → String
-
giftCode Telegram Premium gift code that was received by the current
user; empty if the user isn't a winner in the giveaway or the giveaway
isn't a Telegram Premium giveaway
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isWinner → bool
-
isWinner True, if the current user is a winner of the giveaway
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wasRefunded → bool
-
wasRefunded True, if the giveaway was canceled and was fully refunded
final
- winnerCount → int
-
winnerCount Number of winners in the giveaway
final
- wonStarCount → int
-
wonStarCount The Telegram Star amount won by the current user; 0 if the
user isn't a winner in the giveaway or the giveaway isn't a Telegram Star
giveaway
final
Methods
-
copyWith(
{int? creationDate, int? actualWinnersSelectionDate, bool? wasRefunded, bool? isWinner, int? winnerCount, int? activationCount, String? giftCode, int? wonStarCount}) → GiveawayInfoCompleted -
Available on GiveawayInfoCompleted, provided by the GiveawayInfoCompletedExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult completed(GiveawayInfoCompleted value), required TResult ongoing(GiveawayInfoOngoing value)}) → TResult -
Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult completed(GiveawayInfoCompleted value)?, TResult ongoing(GiveawayInfoOngoing value)?, required TResult orElse()}) → TResult -
Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiveawayInfoCompleted? -
Inherited by:
GiveawayInfoCompleted
GiveawayInfoOngoing
override
Constants
- constructor → const String