GiveawayInfoOngoing class final

Describes an ongoing giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiveawayInfoOngoing({required int creationDate, GiveawayParticipantStatus? status, required bool isEnded})

Properties

creationDate int
creationDate Point in time (Unix timestamp) when the giveaway was created
final
hashCode int
The hash code for this object.
no setteroverride
isEnded bool
isEnded True, if the giveaway has ended and results are being prepared
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GiveawayParticipantStatus?
status Status of the current user in the giveaway
final

Methods

copyWith({int? creationDate, GiveawayParticipantStatus? status, bool? isEnded}) GiveawayInfoOngoing

Available on GiveawayInfoOngoing, provided by the GiveawayInfoOngoingExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult completed(GiveawayInfoCompleted value), required TResult ongoing(GiveawayInfoOngoing value)}) → TResult

Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension

maybeMap<TResult extends Object?>({TResult completed(GiveawayInfoCompleted value)?, TResult ongoing(GiveawayInfoOngoing value)?, required TResult orElse()}) → TResult

Available on GiveawayInfo, provided by the GiveawayInfoExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiveawayInfoOngoing?
Inherited by: GiveawayInfoCompleted GiveawayInfoOngoing
override

Constants

constructor → const String