GiveawayParticipantStatusAlreadyWasMember class final
The user can't participate in the giveaway, because they have already been member of the chat
- Inheritance
-
- Object
- TdObject
- GiveawayParticipantStatus
- GiveawayParticipantStatusAlreadyWasMember
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiveawayParticipantStatusAlreadyWasMember({required int joinedChatDate})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- joinedChatDate → int
-
joinedChatDate Point in time (Unix timestamp) when the user joined the
chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? joinedChatDate}) → GiveawayParticipantStatusAlreadyWasMember -
Available on GiveawayParticipantStatusAlreadyWasMember, provided by the GiveawayParticipantStatusAlreadyWasMemberExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult administrator(GiveawayParticipantStatusAdministrator value), required TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value), required TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value), required TResult eligible(GiveawayParticipantStatusEligible value), required TResult participating(GiveawayParticipantStatusParticipating value)}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult administrator(GiveawayParticipantStatusAdministrator value)?, TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value)?, TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value)?, TResult eligible(GiveawayParticipantStatusEligible value)?, TResult participating(GiveawayParticipantStatusParticipating value)?, required TResult orElse()}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiveawayParticipantStatusAlreadyWasMember? -
Inherited by:
GiveawayParticipantStatusAdministrator
GiveawayParticipantStatusAlreadyWasMember
GiveawayParticipantStatusDisallowedCountry
GiveawayParticipantStatusEligible
GiveawayParticipantStatusParticipating
override
Constants
- constructor → const String