GiveawayParticipantStatusDisallowedCountry class final
The user can't participate in the giveaway, because their phone number is from a disallowed country
- Inheritance
-
- Object
- TdObject
- GiveawayParticipantStatus
- GiveawayParticipantStatusDisallowedCountry
- Available extensions
- Annotations
-
- @immutable
Constructors
- GiveawayParticipantStatusDisallowedCountry({required String userCountryCode})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userCountryCode → String
-
userCountryCode A two-letter ISO 3166-1 alpha-2 country code of the
user's country
final
Methods
-
copyWith(
{String? userCountryCode}) → GiveawayParticipantStatusDisallowedCountry -
Available on GiveawayParticipantStatusDisallowedCountry, provided by the GiveawayParticipantStatusDisallowedCountryExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult administrator(GiveawayParticipantStatusAdministrator value), required TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value), required TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value), required TResult eligible(GiveawayParticipantStatusEligible value), required TResult participating(GiveawayParticipantStatusParticipating value)}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult administrator(GiveawayParticipantStatusAdministrator value)?, TResult alreadyWasMember(GiveawayParticipantStatusAlreadyWasMember value)?, TResult disallowedCountry(GiveawayParticipantStatusDisallowedCountry value)?, TResult eligible(GiveawayParticipantStatusEligible value)?, TResult participating(GiveawayParticipantStatusParticipating value)?, required TResult orElse()}) → TResult -
Available on GiveawayParticipantStatus, provided by the GiveawayParticipantStatusExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GiveawayParticipantStatusDisallowedCountry? -
Inherited by:
GiveawayParticipantStatusAdministrator
GiveawayParticipantStatusAlreadyWasMember
GiveawayParticipantStatusDisallowedCountry
GiveawayParticipantStatusEligible
GiveawayParticipantStatusParticipating
override
Constants
- constructor → const String