GiveawayPrizeStars class final

The giveaway sends Telegram Stars to the winners

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GiveawayPrizeStars({required int starCount})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
starCount int
starCount Number of Telegram Stars that will be shared by all winners
final

Methods

copyWith({int? starCount}) GiveawayPrizeStars

Available on GiveawayPrizeStars, provided by the GiveawayPrizeStarsExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult premium(GiveawayPrizePremium value), required TResult stars(GiveawayPrizeStars value)}) → TResult

Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension

maybeMap<TResult extends Object?>({TResult premium(GiveawayPrizePremium value)?, TResult stars(GiveawayPrizeStars value)?, required TResult orElse()}) → TResult

Available on GiveawayPrize, provided by the GiveawayPrizeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GiveawayPrizeStars?
Inherited by: GiveawayPrizePremium GiveawayPrizeStars
override

Constants

constructor → const String