GramRevenueStatus class final

Contains information about TON Grams earned by the current user

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GramRevenueStatus({required int totalAmount, required int balanceAmount, required int availableAmount, required bool withdrawalEnabled})

Properties

availableAmount int
availableAmount The Gram amount that is available for withdrawal; in the smallest units of the cryptocurrency
final
balanceAmount int
balanceAmount The Gram amount that isn't withdrawn yet; in the smallest units of the cryptocurrency
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAmount int
totalAmount Total Gram amount earned; in the smallest units of the cryptocurrency
final
withdrawalEnabled bool
withdrawalEnabled True, if Grams can be withdrawn
final

Methods

copyWith({int? totalAmount, int? balanceAmount, int? availableAmount, bool? withdrawalEnabled}) GramRevenueStatus

Available on GramRevenueStatus, provided by the GramRevenueStatusExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GramRevenueStatus?

Constants

constructor → const String