GroupCallInfo class final
Contains information about a just created or just joined group call
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GroupCallInfo({required int groupCallId, required String joinPayload})
Properties
- groupCallId → int
-
groupCallId Identifier of the group call
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- joinPayload → String
-
joinPayload Join response payload for tgcalls; empty if the call isn't
joined
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, String? joinPayload}) → GroupCallInfo -
Available on GroupCallInfo, provided by the GroupCallInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallInfo?
Constants
- constructor → const String