GroupCallMessage class final
Represents a message sent in a group call
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- GroupCallMessage({required int messageId, MessageSender? senderId, required int date, FormattedText? text, required int paidMessageStarCount, required bool isFromOwner, required bool canBeDeleted})
Properties
- canBeDeleted → bool
-
canBeDeleted True, if the message can be deleted by the current user;
for live stories only
final
- date → int
-
date Point in time (Unix timestamp) when the message was sent
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFromOwner → bool
-
isFromOwner True, if the message is sent by the owner of the call and
must be treated as a message of the maximum level; for live stories only
final
- messageId → int
-
messageId Unique message identifier within the group call
final
- paidMessageStarCount → int
-
paidMessageStarCount The number of Telegram Stars that were paid to send
the message; for live stories only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the sender of the message
final
- text → FormattedText?
-
text Text of the message. If empty, then the message is a paid reaction
in a live story
final
Methods
-
copyWith(
{int? messageId, MessageSender? senderId, int? date, FormattedText? text, int? paidMessageStarCount, bool? isFromOwner, bool? canBeDeleted}) → GroupCallMessage -
Available on GroupCallMessage, provided by the GroupCallMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallMessage?
Constants
- constructor → const String