isFromOwner property
isFromOwner True, if the message is sent by the owner of the call and must be treated as a message of the maximum level; for live stories only
Implementation
final bool isFromOwner;
isFromOwner True, if the message is sent by the owner of the call and must be treated as a message of the maximum level; for live stories only
final bool isFromOwner;