GroupCallParticipants class final

Contains identifiers of group call participants

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

GroupCallParticipants({required int totalCount, required List<MessageSender> participantIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
participantIds List<MessageSender>
participantIds Identifiers of the participants
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
totalCount Total number of group call participants
final

Methods

copyWith({int? totalCount, List<MessageSender>? participantIds}) GroupCallParticipants

Available on GroupCallParticipants, provided by the GroupCallParticipantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) GroupCallParticipants?

Constants

constructor → const String