GroupCallVideoSourceGroup class final
Describes a group of video synchronization source identifiers
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
GroupCallVideoSourceGroup({required String semantics, required List<
int> sourceIds})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semantics → String
-
semantics The semantics of sources, one of "SIM" or "FID"
final
-
sourceIds
→ List<
int> -
sourceIds The list of synchronization source identifiers
final
Methods
-
copyWith(
{String? semantics, List< int> ? sourceIds}) → GroupCallVideoSourceGroup -
Available on GroupCallVideoSourceGroup, provided by the GroupCallVideoSourceGroupExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → GroupCallVideoSourceGroup?
Constants
- constructor → const String