ImportedContacts class final
Represents the result of an importContacts request
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ImportedContacts({required List<
int> userIds, required List<int> importerCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
importerCount
→ List<
int> -
importerCount The number of users that imported the corresponding
contact; 0 for already registered users or if unavailable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
int> -
userIds User identifiers of the imported contacts in the same order as
they were specified in the request; 0 if the contact is not yet a
registered user
final
Methods
-
copyWith(
{List< int> ? userIds, List<int> ? importerCount}) → ImportedContacts -
Available on ImportedContacts, provided by the ImportedContactsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ImportedContacts?
Constants
- constructor → const String