InlineKeyboardButton class final

Represents a single button in an inline keyboard

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InlineKeyboardButton({required String text, required int iconCustomEmojiId, ButtonStyle? style, InlineKeyboardButtonType? type})

Properties

hashCode int
The hash code for this object.
no setteroverride
iconCustomEmojiId int
iconCustomEmojiId Identifier of the custom emoji that must be shown on the button; 0 if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style ButtonStyle?
style Style of the button
final
text String
text Text of the button
final
type InlineKeyboardButtonType?
type Type of the button
final

Methods

copyWith({String? text, int? iconCustomEmojiId, ButtonStyle? style, InlineKeyboardButtonType? type}) InlineKeyboardButton

Available on InlineKeyboardButton, provided by the InlineKeyboardButtonExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InlineKeyboardButton?

Constants

constructor → const String