InlineQueryResults class final

Represents the results of the inline query. Use sendInlineQueryResultMessage to send the result of the query

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InlineQueryResults({required int inlineQueryId, InlineQueryResultsButton? button, required List<InlineQueryResult> results, required String nextOffset})

Properties

button InlineQueryResultsButton?
button Button to be shown above inline query results; may be null
final
hashCode int
The hash code for this object.
no setteroverride
inlineQueryId int
inlineQueryId Unique identifier of the inline query
final
nextOffset String
nextOffset The offset for the next request. If empty, then there are no more results
final
results List<InlineQueryResult>
results Results of the query
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? inlineQueryId, InlineQueryResultsButton? button, List<InlineQueryResult>? results, String? nextOffset}) InlineQueryResults

Available on InlineQueryResults, provided by the InlineQueryResultsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InlineQueryResults?

Constants

constructor → const String