InlineQueryResultsButtonTypeWebApp class final
Describes the button that opens a Web App by calling getWebAppUrl
- Inheritance
-
- Object
- TdObject
- InlineQueryResultsButtonType
- InlineQueryResultsButtonTypeWebApp
- Available extensions
- Annotations
-
- @immutable
Constructors
- InlineQueryResultsButtonTypeWebApp({required String url})
Properties
Methods
-
copyWith(
{String? url}) → InlineQueryResultsButtonTypeWebApp -
Available on InlineQueryResultsButtonTypeWebApp, provided by the InlineQueryResultsButtonTypeWebAppExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult startBot(InlineQueryResultsButtonTypeStartBot value), required TResult webApp(InlineQueryResultsButtonTypeWebApp value)}) → TResult -
Available on InlineQueryResultsButtonType, provided by the InlineQueryResultsButtonTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult startBot(InlineQueryResultsButtonTypeStartBot value)?, TResult webApp(InlineQueryResultsButtonTypeWebApp value)?, required TResult orElse()}) → TResult -
Available on InlineQueryResultsButtonType, provided by the InlineQueryResultsButtonTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InlineQueryResultsButtonTypeWebApp? -
Inherited by:
InlineQueryResultsButtonTypeStartBot
InlineQueryResultsButtonTypeWebApp
override
Constants
- constructor → const String