InputAnimation class final
An animation to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
InputAnimation({InputFile? animation, InputThumbnail? thumbnail, required List<
int> addedStickerFileIds, required int duration, required int width, required int height})
Properties
-
addedStickerFileIds
→ List<
int> -
addedStickerFileIds File identifiers of the stickers added to the
animation, if applicable
final
- animation → InputFile?
-
animation Animation file to be sent
final
- duration → int
-
duration Duration of the animation, in seconds; may be replaced by the
server
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Height of the animation; may be replaced by the server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → InputThumbnail?
-
thumbnail Animation thumbnail; pass null to skip thumbnail uploading
final
- width → int
-
width Width of the animation; may be replaced by the server
final
Methods
-
copyWith(
{InputFile? animation, InputThumbnail? thumbnail, List< int> ? addedStickerFileIds, int? duration, int? width, int? height}) → InputAnimation -
Available on InputAnimation, provided by the InputAnimationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputAnimation?
Constants
- constructor → const String