InputAudio class final
An audio to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputAudio({InputFile? audio, InputThumbnail? albumCoverThumbnail, required int duration, required String title, required String performer})
Properties
- albumCoverThumbnail → InputThumbnail?
-
albumCoverThumbnail Thumbnail of the cover for the album; pass null to
skip thumbnail uploading
final
- audio → InputFile?
-
audio Audio file to be sent
final
- duration → int
-
duration Duration of the audio, in seconds; may be replaced by the
server
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- performer → String
-
performer Performer of the audio; 0-64 characters, may be replaced by
the server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Title of the audio; 0-64 characters; may be replaced by the server
final
Methods
-
copyWith(
{InputFile? audio, InputThumbnail? albumCoverThumbnail, int? duration, String? title, String? performer}) → InputAudio -
Available on InputAudio, provided by the InputAudioExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputAudio?
Constants
- constructor → const String