InputBackground class sealed
Contains information about background to set
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult local(InputBackgroundLocal value), required TResult previous(InputBackgroundPrevious value), required TResult remote(InputBackgroundRemote value)}) → TResult -
Available on InputBackground, provided by the InputBackgroundExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult local(InputBackgroundLocal value)?, TResult previous(InputBackgroundPrevious value)?, TResult remote(InputBackgroundRemote value)?, required TResult orElse()}) → TResult -
Available on InputBackground, provided by the InputBackgroundExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputBackground? - Inherited by: InputBackgroundLocal InputBackgroundPrevious InputBackgroundRemote
Constants
- constructor → const String