InputBackgroundLocal class final
A background from a local file
- Inheritance
-
- Object
- TdObject
- InputBackground
- InputBackgroundLocal
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputBackgroundLocal({InputFile? background})
Properties
- background → InputFile?
-
background Background file to use. Only inputFileLocal and
inputFileGenerated are supported. The file must be in JPEG format for
wallpapers and in PNG format for patterns
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputFile? background}) → InputBackgroundLocal -
Available on InputBackgroundLocal, provided by the InputBackgroundLocalExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult local(InputBackgroundLocal value), required TResult previous(InputBackgroundPrevious value), required TResult remote(InputBackgroundRemote value)}) → TResult -
Available on InputBackground, provided by the InputBackgroundExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult local(InputBackgroundLocal value)?, TResult previous(InputBackgroundPrevious value)?, TResult remote(InputBackgroundRemote value)?, required TResult orElse()}) → TResult -
Available on InputBackground, provided by the InputBackgroundExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputBackgroundLocal? -
Inherited by:
InputBackgroundLocal
InputBackgroundPrevious
InputBackgroundRemote
override
Constants
- constructor → const String