InputBusinessChatLink class final
Describes a business chat link to create or edit
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputBusinessChatLink({FormattedText? text, required String title})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Message draft text that will be added to the input field
final
- title → String
-
title Link title
final
Methods
-
copyWith(
{FormattedText? text, String? title}) → InputBusinessChatLink -
Available on InputBusinessChatLink, provided by the InputBusinessChatLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputBusinessChatLink?
Constants
- constructor → const String