InputCall class sealed
Describes a call
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult discarded(InputCallDiscarded value), required TResult fromMessage(InputCallFromMessage value)}) → TResult -
Available on InputCall, provided by the InputCallExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult discarded(InputCallDiscarded value)?, TResult fromMessage(InputCallFromMessage value)?, required TResult orElse()}) → TResult -
Available on InputCall, provided by the InputCallExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputCall? - Inherited by: InputCallDiscarded InputCallFromMessage
Constants
- constructor → const String