InputChatPhotoAnimation class final
An animation in MPEG4 format; must be square, at most 10 seconds long, have width between 160 and 1280 and be at most 2MB in size
- Inheritance
-
- Object
- TdObject
- InputChatPhoto
- InputChatPhotoAnimation
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputChatPhotoAnimation({InputFile? animation, required double mainFrameTimestamp})
Properties
- animation → InputFile?
-
animation Animation to be set as profile photo. Only inputFileLocal and
inputFileGenerated are allowed
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mainFrameTimestamp → double
-
mainFrameTimestamp Timestamp of the frame, which will be used as static
chat photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputFile? animation, double? mainFrameTimestamp}) → InputChatPhotoAnimation -
Available on InputChatPhotoAnimation, provided by the InputChatPhotoAnimationExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult animation(InputChatPhotoAnimation value), required TResult previous(InputChatPhotoPrevious value), required TResult static(InputChatPhotoStatic value), required TResult sticker(InputChatPhotoSticker value)}) → TResult -
Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult animation(InputChatPhotoAnimation value)?, TResult previous(InputChatPhotoPrevious value)?, TResult static(InputChatPhotoStatic value)?, TResult sticker(InputChatPhotoSticker value)?, required TResult orElse()}) → TResult -
Available on InputChatPhoto, provided by the InputChatPhotoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputChatPhotoAnimation? -
Inherited by:
InputChatPhotoAnimation
InputChatPhotoPrevious
InputChatPhotoStatic
InputChatPhotoSticker
override
Constants
- constructor → const String