InputCredentialsApplePay class final
Applies if a user enters new credentials using Apple Pay
- Inheritance
-
- Object
- TdObject
- InputCredentials
- InputCredentialsApplePay
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputCredentialsApplePay({required String data})
Properties
Methods
-
copyWith(
{String? data}) → InputCredentialsApplePay -
Available on InputCredentialsApplePay, provided by the InputCredentialsApplePayExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult applePay(InputCredentialsApplePay value), required TResult googlePay(InputCredentialsGooglePay value), required TResult $new(InputCredentialsNew value), required TResult saved(InputCredentialsSaved value)}) → TResult -
Available on InputCredentials, provided by the InputCredentialsExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult applePay(InputCredentialsApplePay value)?, TResult googlePay(InputCredentialsGooglePay value)?, TResult $new(InputCredentialsNew value)?, TResult saved(InputCredentialsSaved value)?, required TResult orElse()}) → TResult -
Available on InputCredentials, provided by the InputCredentialsExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputCredentialsApplePay? -
Inherited by:
InputCredentialsApplePay
InputCredentialsGooglePay
InputCredentialsNew
InputCredentialsSaved
override
Constants
- constructor → const String