InputCredentialsNew class final
Applies if a user enters new credentials on a payment provider website
- Inheritance
-
- Object
- TdObject
- InputCredentials
- InputCredentialsNew
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputCredentialsNew({required String data, required bool allowSave})
Properties
- allowSave → bool
-
allowSave True, if the credential identifier can be saved on the server
side
final
- data → String
-
data JSON-encoded data with the credential identifier from the payment
provider
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? data, bool? allowSave}) → InputCredentialsNew -
Available on InputCredentialsNew, provided by the InputCredentialsNewExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult applePay(InputCredentialsApplePay value), required TResult googlePay(InputCredentialsGooglePay value), required TResult $new(InputCredentialsNew value), required TResult saved(InputCredentialsSaved value)}) → TResult -
Available on InputCredentials, provided by the InputCredentialsExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult applePay(InputCredentialsApplePay value)?, TResult googlePay(InputCredentialsGooglePay value)?, TResult $new(InputCredentialsNew value)?, TResult saved(InputCredentialsSaved value)?, required TResult orElse()}) → TResult -
Available on InputCredentials, provided by the InputCredentialsExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputCredentialsNew? -
Inherited by:
InputCredentialsApplePay
InputCredentialsGooglePay
InputCredentialsNew
InputCredentialsSaved
override
Constants
- constructor → const String