InputDocument class final

A document (general file) to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputDocument({InputFile? document, InputThumbnail? thumbnail, required bool disableContentTypeDetection})

Properties

disableContentTypeDetection bool
disableContentTypeDetection Pass true to disable automatic file type detection and send the document as a file. Always true for files sent to secret chats
final
document InputFile?
document File to be sent
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail InputThumbnail?
thumbnail Document thumbnail; pass null to skip thumbnail uploading
final

Methods

copyWith({InputFile? document, InputThumbnail? thumbnail, bool? disableContentTypeDetection}) InputDocument

Available on InputDocument, provided by the InputDocumentExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputDocument?

Constants

constructor → const String