InputFile class sealed
Points to a file
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult generated(InputFileGenerated value), required TResult id(InputFileId value), required TResult local(InputFileLocal value), required TResult remote(InputFileRemote value)}) → TResult -
Available on InputFile, provided by the InputFileExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult generated(InputFileGenerated value)?, TResult id(InputFileId value)?, TResult local(InputFileLocal value)?, TResult remote(InputFileRemote value)?, required TResult orElse()}) → TResult -
Available on InputFile, provided by the InputFileExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputFile? - Inherited by: InputFileGenerated InputFileId InputFileLocal InputFileRemote
Constants
- constructor → const String