InputFileGenerated class final
A file generated by the application. The application must handle updates updateFileGenerationStart and updateFileGenerationStop to generate the file when asked by TDLib
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputFileGenerated({required String originalPath, required String conversion, required int expectedSize})
Properties
- conversion → String
-
conversion String specifying the conversion applied to the original
file; must be persistent across application restarts. Conversions
beginning with '#' are reserved for internal TDLib usage
final
- expectedSize → int
-
expectedSize Expected size of the generated file, in bytes; pass 0 if
unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- originalPath → String
-
originalPath Local path to a file from which the file is generated. The
path doesn't have to be a valid path and is used by TDLib only to detect
name and MIME type of the generated file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? originalPath, String? conversion, int? expectedSize}) → InputFileGenerated -
Available on InputFileGenerated, provided by the InputFileGeneratedExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult generated(InputFileGenerated value), required TResult id(InputFileId value), required TResult local(InputFileLocal value), required TResult remote(InputFileRemote value)}) → TResult -
Available on InputFile, provided by the InputFileExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult generated(InputFileGenerated value)?, TResult id(InputFileId value)?, TResult local(InputFileLocal value)?, TResult remote(InputFileRemote value)?, required TResult orElse()}) → TResult -
Available on InputFile, provided by the InputFileExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputFileGenerated? -
Inherited by:
InputFileGenerated
InputFileId
InputFileLocal
InputFileRemote
override
Constants
- constructor → const String