InputIdentityDocument class final
An identity document to be saved to Telegram Passport
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- expirationDate → Date?
-
expirationDate Document expiration date; pass null if not applicable
final
- frontSide → InputFile?
-
frontSide Front side of the document
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- number → String
-
number Document number; 1-24 characters
final
- reverseSide → InputFile?
-
reverseSide Reverse side of the document; only for driver license and
identity card; pass null otherwise
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfie → InputFile?
-
selfie Selfie with the document; pass null if unavailable
final
-
translation
→ List<
InputFile> -
translation List of files containing a certified English translation of
the document
final
Methods
-
copyWith(
{String? number, Date? expirationDate, InputFile? frontSide, InputFile? reverseSide, InputFile? selfie, List< InputFile> ? translation}) → InputIdentityDocument -
Available on InputIdentityDocument, provided by the InputIdentityDocumentExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputIdentityDocument?
Constants
- constructor → const String