showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation; not supported in secret chats
final bool showCaptionAboveMedia;