InputMessageReplyToExternalMessage class final
Describes a message to be replied that is from a different chat or a forum topic; not supported in secret chats
- Inheritance
-
- Object
- TdObject
- InputMessageReplyTo
- InputMessageReplyToExternalMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputMessageReplyToExternalMessage({required int chatId, required int messageId, InputTextQuote? quote, required int checklistTaskId, required String pollOptionId})
Properties
- chatId → int
-
chatId The identifier of the chat to which the message to be replied
belongs
final
- checklistTaskId → int
-
checklistTaskId Identifier of the checklist task in the message to be
replied; pass 0 to reply to the whole message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId The identifier of the message to be replied in the specified
chat. A message can be replied in another chat or forum topic only if
messageProperties.can_be_replied_in_another_chat
final
- pollOptionId → String
-
pollOptionId Identifier of the poll option in the message to be replied;
pass an empty string if none
final
- quote → InputTextQuote?
-
quote Quote from the message to be replied; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, InputTextQuote? quote, int? checklistTaskId, String? pollOptionId}) → InputMessageReplyToExternalMessage -
Available on InputMessageReplyToExternalMessage, provided by the InputMessageReplyToExternalMessageExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value), required TResult externalMessage(InputMessageReplyToExternalMessage value), required TResult message(InputMessageReplyToMessage value), required TResult story(InputMessageReplyToStory value)}) → TResult -
Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ephemeralMessage(InputMessageReplyToEphemeralMessage value)?, TResult externalMessage(InputMessageReplyToExternalMessage value)?, TResult message(InputMessageReplyToMessage value)?, TResult story(InputMessageReplyToStory value)?, required TResult orElse()}) → TResult -
Available on InputMessageReplyTo, provided by the InputMessageReplyToExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputMessageReplyToExternalMessage? -
Inherited by:
InputMessageReplyToEphemeralMessage
InputMessageReplyToExternalMessage
InputMessageReplyToMessage
InputMessageReplyToStory
override
Constants
- constructor → const String