InputPageBlockListItem class final

Describes an item of a list page block to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPageBlockListItem({required List<InputPageBlock> blocks, required bool hasCheckbox, required bool isChecked, required int value, required String type})

Properties

blocks List<InputPageBlock>
blocks Item blocks
final
hasCheckbox bool
hasCheckbox True, if the item has a checkbox
final
hashCode int
The hash code for this object.
no setteroverride
isChecked bool
isChecked True, if the item is checked
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
type Type of the item numbering type; must be one of "a" for a lowercase letter, "A" for an uppercase letter, "i" for lowercase Roman numerals, "I" for uppercase Roman numerals, "1" for decimal numbers, or empty for unordered lists
final
value int
value Value of the item; pass 0 for unordered lists
final

Methods

copyWith({List<InputPageBlock>? blocks, bool? hasCheckbox, bool? isChecked, int? value, String? type}) InputPageBlockListItem

Available on InputPageBlockListItem, provided by the InputPageBlockListItemExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPageBlockListItem?

Constants

constructor → const String