InputPaidMedia class final

Describes a paid media to be sent

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InputPaidMedia({InputPaidMediaType? type, InputFile? media, InputThumbnail? thumbnail, required List<int> addedStickerFileIds, required int width, required int height})

Properties

addedStickerFileIds List<int>
addedStickerFileIds File identifiers of the stickers added to the media, if applicable
final
hashCode int
The hash code for this object.
no setteroverride
height int
height Media height
final
media InputFile?
media Photo or video to be sent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail InputThumbnail?
thumbnail Media thumbnail; pass null to skip thumbnail uploading
final
type InputPaidMediaType?
type Type of the media
final
width int
width Media width
final

Methods

copyWith({InputPaidMediaType? type, InputFile? media, InputThumbnail? thumbnail, List<int>? addedStickerFileIds, int? width, int? height}) InputPaidMedia

Available on InputPaidMedia, provided by the InputPaidMediaExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) InputPaidMedia?

Constants

constructor → const String