InputPersonalDocument class final
A personal document to be saved to Telegram Passport
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
InputPersonalDocument({required List<
InputFile> files, required List<InputFile> translation})
Properties
-
files
→ List<
InputFile> -
files List of files containing the pages of the document
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translation
→ List<
InputFile> -
translation List of files containing a certified English translation of
the document
final
Methods
-
copyWith(
{List< InputFile> ? files, List<InputFile> ? translation}) → InputPersonalDocument -
Available on InputPersonalDocument, provided by the InputPersonalDocumentExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputPersonalDocument?
Constants
- constructor → const String