InputStoryAreas class final
Contains a list of story areas to be added
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
InputStoryAreas({required List<
InputStoryArea> areas})
Properties
-
areas
→ List<
InputStoryArea> -
areas List of input story areas. Currently, a story can have up to 10
inputStoryAreaTypeLocation, inputStoryAreaTypeFoundVenue, and
inputStoryAreaTypePreviousVenue areas, up to
getOption("story_suggested_reaction_area_count_max")
inputStoryAreaTypeSuggestedReaction areas, up to 1
inputStoryAreaTypeMessage area, up to
getOption("story_link_area_count_max") inputStoryAreaTypeLink areas if the
current user is a Telegram Premium user, up to 3 inputStoryAreaTypeWeather
areas, and up to 1 inputStoryAreaTypeUpgradedGift area
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< InputStoryArea> ? areas}) → InputStoryAreas -
Available on InputStoryAreas, provided by the InputStoryAreasExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputStoryAreas?
Constants
- constructor → const String