InputStoryContentPhoto class final
A photo story
- Inheritance
-
- Object
- TdObject
- InputStoryContent
- InputStoryContentPhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
-
InputStoryContentPhoto({InputFile? photo, required List<
int> addedStickerFileIds})
Properties
-
addedStickerFileIds
→ List<
int> -
addedStickerFileIds File identifiers of the stickers added to the photo,
if applicable
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- photo → InputFile?
-
photo Photo to send. The photo must be at most 10 MB in size. The photo
size must be 1080x1920
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputFile? photo, List< int> ? addedStickerFileIds}) → InputStoryContentPhoto -
Available on InputStoryContentPhoto, provided by the InputStoryContentPhotoExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult photo(InputStoryContentPhoto value), required TResult video(InputStoryContentVideo value)}) → TResult -
Available on InputStoryContent, provided by the InputStoryContentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult photo(InputStoryContentPhoto value)?, TResult video(InputStoryContentVideo value)?, required TResult orElse()}) → TResult -
Available on InputStoryContent, provided by the InputStoryContentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputStoryContentPhoto? -
Inherited by:
InputStoryContentPhoto
InputStoryContentVideo
override
Constants
- constructor → const String