InputSuggestedPostInfo class final
Contains information about a post to suggest
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputSuggestedPostInfo({SuggestedPostPrice? price, required int sendDate})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- price → SuggestedPostPrice?
-
price Price of the suggested post; pass null to suggest a post without
payment. If the current user isn't an administrator of the channel direct
messages chat and doesn't have enough funds to pay for the post, then the
error "BALANCE_TOO_LOW" will be returned immediately
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendDate → int
-
sendDate Point in time (Unix timestamp) when the post is expected to be
published; pass 0 if the date isn't restricted. If specified, then the
date must be
getOption("suggested_post_send_delay_min")-getOption("suggested_post_send_delay_max")
seconds in the future
final
Methods
-
copyWith(
{SuggestedPostPrice? price, int? sendDate}) → InputSuggestedPostInfo -
Available on InputSuggestedPostInfo, provided by the InputSuggestedPostInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputSuggestedPostInfo?
Constants
- constructor → const String