InputTextQuote class final
Describes manually chosen quote from another message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputTextQuote({FormattedText? text, required int position})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- position → int
-
position Quote position in the original message in UTF-16 code units
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Text of the quote; 0-getOption("message_reply_quote_length_max")
characters. Only Bold, Italic, Underline, Strikethrough, Spoiler,
CustomEmoji, and DateTime entities are allowed to be kept and must be kept
in the quote
final
Methods
-
copyWith(
{FormattedText? text, int? position}) → InputTextQuote -
Available on InputTextQuote, provided by the InputTextQuoteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputTextQuote?
Constants
- constructor → const String