InputVideo class final
A video to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
addedStickerFileIds
→ List<
int> -
addedStickerFileIds File identifiers of the stickers added to the video,
if applicable
final
- cover → InputFile?
-
cover Cover of the video; pass null to skip cover uploading; not
supported in secret chats and for self-destructing messages
final
- duration → int
-
duration Duration of the video, in seconds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Video height
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTimestamp → int
-
startTimestamp Timestamp from which the video playing must start, in
seconds
final
- supportsStreaming → bool
-
supportsStreaming True, if the video is expected to be streamed
final
- thumbnail → InputThumbnail?
-
thumbnail Video thumbnail; pass null to skip thumbnail uploading
final
- video → InputFile?
-
video Video file to be sent. The video is expected to be re-encoded to
MPEG4 format with H.264 codec by the sender
final
- width → int
-
width Video width
final
Methods
-
copyWith(
{InputFile? video, InputThumbnail? thumbnail, InputFile? cover, int? startTimestamp, List< int> ? addedStickerFileIds, int? duration, int? width, int? height, bool? supportsStreaming}) → InputVideo -
Available on InputVideo, provided by the InputVideoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputVideo?
Constants
- constructor → const String