InputVideoNote class final
A video note to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputVideoNote({InputFile? videoNote, InputThumbnail? thumbnail, required int duration, required int length})
Properties
- duration → int
-
duration Duration of the video, in seconds; 0-60
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- length → int
-
length Video width and height; must be positive and not greater than 640
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → InputThumbnail?
-
thumbnail Video thumbnail; may be null if empty; pass null to skip
thumbnail uploading
final
- videoNote → InputFile?
-
videoNote Video note file to be sent. The video is expected to be
encoded to MPEG4 format with H.264 codec and have no data outside of the
visible circle
final
Methods
-
copyWith(
{InputFile? videoNote, InputThumbnail? thumbnail, int? duration, int? length}) → InputVideoNote -
Available on InputVideoNote, provided by the InputVideoNoteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputVideoNote?
Constants
- constructor → const String