InputVoiceNote class final
A video note to be sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- InputVoiceNote({InputFile? voiceNote, required int duration, required String waveform})
Properties
- duration → int
-
duration Duration of the voice note, in seconds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voiceNote → InputFile?
-
voiceNote Voice note file to be sent. The voice note must be encoded
with the Opus codec and stored inside an OGG container with a single audio
channel, or be in MP3 or M4A format as regular audio
final
- waveform → String
-
waveform Waveform representation of the voice note in 5-bit format
final
Methods
-
copyWith(
{InputFile? voiceNote, int? duration, String? waveform}) → InputVoiceNote -
Available on InputVoiceNote, provided by the InputVoiceNoteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → InputVoiceNote?
Constants
- constructor → const String