InviteGroupCallParticipantResultSuccess class final
The user was invited and a service message of the type messageGroupCall was sent which can be used in declineGroupCallInvitation to cancel the invitation
- Inheritance
-
- Object
- TdObject
- InviteGroupCallParticipantResult
- InviteGroupCallParticipantResultSuccess
- Available extensions
- Annotations
-
- @immutable
Constructors
- InviteGroupCallParticipantResultSuccess({required int chatId, required int messageId})
Properties
Methods
-
copyWith(
{int? chatId, int? messageId}) → InviteGroupCallParticipantResultSuccess -
Available on InviteGroupCallParticipantResultSuccess, provided by the InviteGroupCallParticipantResultSuccessExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult success(InviteGroupCallParticipantResultSuccess value), required TResult userAlreadyParticipant(InviteGroupCallParticipantResultUserAlreadyParticipant value), required TResult userPrivacyRestricted(InviteGroupCallParticipantResultUserPrivacyRestricted value), required TResult userWasBanned(InviteGroupCallParticipantResultUserWasBanned value)}) → TResult -
Available on InviteGroupCallParticipantResult, provided by the InviteGroupCallParticipantResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult success(InviteGroupCallParticipantResultSuccess value)?, TResult userAlreadyParticipant(InviteGroupCallParticipantResultUserAlreadyParticipant value)?, TResult userPrivacyRestricted(InviteGroupCallParticipantResultUserPrivacyRestricted value)?, TResult userWasBanned(InviteGroupCallParticipantResultUserWasBanned value)?, required TResult orElse()}) → TResult -
Available on InviteGroupCallParticipantResult, provided by the InviteGroupCallParticipantResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String