InviteVideoChatParticipants class final

Invites users to an active video chat. Sends a service message of the type messageInviteVideoChatParticipants to the chat bound to the group call Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

InviteVideoChatParticipants({required int groupCallId, required List<int> userIds})

Properties

groupCallId int
groupCallId Group call identifier
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userIds List<int>
userIds User identifiers. At most 10 users can be invited simultaneously
final

Methods

copyWith({int? groupCallId, List<int>? userIds}) InviteVideoChatParticipants

Available on InviteVideoChatParticipants, provided by the InviteVideoChatParticipantsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String