Invoice class final
Product invoice
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Invoice({required String currency, required List<
LabeledPricePart> priceParts, required int subscriptionPeriod, required int maxTipAmount, required List<int> suggestedTipAmounts, required String recurringPaymentTermsOfServiceUrl, required String termsOfServiceUrl, required bool isTest, required bool needName, required bool needPhoneNumber, required bool needEmailAddress, required bool needShippingAddress, required bool sendPhoneNumberToProvider, required bool sendEmailAddressToProvider, required bool isFlexible})
Properties
- currency → String
-
currency ISO 4217 currency code
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFlexible → bool
-
isFlexible True, if the total price depends on the shipping method
final
- isTest → bool
-
isTest True, if the payment is a test payment
final
- maxTipAmount → int
-
maxTipAmount The maximum allowed amount of tip in the smallest units of
the currency
final
- needEmailAddress → bool
-
needEmailAddress True, if the user's email address is needed for payment
final
- needName → bool
-
needName True, if the user's name is needed for payment
final
- needPhoneNumber → bool
-
needPhoneNumber True, if the user's phone number is needed for payment
final
- needShippingAddress → bool
-
needShippingAddress True, if the user's shipping address is needed for
payment
final
-
priceParts
→ List<
LabeledPricePart> -
priceParts A list of objects used to calculate the total price of the
product
final
- recurringPaymentTermsOfServiceUrl → String
-
recurringPaymentTermsOfServiceUrl An HTTP URL with terms of service for
recurring payments. If non-empty, the invoice payment will result in
recurring payments and the user must accept the terms of service before
allowed to pay
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendEmailAddressToProvider → bool
-
sendEmailAddressToProvider True, if the user's email address will be
sent to the provider
final
- sendPhoneNumberToProvider → bool
-
sendPhoneNumberToProvider True, if the user's phone number will be sent
to the provider
final
- subscriptionPeriod → int
-
subscriptionPeriod The number of seconds between consecutive Telegram
Star debiting for subscription invoices; 0 if the invoice doesn't create
subscription
final
-
suggestedTipAmounts
→ List<
int> -
suggestedTipAmounts Suggested amounts of tip in the smallest units of
the currency
final
- termsOfServiceUrl → String
-
termsOfServiceUrl An HTTP URL with terms of service for non-recurring
payments. If non-empty, then the user must accept the terms of service
before allowed to pay
final
Methods
-
copyWith(
{String? currency, List< LabeledPricePart> ? priceParts, int? subscriptionPeriod, int? maxTipAmount, List<int> ? suggestedTipAmounts, String? recurringPaymentTermsOfServiceUrl, String? termsOfServiceUrl, bool? isTest, bool? needName, bool? needPhoneNumber, bool? needEmailAddress, bool? needShippingAddress, bool? sendPhoneNumberToProvider, bool? sendEmailAddressToProvider, bool? isFlexible}) → Invoice -
Available on Invoice, provided by the InvoiceExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String