JoinGroupCall class final

Joins a regular group call that is not bound to a chat Returns GroupCallInfo

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

JoinGroupCall({InputGroupCall? inputGroupCall, GroupCallJoinParameters? joinParameters})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputGroupCall InputGroupCall?
inputGroupCall The group call to join
final
joinParameters GroupCallJoinParameters?
joinParameters Parameters to join the call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({InputGroupCall? inputGroupCall, GroupCallJoinParameters? joinParameters}) JoinGroupCall

Available on JoinGroupCall, provided by the JoinGroupCallExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String