JoinLiveStory class final
Joins a group call of an active live story. Returns join response payload for tgcalls Returns Text
- Inheritance
-
- Object
- TdFunction
- JoinLiveStory
- Available extensions
- Annotations
-
- @immutable
Constructors
- JoinLiveStory({required int groupCallId, GroupCallJoinParameters? joinParameters})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- joinParameters → GroupCallJoinParameters?
-
joinParameters Parameters to join the call
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, GroupCallJoinParameters? joinParameters}) → JoinLiveStory -
Available on JoinLiveStory, provided by the JoinLiveStoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String