JoinVideoChat class final
Joins an active video chat. Returns join response payload for tgcalls Returns Text
- Inheritance
-
- Object
- TdFunction
- JoinVideoChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- JoinVideoChat({required int groupCallId, MessageSender? participantId, GroupCallJoinParameters? joinParameters, required String inviteHash})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inviteHash → String
-
inviteHash Invite hash as received from internalLinkTypeVideoChat
final
- joinParameters → GroupCallJoinParameters?
-
joinParameters Parameters to join the call
final
- participantId → MessageSender?
-
participantId Identifier of a group call participant, which will be used
to join the call; pass null to join as self
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, MessageSender? participantId, GroupCallJoinParameters? joinParameters, String? inviteHash}) → JoinVideoChat -
Available on JoinVideoChat, provided by the JoinVideoChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String