KeyboardButtonSourceWebApp class final
The button is a prepared keyboard button from a Mini App received via getPreparedKeyboardButton
- Inheritance
-
- Object
- TdObject
- KeyboardButtonSource
- KeyboardButtonSourceWebApp
- Available extensions
- Annotations
-
- @immutable
Constructors
- KeyboardButtonSourceWebApp({required int botUserId, required String preparedButtonId})
Properties
- botUserId → int
-
botUserId Identifier of the bot that created the button
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- preparedButtonId → String
-
preparedButtonId Identifier of the prepared button
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? preparedButtonId}) → KeyboardButtonSourceWebApp -
Available on KeyboardButtonSourceWebApp, provided by the KeyboardButtonSourceWebAppExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult message(KeyboardButtonSourceMessage value), required TResult webApp(KeyboardButtonSourceWebApp value)}) → TResult -
Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult message(KeyboardButtonSourceMessage value)?, TResult webApp(KeyboardButtonSourceWebApp value)?, required TResult orElse()}) → TResult -
Available on KeyboardButtonSource, provided by the KeyboardButtonSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → KeyboardButtonSourceWebApp? -
Inherited by:
KeyboardButtonSourceMessage
KeyboardButtonSourceWebApp
override
Constants
- constructor → const String