LaunchPrepaidGiveaway class final
Launches a prepaid giveaway Returns Ok
- Inheritance
-
- Object
- TdFunction
- LaunchPrepaidGiveaway
- Available extensions
- Annotations
-
- @immutable
Constructors
- LaunchPrepaidGiveaway({required int giveawayId, GiveawayParameters? parameters, required int winnerCount, required int starCount})
Properties
- giveawayId → int
-
giveawayId Unique identifier of the prepaid giveaway
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- parameters → GiveawayParameters?
-
parameters Giveaway parameters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount The number of Telegram Stars to be distributed through the
giveaway; pass 0 for Telegram Premium giveaways
final
- winnerCount → int
-
winnerCount The number of users to receive giveaway prize
final
Methods
-
copyWith(
{int? giveawayId, GiveawayParameters? parameters, int? winnerCount, int? starCount}) → LaunchPrepaidGiveaway -
Available on LaunchPrepaidGiveaway, provided by the LaunchPrepaidGiveawayExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String