showAboveText property
showAboveText True, if the link preview must be shown above message text; otherwise, the link preview must be shown below the message text
Implementation
final bool showAboveText;
showAboveText True, if the link preview must be shown above message text; otherwise, the link preview must be shown below the message text
final bool showAboveText;