ListenToAudio class final

Informs TDLib that an audio was listened by the user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ListenToAudio({required int audioFileId, required int duration})

Properties

audioFileId int
audioFileId Identifier of the file with an audio
final
duration int
duration Duration of the listening to the audio, in seconds
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? audioFileId, int? duration}) ListenToAudio

Available on ListenToAudio, provided by the ListenToAudioExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String