LiveStoryDonors class final
Contains a list of users and chats that spend most money on paid messages and reactions in a live story
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
LiveStoryDonors({required int totalStarCount, required List<
PaidReactor> topDonors})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topDonors
→ List<
PaidReactor> -
topDonors List of top donors in the live story
final
- totalStarCount → int
-
totalStarCount Total amount of spend Telegram Stars
final
Methods
-
copyWith(
{int? totalStarCount, List< PaidReactor> ? topDonors}) → LiveStoryDonors -
Available on LiveStoryDonors, provided by the LiveStoryDonorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LiveStoryDonors?
Constants
- constructor → const String