LoginUrlInfoOpen class final
An HTTP URL needs to be open
- Inheritance
-
- Object
- TdObject
- LoginUrlInfo
- LoginUrlInfoOpen
- Available extensions
- Annotations
-
- @immutable
Constructors
- LoginUrlInfoOpen({required String url, required bool skipConfirmation})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipConfirmation → bool
-
skipConfirmation True, if there is no need to show an ordinary open URL
confirmation
final
- url → String
-
url The URL to open
final
Methods
-
copyWith(
{String? url, bool? skipConfirmation}) → LoginUrlInfoOpen -
Available on LoginUrlInfoOpen, provided by the LoginUrlInfoOpenExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult open(LoginUrlInfoOpen value), required TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)}) → TResult -
Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult open(LoginUrlInfoOpen value)?, TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)?, required TResult orElse()}) → TResult -
Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LoginUrlInfoOpen? -
Inherited by:
LoginUrlInfoOpen
LoginUrlInfoRequestConfirmation
override
Constants
- constructor → const String