LoginUrlInfoRequestConfirmation class final
An authorization confirmation dialog needs to be shown to the user
- Inheritance
-
- Object
- TdObject
- LoginUrlInfo
- LoginUrlInfoRequestConfirmation
- Available extensions
- Annotations
-
- @immutable
Constructors
- LoginUrlInfoRequestConfirmation({required String url, required String domain, required int botUserId, required bool requestWriteAccess})
Properties
- botUserId → int
-
botUserId User identifier of a bot linked with the website
final
- domain → String
-
domain A domain of the URL
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- requestWriteAccess → bool
-
requestWriteAccess True, if the user must be asked for the permission to
the bot to send them messages
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url An HTTP URL to be opened
final
Methods
-
copyWith(
{String? url, String? domain, int? botUserId, bool? requestWriteAccess}) → LoginUrlInfoRequestConfirmation -
Available on LoginUrlInfoRequestConfirmation, provided by the LoginUrlInfoRequestConfirmationExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult open(LoginUrlInfoOpen value), required TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)}) → TResult -
Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult open(LoginUrlInfoOpen value)?, TResult requestConfirmation(LoginUrlInfoRequestConfirmation value)?, required TResult orElse()}) → TResult -
Available on LoginUrlInfo, provided by the LoginUrlInfoExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → LoginUrlInfoRequestConfirmation? -
Inherited by:
LoginUrlInfoOpen
LoginUrlInfoRequestConfirmation
override
Constants
- constructor → const String