MaskPosition class final
Position on a photo where a mask is placed
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- MaskPosition({MaskPoint? point, required double xShift, required double yShift, required double scale})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- point → MaskPoint?
-
point Part of the face, relative to which the mask is placed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double
-
scale Mask scaling coefficient. (For example, 2.0 means a doubled size)
final
- xShift → double
-
xShift Shift by X-axis measured in widths of the mask scaled to the face
size, from left to right. (For example, -1.0 will place the mask just to
the left of the default mask position)
final
- yShift → double
-
yShift Shift by Y-axis measured in heights of the mask scaled to the
face size, from top to bottom. (For example, 1.0 will place the mask just
below the default mask position)
final
Methods
-
copyWith(
{MaskPoint? point, double? xShift, double? yShift, double? scale}) → MaskPosition -
Available on MaskPosition, provided by the MaskPositionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MaskPosition?
Constants
- constructor → const String