guestBotCallerId property
guestBotCallerId The identifier of the user or chat which used a guest bot to send the message; may be null if none
Implementation
final MessageSender? guestBotCallerId;
guestBotCallerId The identifier of the user or chat which used a guest bot to send the message; may be null if none
final MessageSender? guestBotCallerId;