topicId property
topicId Identifier of the topic within the chat to which the message belongs; may be null if none; may change when the chat is converted to a forum or back
Implementation
final MessageTopic? topicId;
topicId Identifier of the topic within the chat to which the message belongs; may be null if none; may change when the chat is converted to a forum or back
final MessageTopic? topicId;