showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the animation; otherwise, the caption must be shown below the animation
final bool showCaptionAboveMedia;