requestMessageId property
requestMessageId Identifier of the message with the request to change the setting; can be an identifier of a deleted message or 0
Implementation
final int requestMessageId;
requestMessageId Identifier of the message with the request to change the setting; can be an identifier of a deleted message or 0
final int requestMessageId;