MessageCopyOptions class final
Options to be used when a message content is copied without reference to the original sender. Service messages, messages with messageInvoice, messagePaidMedia, messageGiveaway, or messageGiveawayWinners content can't be copied
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageCopyOptions({required bool sendCopy, required bool replaceCaption, FormattedText? newCaption, required bool newShowCaptionAboveMedia})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- newCaption → FormattedText?
-
newCaption New message caption; pass null to copy message without
caption. Ignored if replace_caption is false
final
- newShowCaptionAboveMedia → bool
-
newShowCaptionAboveMedia True, if new caption must be shown above the
media; otherwise, new caption must be shown below the media; not supported
in secret chats. Ignored if replace_caption is false
final
- replaceCaption → bool
-
replaceCaption True, if media caption of the message copy needs to be
replaced. Ignored if send_copy is false
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendCopy → bool
-
sendCopy True, if content of the message needs to be copied without
reference to the original sender. Always true if the message is forwarded
to a secret chat or is local. Use messageProperties.can_be_copied and
messageProperties.can_be_copied_to_secret_chat to check whether the
message is suitable
final
Methods
-
copyWith(
{bool? sendCopy, bool? replaceCaption, FormattedText? newCaption, bool? newShowCaptionAboveMedia}) → MessageCopyOptions -
Available on MessageCopyOptions, provided by the MessageCopyOptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageCopyOptions?
Constants
- constructor → const String