MessageForwardInfo class final
Contains information about a forwarded message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageForwardInfo({MessageOrigin? origin, required int date, ForwardSource? source, required String publicServiceAnnouncementType})
Properties
- date → int
-
date Point in time (Unix timestamp) when the message was originally sent
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- origin → MessageOrigin?
-
origin Origin of the forwarded message
final
- publicServiceAnnouncementType → String
-
publicServiceAnnouncementType The type of public service announcement
for the forwarded message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ForwardSource?
-
source For messages forwarded to the chat with the current user (Saved
Messages), to the Replies bot chat, or to the channel's discussion group,
information about the source message from which the message was forwarded
last time; may be null for other forwards or if unknown
final
Methods
-
copyWith(
{MessageOrigin? origin, int? date, ForwardSource? source, String? publicServiceAnnouncementType}) → MessageForwardInfo -
Available on MessageForwardInfo, provided by the MessageForwardInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageForwardInfo?
Constants
- constructor → const String