MessageLinkInfo class final

Contains information about a link to a message or a forum topic in a chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageLinkInfo({required bool isPublic, required int chatId, MessageTopic? topicId, Message? message, required int mediaTimestamp, required int checklistTaskId, required String pollOptionId, required bool forAlbum})

Properties

chatId int
chatId If found, identifier of the chat to which the link points, 0 otherwise
final
checklistTaskId int
checklistTaskId Identifier of the checklist task that is linked; 0 if none
final
forAlbum bool
forAlbum True, if the whole media album to which the message belongs is linked
final
hashCode int
The hash code for this object.
no setteroverride
isPublic bool
isPublic True, if the link is a public link for a message or a forum topic in a chat
final
mediaTimestamp int
mediaTimestamp Timestamp from which the video/audio/video note/voice note/story playing must start, in seconds; 0 if not specified. The media can be in the message content or in its link preview
final
message Message?
message If found, the linked message; may be null
final
pollOptionId String
pollOptionId Identifier of the poll option that is linked; empty if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topicId MessageTopic?
topicId Identifier of the specific topic in which the message must be opened, or a topic to open if the message is missing; may be null if none
final

Methods

copyWith({bool? isPublic, int? chatId, MessageTopic? topicId, Message? message, int? mediaTimestamp, int? checklistTaskId, String? pollOptionId, bool? forAlbum}) MessageLinkInfo

Available on MessageLinkInfo, provided by the MessageLinkInfoExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageLinkInfo?

Constants

constructor → const String