paidMessageStarCount property
paidMessageStarCount The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message
Implementation
final int paidMessageStarCount;
paidMessageStarCount The new number of Telegram Stars that must be paid by non-administrator users of the supergroup chat for each sent message
final int paidMessageStarCount;