showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the photo; otherwise, the caption must be shown below the photo
final bool showCaptionAboveMedia;