canBeApproved property
canBeApproved True, if the message is a suggested post that can be approved by the user using approveSuggestedPost
Implementation
final bool canBeApproved;
canBeApproved True, if the message is a suggested post that can be approved by the user using approveSuggestedPost
final bool canBeApproved;