canBeDeclined property
canBeDeclined True, if the message is a suggested post that can be declined by the user using declineSuggestedPost
Implementation
final bool canBeDeclined;
canBeDeclined True, if the message is a suggested post that can be declined by the user using declineSuggestedPost
final bool canBeDeclined;