canBeDeletedOnlyForSelf property
canBeDeletedOnlyForSelf True, if the message can be deleted only for the current user while other users will continue to see it using the method deleteMessages with revoke == false
Implementation
final bool canBeDeletedOnlyForSelf;