canGetStatistics property
canGetStatistics True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards
Implementation
final bool canGetStatistics;
canGetStatistics True, if message statistics are available through getMessageStatistics and message forwards can be received using getMessagePublicForwards
final bool canGetStatistics;