MessageReactions class final
Contains a list of reactions added to a message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
MessageReactions({required List<
MessageReaction> reactions, required bool areTags, required List<PaidReactor> paidReactors, required bool canGetAddedReactions})
Properties
- areTags → bool
-
areTags True, if the reactions are tags and Telegram Premium users can
filter messages by them
final
- canGetAddedReactions → bool
-
canGetAddedReactions True, if the list of added reactions is available
using getMessageAddedReactions
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
paidReactors
→ List<
PaidReactor> -
paidReactors Information about top users that added the paid reaction
final
-
reactions
→ List<
MessageReaction> -
reactions List of added reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< MessageReaction> ? reactions, bool? areTags, List<PaidReactor> ? paidReactors, bool? canGetAddedReactions}) → MessageReactions -
Available on MessageReactions, provided by the MessageReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageReactions?
Constants
- constructor → const String