MessageReplyInfo class final
Contains information about replies to a message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
MessageReplyInfo({required int replyCount, required List<
MessageSender> recentReplierIds, required int lastReadInboxMessageId, required int lastReadOutboxMessageId, required int lastMessageId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastMessageId → int
-
lastMessageId Identifier of the last reply to the message
final
- lastReadInboxMessageId → int
-
lastReadInboxMessageId Identifier of the last read incoming reply to the
message
final
- lastReadOutboxMessageId → int
-
lastReadOutboxMessageId Identifier of the last read outgoing reply to
the message
final
-
recentReplierIds
→ List<
MessageSender> -
recentReplierIds Identifiers of at most 3 recent repliers to the
message; available in channels with a discussion supergroup. The users and
chats are expected to be inaccessible: only their photo and name will be
available
final
- replyCount → int
-
replyCount Number of times the message was directly or indirectly
replied
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? replyCount, List< MessageSender> ? recentReplierIds, int? lastReadInboxMessageId, int? lastReadOutboxMessageId, int? lastMessageId}) → MessageReplyInfo -
Available on MessageReplyInfo, provided by the MessageReplyInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageReplyInfo?
Constants
- constructor → const String