MessageReplyToMessage class final
Describes a message replied by a given message
- Inheritance
-
- Object
- TdObject
- MessageReplyTo
- MessageReplyToMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageReplyToMessage({required int chatId, required int messageId, TextQuote? quote, required int checklistTaskId, required String pollOptionId, MessageOrigin? origin, required int originSendDate, MessageContent? content})
Properties
- chatId → int
-
chatId The identifier of the chat to which the message belongs; may be 0
if the replied message is in unknown chat
final
- checklistTaskId → int
-
checklistTaskId Identifier of the checklist task in the original message
that was replied; 0 if none
final
- content → MessageContent?
-
content Media content of the message if the message was from another
chat or topic; may be null for messages from the same chat and messages
without media. Can be only one of the following types: messageAnimation,
messageAudio, messageChecklist, messageContact, messageDice,
messageDocument, messageGame, messageGiveaway, messageGiveawayWinners,
messageInvoice, messageLocation, messagePaidMedia, messagePhoto,
messagePoll, messageStakeDice, messageSticker, messageStory, messageText
(for link preview), messageVenue, messageVideo, messageVideoNote, or
messageVoiceNote
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId The identifier of the message; may be 0 if the replied message
is in unknown chat
final
- origin → MessageOrigin?
-
origin Information about origin of the message if the message was from
another chat or topic; may be null for messages from the same chat
final
- originSendDate → int
-
originSendDate Point in time (Unix timestamp) when the message was sent
if the message was from another chat or topic; 0 for messages from the
same chat
final
- pollOptionId → String
-
pollOptionId Identifier of the poll option in the original message that
was replied; empty if none
final
- quote → TextQuote?
-
quote Chosen quote from the replied message; may be null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, TextQuote? quote, int? checklistTaskId, String? pollOptionId, MessageOrigin? origin, int? originSendDate, MessageContent? content}) → MessageReplyToMessage -
Available on MessageReplyToMessage, provided by the MessageReplyToMessageExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult message(MessageReplyToMessage value), required TResult story(MessageReplyToStory value)}) → TResult -
Available on MessageReplyTo, provided by the MessageReplyToExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult message(MessageReplyToMessage value)?, TResult story(MessageReplyToStory value)?, required TResult orElse()}) → TResult -
Available on MessageReplyTo, provided by the MessageReplyToExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageReplyToMessage? -
Inherited by:
MessageReplyToMessage
MessageReplyToStory
override
Constants
- constructor → const String