MessageSchedulingStateSendWhenOnline class final

The message will be sent when the other user is online. Applicable to private chats only and when the exact online status of the other user is known

Inheritance
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult sendAtDate(MessageSchedulingStateSendAtDate value), required TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value), required TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)}) → TResult

Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension

maybeMap<TResult extends Object?>({TResult sendAtDate(MessageSchedulingStateSendAtDate value)?, TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value)?, TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)?, required TResult orElse()}) → TResult

Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String