MessageSchedulingStateSendWhenVideoProcessed class final
The message will be sent when the video in the message is converted and optimized; can be used only by the server
- Inheritance
-
- Object
- TdObject
- MessageSchedulingState
- MessageSchedulingStateSendWhenVideoProcessed
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageSchedulingStateSendWhenVideoProcessed({required int sendDate})
Properties
Methods
-
copyWith(
{int? sendDate}) → MessageSchedulingStateSendWhenVideoProcessed -
Available on MessageSchedulingStateSendWhenVideoProcessed, provided by the MessageSchedulingStateSendWhenVideoProcessedExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult sendAtDate(MessageSchedulingStateSendAtDate value), required TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value), required TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)}) → TResult -
Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult sendAtDate(MessageSchedulingStateSendAtDate value)?, TResult sendWhenOnline(MessageSchedulingStateSendWhenOnline value)?, TResult sendWhenVideoProcessed(MessageSchedulingStateSendWhenVideoProcessed value)?, required TResult orElse()}) → TResult -
Available on MessageSchedulingState, provided by the MessageSchedulingStateExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageSchedulingStateSendWhenVideoProcessed? -
Inherited by:
MessageSchedulingStateSendAtDate
MessageSchedulingStateSendWhenOnline
MessageSchedulingStateSendWhenVideoProcessed
override
Constants
- constructor → const String