MessageSendOptions class final
Options to be used when a message is sent
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- MessageSendOptions({InputSuggestedPostInfo? suggestedPostInfo, required bool disableNotification, required bool fromBackground, bool? protectContent, bool? allowPaidBroadcast, required int paidMessageStarCount, required bool updateOrderOfInstalledStickerSets, MessageSchedulingState? schedulingState, required int effectId, required int sendingId, required bool onlyPreview})
Properties
- allowPaidBroadcast → bool?
-
allowPaidBroadcast Pass true to allow the message to ignore regular
broadcast limits for a small fee; for bots only
final
- disableNotification → bool
-
disableNotification Pass true to disable notification for the message
final
- effectId → int
-
effectId Identifier of the effect to apply to the message; pass 0 if
none; applicable only to sendMessage, sendMessageAlbum in private chats
and forwardMessages with one message to private chats
final
- fromBackground → bool
-
fromBackground Pass true if the message is sent from the background
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- onlyPreview → bool
-
onlyPreview Pass true to get a fake message instead of actually sending
them
final
- paidMessageStarCount → int
-
paidMessageStarCount The number of Telegram Stars the user agreed to pay
to send the messages
final
- protectContent → bool?
-
protectContent Pass true if the content of the message must be protected
from forwarding and saving; for bots only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedulingState → MessageSchedulingState?
-
schedulingState Message scheduling state; pass null to send message
immediately. Messages sent to a secret chat, to a chat with paid messages,
to a channel direct messages chat, live location messages and
self-destructing messages can't be scheduled
final
- sendingId → int
-
sendingId Non-persistent identifier, which will be returned back in
messageSendingStatePending object and can be used to match sent messages
and corresponding updateNewMessage updates
final
- suggestedPostInfo → InputSuggestedPostInfo?
-
suggestedPostInfo Information about the suggested post; pass null if
none. For messages to channel direct messages chat only. Applicable only
to sendMessage and addOffer
final
- updateOrderOfInstalledStickerSets → bool
-
updateOrderOfInstalledStickerSets Pass true if the user explicitly
chosen a sticker or a custom emoji from an installed sticker set;
applicable only to sendMessage and sendMessageAlbum
final
Methods
-
copyWith(
{InputSuggestedPostInfo? suggestedPostInfo, bool? disableNotification, bool? fromBackground, bool? protectContent, bool? allowPaidBroadcast, int? paidMessageStarCount, bool? updateOrderOfInstalledStickerSets, MessageSchedulingState? schedulingState, int? effectId, int? sendingId, bool? onlyPreview}) → MessageSendOptions -
Available on MessageSendOptions, provided by the MessageSendOptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageSendOptions?
Constants
- constructor → const String