needAnotherReplyQuote property
needAnotherReplyQuote True, if the message can be re-sent only if another quote is chosen in the message that is replied by the given message
Implementation
final bool needAnotherReplyQuote;
needAnotherReplyQuote True, if the message can be re-sent only if another quote is chosen in the message that is replied by the given message
final bool needAnotherReplyQuote;