MessageSource class sealed
Describes source of a message
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult chatEventLog(MessageSourceChatEventLog value), required TResult chatHistory(MessageSourceChatHistory value), required TResult chatList(MessageSourceChatList value), required TResult directMessagesChatTopicHistory(MessageSourceDirectMessagesChatTopicHistory value), required TResult forumTopicHistory(MessageSourceForumTopicHistory value), required TResult historyPreview(MessageSourceHistoryPreview value), required TResult messageThreadHistory(MessageSourceMessageThreadHistory value), required TResult notification(MessageSourceNotification value), required TResult other(MessageSourceOther value), required TResult screenshot(MessageSourceScreenshot value), required TResult search(MessageSourceSearch value)}) → TResult -
Available on MessageSource, provided by the MessageSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult chatEventLog(MessageSourceChatEventLog value)?, TResult chatHistory(MessageSourceChatHistory value)?, TResult chatList(MessageSourceChatList value)?, TResult directMessagesChatTopicHistory(MessageSourceDirectMessagesChatTopicHistory value)?, TResult forumTopicHistory(MessageSourceForumTopicHistory value)?, TResult historyPreview(MessageSourceHistoryPreview value)?, TResult messageThreadHistory(MessageSourceMessageThreadHistory value)?, TResult notification(MessageSourceNotification value)?, TResult other(MessageSourceOther value)?, TResult screenshot(MessageSourceScreenshot value)?, TResult search(MessageSourceSearch value)?, required TResult orElse()}) → TResult -
Available on MessageSource, provided by the MessageSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageSource? - Inherited by: MessageSourceChatEventLog MessageSourceChatHistory MessageSourceChatList MessageSourceDirectMessagesChatTopicHistory MessageSourceForumTopicHistory MessageSourceHistoryPreview MessageSourceMessageThreadHistory MessageSourceNotification MessageSourceOther MessageSourceScreenshot MessageSourceSearch
Constants
- constructor → const String