MessageStatistics class final

A detailed statistics about a message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

MessageStatistics({StatisticalGraph? messageInteractionGraph, StatisticalGraph? messageReactionGraph})

Properties

hashCode int
The hash code for this object.
no setteroverride
messageInteractionGraph StatisticalGraph?
messageInteractionGraph A graph containing number of message views and shares
final
messageReactionGraph StatisticalGraph?
messageReactionGraph A graph containing number of message reactions
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({StatisticalGraph? messageInteractionGraph, StatisticalGraph? messageReactionGraph}) MessageStatistics

Available on MessageStatistics, provided by the MessageStatisticsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) MessageStatistics?

Constants

constructor → const String