MessageThreadInfo class final
Contains information about a message thread
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
MessageThreadInfo({required int chatId, required int messageThreadId, MessageReplyInfo? replyInfo, required int unreadMessageCount, required List<
Message> messages, DraftMessage? draftMessage})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message thread belongs
final
- draftMessage → DraftMessage?
-
draftMessage A draft of a message in the message thread; may be null if
none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messages
→ List<
Message> -
messages The messages from which the thread starts. The messages are
returned in reverse chronological order (i.e., in order of decreasing
message_id)
final
- messageThreadId → int
-
messageThreadId Message thread identifier, unique within the chat
final
- replyInfo → MessageReplyInfo?
-
replyInfo Information about the message thread; may be null for forum
topic threads
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unreadMessageCount → int
-
unreadMessageCount Approximate number of unread messages in the message
thread
final
Methods
-
copyWith(
{int? chatId, int? messageThreadId, MessageReplyInfo? replyInfo, int? unreadMessageCount, List< Message> ? messages, DraftMessage? draftMessage}) → MessageThreadInfo -
Available on MessageThreadInfo, provided by the MessageThreadInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → MessageThreadInfo?
Constants
- constructor → const String