showCaptionAboveMedia property
showCaptionAboveMedia True, if the caption must be shown above the video; otherwise, the caption must be shown below the video
Implementation
final bool showCaptionAboveMedia;
showCaptionAboveMedia True, if the caption must be shown above the video; otherwise, the caption must be shown below the video
final bool showCaptionAboveMedia;