Messages class final
Contains a list of messages
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
messages
→ List<
Message> ? -
messages List of messages; messages may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Approximate total number of messages found
final
Methods
-
copyWith(
{int? totalCount, List< Message> ? messages}) → Messages -
Available on Messages, provided by the MessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String