NetworkStatistics class final
A full list of available network statistic entries
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
NetworkStatistics({required int sinceDate, required List<
NetworkStatisticsEntry> entries})
Properties
-
entries
→ List<
NetworkStatisticsEntry> -
entries Network statistics entries
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sinceDate → int
-
sinceDate Point in time (Unix timestamp) from which the statistics are
collected
final
Methods
-
copyWith(
{int? sinceDate, List< NetworkStatisticsEntry> ? entries}) → NetworkStatistics -
Available on NetworkStatistics, provided by the NetworkStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → NetworkStatistics?
Constants
- constructor → const String