NotificationSound class final
Describes a notification sound in MP3 format
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- data → String
-
data Arbitrary data, defined while the sound was uploaded
final
- date → int
-
date Point in time (Unix timestamp) when the sound was created
final
- duration → int
-
duration Duration of the sound, in seconds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique identifier of the notification sound
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound → File?
-
sound File containing the sound
final
- title → String
-
title Title of the notification sound
final
Methods
-
copyWith(
{int? id, int? duration, int? date, String? title, String? data, File? sound}) → NotificationSound -
Available on NotificationSound, provided by the NotificationSoundExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → NotificationSound?
Constants
- constructor → const String