OpenChat class final
Informs TDLib that the chat is opened by the user. Many useful activities depend on the chat being opened or closed (e.g., in supergroups and channels all updates are received only for opened chats) Returns Ok
- Inheritance
-
- Object
- TdFunction
- OpenChat
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{int? chatId}) → OpenChat -
Available on OpenChat, provided by the OpenChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String