OpenChatSimilarChat class final
Informs TDLib that a chat was opened from the list of similar chats. The method is independent of openChat and closeChat methods Returns Ok
- Inheritance
-
- Object
- TdFunction
- OpenChatSimilarChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- OpenChatSimilarChat({required int chatId, required int openedChatId})
Properties
- chatId → int
-
chatId Identifier of the original chat, which similar chats were
requested
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- openedChatId → int
-
openedChatId Identifier of the opened chat
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? openedChatId}) → OpenChatSimilarChat -
Available on OpenChatSimilarChat, provided by the OpenChatSimilarChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String