OpenStory class final
Informs TDLib that a story is opened and is being viewed by the user Returns Ok
- Inheritance
-
- Object
- TdFunction
- OpenStory
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId The identifier of the story
final
- storyPosterChatId → int
-
storyPosterChatId The identifier of the chat that posted the opened
story
final
Methods
-
copyWith(
{int? storyPosterChatId, int? storyId}) → OpenStory -
Available on OpenStory, provided by the OpenStoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String