OpenWebApp class final
Informs TDLib that a Web App is being opened from the attachment menu, a botMenuButton button, an internalLinkTypeAttachmentMenuBot link, or an inlineKeyboardButtonTypeWebApp button. For each bot, a confirmation alert about data sent to the bot must be shown once Returns WebAppInfo
- Inheritance
-
- Object
- TdFunction
- OpenWebApp
- Available extensions
- Annotations
-
- @immutable
Constructors
- OpenWebApp({required int chatId, required int botUserId, required String url, MessageTopic? topicId, InputMessageReplyTo? replyTo, WebAppOpenParameters? parameters})
Properties
- botUserId → int
-
botUserId Identifier of the bot, providing the Web App. If the bot is
restricted for the current user, then show an error instead of calling the
method
final
- chatId → int
-
chatId Identifier of the chat in which the Web App is opened. The Web
App can't be opened in secret chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- parameters → WebAppOpenParameters?
-
parameters Parameters to use to open the Web App
final
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message or story to be replied in the
message sent by the Web App; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Topic in which the message will be sent; pass null if none
final
- url → String
-
url The URL from an inlineKeyboardButtonTypeWebApp button, a
botMenuButton button, an internalLinkTypeAttachmentMenuBot link, or an
empty string otherwise
final
Methods
-
copyWith(
{int? chatId, int? botUserId, String? url, MessageTopic? topicId, InputMessageReplyTo? replyTo, WebAppOpenParameters? parameters}) → OpenWebApp -
Available on OpenWebApp, provided by the OpenWebAppExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String