OrderInfo class final
Order information
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- emailAddress → String
-
emailAddress Email address of the user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name Name of the user
final
- phoneNumber → String
-
phoneNumber Phone number of the user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingAddress → Address?
-
shippingAddress Shipping address for this order; may be null
final
Methods
-
copyWith(
{String? name, String? phoneNumber, String? emailAddress, Address? shippingAddress}) → OrderInfo -
Available on OrderInfo, provided by the OrderInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String