Outline class final
Represents outline of an image
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Outline({required List<
ClosedVectorPath> paths})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
paths
→ List<
ClosedVectorPath> -
paths The list of closed vector paths
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< ClosedVectorPath> ? paths}) → Outline -
Available on Outline, provided by the OutlineExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String