PageBlockListItem class final
Describes an item of a list page block
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
blocks
→ List<
PageBlock> -
blocks Item blocks
final
- hasCheckbox → bool
-
hasCheckbox True, if the item has a checkbox
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isChecked → bool
-
isChecked True, if the item is checked
final
- label → String
-
label Item label
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
type Type of the item numbering type; must be one of "a" for lowercase
letters, "A" for uppercase letters, "i" for lowercase Roman numerals, "I"
for uppercase Roman numerals, "1" for decimal numbers, or empty for
unordered lists
final
- value → int
-
value Value of the item; 0 for unordered lists
final
Methods
-
copyWith(
{String? label, List< PageBlock> ? blocks, bool? hasCheckbox, bool? isChecked, int? value, String? type}) → PageBlockListItem -
Available on PageBlockListItem, provided by the PageBlockListItemExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PageBlockListItem?
Constants
- constructor → const String