PageBlockRelatedArticle class final
Contains information about a related article
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
author Article author; may be empty
final
- description → String
-
param_description Article description; may be empty
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- photo → Photo?
-
photo Article photo; may be null
final
- publishDate → int
-
publishDate Point in time (Unix timestamp) when the article was
published; 0 if unknown
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Article title; may be empty
final
- url → String
-
url Related article URL
final
Methods
-
copyWith(
{String? url, String? title, String? description, Photo? photo, String? author, int? publishDate}) → PageBlockRelatedArticle -
Available on PageBlockRelatedArticle, provided by the PageBlockRelatedArticleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PageBlockRelatedArticle?
Constants
- constructor → const String