PageBlockTableCell class final
Represents a cell of a table
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PageBlockTableCell({RichText? text, required bool isHeader, required int colspan, required int rowspan, PageBlockHorizontalAlignment? align, PageBlockVerticalAlignment? valign})
Properties
- align → PageBlockHorizontalAlignment?
-
align Horizontal cell content alignment
final
- colspan → int
-
colspan The number of columns the cell spans
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isHeader → bool
-
isHeader True, if it is a header cell
final
- rowspan → int
-
rowspan The number of rows the cell spans
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → RichText?
-
text Cell text; may be null. If the text is null, then the cell must be
invisible
final
- valign → PageBlockVerticalAlignment?
-
valign Vertical cell content alignment
final
Methods
-
copyWith(
{RichText? text, bool? isHeader, int? colspan, int? rowspan, PageBlockHorizontalAlignment? align, PageBlockVerticalAlignment? valign}) → PageBlockTableCell -
Available on PageBlockTableCell, provided by the PageBlockTableCellExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PageBlockTableCell?
Constants
- constructor → const String