PaidMediaPreview class final
The media is hidden until the invoice is paid
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaidMediaPreview({required int width, required int height, required int duration, Minithumbnail? minithumbnail})
Properties
- duration → int
-
duration Media duration, in seconds; 0 if unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Media height; 0 if unknown
final
- minithumbnail → Minithumbnail?
-
minithumbnail Media minithumbnail; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
width Media width; 0 if unknown
final
Methods
-
copyWith(
{int? width, int? height, int? duration, Minithumbnail? minithumbnail}) → PaidMediaPreview -
Available on PaidMediaPreview, provided by the PaidMediaPreviewExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult photo(PaidMediaPhoto value), required TResult preview(PaidMediaPreview value), required TResult unsupported(PaidMediaUnsupported value), required TResult video(PaidMediaVideo value)}) → TResult -
Available on PaidMedia, provided by the PaidMediaExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult photo(PaidMediaPhoto value)?, TResult preview(PaidMediaPreview value)?, TResult unsupported(PaidMediaUnsupported value)?, TResult video(PaidMediaVideo value)?, required TResult orElse()}) → TResult -
Available on PaidMedia, provided by the PaidMediaExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaidMediaPreview? -
Inherited by:
PaidMediaPhoto
PaidMediaPreview
PaidMediaUnsupported
PaidMediaVideo
override
Constants
- constructor → const String