PaidReactor class final
Contains information about a user who added paid reactions
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaidReactor({MessageSender? senderId, required int starCount, required bool isTop, required bool isMe, required bool isAnonymous})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAnonymous → bool
-
isAnonymous True, if the reactor is anonymous
final
- isMe → bool
-
isMe True, if the paid reaction was added by the current user
final
- isTop → bool
-
isTop True, if the reactor is one of the most active reactors; may be
false if the reactor is the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the user or chat that added the reactions; may be
null for anonymous reactors that aren't the current user
final
- starCount → int
-
starCount Number of Telegram Stars added
final
Methods
-
copyWith(
{MessageSender? senderId, int? starCount, bool? isTop, bool? isMe, bool? isAnonymous}) → PaidReactor -
Available on PaidReactor, provided by the PaidReactorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaidReactor?
Constants
- constructor → const String