Passkey class final
Describes a passkey
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- additionDate → int
-
additionDate Point in time (Unix timestamp) when the passkey was added
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique identifier of the passkey
final
- lastUsageDate → int
-
lastUsageDate Point in time (Unix timestamp) when the passkey was used
last time; 0 if never
final
- name → String
-
name Name of the passkey
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softwareIconCustomEmojiId → int
-
softwareIconCustomEmojiId Identifier of the custom emoji that is used as
the icon of the software, which created the passkey; 0 if unknown
final
Methods
-
copyWith(
{String? id, String? name, int? additionDate, int? lastUsageDate, int? softwareIconCustomEmojiId}) → Passkey -
Available on Passkey, provided by the PasskeyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String