PassportElementError class final
Contains the description of an error in a Telegram Passport element
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PassportElementError({PassportElementType? type, required String message, PassportElementErrorSource? source})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → String
-
message Error message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PassportElementErrorSource?
-
source Error source
final
- type → PassportElementType?
-
type Type of the Telegram Passport element which has the error
final
Methods
-
copyWith(
{PassportElementType? type, String? message, PassportElementErrorSource? source}) → PassportElementError -
Available on PassportElementError, provided by the PassportElementErrorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PassportElementError?
Constants
- constructor → const String