PassportElementsWithErrors class final
Contains information about a Telegram Passport elements and corresponding errors
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PassportElementsWithErrors({required List<
PassportElement> elements, required List<PassportElementError> errors})
Properties
-
elements
→ List<
PassportElement> -
elements Telegram Passport elements
final
-
errors
→ List<
PassportElementError> -
errors Errors in the elements that are already available
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< PassportElement> ? elements, List<PassportElementError> ? errors}) → PassportElementsWithErrors -
Available on PassportElementsWithErrors, provided by the PassportElementsWithErrorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PassportElementsWithErrors?
Constants
- constructor → const String