PassportSuitableElement class final
Contains information about a Telegram Passport element that was requested by a service
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PassportSuitableElement({PassportElementType? type, required bool isSelfieRequired, required bool isTranslationRequired, required bool isNativeNameRequired})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isNativeNameRequired → bool
-
isNativeNameRequired True, if personal details must include the user's
name in the language of their country of residence
final
- isSelfieRequired → bool
-
isSelfieRequired True, if a selfie is required with the identity
document
final
- isTranslationRequired → bool
-
isTranslationRequired True, if a certified English translation is
required with the document
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PassportElementType?
-
type Type of the element
final
Methods
-
copyWith(
{PassportElementType? type, bool? isSelfieRequired, bool? isTranslationRequired, bool? isNativeNameRequired}) → PassportSuitableElement -
Available on PassportSuitableElement, provided by the PassportSuitableElementExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PassportSuitableElement?
Constants
- constructor → const String