PasswordState class final
Represents the current state of 2-step verification
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PasswordState({required bool hasPassword, required String passwordHint, required bool hasRecoveryEmailAddress, required bool hasPassportData, EmailAddressAuthenticationCodeInfo? recoveryEmailAddressCodeInfo, required String loginEmailAddressPattern, required int pendingResetDate})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasPassportData → bool
-
hasPassportData True, if some Telegram Passport elements were saved
final
- hasPassword → bool
-
hasPassword True, if a 2-step verification password is set
final
- hasRecoveryEmailAddress → bool
-
hasRecoveryEmailAddress True, if a recovery email is set
final
- loginEmailAddressPattern → String
-
loginEmailAddressPattern Pattern of the email address set up for logging
in
final
- passwordHint → String
-
passwordHint Hint for the password; may be empty
final
- pendingResetDate → int
-
pendingResetDate If not 0, point in time (Unix timestamp) after which
the 2-step verification password can be reset immediately using
resetPassword
final
- recoveryEmailAddressCodeInfo → EmailAddressAuthenticationCodeInfo?
-
recoveryEmailAddressCodeInfo Information about the recovery email
address to which the confirmation email was sent; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? hasPassword, String? passwordHint, bool? hasRecoveryEmailAddress, bool? hasPassportData, EmailAddressAuthenticationCodeInfo? recoveryEmailAddressCodeInfo, String? loginEmailAddressPattern, int? pendingResetDate}) → PasswordState -
Available on PasswordState, provided by the PasswordStateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PasswordState?
Constants
- constructor → const String