PaymentForm class final
Contains information about an invoice payment form
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentForm({required int id, PaymentFormType? type, required int sellerBotUserId, ProductInfo? productInfo})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id The payment form identifier
final
- productInfo → ProductInfo?
-
productInfo Information about the product
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sellerBotUserId → int
-
sellerBotUserId User identifier of the seller bot
final
- type → PaymentFormType?
-
type Type of the payment form
final
Methods
-
copyWith(
{int? id, PaymentFormType? type, int? sellerBotUserId, ProductInfo? productInfo}) → PaymentForm -
Available on PaymentForm, provided by the PaymentFormExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentForm?
Constants
- constructor → const String