PaymentFormTypeRegular class final
The payment form is for a regular payment
- Inheritance
-
- Object
- TdObject
- PaymentFormType
- PaymentFormTypeRegular
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PaymentFormTypeRegular({Invoice? invoice, required int paymentProviderUserId, PaymentProvider? paymentProvider, required List<
PaymentOption> additionalPaymentOptions, OrderInfo? savedOrderInfo, required List<SavedCredentials> savedCredentials, required bool canSaveCredentials, required bool needPassword})
Properties
-
additionalPaymentOptions
→ List<
PaymentOption> -
additionalPaymentOptions The list of additional payment options
final
- canSaveCredentials → bool
-
canSaveCredentials True, if the user can choose to save credentials
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- invoice → Invoice?
-
invoice Full information about the invoice
final
- needPassword → bool
-
needPassword True, if the user will be able to save credentials, if sets
up a 2-step verification password
final
- paymentProvider → PaymentProvider?
-
paymentProvider Information about the payment provider
final
- paymentProviderUserId → int
-
paymentProviderUserId User identifier of the payment provider bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
savedCredentials
→ List<
SavedCredentials> -
savedCredentials The list of saved payment credentials
final
- savedOrderInfo → OrderInfo?
-
savedOrderInfo Saved server-side order information; may be null
final
Methods
-
copyWith(
{Invoice? invoice, int? paymentProviderUserId, PaymentProvider? paymentProvider, List< PaymentOption> ? additionalPaymentOptions, OrderInfo? savedOrderInfo, List<SavedCredentials> ? savedCredentials, bool? canSaveCredentials, bool? needPassword}) → PaymentFormTypeRegular -
Available on PaymentFormTypeRegular, provided by the PaymentFormTypeRegularExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult regular(PaymentFormTypeRegular value), required TResult starSubscription(PaymentFormTypeStarSubscription value), required TResult stars(PaymentFormTypeStars value)}) → TResult -
Available on PaymentFormType, provided by the PaymentFormTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult regular(PaymentFormTypeRegular value)?, TResult starSubscription(PaymentFormTypeStarSubscription value)?, TResult stars(PaymentFormTypeStars value)?, required TResult orElse()}) → TResult -
Available on PaymentFormType, provided by the PaymentFormTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentFormTypeRegular? -
Inherited by:
PaymentFormTypeRegular
PaymentFormTypeStarSubscription
PaymentFormTypeStars
override
Constants
- constructor → const String