PaymentProviderSmartGlocal class final
Smart Glocal payment provider
- Inheritance
-
- Object
- TdObject
- PaymentProvider
- PaymentProviderSmartGlocal
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentProviderSmartGlocal({required String publicToken, required String tokenizeUrl})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- publicToken → String
-
publicToken Public payment token
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenizeUrl → String
-
tokenizeUrl URL for sending card tokenization requests
final
Methods
-
copyWith(
{String? publicToken, String? tokenizeUrl}) → PaymentProviderSmartGlocal -
Available on PaymentProviderSmartGlocal, provided by the PaymentProviderSmartGlocalExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult other(PaymentProviderOther value), required TResult smartGlocal(PaymentProviderSmartGlocal value), required TResult stripe(PaymentProviderStripe value)}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult other(PaymentProviderOther value)?, TResult smartGlocal(PaymentProviderSmartGlocal value)?, TResult stripe(PaymentProviderStripe value)?, required TResult orElse()}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentProviderSmartGlocal? -
Inherited by:
PaymentProviderOther
PaymentProviderSmartGlocal
PaymentProviderStripe
override
Constants
- constructor → const String