PaymentProviderStripe class final
Stripe payment provider
- Inheritance
-
- Object
- TdObject
- PaymentProvider
- PaymentProviderStripe
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentProviderStripe({required String publishableKey, required bool needCountry, required bool needPostalCode, required bool needCardholderName})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- needCardholderName → bool
-
needCardholderName True, if the cardholder name must be provided
final
- needCountry → bool
-
needCountry True, if the user country must be provided
final
- needPostalCode → bool
-
needPostalCode True, if the user ZIP/postal code must be provided
final
- publishableKey → String
-
publishableKey Stripe API publishable key
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? publishableKey, bool? needCountry, bool? needPostalCode, bool? needCardholderName}) → PaymentProviderStripe -
Available on PaymentProviderStripe, provided by the PaymentProviderStripeExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult other(PaymentProviderOther value), required TResult smartGlocal(PaymentProviderSmartGlocal value), required TResult stripe(PaymentProviderStripe value)}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult other(PaymentProviderOther value)?, TResult smartGlocal(PaymentProviderSmartGlocal value)?, TResult stripe(PaymentProviderStripe value)?, required TResult orElse()}) → TResult -
Available on PaymentProvider, provided by the PaymentProviderExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentProviderStripe? -
Inherited by:
PaymentProviderOther
PaymentProviderSmartGlocal
PaymentProviderStripe
override
Constants
- constructor → const String