PaymentReceipt class final
Contains information about a successful payment
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentReceipt({ProductInfo? productInfo, required int date, required int sellerBotUserId, PaymentReceiptType? type})
Properties
- date → int
-
date Point in time (Unix timestamp) when the payment was made
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- productInfo → ProductInfo?
-
productInfo Information about the product
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sellerBotUserId → int
-
sellerBotUserId User identifier of the seller bot
final
- type → PaymentReceiptType?
-
type Type of the payment receipt
final
Methods
-
copyWith(
{ProductInfo? productInfo, int? date, int? sellerBotUserId, PaymentReceiptType? type}) → PaymentReceipt -
Available on PaymentReceipt, provided by the PaymentReceiptExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentReceipt?
Constants
- constructor → const String