PaymentReceiptTypeRegular class final
The payment was done using a third-party payment provider
- Inheritance
-
- Object
- TdObject
- PaymentReceiptType
- PaymentReceiptTypeRegular
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentReceiptTypeRegular({required int paymentProviderUserId, Invoice? invoice, OrderInfo? orderInfo, ShippingOption? shippingOption, required String credentialsTitle, required int tipAmount})
Properties
- credentialsTitle → String
-
credentialsTitle Title of the saved credentials chosen by the buyer
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- invoice → Invoice?
-
invoice Information about the invoice
final
- orderInfo → OrderInfo?
-
orderInfo Order information; may be null
final
- paymentProviderUserId → int
-
paymentProviderUserId User identifier of the payment provider bot
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shippingOption → ShippingOption?
-
shippingOption Chosen shipping option; may be null
final
- tipAmount → int
-
tipAmount The amount of tip chosen by the buyer in the smallest units of
the currency
final
Methods
-
copyWith(
{int? paymentProviderUserId, Invoice? invoice, OrderInfo? orderInfo, ShippingOption? shippingOption, String? credentialsTitle, int? tipAmount}) → PaymentReceiptTypeRegular -
Available on PaymentReceiptTypeRegular, provided by the PaymentReceiptTypeRegularExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult regular(PaymentReceiptTypeRegular value), required TResult stars(PaymentReceiptTypeStars value)}) → TResult -
Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult regular(PaymentReceiptTypeRegular value)?, TResult stars(PaymentReceiptTypeStars value)?, required TResult orElse()}) → TResult -
Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentReceiptTypeRegular? -
Inherited by:
PaymentReceiptTypeRegular
PaymentReceiptTypeStars
override
Constants
- constructor → const String