PaymentReceiptTypeStars class final
The payment was done using Telegram Stars
- Inheritance
-
- Object
- TdObject
- PaymentReceiptType
- PaymentReceiptTypeStars
- Available extensions
- Annotations
-
- @immutable
Constructors
- PaymentReceiptTypeStars({required int starCount, required String transactionId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount Number of Telegram Stars that were paid
final
- transactionId → String
-
transactionId Unique identifier of the transaction that can be used to
dispute it
final
Methods
-
copyWith(
{int? starCount, String? transactionId}) → PaymentReceiptTypeStars -
Available on PaymentReceiptTypeStars, provided by the PaymentReceiptTypeStarsExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult regular(PaymentReceiptTypeRegular value), required TResult stars(PaymentReceiptTypeStars value)}) → TResult -
Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult regular(PaymentReceiptTypeRegular value)?, TResult stars(PaymentReceiptTypeStars value)?, required TResult orElse()}) → TResult -
Available on PaymentReceiptType, provided by the PaymentReceiptTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PaymentReceiptTypeStars? -
Inherited by:
PaymentReceiptTypeRegular
PaymentReceiptTypeStars
override
Constants
- constructor → const String