PhoneNumberAuthenticationSettings class final
Contains settings for the authentication of the user's phone number
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PhoneNumberAuthenticationSettings({required bool allowFlashCall, required bool allowMissedCall, required bool isCurrentPhoneNumber, required bool hasUnknownPhoneNumber, required bool allowSmsRetrieverApi, FirebaseAuthenticationSettings? firebaseAuthenticationSettings, required List<
String> authenticationTokens})
Properties
- allowFlashCall → bool
-
allowFlashCall Pass true if the authentication code may be sent via a
flash call to the specified phone number
final
- allowMissedCall → bool
-
allowMissedCall Pass true if the authentication code may be sent via a
missed call to the specified phone number
final
- allowSmsRetrieverApi → bool
-
allowSmsRetrieverApi For official applications only. True, if the
application can use Android SMS Retriever API (requires Google Play
Services
final
-
authenticationTokens
→ List<
String> -
authenticationTokens List of up to 20 authentication tokens, recently
received in updateOption("authentication_token") in previously logged out
sessions; for setAuthenticationPhoneNumber only
final
- firebaseAuthenticationSettings → FirebaseAuthenticationSettings?
-
firebaseAuthenticationSettings For official Android and iOS applications
only; pass null otherwise. Settings for Firebase Authentication
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasUnknownPhoneNumber → bool
-
hasUnknownPhoneNumber Pass true if there is a SIM card in the current
device, but it is not possible to check whether phone number matches
final
- isCurrentPhoneNumber → bool
-
isCurrentPhoneNumber Pass true if the authenticated phone number is used
on the current device
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? allowFlashCall, bool? allowMissedCall, bool? isCurrentPhoneNumber, bool? hasUnknownPhoneNumber, bool? allowSmsRetrieverApi, FirebaseAuthenticationSettings? firebaseAuthenticationSettings, List< String> ? authenticationTokens}) → PhoneNumberAuthenticationSettings -
Available on PhoneNumberAuthenticationSettings, provided by the PhoneNumberAuthenticationSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PhoneNumberAuthenticationSettings?
Constants
- constructor → const String