PinChatMessage class final
Pins a message in a chat. A message can be pinned only if messageProperties.can_be_pinned Returns Ok
- Inheritance
-
- Object
- TdFunction
- PinChatMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- PinChatMessage({required int chatId, required int messageId, required bool disableNotification, required bool onlyForSelf})
Properties
- chatId → int
-
chatId Identifier of the chat
final
- disableNotification → bool
-
disableNotification Pass true to disable notification about the pinned
message. Notifications are always disabled in channels and private chats
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the new pinned message
final
- onlyForSelf → bool
-
onlyForSelf Pass true to pin the message only for self; private chats
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, bool? disableNotification, bool? onlyForSelf}) → PinChatMessage -
Available on PinChatMessage, provided by the PinChatMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String