PingProxy class final
Computes time needed to receive a response from a Telegram server through a proxy. Can be called before authorization Returns Seconds
- Inheritance
-
- Object
- TdFunction
- PingProxy
- Available extensions
- Annotations
-
- @immutable
Properties
Methods
-
copyWith(
{Proxy? proxy}) → PingProxy -
Available on PingProxy, provided by the PingProxyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String