PingProxy class final

Computes time needed to receive a response from a Telegram server through a proxy. Can be called before authorization Returns Seconds

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PingProxy({Proxy? proxy})

Properties

hashCode int
The hash code for this object.
no setteroverride
proxy Proxy?
proxy The proxy to test; pass null to ping a Telegram server without a proxy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Proxy? proxy}) PingProxy

Available on PingProxy, provided by the PingProxyExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String