optionOrder property
optionOrder The list of 0-based poll identifiers in which the options of the poll must be shown; empty if the order of options must not be changed
Implementation
final List<int> optionOrder;
optionOrder The list of 0-based poll identifiers in which the options of the poll must be shown; empty if the order of options must not be changed
final List<int> optionOrder;