voteRestrictionReason property
voteRestrictionReason The reason describing, why the current user can't vote in the poll; may be null if the user can vote in the poll
Implementation
final PollVoteRestrictionReason? voteRestrictionReason;
voteRestrictionReason The reason describing, why the current user can't vote in the poll; may be null if the user can vote in the poll
final PollVoteRestrictionReason? voteRestrictionReason;