voterCount property
voterCount Number of voters for this option, available only for closed or voted polls, or if the current user is the creator of the poll
Implementation
final int voterCount;
voterCount Number of voters for this option, available only for closed or voted polls, or if the current user is the creator of the poll
final int voterCount;