PollOptionProperties class final
Contains properties of a poll option and describes actions that can be done with the option right now
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PollOptionProperties({required bool canBeDeleted, required bool canBeReplied, required bool canBeRepliedInAnotherChat, required bool canGetLink})
Properties
- canBeDeleted → bool
-
canBeDeleted True, if the option can be deleted using deletePollOption
final
- canBeReplied → bool
-
canBeReplied True, if the poll option can be replied in the same chat
and forum topic using inputMessageReplyToMessage
final
- canBeRepliedInAnotherChat → bool
-
canBeRepliedInAnotherChat True, if the poll option can be replied in
another chat or forum topic using inputMessageReplyToExternalMessage
final
- canGetLink → bool
-
canGetLink True, if a link can be generated for the poll option using
getMessageLink
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? canBeDeleted, bool? canBeReplied, bool? canBeRepliedInAnotherChat, bool? canGetLink}) → PollOptionProperties -
Available on PollOptionProperties, provided by the PollOptionPropertiesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PollOptionProperties?
Constants
- constructor → const String