canBeReplied property
canBeReplied True, if the poll option can be replied in the same chat and forum topic using inputMessageReplyToMessage
Implementation
final bool canBeReplied;
canBeReplied True, if the poll option can be replied in the same chat and forum topic using inputMessageReplyToMessage
final bool canBeReplied;