PollVoteRestrictionReasonOther class final

The poll can't be voted by the user due to some other reason

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PollVoteRestrictionReasonOther()
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult closed(PollVoteRestrictionReasonClosed value), required TResult countryRestricted(PollVoteRestrictionReasonCountryRestricted value), required TResult membershipRequired(PollVoteRestrictionReasonMembershipRequired value), required TResult other(PollVoteRestrictionReasonOther value), required TResult scheduled(PollVoteRestrictionReasonScheduled value), required TResult yetUnsent(PollVoteRestrictionReasonYetUnsent value)}) → TResult

Available on PollVoteRestrictionReason, provided by the PollVoteRestrictionReasonExtensions extension

maybeMap<TResult extends Object?>({TResult closed(PollVoteRestrictionReasonClosed value)?, TResult countryRestricted(PollVoteRestrictionReasonCountryRestricted value)?, TResult membershipRequired(PollVoteRestrictionReasonMembershipRequired value)?, TResult other(PollVoteRestrictionReasonOther value)?, TResult scheduled(PollVoteRestrictionReasonScheduled value)?, TResult yetUnsent(PollVoteRestrictionReasonYetUnsent value)?, required TResult orElse()}) → TResult

Available on PollVoteRestrictionReason, provided by the PollVoteRestrictionReasonExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String