PollVoteStatistics class final
A detailed statistics about poll votes
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PollVoteStatistics({StatisticalGraph? voteGraph})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voteGraph → StatisticalGraph?
-
voteGraph A graph containing distribution of votes in the poll
final
Methods
-
copyWith(
{StatisticalGraph? voteGraph}) → PollVoteStatistics -
Available on PollVoteStatistics, provided by the PollVoteStatisticsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PollVoteStatistics?
Constants
- constructor → const String