PollVoters class final
Represents a list of poll voters
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
PollVoters({required int totalCount, required List<
PollVoter> voters})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Approximate total number of poll voters found
final
-
voters
→ List<
PollVoter> -
voters List of poll voters
final
Methods
-
copyWith(
{int? totalCount, List< PollVoter> ? voters}) → PollVoters -
Available on PollVoters, provided by the PollVotersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PollVoters?
Constants
- constructor → const String