PreliminaryUploadFile class final
Preliminarily uploads a file to the cloud before sending it in a message, which can be useful for uploading of being recorded voice and video notes. In all other cases there is no need to preliminary upload a file. Updates updateFile will be used to notify about upload progress. The upload will not be completed until the file is sent in a message Returns File
- Inheritance
-
- Object
- TdFunction
- PreliminaryUploadFile
- Available extensions
- Annotations
-
- @immutable
Constructors
- PreliminaryUploadFile({InputFile? file, FileType? fileType, required int priority})
Properties
- file → InputFile?
-
file File to upload
final
- fileType → FileType?
-
fileType File type; pass null if unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- priority → int
-
priority Priority of the upload (1-32). The higher the priority, the
earlier the file will be uploaded. If the priorities of two files are
equal, then the first one for which preliminaryUploadFile was called will
be uploaded first
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputFile? file, FileType? fileType, int? priority}) → PreliminaryUploadFile -
Available on PreliminaryUploadFile, provided by the PreliminaryUploadFileExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String