PremiumFeaturePromotionAnimation class final
Describes a promotion animation for a Premium feature
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PremiumFeaturePromotionAnimation({PremiumFeature? feature, Animation? animation})
Properties
- animation → Animation?
-
animation Promotion animation for the feature
final
- feature → PremiumFeature?
-
feature Premium feature
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PremiumFeature? feature, Animation? animation}) → PremiumFeaturePromotionAnimation -
Available on PremiumFeaturePromotionAnimation, provided by the PremiumFeaturePromotionAnimationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumFeaturePromotionAnimation?
Constants
- constructor → const String