PremiumGiftPaymentOption class final
Describes an option for gifting Telegram Premium to a user. Use telegramPaymentPurposePremiumGift for out-of-store payments or payments in Telegram Stars
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- amount → int
-
amount The amount to pay, in the smallest units of the currency
final
- currency → String
-
currency ISO 4217 currency code for the payment
final
- discountPercentage → int
-
discountPercentage The discount associated with this option, as a
percentage
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- monthCount → int
-
monthCount Number of months the Telegram Premium subscription will be
active
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount The alternative Telegram Star amount to pay; 0 if payment in
Telegram Stars is not possible
final
- sticker → Sticker?
-
sticker A sticker to be shown along with the option; may be null if
unknown
final
- storeProductId → String
-
storeProductId Identifier of the store product associated with the
option
final
Methods
-
copyWith(
{String? currency, int? amount, int? starCount, int? discountPercentage, int? monthCount, String? storeProductId, Sticker? sticker}) → PremiumGiftPaymentOption -
Available on PremiumGiftPaymentOption, provided by the PremiumGiftPaymentOptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumGiftPaymentOption?
Constants
- constructor → const String