PremiumLimit class final

Contains information about a limit, increased for Premium users

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumLimit({PremiumLimitType? type, required int defaultValue, required int premiumValue})

Properties

defaultValue int
defaultValue Default value of the limit
final
hashCode int
The hash code for this object.
no setteroverride
premiumValue int
premiumValue Value of the limit for Premium users
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type PremiumLimitType?
type The type of the limit
final

Methods

copyWith({PremiumLimitType? type, int? defaultValue, int? premiumValue}) PremiumLimit

Available on PremiumLimit, provided by the PremiumLimitExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PremiumLimit?

Constants

constructor → const String