PremiumSourceLimitExceeded class final

A limit was exceeded

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PremiumSourceLimitExceeded({PremiumLimitType? limitType})

Properties

hashCode int
The hash code for this object.
no setteroverride
limitType PremiumLimitType?
limitType Type of the exceeded limit
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({PremiumLimitType? limitType}) PremiumSourceLimitExceeded

Available on PremiumSourceLimitExceeded, provided by the PremiumSourceLimitExceededExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult businessFeature(PremiumSourceBusinessFeature value), required TResult feature(PremiumSourceFeature value), required TResult limitExceeded(PremiumSourceLimitExceeded value), required TResult link(PremiumSourceLink value), required TResult settings(PremiumSourceSettings value), required TResult storyFeature(PremiumSourceStoryFeature value)}) → TResult

Available on PremiumSource, provided by the PremiumSourceExtensions extension

maybeMap<TResult extends Object?>({TResult businessFeature(PremiumSourceBusinessFeature value)?, TResult feature(PremiumSourceFeature value)?, TResult limitExceeded(PremiumSourceLimitExceeded value)?, TResult link(PremiumSourceLink value)?, TResult settings(PremiumSourceSettings value)?, TResult storyFeature(PremiumSourceStoryFeature value)?, required TResult orElse()}) → TResult

Available on PremiumSource, provided by the PremiumSourceExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String