PremiumStatePaymentOption class final
Describes an option for buying or upgrading Telegram Premium for self
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PremiumStatePaymentOption({PremiumPaymentOption? paymentOption, required bool isCurrent, required bool isUpgrade, required String lastTransactionId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCurrent → bool
-
isCurrent True, if this is the currently used Telegram Premium
subscription option
final
- isUpgrade → bool
-
isUpgrade True, if the payment option can be used to upgrade the
existing Telegram Premium subscription
final
- lastTransactionId → String
-
lastTransactionId Identifier of the last in-store transaction for the
currently used option
final
- paymentOption → PremiumPaymentOption?
-
paymentOption Information about the payment option
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{PremiumPaymentOption? paymentOption, bool? isCurrent, bool? isUpgrade, String? lastTransactionId}) → PremiumStatePaymentOption -
Available on PremiumStatePaymentOption, provided by the PremiumStatePaymentOptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PremiumStatePaymentOption?
Constants
- constructor → const String