PrepaidGiveaway class final

Describes a prepaid giveaway

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

PrepaidGiveaway({required int id, required int winnerCount, GiveawayPrize? prize, required int boostCount, required int paymentDate})

Properties

boostCount int
boostCount The number of boosts received by the chat from the giveaway; for Telegram Star giveaways only
final
hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the prepaid giveaway
final
paymentDate int
paymentDate Point in time (Unix timestamp) when the giveaway was paid
final
prize GiveawayPrize?
prize Prize of the giveaway
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
winnerCount int
winnerCount Number of users which will receive giveaway prize
final

Methods

copyWith({int? id, int? winnerCount, GiveawayPrize? prize, int? boostCount, int? paymentDate}) PrepaidGiveaway

Available on PrepaidGiveaway, provided by the PrepaidGiveawayExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) PrepaidGiveaway?

Constants

constructor → const String