PreparedInlineMessageId class final
Represents an inline message that can be sent via the bot
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PreparedInlineMessageId({required String id, required int expirationDate})
Properties
- expirationDate → int
-
expirationDate Point in time (Unix timestamp) when the message can't be
used anymore
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Unique identifier for the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? id, int? expirationDate}) → PreparedInlineMessageId -
Available on PreparedInlineMessageId, provided by the PreparedInlineMessageIdExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PreparedInlineMessageId?
Constants
- constructor → const String