ProcessChatHasProtectedContentDisableRequest class final

Processes request to disable has_protected_content in a chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProcessChatHasProtectedContentDisableRequest({required int chatId, required int requestMessageId, required bool approve})

Properties

approve bool
approve Pass true to approve the request; pass false to reject the request
final
chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
requestMessageId int
requestMessageId Identifier of the message with the request. The message must be incoming and has content of the type messageChatHasProtectedContentDisableRequested
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? requestMessageId, bool? approve}) ProcessChatHasProtectedContentDisableRequest

Available on ProcessChatHasProtectedContentDisableRequest, provided by the ProcessChatHasProtectedContentDisableRequestExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String