ProcessGiftPurchaseOffer class final
Handles a pending gift purchase offer Returns Ok
- Inheritance
-
- Object
- TdFunction
- ProcessGiftPurchaseOffer
- Available extensions
- Annotations
-
- @immutable
Constructors
- ProcessGiftPurchaseOffer({required int messageId, required bool accept})
Properties
- accept → bool
-
accept Pass true to accept the request; pass false to reject it
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message with the gift purchase offer
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? messageId, bool? accept}) → ProcessGiftPurchaseOffer -
Available on ProcessGiftPurchaseOffer, provided by the ProcessGiftPurchaseOfferExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String