ProcessPushNotification class final

Handles a push notification. Returns error with code 406 if the push notification is not supported and connection to the server is required to fetch new data. Can be called before authorization Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ProcessPushNotification({required String payload})

Properties

hashCode int
The hash code for this object.
no setteroverride
payload String
payload JSON-encoded push notification payload with all fields sent by the server, and "google.sent_time" and "google.notification.sound" fields added
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? payload}) ProcessPushNotification

Available on ProcessPushNotification, provided by the ProcessPushNotificationExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String