ProfileAccentColors class final
Contains information about supported accent colors for user profile photo background in RGB format
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
-
backgroundColors
→ List<
int> -
backgroundColors The list of 1-2 colors in RGB format, describing the
colors, as expected to be used for the profile photo background
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
paletteColors
→ List<
int> -
paletteColors The list of 1-2 colors in RGB format, describing the
colors, as expected to be shown in the color palette settings
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storyColors
→ List<
int> -
storyColors The list of 2 colors in RGB format, describing the colors of
the gradient to be used for the unread active story indicator around
profile photo
final
Methods
-
copyWith(
{List< int> ? paletteColors, List<int> ? backgroundColors, List<int> ? storyColors}) → ProfileAccentColors -
Available on ProfileAccentColors, provided by the ProfileAccentColorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ProfileAccentColors?
Constants
- constructor → const String