ProfilePhoto class final
Describes a user profile photo
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ProfilePhoto({required int id, File? small, File? big, Minithumbnail? minithumbnail, required bool hasAnimation, required bool isPersonal})
Properties
- big → File?
-
big A big (640x640) user profile photo. The file can be downloaded only
before the photo is changed
final
- hasAnimation → bool
-
hasAnimation True, if the photo has animated variant
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Photo identifier; 0 for an empty photo. Can be used to find a photo
in a list of user profile photos
final
- isPersonal → bool
-
isPersonal True, if the photo is visible only for the current user
final
- minithumbnail → Minithumbnail?
-
minithumbnail User profile photo minithumbnail; may be null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- small → File?
-
small A small (160x160) user profile photo. The file can be downloaded
only before the photo is changed
final
Methods
-
copyWith(
{int? id, File? small, File? big, Minithumbnail? minithumbnail, bool? hasAnimation, bool? isPersonal}) → ProfilePhoto -
Available on ProfilePhoto, provided by the ProfilePhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ProfilePhoto?
Constants
- constructor → const String