ProxyType class sealed

Describes the type of proxy server

Inheritance
Implementers
Available extensions
Annotations
  • @immutable

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConstructor() String
override
map<TResult extends Object?>({required TResult http(ProxyTypeHttp value), required TResult mtproto(ProxyTypeMtproto value), required TResult socks5(ProxyTypeSocks5 value)}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

maybeMap<TResult extends Object?>({TResult http(ProxyTypeHttp value)?, TResult mtproto(ProxyTypeMtproto value)?, TResult socks5(ProxyTypeSocks5 value)?, required TResult orElse()}) → TResult

Available on ProxyType, provided by the ProxyTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ProxyType?
Inherited by: ProxyTypeHttp ProxyTypeMtproto ProxyTypeSocks5

Constants

constructor → const String