PublicChatTypeIsLocationBased class final
The chat is public, because it is a location-based supergroup
- Inheritance
-
- Object
- TdObject
- PublicChatType
- PublicChatTypeIsLocationBased
- Available extensions
- Annotations
-
- @immutable
Constructors
- PublicChatTypeIsLocationBased()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult hasUsername(PublicChatTypeHasUsername value), required TResult isLocationBased(PublicChatTypeIsLocationBased value)}) → TResult -
Available on PublicChatType, provided by the PublicChatTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult hasUsername(PublicChatTypeHasUsername value)?, TResult isLocationBased(PublicChatTypeIsLocationBased value)?, required TResult orElse()}) → TResult -
Available on PublicChatType, provided by the PublicChatTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PublicChatTypeIsLocationBased? -
Inherited by:
PublicChatTypeHasUsername
PublicChatTypeIsLocationBased
override
Constants
- constructor → const String