PublicPostSearchLimits class final
Contains information about public post search limits
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- dailyFreeQueryCount → int
-
dailyFreeQueryCount Number of queries that can be sent daily for free
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCurrentQueryFree → bool
-
isCurrentQueryFree True, if the search for the specified query isn't
charged
final
- nextFreeQueryIn → int
-
nextFreeQueryIn Amount of time till the next free query can be sent; 0
if it can be sent now
final
- remainingFreeQueryCount → int
-
remainingFreeQueryCount Number of remaining free queries today
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount Number of Telegram Stars that must be paid for each non-free
query
final
Methods
-
copyWith(
{int? dailyFreeQueryCount, int? remainingFreeQueryCount, int? nextFreeQueryIn, int? starCount, bool? isCurrentQueryFree}) → PublicPostSearchLimits -
Available on PublicPostSearchLimits, provided by the PublicPostSearchLimitsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PublicPostSearchLimits?
Constants
- constructor → const String