PushReceiverId class final
Contains a globally unique push receiver identifier, which can be used to identify which account has received a push notification
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- PushReceiverId({required int id})
Properties
Methods
-
copyWith(
{int? id}) → PushReceiverId -
Available on PushReceiverId, provided by the PushReceiverIdExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → PushReceiverId?
Constants
- constructor → const String