QuickReplyMessages class final

Contains a list of quick reply messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

QuickReplyMessages({List<QuickReplyMessage>? messages})

Properties

hashCode int
The hash code for this object.
no setteroverride
messages List<QuickReplyMessage>?
messages List of quick reply messages; messages may be null
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<QuickReplyMessage>? messages}) QuickReplyMessages

Available on QuickReplyMessages, provided by the QuickReplyMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) QuickReplyMessages?

Constants

constructor → const String