ReadAllForumTopicReactions class final
Marks all reactions in a topic in a forum supergroup chat or a chat with a bot with topics as read Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReadAllForumTopicReactions
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReadAllForumTopicReactions({required int chatId, required int forumTopicId})
Properties
- chatId → int
-
chatId Chat identifier
final
- forumTopicId → int
-
forumTopicId Forum topic identifier in which reactions are marked as
read
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId}) → ReadAllForumTopicReactions -
Available on ReadAllForumTopicReactions, provided by the ReadAllForumTopicReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String