ReadFilePart class final
Reads a part of a file from the TDLib file cache and returns read bytes. This method is intended to be used only if the application has no direct access to TDLib's file system, because it is usually slower than a direct read from the file Returns Data
- Inheritance
-
- Object
- TdFunction
- ReadFilePart
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReadFilePart({required int fileId, required int offset, required int count})
Properties
- count → int
-
count Number of bytes to read. An error will be returned if there are
not enough bytes available in the file from the specified position. Pass 0
to read all available data from the specified position
final
- fileId → int
-
fileId Identifier of the file. The file must be located in the TDLib
file cache
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- offset → int
-
offset The offset from which to read the file
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? fileId, int? offset, int? count}) → ReadFilePart -
Available on ReadFilePart, provided by the ReadFilePartExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String