messageIds property
messageIds Identifiers of the quick reply messages to re-add. Message identifiers must be in a strictly increasing order
Implementation
final List<int> messageIds;
messageIds Identifiers of the quick reply messages to re-add. Message identifiers must be in a strictly increasing order
final List<int> messageIds;