prepaidUpgradeStarCount property
prepaidUpgradeStarCount Number of Telegram Stars that were paid by the sender for the ability to upgrade the gift
Implementation
final int prepaidUpgradeStarCount;
prepaidUpgradeStarCount Number of Telegram Stars that were paid by the sender for the ability to upgrade the gift
final int prepaidUpgradeStarCount;