RecommendedChatFolder class final
Describes a recommended chat folder
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- RecommendedChatFolder({ChatFolder? folder, required String description})
Properties
- description → String
-
param_description Chat folder description
final
- folder → ChatFolder?
-
folder The chat folder
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatFolder? folder, String? description}) → RecommendedChatFolder -
Available on RecommendedChatFolder, provided by the RecommendedChatFolderExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RecommendedChatFolder?
Constants
- constructor → const String