RegisterUser class final
Finishes user registration. Works only when the current authorization state is authorizationStateWaitRegistration Returns Ok
- Inheritance
-
- Object
- TdFunction
- RegisterUser
- Available extensions
- Annotations
-
- @immutable
Constructors
- RegisterUser({required String firstName, required String lastName, required bool disableNotification})
Properties
- disableNotification → bool
-
disableNotification Pass true to disable notification about the current
user joining Telegram for other users that added them to contact list
final
- firstName → String
-
firstName The first name of the user; 1-64 characters
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastName → String
-
lastName The last name of the user; 0-64 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? firstName, String? lastName, bool? disableNotification}) → RegisterUser -
Available on RegisterUser, provided by the RegisterUserExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String