RemoveMessageSenderBotVerification class final
Removes the verification status of a user or a chat by an owned bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveMessageSenderBotVerification
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveMessageSenderBotVerification({required int botUserId, MessageSender? verifiedId})
Properties
- botUserId → int
-
botUserId Identifier of the owned bot, which verified the user or the
chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifiedId → MessageSender?
-
verifiedId Identifier of the user or the supergroup or channel chat,
which verification is removed
final
Methods
-
copyWith(
{int? botUserId, MessageSender? verifiedId}) → RemoveMessageSenderBotVerification -
Available on RemoveMessageSenderBotVerification, provided by the RemoveMessageSenderBotVerificationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String