RemoveSavedAnimation class final
Removes an animation from the list of saved animations Returns Ok
- Inheritance
-
- Object
- TdFunction
- RemoveSavedAnimation
- Available extensions
- Annotations
-
- @immutable
Constructors
- RemoveSavedAnimation({InputFile? animation})
Properties
Methods
-
copyWith(
{InputFile? animation}) → RemoveSavedAnimation -
Available on RemoveSavedAnimation, provided by the RemoveSavedAnimationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String