RemoveSavedNotificationSound class final

Removes a notification sound from the list of saved notification sounds Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveSavedNotificationSound({required int notificationSoundId})

Properties

hashCode int
The hash code for this object.
no setteroverride
notificationSoundId int
notificationSoundId Identifier of the notification sound
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? notificationSoundId}) RemoveSavedNotificationSound

Available on RemoveSavedNotificationSound, provided by the RemoveSavedNotificationSoundExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String