RemoveTextCompositionStyle class final

Removes a custom text composition style from the list of used by the user styles. If the style was created by the current user, then it can only be deleted Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

RemoveTextCompositionStyle({required String name})

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
name Name of the style
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name}) RemoveTextCompositionStyle

Available on RemoveTextCompositionStyle, provided by the RemoveTextCompositionStyleExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String