ReorderActiveUsernames class final
Changes order of active usernames of the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReorderActiveUsernames
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ReorderActiveUsernames({required List<
String> usernames})
Properties
Methods
-
copyWith(
{List< String> ? usernames}) → ReorderActiveUsernames -
Available on ReorderActiveUsernames, provided by the ReorderActiveUsernamesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String