ReorderBotMediaPreviews class final
Changes order of media previews in the list of media previews of a bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReorderBotMediaPreviews
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ReorderBotMediaPreviews({required int botUserId, required String languageCode, required List<
int> fileIds})
Properties
- botUserId → int
-
botUserId Identifier of the target bot. The bot must be owned and must
have the main Web App
final
-
fileIds
→ List<
int> -
fileIds File identifiers of the media in the new order
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode Language code of the media previews to reorder
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, List< int> ? fileIds}) → ReorderBotMediaPreviews -
Available on ReorderBotMediaPreviews, provided by the ReorderBotMediaPreviewsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String