ReorderChatFolders class final
Changes the order of chat folders Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReorderChatFolders
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ReorderChatFolders({required List<
int> chatFolderIds, required int mainChatListPosition})
Properties
-
chatFolderIds
→ List<
int> -
chatFolderIds Identifiers of chat folders in the new correct order
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mainChatListPosition → int
-
mainChatListPosition Position of the main chat list among chat folders,
0-based. Can be non-zero only for Premium users
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< int> ? chatFolderIds, int? mainChatListPosition}) → ReorderChatFolders -
Available on ReorderChatFolders, provided by the ReorderChatFoldersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String