ReorderGiftCollections class final
Changes order of gift collections. If the collections are owned by a channel chat, then requires can_post_messages administrator right in the channel chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReorderGiftCollections
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ReorderGiftCollections({MessageSender? ownerId, required List<
int> collectionIds})
Properties
-
collectionIds
→ List<
int> -
collectionIds New order of gift collections
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- ownerId → MessageSender?
-
ownerId Identifier of the user or the channel chat that owns the
collection
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageSender? ownerId, List< int> ? collectionIds}) → ReorderGiftCollections -
Available on ReorderGiftCollections, provided by the ReorderGiftCollectionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String