ReorderQuickReplyShortcuts class final
Changes the order of quick reply shortcuts Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReorderQuickReplyShortcuts
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ReorderQuickReplyShortcuts({required List<
int> shortcutIds})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shortcutIds
→ List<
int> -
shortcutIds The new order of quick reply shortcuts
final
Methods
-
copyWith(
{List< int> ? shortcutIds}) → ReorderQuickReplyShortcuts -
Available on ReorderQuickReplyShortcuts, provided by the ReorderQuickReplyShortcutsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String