ReorderStoryAlbums class final

Changes order of story albums. If the albums are owned by a supergroup or a channel chat, then requires can_edit_stories administrator right in the chat Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReorderStoryAlbums({required int chatId, required List<int> storyAlbumIds})

Properties

chatId int
chatId Identifier of the chat that owns the stories
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyAlbumIds List<int>
storyAlbumIds New order of story albums
final

Methods

copyWith({int? chatId, List<int>? storyAlbumIds}) ReorderStoryAlbums

Available on ReorderStoryAlbums, provided by the ReorderStoryAlbumsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String