ReplyMarkupForceReply class final

Instructs application to force a reply to this message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReplyMarkupForceReply({required bool isPersonal, required String inputFieldPlaceholder})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputFieldPlaceholder String
inputFieldPlaceholder If non-empty, the placeholder to be shown in the input field when the reply is active; 0-64 characters
final
isPersonal bool
isPersonal True, if a forced reply must automatically be shown to the current user. For outgoing messages, specify true to show the forced reply only for the mentioned users and for the target user of a reply
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({bool? isPersonal, String? inputFieldPlaceholder}) ReplyMarkupForceReply

Available on ReplyMarkupForceReply, provided by the ReplyMarkupForceReplyExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forceReply(ReplyMarkupForceReply value), required TResult inlineKeyboard(ReplyMarkupInlineKeyboard value), required TResult removeKeyboard(ReplyMarkupRemoveKeyboard value), required TResult showKeyboard(ReplyMarkupShowKeyboard value)}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

maybeMap<TResult extends Object?>({TResult forceReply(ReplyMarkupForceReply value)?, TResult inlineKeyboard(ReplyMarkupInlineKeyboard value)?, TResult removeKeyboard(ReplyMarkupRemoveKeyboard value)?, TResult showKeyboard(ReplyMarkupShowKeyboard value)?, required TResult orElse()}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String