ReplyMarkupShowKeyboard class final

Contains a custom keyboard layout to quickly reply to bots

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ReplyMarkupShowKeyboard({required List<List<KeyboardButton>> rows, required bool isPersistent, required bool resizeKeyboard, required bool oneTime, required bool isPersonal, required String inputFieldPlaceholder})

Properties

hashCode int
The hash code for this object.
no setteroverride
inputFieldPlaceholder String
inputFieldPlaceholder If non-empty, the placeholder to be shown in the input field when the keyboard is active; 0-64 characters
final
isPersistent bool
isPersistent True, if the keyboard is expected to always be shown when the ordinary keyboard is hidden
final
isPersonal bool
isPersonal True, if the keyboard must automatically be shown to the current user. For outgoing messages, specify true to show the keyboard only for the mentioned users and for the target user of a reply
final
oneTime bool
oneTime True, if the application needs to hide the keyboard after use
final
resizeKeyboard bool
resizeKeyboard True, if the application needs to resize the keyboard vertically
final
rows List<List<KeyboardButton>>
rows A list of rows of bot keyboard buttons
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<List<KeyboardButton>>? rows, bool? isPersistent, bool? resizeKeyboard, bool? oneTime, bool? isPersonal, String? inputFieldPlaceholder}) ReplyMarkupShowKeyboard

Available on ReplyMarkupShowKeyboard, provided by the ReplyMarkupShowKeyboardExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult forceReply(ReplyMarkupForceReply value), required TResult inlineKeyboard(ReplyMarkupInlineKeyboard value), required TResult removeKeyboard(ReplyMarkupRemoveKeyboard value), required TResult showKeyboard(ReplyMarkupShowKeyboard value)}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

maybeMap<TResult extends Object?>({TResult forceReply(ReplyMarkupForceReply value)?, TResult inlineKeyboard(ReplyMarkupInlineKeyboard value)?, TResult removeKeyboard(ReplyMarkupRemoveKeyboard value)?, TResult showKeyboard(ReplyMarkupShowKeyboard value)?, required TResult orElse()}) → TResult

Available on ReplyMarkup, provided by the ReplyMarkupExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String