ReportChatPhoto class final
Reports a chat photo to the Telegram moderators. A chat photo can be reported only if chat.can_be_reported Returns Ok
- Inheritance
-
- Object
- TdFunction
- ReportChatPhoto
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReportChatPhoto({required int chatId, required int fileId, ReportReason? reason, required String text})
Properties
- chatId → int
-
chatId Chat identifier
final
- fileId → int
-
fileId Identifier of the photo to report. Only full photos from
chatPhoto can be reported
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- reason → ReportReason?
-
reason The reason for reporting the chat photo
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
text Additional report details; 0-1024 characters
final
Methods
-
copyWith(
{int? chatId, int? fileId, ReportReason? reason, String? text}) → ReportChatPhoto -
Available on ReportChatPhoto, provided by the ReportChatPhotoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String