ReportStoryResultTextRequired class final
The user must add additional text details to the report
- Inheritance
-
- Object
- TdObject
- ReportStoryResult
- ReportStoryResultTextRequired
- Available extensions
- Annotations
-
- @immutable
Constructors
- ReportStoryResultTextRequired({required String optionId, bool? isOptional})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isOptional → bool?
-
isOptional True, if the user can skip text adding
final
- optionId → String
-
optionId Option identifier for the next reportStory request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? optionId, bool? isOptional}) → ReportStoryResultTextRequired -
Available on ReportStoryResultTextRequired, provided by the ReportStoryResultTextRequiredExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult ok(ReportStoryResultOk value), required TResult optionRequired(ReportStoryResultOptionRequired value), required TResult textRequired(ReportStoryResultTextRequired value)}) → TResult -
Available on ReportStoryResult, provided by the ReportStoryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult ok(ReportStoryResultOk value)?, TResult optionRequired(ReportStoryResultOptionRequired value)?, TResult textRequired(ReportStoryResultTextRequired value)?, required TResult orElse()}) → TResult -
Available on ReportStoryResult, provided by the ReportStoryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ReportStoryResultTextRequired? -
Inherited by:
ReportStoryResultOk
ReportStoryResultOptionRequired
ReportStoryResultTextRequired
override
Constants
- constructor → const String