RequestQrCodeAuthentication class final
Requests QR code authentication by scanning a QR code on another logged in device. Works only when the current authorization state is authorizationStateWaitPhoneNumber, or if there is no pending authentication query and the current authorization state is authorizationStateWaitPremiumPurchase, authorizationStateWaitEmailAddress, authorizationStateWaitEmailCode, authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword Returns Ok
- Inheritance
-
- Object
- TdFunction
- RequestQrCodeAuthentication
- Available extensions
- Annotations
-
- @immutable
Constructors
-
RequestQrCodeAuthentication({required List<
int> otherUserIds})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
otherUserIds
→ List<
int> -
otherUserIds List of user identifiers of other users currently using the
application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< int> ? otherUserIds}) → RequestQrCodeAuthentication -
Available on RequestQrCodeAuthentication, provided by the RequestQrCodeAuthenticationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String