ResendAuthenticationCode class final
Resends an authentication code to the user. Works only when the current authorization state is authorizationStateWaitCode, the next_code_type of the result is not null and the server-specified timeout has passed, or when the current authorization state is authorizationStateWaitEmailCode Returns Ok
- Inheritance
-
- Object
- TdFunction
- ResendAuthenticationCode
- Available extensions
- Annotations
-
- @immutable
Constructors
- ResendAuthenticationCode({ResendCodeReason? reason})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- reason → ResendCodeReason?
-
reason Reason of code resending; pass null if unknown
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ResendCodeReason? reason}) → ResendAuthenticationCode -
Available on ResendAuthenticationCode, provided by the ResendAuthenticationCodeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String