RestrictionInfo class final
Contains information about restrictions that must be applied to a chat or a message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- RestrictionInfo({required String restrictionReason, required bool hasSensitiveContent})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasSensitiveContent → bool
-
hasSensitiveContent True, if media content of the messages must be
hidden with 18+ spoiler. Use value of the option
"can_ignore_sensitive_content_restrictions" to check whether the current
user can ignore the restriction. If age verification parameters were
received in updateAgeVerificationParameters, then the user must complete
age verification to ignore the restriction. Set the option
"ignore_sensitive_content_restrictions" to true if the user passes age
verification
final
- restrictionReason → String
-
restrictionReason A human-readable description of the reason why access
to the content must be restricted. If empty, then the content can be
accessed, but may be covered by hidden with 18+ spoiler anyway
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? restrictionReason, bool? hasSensitiveContent}) → RestrictionInfo -
Available on RestrictionInfo, provided by the RestrictionInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RestrictionInfo?
Constants
- constructor → const String