RichMessageSource class sealed
Describes source of a rich message
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult blocks(RichMessageSourceBlocks value), required TResult html(RichMessageSourceHtml value), required TResult markdown(RichMessageSourceMarkdown value)}) → TResult -
Available on RichMessageSource, provided by the RichMessageSourceExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult blocks(RichMessageSourceBlocks value)?, TResult html(RichMessageSourceHtml value)?, TResult markdown(RichMessageSourceMarkdown value)?, required TResult orElse()}) → TResult -
Available on RichMessageSource, provided by the RichMessageSourceExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → RichMessageSource? - Inherited by: RichMessageSourceBlocks RichMessageSourceHtml RichMessageSourceMarkdown
Constants
- constructor → const String