SaveApplicationLogEvent class final
Saves application log event on the server. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- SaveApplicationLogEvent
- Available extensions
- Annotations
-
- @immutable
Constructors
- SaveApplicationLogEvent({required String type, int? chatId, JsonValue? data})
Properties
- chatId → int?
-
chatId Optional chat identifier, associated with the event
final
- data → JsonValue?
-
data The log event data
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
type Event type
final
Methods
-
copyWith(
{String? type, int? chatId, JsonValue? data}) → SaveApplicationLogEvent -
Available on SaveApplicationLogEvent, provided by the SaveApplicationLogEventExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String