SavePreparedKeyboardButton class final
Saves a keyboard button to be shown to the given user; for bots only Returns Text
- Inheritance
-
- Object
- TdFunction
- SavePreparedKeyboardButton
- Available extensions
- Annotations
-
- @immutable
Constructors
- SavePreparedKeyboardButton({required int userId, KeyboardButton? button})
Properties
-
button The button; must be of the type keyboardButtonTypeRequestUsers,
keyboardButtonTypeRequestChat, or keyboardButtonTypeRequestManagedBot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → int
-
userId Identifier of the user
final
Methods
-
copyWith(
{int? userId, KeyboardButton? button}) → SavePreparedKeyboardButton -
Available on SavePreparedKeyboardButton, provided by the SavePreparedKeyboardButtonExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String