SavedMessagesTopic class final
Contains information about a Saved Messages topic
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- SavedMessagesTopic({required int id, SavedMessagesTopicType? type, required bool isPinned, required int order, Message? lastMessage, DraftMessage? draftMessage})
Properties
- draftMessage → DraftMessage?
-
draftMessage A draft of a message in the topic; may be null if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique topic identifier
final
- isPinned → bool
-
isPinned True, if the topic is pinned
final
- lastMessage → Message?
-
lastMessage Last message in the topic; may be null if none or unknown
final
- order → int
-
order A parameter used to determine order of the topic in the topic
list. Topics must be sorted by the order in descending order
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SavedMessagesTopicType?
-
type Type of the topic
final
Methods
-
copyWith(
{int? id, SavedMessagesTopicType? type, bool? isPinned, int? order, Message? lastMessage, DraftMessage? draftMessage}) → SavedMessagesTopic -
Available on SavedMessagesTopic, provided by the SavedMessagesTopicExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SavedMessagesTopic?
Constants
- constructor → const String