ScopeAutosaveSettings class final
Contains autosave settings for an autosave settings scope
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ScopeAutosaveSettings({required bool autosavePhotos, required bool autosaveVideos, required int maxVideoFileSize})
Properties
- autosavePhotos → bool
-
autosavePhotos True, if photo autosave is enabled
final
- autosaveVideos → bool
-
autosaveVideos True, if video autosave is enabled
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxVideoFileSize → int
-
maxVideoFileSize The maximum size of a video file to be autosaved, in
bytes; 512 KB - 4000 MB
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? autosavePhotos, bool? autosaveVideos, int? maxVideoFileSize}) → ScopeAutosaveSettings -
Available on ScopeAutosaveSettings, provided by the ScopeAutosaveSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ScopeAutosaveSettings?
Constants
- constructor → const String