ScopeNotificationSettings class final
Contains information about notification settings for several chats
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ScopeNotificationSettings({required int muteFor, required int soundId, required bool showPreview, required bool useDefaultMuteStories, required bool muteStories, required int storySoundId, required bool showStoryPoster, required bool disablePinnedMessageNotifications, required bool disableMentionNotifications})
Properties
- disableMentionNotifications → bool
-
disableMentionNotifications True, if notifications for messages with
mentions will be created as for an ordinary unread message
final
- disablePinnedMessageNotifications → bool
-
disablePinnedMessageNotifications True, if notifications for incoming
pinned messages will be created as for an ordinary unread message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- muteFor → int
-
muteFor Time left before notifications will be unmuted, in seconds
final
- muteStories → bool
-
muteStories True, if story notifications are disabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPreview → bool
-
showPreview True, if message content must be displayed in notifications
final
- showStoryPoster → bool
-
showStoryPoster True, if the chat that posted a story must be displayed
in notifications
final
- soundId → int
-
soundId Identifier of the notification sound to be played; 0 if sound is
disabled; pass -1 to use the app-dependent default sound
final
- storySoundId → int
-
storySoundId Identifier of the notification sound to be played for
stories; 0 if sound is disabled; pass -1 to use the app-dependent default
sound
final
- useDefaultMuteStories → bool
-
useDefaultMuteStories If true, story notifications are received only for
the first 5 chats from topChatCategoryUsers regardless of the value of
mute_stories
final
Methods
-
copyWith(
{int? muteFor, int? soundId, bool? showPreview, bool? useDefaultMuteStories, bool? muteStories, int? storySoundId, bool? showStoryPoster, bool? disablePinnedMessageNotifications, bool? disableMentionNotifications}) → ScopeNotificationSettings -
Available on ScopeNotificationSettings, provided by the ScopeNotificationSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ScopeNotificationSettings?
Constants
- constructor → const String