SearchChatMessages class final
Searches for messages with given words in the chat. Returns the results in reverse chronological order, i.e. in order of decreasing message_id. Cannot be used in secret chats with a non-empty query (searchSecretMessages must be used instead), or without an enabled message database. For optimal performance, the number of returned messages is chosen by TDLib and can be smaller than the specified limit. A combination of query, sender_id, filter and topic_id search criteria is expected to be supported, only if it is required for Telegram official application implementation Returns FoundChatMessages
- Inheritance
-
- Object
- TdFunction
- SearchChatMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchChatMessages({required int chatId, MessageTopic? topicId, required String query, MessageSender? senderId, required int fromMessageId, required int offset, required int limit, SearchMessagesFilter? filter})
Properties
- chatId → int
-
chatId Identifier of the chat in which to search messages
final
- filter → SearchMessagesFilter?
-
filter Additional filter for messages to search; pass null to search for
all messages
final
- fromMessageId → int
-
fromMessageId Identifier of the message starting from which history must
be fetched; use 0 to get results from the last message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of messages to be returned; must be positive
and can't be greater than 100. If the offset is negative, then the limit
must be greater than -offset. For optimal performance, the number of
returned messages is chosen by TDLib and can be smaller than the specified
limit
final
- offset → int
-
offset Specify 0 to get results from exactly the message from_message_id
or a negative number to get the specified message and some newer messages
final
- query → String
-
query Query to search for
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- senderId → MessageSender?
-
senderId Identifier of the sender of messages to search for; pass null
to search for messages from any sender. Not supported in secret chats
final
- topicId → MessageTopic?
-
topicId Pass topic identifier to search messages only in specific topic;
pass null to search for messages in all topics
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, String? query, MessageSender? senderId, int? fromMessageId, int? offset, int? limit, SearchMessagesFilter? filter}) → SearchChatMessages -
Available on SearchChatMessages, provided by the SearchChatMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String