SearchChatRecentLocationMessages class final

Returns information about the recent live locations of chat members that were sent to the chat. Returns at most one live location message per user Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchChatRecentLocationMessages({required int chatId, required int limit})

Properties

chatId int
chatId Chat identifier
final
hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of messages to be returned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? chatId, int? limit}) SearchChatRecentLocationMessages

Available on SearchChatRecentLocationMessages, provided by the SearchChatRecentLocationMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String