SearchFileDownloads class final
Searches for files in the file download list or recently downloaded files from the list Returns FoundFileDownloads
- Inheritance
-
- Object
- TdFunction
- SearchFileDownloads
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of files to be returned
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- onlyActive → bool
-
onlyActive Pass true to search only for active downloads, including
paused
final
- onlyCompleted → bool
-
onlyCompleted Pass true to search only for completed downloads
final
- query → String
-
query Query to search for; may be empty to return all downloaded files
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? query, bool? onlyActive, bool? onlyCompleted, String? offset, int? limit}) → SearchFileDownloads -
Available on SearchFileDownloads, provided by the SearchFileDownloadsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String