SearchGiftsForResale class final
Returns upgraded gifts that can be bought from other owners using sendResoldGift Returns GiftsForResale
- Inheritance
-
- Object
- TdFunction
- SearchGiftsForResale
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SearchGiftsForResale({required int giftId, GiftForResaleOrder? order, required bool forCrafting, required bool forStars, required List<
UpgradedGiftAttributeId> attributes, required String offset, required int limit})
Properties
-
attributes
→ List<
UpgradedGiftAttributeId> -
attributes Attributes used to filter received gifts. If multiple
attributes of the same type are specified, then all of them are allowed.
If none attributes of specific type are specified, then all values for
this attribute type are allowed
final
- forCrafting → bool
-
forCrafting Pass true to get only gifts suitable for crafting
final
- forStars → bool
-
forStars Pass true to get only gifts that can be bought using Telegram
Stars
final
- giftId → int
-
giftId Identifier of the regular gift that was upgraded to a unique gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of gifts to return
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request with the same order and attributes; use empty string to get the
first chunk of results
final
- order → GiftForResaleOrder?
-
order Order in which the results will be sorted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? giftId, GiftForResaleOrder? order, bool? forCrafting, bool? forStars, List< UpgradedGiftAttributeId> ? attributes, String? offset, int? limit}) → SearchGiftsForResale -
Available on SearchGiftsForResale, provided by the SearchGiftsForResaleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String