SearchInstalledStickerSets class final

Searches for installed sticker sets by looking for specified query in their title and name Returns StickerSets

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchInstalledStickerSets({StickerType? stickerType, required String query, required int limit})

Properties

hashCode int
The hash code for this object.
no setteroverride
limit int
limit The maximum number of sticker sets to return
final
query String
query Query to search for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickerType StickerType?
stickerType Type of the sticker sets to search for
final

Methods

copyWith({StickerType? stickerType, String? query, int? limit}) SearchInstalledStickerSets

Available on SearchInstalledStickerSets, provided by the SearchInstalledStickerSetsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String