SearchPublicChats class final
Searches public chats by looking for specified query in their username and title. Currently, only private chats, supergroups and channels can be public. Returns a meaningful number of results. Excludes private chats with contacts and chats from the chat list from the results Returns Chats
- Inheritance
-
- Object
- TdFunction
- SearchPublicChats
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchPublicChats({required String query, SearchChatTypeFilter? typeFilter})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- query → String
-
query Query to search for
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeFilter → SearchChatTypeFilter?
-
typeFilter Additional filter for type of the chats to be returned; pass
null to search for chats of all types
final
Methods
-
copyWith(
{String? query, SearchChatTypeFilter? typeFilter}) → SearchPublicChats -
Available on SearchPublicChats, provided by the SearchPublicChatsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String