SearchPublicStoriesByVenue class final
Searches for public stories from the given venue. For optimal performance, the number of returned stories is chosen by TDLib and can be smaller than the specified limit Returns FoundStories
- Inheritance
-
- Object
- TdFunction
- SearchPublicStoriesByVenue
- Available extensions
- Annotations
-
- @immutable
Constructors
- SearchPublicStoriesByVenue({required String venueProvider, required String venueId, required String offset, required int limit})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- limit → int
-
limit The maximum number of stories to be returned; up to 100. For
optimal performance, the number of returned stories is chosen by TDLib and
can be smaller than the specified limit
final
- offset → String
-
offset Offset of the first entry to return as received from the previous
request; use empty string to get the first chunk of results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- venueId → String
-
venueId Identifier of the venue in the provider database
final
- venueProvider → String
-
venueProvider Provider of the venue
final
Methods
-
copyWith(
{String? venueProvider, String? venueId, String? offset, int? limit}) → SearchPublicStoriesByVenue -
Available on SearchPublicStoriesByVenue, provided by the SearchPublicStoriesByVenueExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String