SearchStickerSet class final

Searches for a sticker set by its name Returns StickerSet

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SearchStickerSet({required String name, required bool ignoreCache})

Properties

hashCode int
The hash code for this object.
no setteroverride
ignoreCache bool
ignoreCache Pass true to ignore local cache of sticker sets and always send a network request
final
name String
name Name of the sticker set
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, bool? ignoreCache}) SearchStickerSet

Available on SearchStickerSet, provided by the SearchStickerSetExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String