SearchStickers class final
Searches for stickers from public sticker sets that correspond to any of the given emoji Returns Stickers
- Inheritance
-
- Object
- TdFunction
- SearchStickers
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SearchStickers({StickerType? stickerType, required String emojis, required String query, required List<
String> inputLanguageCodes, required int offset, required int limit})
Properties
- emojis → String
-
emojis Space-separated list of emojis to search for
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
inputLanguageCodes
→ List<
String> -
inputLanguageCodes List of possible IETF language tags of the user's
input language; may be empty if unknown
final
- limit → int
-
limit The maximum number of stickers to be returned; 0-100
final
- offset → int
-
offset The offset from which to return the stickers; must be
non-negative
final
- query → String
-
query Query to search for; may be empty to search for emoji only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stickerType → StickerType?
-
stickerType Type of the stickers to return
final
Methods
-
copyWith(
{StickerType? stickerType, String? emojis, String? query, List< String> ? inputLanguageCodes, int? offset, int? limit}) → SearchStickers -
Available on SearchStickers, provided by the SearchStickersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String