SecretChat class final

Represents a secret chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SecretChat({required int id, required int userId, SecretChatState? state, required bool isOutbound, required String keyHash, required int layer})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Secret chat identifier
final
isOutbound bool
isOutbound True, if the chat was created by the current user; false otherwise
final
keyHash String
keyHash Hash of the currently used key for comparison with the hash of the chat partner's key. This is a string of 36 little-endian bytes, which must be split into groups of 2 bits, each denoting a pixel of one of 4 colors FFFFFF, D5E6F3, 2D5775, and 2F99C9. The pixels must be used to make a 12x12 square image filled from left to right, top to bottom. Alternatively, the first 32 bytes of the hash can be converted to the hexadecimal format and printed as 32 2-digit hex numbers
final
layer int
layer Secret chat layer; determines features supported by the chat partner's application. Nested text entities and underline and strikethrough entities are supported if the layer files bigger than 2000MB are supported if the layer
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state SecretChatState?
state State of the secret chat
final
userId int
userId Identifier of the chat partner
final

Methods

copyWith({int? id, int? userId, SecretChatState? state, bool? isOutbound, String? keyHash, int? layer}) SecretChat

Available on SecretChat, provided by the SecretChatExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) SecretChat?

Constants

constructor → const String