SellGift class final
Sells a gift for Telegram Stars; requires owner privileges for gifts owned by a chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- SellGift
- Available extensions
- Annotations
-
- @immutable
Properties
- businessConnectionId → String?
-
businessConnectionId Unique identifier of business connection on behalf
of which to send the request; for bots only
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- receivedGiftId → String
-
receivedGiftId Identifier of the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId, String? receivedGiftId}) → SellGift -
Available on SellGift, provided by the SellGiftExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String