SendBusinessMessageAlbum class final
Sends 2-10 messages grouped together into an album on behalf of a business account; for bots only. Currently, only audio, document, photo and video messages can be grouped into an album. Documents and audio files can be only grouped in an album with messages of the same type. Returns sent messages Returns BusinessMessages
- Inheritance
-
- Object
- TdFunction
- SendBusinessMessageAlbum
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SendBusinessMessageAlbum({required String businessConnectionId, required int chatId, InputMessageReplyTo? replyTo, required bool disableNotification, required bool protectContent, required int effectId, required List<
InputMessageContent> inputMessageContents})
Properties
- businessConnectionId → String
-
businessConnectionId Unique identifier of business connection on behalf
of which to send the request
final
- chatId → int
-
chatId Target chat
final
- disableNotification → bool
-
disableNotification Pass true to disable notification for the message
final
- effectId → int
-
effectId Identifier of the effect to apply to the message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
inputMessageContents
→ List<
InputMessageContent> -
inputMessageContents Contents of messages to be sent. At most 10
messages can be added to an album. All messages must have the same value
of show_caption_above_media
final
- protectContent → bool
-
protectContent Pass true if the content of the message must be protected
from forwarding and saving
final
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message to be replied; pass null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId, int? chatId, InputMessageReplyTo? replyTo, bool? disableNotification, bool? protectContent, int? effectId, List< InputMessageContent> ? inputMessageContents}) → SendBusinessMessageAlbum -
Available on SendBusinessMessageAlbum, provided by the SendBusinessMessageAlbumExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String