SendCallDebugInformation class final
Sends debug information for a call to Telegram servers Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendCallDebugInformation
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendCallDebugInformation({InputCall? callId, required String debugInformation})
Properties
- callId → InputCall?
-
callId Call identifier
final
- debugInformation → String
-
debugInformation Debug information in application-specific format
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputCall? callId, String? debugInformation}) → SendCallDebugInformation -
Available on SendCallDebugInformation, provided by the SendCallDebugInformationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String