SendCallRating class final
Sends a call rating Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendCallRating
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SendCallRating({InputCall? callId, required int rating, String? comment, required List<
CallProblem> problems})
Properties
- callId → InputCall?
-
callId Call identifier
final
- comment → String?
-
comment An optional user comment if the rating is less than 5
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
problems
→ List<
CallProblem> -
problems List of the exact types of problems with the call, specified by
the user
final
- rating → int
-
rating Call rating; 1-5
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputCall? callId, int? rating, String? comment, List< CallProblem> ? problems}) → SendCallRating -
Available on SendCallRating, provided by the SendCallRatingExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String