SendEphemeralMessage class final

Sends an ephemeral message which will be received only by one bot in a chat. Currently, only ephemeral bot commands and replies to bot ephemeral messages can be sent using the method. The message is persistent across application restarts only if the message database is used. Returns the sent message Returns Message

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendEphemeralMessage({required int chatId, MessageTopic? topicId, required int receiverUserId, int? callbackQueryId, InputMessageReplyTo? replyTo, required int sendingId, required bool onlyPreview, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})

Properties

callbackQueryId int?
callbackQueryId Identifier of the callback query which triggered the message; for bots only
final
chatId int
chatId Target chat
final
hashCode int
The hash code for this object.
no setteroverride
inputMessageContent InputMessageContent?
inputMessageContent The content of the message to be sent. Must be one of the following types: inputMessageText, inputMessageAnimation, inputMessageAudio, inputMessageDocument, inputMessagePhoto, inputMessageSticker, inputMessageVideo, inputMessageVideoNote, inputMessageVoiceNote, inputMessageLocation, inputMessageVenue, inputMessageContact
final
onlyPreview bool
onlyPreview Pass true to get a fake message instead of actually sending them
final
receiverUserId int
receiverUserId Identifier of the user who will receive the message
final
replyMarkup ReplyMarkup?
replyMarkup Markup for replying to the message; pass null if none; for bots only
final
replyTo InputMessageReplyTo?
replyTo Information about the message to be replied; pass null if none. The message can be an incoming ephemeral message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendingId int
sendingId Non-persistent identifier, which will be returned back in messageSendingStatePending object and can be used to match sent messages and corresponding updateNewMessage updates
final
topicId MessageTopic?
topicId Topic in which the message will be sent; pass null if none
final

Methods

copyWith({int? chatId, MessageTopic? topicId, int? receiverUserId, int? callbackQueryId, InputMessageReplyTo? replyTo, int? sendingId, bool? onlyPreview, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) SendEphemeralMessage

Available on SendEphemeralMessage, provided by the SendEphemeralMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String