SendGiftPurchaseOffer class final
Sends an offer to purchase an upgraded gift Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendGiftPurchaseOffer
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendGiftPurchaseOffer({MessageSender? ownerId, required String giftName, GiftResalePrice? price, required int duration, required int paidMessageStarCount})
Properties
- duration → int
-
duration Duration of the offer, in seconds; must be one of 21600, 43200,
86400, 129600, 172800, or 259200. Can also be 120 if Telegram test
environment is used
final
- giftName → String
-
giftName Name of the upgraded gift
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- ownerId → MessageSender?
-
ownerId Identifier of the user or the channel chat that currently owns
the gift and will receive the offer
final
- paidMessageStarCount → int
-
paidMessageStarCount The number of Telegram Stars the user agreed to pay
additionally for sending of the offer message to the current gift owner;
pass userFullInfo.outgoing_paid_message_star_count for users and 0
otherwise
final
- price → GiftResalePrice?
-
price The price that the user agreed to pay for the gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageSender? ownerId, String? giftName, GiftResalePrice? price, int? duration, int? paidMessageStarCount}) → SendGiftPurchaseOffer -
Available on SendGiftPurchaseOffer, provided by the SendGiftPurchaseOfferExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String