SendInlineQueryResultMessage class final
Sends the result of an inline query as a message. Returns the sent message. Always clears a chat draft message Returns Message
- Inheritance
-
- Object
- TdFunction
- SendInlineQueryResultMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendInlineQueryResultMessage({required int chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, required int queryId, required String resultId, required bool hideViaBot})
Properties
- chatId → int
-
chatId Target chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hideViaBot → bool
-
hideViaBot Pass true to hide the bot, via which the message is sent. Can
be used only for bots getOption("animation_search_bot_username"),
getOption("photo_search_bot_username"), and
getOption("venue_search_bot_username")
final
- options → MessageSendOptions?
-
options Options to be used to send the message; pass null to use default
options
final
- queryId → int
-
queryId Identifier of the inline query
final
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message or story to be replied; pass null
if none
final
- resultId → String
-
resultId Identifier of the inline query result
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Topic in which the message will be sent; pass null if none
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, int? queryId, String? resultId, bool? hideViaBot}) → SendInlineQueryResultMessage -
Available on SendInlineQueryResultMessage, provided by the SendInlineQueryResultMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String