SendMessage class final
Sends a message. Returns the sent message Returns Message
- Inheritance
-
- Object
- TdFunction
- SendMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendMessage({required int chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent})
Properties
- chatId → int
-
chatId Target chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- inputMessageContent → InputMessageContent?
-
inputMessageContent The content of the message to be sent
final
- options → MessageSendOptions?
-
options Options to be used to send the message; pass null to use default
options
final
- replyMarkup → ReplyMarkup?
-
replyMarkup Markup for replying to the message; pass null if none; for
bots only
final
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message or story to be replied; pass null
if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Topic in which the message will be sent; pass null if none
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, ReplyMarkup? replyMarkup, InputMessageContent? inputMessageContent}) → SendMessage -
Available on SendMessage, provided by the SendMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String