SendMessageAlbum class final
Sends 2-10 messages grouped together into an album. Currently, only audio, document, photo and video messages can be grouped into an album. Documents and audio files can be only grouped in an album with messages of the same type. Returns sent messages Returns Messages
- Inheritance
-
- Object
- TdFunction
- SendMessageAlbum
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SendMessageAlbum({required int chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, required List<
InputMessageContent> inputMessageContents})
Properties
- chatId → int
-
chatId Target chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
-
inputMessageContents
→ List<
InputMessageContent> -
inputMessageContents Contents of messages to be sent. At most 10
messages can be added to an album. All messages must have the same value
of show_caption_above_media
final
- options → MessageSendOptions?
-
options Options to be used to send the messages; pass null to use
default options
final
- replyTo → InputMessageReplyTo?
-
replyTo Information about the message or story to be replied; pass null
if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → MessageTopic?
-
topicId Topic in which the messages will be sent; pass null if none
final
Methods
-
copyWith(
{int? chatId, MessageTopic? topicId, InputMessageReplyTo? replyTo, MessageSendOptions? options, List< InputMessageContent> ? inputMessageContents}) → SendMessageAlbum -
Available on SendMessageAlbum, provided by the SendMessageAlbumExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String