SendPhoneNumberFirebaseSms class final
Sends Firebase Authentication SMS to the specified phone number. Works only when received a code of the type authenticationCodeTypeFirebaseAndroid or authenticationCodeTypeFirebaseIos Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendPhoneNumberFirebaseSms
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendPhoneNumberFirebaseSms({required String token})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
token Play Integrity API or SafetyNet Attestation API token for the
Android application, or secret from push notification for the iOS
application
final
Methods
-
copyWith(
{String? token}) → SendPhoneNumberFirebaseSms -
Available on SendPhoneNumberFirebaseSms, provided by the SendPhoneNumberFirebaseSmsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String