SendQuickReplyShortcutMessages class final

Sends messages from a quick reply shortcut. Requires Telegram Business subscription. Can't be used to send paid messages Returns Messages

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SendQuickReplyShortcutMessages({required int chatId, required int shortcutId, required int sendingId})

Properties

chatId int
chatId Identifier of the chat to which to send messages. The chat must be a private chat with a regular user
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendingId int
sendingId Non-persistent identifier, which will be returned back in messageSendingStatePending object and can be used to match sent messages and corresponding updateNewMessage updates
final
shortcutId int
shortcutId Unique identifier of the quick reply shortcut
final

Methods

copyWith({int? chatId, int? shortcutId, int? sendingId}) SendQuickReplyShortcutMessages

Available on SendQuickReplyShortcutMessages, provided by the SendQuickReplyShortcutMessagesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String