SendRichMessageDraft class final
Sends a draft for a being generated rich message; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendRichMessageDraft
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendRichMessageDraft({required int chatId, required int forumTopicId, required int draftId, InputRichMessage? message})
Properties
- chatId → int
-
chatId Chat identifier
final
- draftId → int
-
draftId Unique identifier of the draft
final
- forumTopicId → int
-
forumTopicId The forum topic identifier in which the message will be
sent; pass 0 if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- message → InputRichMessage?
-
message Draft of the message; file upload isn't supported
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId, int? draftId, InputRichMessage? message}) → SendRichMessageDraft -
Available on SendRichMessageDraft, provided by the SendRichMessageDraftExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String