SendWebAppData class final
Sends data received from a keyboardButtonTypeWebApp Web App to a bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- SendWebAppData
- Available extensions
- Annotations
-
- @immutable
Constructors
- SendWebAppData({required int botUserId, required String buttonText, required String data})
Properties
- botUserId → int
-
botUserId Identifier of the target bot
final
-
buttonText Text of the keyboardButtonTypeWebApp button, which opened the
Web App
final
- data → String
-
data The data
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? buttonText, String? data}) → SendWebAppData -
Available on SendWebAppData, provided by the SendWebAppDataExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String