deviceType property
deviceType Session device type based on the system and application version, which can be used to display a corresponding icon
Implementation
final SessionDeviceType? deviceType;
deviceType Session device type based on the system and application version, which can be used to display a corresponding icon
final SessionDeviceType? deviceType;