SessionTypeConnectedBot class final
A business bot connected to the current user's account
- Inheritance
-
- Object
- TdObject
- SessionType
- SessionTypeConnectedBot
- Available extensions
- Annotations
-
- @immutable
Constructors
- SessionTypeConnectedBot({required int botUserId})
Properties
- botUserId → int
-
botUserId User identifier of the bot. Use deleteBusinessConnectedBot to
remove it or confirmBusinessConnectedBot to confirm it if it isn't
confirmed yet
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId}) → SessionTypeConnectedBot -
Available on SessionTypeConnectedBot, provided by the SessionTypeConnectedBotExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult connectedBot(SessionTypeConnectedBot value), required TResult device(SessionTypeDevice value)}) → TResult -
Available on SessionType, provided by the SessionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult connectedBot(SessionTypeConnectedBot value)?, TResult device(SessionTypeDevice value)?, required TResult orElse()}) → TResult -
Available on SessionType, provided by the SessionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SessionTypeConnectedBot? -
Inherited by:
SessionTypeConnectedBot
SessionTypeDevice
override
Constants
- constructor → const String