SetApplicationVerificationToken class final
Informs TDLib that application or reCAPTCHA verification has been completed. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetApplicationVerificationToken
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetApplicationVerificationToken({required int verificationId, required String token})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
token Play Integrity API token for the Android application, or secret
from push notification for the iOS application for application
verification, or reCAPTCHA token for reCAPTCHA verifications; pass an
empty string to abort verification and receive the error
"VERIFICATION_FAILED" for the request
final
- verificationId → int
-
verificationId Unique identifier for the verification process as
received from updateApplicationVerificationRequired or
updateApplicationRecaptchaVerificationRequired
final
Methods
-
copyWith(
{int? verificationId, String? token}) → SetApplicationVerificationToken -
Available on SetApplicationVerificationToken, provided by the SetApplicationVerificationTokenExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String