SetAuthenticationEmailAddress class final
Sets the email address of the user and sends an authentication code to the email address. Works only when the current authorization state is authorizationStateWaitEmailAddress Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetAuthenticationEmailAddress
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetAuthenticationEmailAddress({required String emailAddress})
Properties
- emailAddress → String
-
emailAddress The email address of the user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? emailAddress}) → SetAuthenticationEmailAddress -
Available on SetAuthenticationEmailAddress, provided by the SetAuthenticationEmailAddressExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String