SetAuthenticationPhoneNumber class final
Sets the phone number of the user and sends an authentication code to the user. Works only when the current authorization state is authorizationStateWaitPhoneNumber, or if there is no pending authentication query and the current authorization state is authorizationStateWaitPremiumPurchase, authorizationStateWaitEmailAddress, authorizationStateWaitEmailCode, authorizationStateWaitCode, authorizationStateWaitRegistration, or authorizationStateWaitPassword Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetAuthenticationPhoneNumber
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetAuthenticationPhoneNumber({required String phoneNumber, PhoneNumberAuthenticationSettings? settings})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- phoneNumber → String
-
phoneNumber The phone number of the user, in international format
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → PhoneNumberAuthenticationSettings?
-
settings Settings for the authentication of the user's phone number;
pass null to use default settings
final
Methods
-
copyWith(
{String? phoneNumber, PhoneNumberAuthenticationSettings? settings}) → SetAuthenticationPhoneNumber -
Available on SetAuthenticationPhoneNumber, provided by the SetAuthenticationPhoneNumberExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String