SetAutoDownloadSettings class final
Sets auto-download settings Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetAutoDownloadSettings
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetAutoDownloadSettings({AutoDownloadSettings? settings, NetworkType? type})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → AutoDownloadSettings?
-
settings New user auto-download settings
final
- type → NetworkType?
-
type Type of the network for which the new settings are relevant
final
Methods
-
copyWith(
{AutoDownloadSettings? settings, NetworkType? type}) → SetAutoDownloadSettings -
Available on SetAutoDownloadSettings, provided by the SetAutoDownloadSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String