SetBirthdate class final
Changes the birthdate of the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBirthdate
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBirthdate({Birthdate? birthdate})
Properties
Methods
-
copyWith(
{Birthdate? birthdate}) → SetBirthdate -
Available on SetBirthdate, provided by the SetBirthdateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String