SetBotInfoDescription class final
Sets the text shown in the chat with a bot if the chat is empty. Can be called only if userTypeBot.can_be_edited == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBotInfoDescription
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBotInfoDescription({required int botUserId, required String languageCode, required String description})
Properties
- botUserId → int
-
botUserId Identifier of the target bot
final
- description → String
-
param_description New bot's description on the specified language
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- languageCode → String
-
languageCode A two-letter ISO 639-1 language code. If empty, the
description will be shown to all users for whose languages there is no
dedicated description
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, String? languageCode, String? description}) → SetBotInfoDescription -
Available on SetBotInfoDescription, provided by the SetBotInfoDescriptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String