SetBusinessAccountName class final
Changes the first and last name of a business account; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBusinessAccountName
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBusinessAccountName({required String businessConnectionId, required String firstName, String? lastName})
Properties
- businessConnectionId → String
-
businessConnectionId Unique identifier of business connection
final
- firstName → String
-
firstName The new value of the first name for the business account; 1-64
characters
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- lastName → String?
-
lastName The new value of the optional last name for the business
account; 0-64 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? businessConnectionId, String? firstName, String? lastName}) → SetBusinessAccountName -
Available on SetBusinessAccountName, provided by the SetBusinessAccountNameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String