SetBusinessConnectedBot class final
Adds or changes business bot that is connected to the current user account Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBusinessConnectedBot
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- bot → BusinessConnectedBot?
-
bot Connection settings for the bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BusinessConnectedBot? bot}) → SetBusinessConnectedBot -
Available on SetBusinessConnectedBot, provided by the SetBusinessConnectedBotExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String