SetBusinessLocation class final
Changes the business location of the current user. Requires Telegram Business subscription Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBusinessLocation
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBusinessLocation({BusinessLocation? location})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → BusinessLocation?
-
location The new location of the business; pass null to remove the
location
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BusinessLocation? location}) → SetBusinessLocation -
Available on SetBusinessLocation, provided by the SetBusinessLocationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String