SetBusinessOpeningHours class final
Changes the business opening hours of the current user. Requires Telegram Business subscription Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetBusinessOpeningHours
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetBusinessOpeningHours({BusinessOpeningHours? openingHours})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- openingHours → BusinessOpeningHours?
-
openingHours The new opening hours of the business; pass null to remove
the opening hours; up to 28 time intervals can be specified
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BusinessOpeningHours? openingHours}) → SetBusinessOpeningHours -
Available on SetBusinessOpeningHours, provided by the SetBusinessOpeningHoursExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String