SetChatAccentColor class final
Changes accent color and background custom emoji of a channel chat. Requires can_change_info administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatAccentColor
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatAccentColor({required int chatId, required int accentColorId, required int backgroundCustomEmojiId})
Properties
- accentColorId → int
-
accentColorId Identifier of the accent color to use. The chat must have
at least accentColor.min_channel_chat_boost_level boost level to pass the
corresponding color
final
- backgroundCustomEmojiId → int
-
backgroundCustomEmojiId Identifier of a custom emoji to be shown on the
reply header and link preview background; 0 if none. Use
chatBoostLevelFeatures.can_set_background_custom_emoji to check whether a
custom emoji can be set
final
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? accentColorId, int? backgroundCustomEmojiId}) → SetChatAccentColor -
Available on SetChatAccentColor, provided by the SetChatAccentColorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String