SetChatDirectMessagesGroup class final
Changes direct messages group settings for a channel chat; requires owner privileges in the chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatDirectMessagesGroup
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatDirectMessagesGroup({required int chatId, required bool isEnabled, required int paidMessageStarCount})
Properties
- chatId → int
-
chatId Identifier of the channel chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isEnabled → bool
-
isEnabled Pass true if the direct messages group is enabled for the
channel chat; pass false otherwise
final
- paidMessageStarCount → int
-
paidMessageStarCount The new number of Telegram Stars that must be paid
for each message that is sent to the direct messages chat unless the
sender is an administrator of the channel chat;
0-getOption("paid_message_star_count_max"). The channel will receive
getOption("paid_message_earnings_per_mille") Telegram Stars for each 1000
Telegram Stars paid for message sending. Requires
supergroupFullInfo.can_enable_paid_messages for positive amounts
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? isEnabled, int? paidMessageStarCount}) → SetChatDirectMessagesGroup -
Available on SetChatDirectMessagesGroup, provided by the SetChatDirectMessagesGroupExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String