SetChatDiscussionGroup class final
Changes the discussion group of a channel chat; requires can_change_info administrator right in the channel if it is specified Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatDiscussionGroup
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatDiscussionGroup({required int chatId, required int discussionChatId})
Properties
- chatId → int
-
chatId Identifier of the channel chat. Pass 0 to remove a link from the
supergroup passed in the second argument to a linked channel chat
(requires can_pin_messages member right in the supergroup)
final
- discussionChatId → int
-
discussionChatId Identifier of a new channel's discussion group. Use 0
to remove the discussion group. Use the method getSuitableDiscussionChats
to find all suitable groups. Basic group chats must be first upgraded to
supergroup chats. If new chat members don't have access to old messages in
the supergroup, then toggleSupergroupIsAllHistoryAvailable must be used
first to change that
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? discussionChatId}) → SetChatDiscussionGroup -
Available on SetChatDiscussionGroup, provided by the SetChatDiscussionGroupExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String