SetChatEmojiStatus class final
Changes the emoji status of a chat. Use chatBoostLevelFeatures.can_set_emoji_status to check whether an emoji status can be set. Requires can_change_info administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatEmojiStatus
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatEmojiStatus({required int chatId, EmojiStatus? emojiStatus})
Properties
- chatId → int
-
chatId Chat identifier
final
- emojiStatus → EmojiStatus?
-
emojiStatus New emoji status; pass null to remove emoji status
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, EmojiStatus? emojiStatus}) → SetChatEmojiStatus -
Available on SetChatEmojiStatus, provided by the SetChatEmojiStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String