SetChatLocation class final
Changes the location of a chat. Available only for some location-based supergroups, use supergroupFullInfo.can_set_location to check whether the method is allowed to use Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatLocation
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatLocation({required int chatId, ChatLocation? location})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- location → ChatLocation?
-
location New location for the chat; must be valid and not null
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, ChatLocation? location}) → SetChatLocation -
Available on SetChatLocation, provided by the SetChatLocationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String