SetChatMemberStatus class final
Changes the status of a chat member; requires can_invite_users member right to add a chat member, can_promote_members administrator right to change administrator rights of the member, and can_restrict_members administrator right to change restrictions of a user. This function is currently not suitable for transferring chat ownership; use transferChatOwnership instead. Use addChatMember or banChatMember if some additional parameters need to be passed Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatMemberStatus
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatMemberStatus({required int chatId, MessageSender? memberId, ChatMemberStatus? status})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- memberId → MessageSender?
-
memberId Member identifier. Chats can be only banned and unbanned in
supergroups and channels
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ChatMemberStatus?
-
status The new status of the member in the chat
final
Methods
-
copyWith(
{int? chatId, MessageSender? memberId, ChatMemberStatus? status}) → SetChatMemberStatus -
Available on SetChatMemberStatus, provided by the SetChatMemberStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String