SetChatMemberTag class final
Changes the tag or custom title of a chat member; requires can_manage_tags administrator right to change tag of other users; for basic groups and supergroups only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatMemberTag
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatMemberTag({required int chatId, required int userId, required String tag})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
tag The new tag of the member in the chat; 0-16 characters without emoji
final
- userId → int
-
userId Identifier of the user, which tag is changed. Chats can't have
member tags
final
Methods
-
copyWith(
{int? chatId, int? userId, String? tag}) → SetChatMemberTag -
Available on SetChatMemberTag, provided by the SetChatMemberTagExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String