SetChatMessageAutoDeleteTime class final
Changes the message auto-delete or self-destruct (for secret chats) time in a chat. Requires change_info administrator right in basic groups, supergroups and channels. Message auto-delete time can't be changed in a chat with the current user (Saved Messages) and the chat 777000 (Telegram). Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatMessageAutoDeleteTime
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatMessageAutoDeleteTime({required int chatId, required int messageAutoDeleteTime})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageAutoDeleteTime → int
-
messageAutoDeleteTime New time value, in seconds; unless the chat is
secret, it must be from 0 up to 365 * 86400 and be divisible by 86400. If
0, then messages aren't deleted automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageAutoDeleteTime}) → SetChatMessageAutoDeleteTime -
Available on SetChatMessageAutoDeleteTime, provided by the SetChatMessageAutoDeleteTimeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String