SetChatPaidMessageStarCount class final
Changes the Telegram Star amount that must be paid to send a message to a supergroup chat; requires can_restrict_members administrator right and supergroupFullInfo.can_enable_paid_messages Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatPaidMessageStarCount
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatPaidMessageStarCount({required int chatId, required int paidMessageStarCount})
Properties
- chatId → int
-
chatId Identifier of the supergroup chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- paidMessageStarCount → int
-
paidMessageStarCount The new number of Telegram Stars that must be paid
for each message that is sent to the supergroup chat unless the sender is
an administrator of the chat; 0-getOption("paid_message_star_count_max").
The supergroup will receive getOption("paid_message_earnings_per_mille")
Telegram Stars for each 1000 Telegram Stars paid for message sending
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? paidMessageStarCount}) → SetChatPaidMessageStarCount -
Available on SetChatPaidMessageStarCount, provided by the SetChatPaidMessageStarCountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String