SetChatPinnedStories class final
Changes the list of pinned stories on a chat page; requires can_edit_stories administrator right in the chat Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatPinnedStories
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SetChatPinnedStories({required int chatId, required List<
int> storyIds})
Properties
- chatId → int
-
chatId Identifier of the chat that posted the stories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
storyIds
→ List<
int> -
storyIds New list of pinned stories. All stories must be posted to the
chat page first. There can be up to getOption("pinned_story_count_max")
pinned stories on a chat page
final
Methods
-
copyWith(
{int? chatId, List< int> ? storyIds}) → SetChatPinnedStories -
Available on SetChatPinnedStories, provided by the SetChatPinnedStoriesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String