SetChatProfileAccentColor class final
Changes accent color and background custom emoji for profile of a supergroup or channel chat. Requires can_change_info administrator right Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetChatProfileAccentColor
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetChatProfileAccentColor({required int chatId, required int profileAccentColorId, required int profileBackgroundCustomEmojiId})
Properties
- chatId → int
-
chatId Chat identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- profileAccentColorId → int
-
profileAccentColorId Identifier of the accent color to use for profile;
pass -1 if none. The chat must have at least
profileAccentColor.min_supergroup_chat_boost_level for supergroups or
profileAccentColor.min_channel_chat_boost_level for channels boost level
to pass the corresponding color
final
- profileBackgroundCustomEmojiId → int
-
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown
on the chat's profile photo background; 0 if none. Use
chatBoostLevelFeatures.can_set_profile_background_custom_emoji to check
whether a custom emoji can be set
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? profileAccentColorId, int? profileBackgroundCustomEmojiId}) → SetChatProfileAccentColor -
Available on SetChatProfileAccentColor, provided by the SetChatProfileAccentColorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String