SetCommands class final

Sets the list of commands supported by the bot for the given user scope and language; for bots only Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetCommands({BotCommandScope? scope, required String languageCode, required List<BotCommand> commands})

Properties

commands List<BotCommand>
commands List of the bot's commands
final
hashCode int
The hash code for this object.
no setteroverride
languageCode String
languageCode A two-letter ISO 639-1 language code. If empty, the commands will be applied to all users from the given scope, for which language there are no dedicated commands
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope BotCommandScope?
scope The scope to which the commands are relevant; pass null to change commands in the default bot command scope
final

Methods

copyWith({BotCommandScope? scope, String? languageCode, List<BotCommand>? commands}) SetCommands

Available on SetCommands, provided by the SetCommandsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String