SetCustomLanguagePackString class final
Adds, edits or deletes a string in a custom local language pack. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetCustomLanguagePackString
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetCustomLanguagePackString({required String languagePackId, LanguagePackString? newString})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- languagePackId → String
-
languagePackId Identifier of a previously added custom local language
pack in the current localization target
final
- newString → LanguagePackString?
-
newString New language pack string
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? languagePackId, LanguagePackString? newString}) → SetCustomLanguagePackString -
Available on SetCustomLanguagePackString, provided by the SetCustomLanguagePackStringExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String