SetDefaultBackground class final
Sets default background for chats; adds the background to the list of installed backgrounds Returns Background
- Inheritance
-
- Object
- TdFunction
- SetDefaultBackground
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDefaultBackground({InputBackground? background, BackgroundType? type, required bool forDarkTheme})
Properties
- background → InputBackground?
-
background The input background to use; pass null to create a new filled
background
final
- forDarkTheme → bool
-
forDarkTheme Pass true if the background is set for a dark theme
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → BackgroundType?
-
type Background type; pass null to use the default type of the remote
background; backgroundTypeChatTheme isn't supported
final
Methods
-
copyWith(
{InputBackground? background, BackgroundType? type, bool? forDarkTheme}) → SetDefaultBackground -
Available on SetDefaultBackground, provided by the SetDefaultBackgroundExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String