SetDefaultGroupAdministratorRights class final
Sets default administrator rights for adding the bot to basic group and supergroup chats; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetDefaultGroupAdministratorRights
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDefaultGroupAdministratorRights({ChatAdministratorRights? defaultGroupAdministratorRights})
Properties
- defaultGroupAdministratorRights → ChatAdministratorRights?
-
defaultGroupAdministratorRights Default administrator rights for adding
the bot to basic group and supergroup chats; pass null to remove default
rights
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{ChatAdministratorRights? defaultGroupAdministratorRights}) → SetDefaultGroupAdministratorRights -
Available on SetDefaultGroupAdministratorRights, provided by the SetDefaultGroupAdministratorRightsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String