SetDefaultMessageAutoDeleteTime class final
Changes the default message auto-delete time for new chats Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetDefaultMessageAutoDeleteTime
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDefaultMessageAutoDeleteTime({MessageAutoDeleteTime? messageAutoDeleteTime})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageAutoDeleteTime → MessageAutoDeleteTime?
-
messageAutoDeleteTime New default message auto-delete time; must be from
0 up to 365 * 86400 and be divisible by 86400. If 0, then messages aren't
deleted automatically
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{MessageAutoDeleteTime? messageAutoDeleteTime}) → SetDefaultMessageAutoDeleteTime -
Available on SetDefaultMessageAutoDeleteTime, provided by the SetDefaultMessageAutoDeleteTimeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String