SetDirectMessagesChatTopicIsMarkedAsUnread class final
Changes the marked as unread state of the topic in a channel direct messages chat administered by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetDirectMessagesChatTopicIsMarkedAsUnread
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetDirectMessagesChatTopicIsMarkedAsUnread({required int chatId, required int topicId, required bool isMarkedAsUnread})
Properties
- chatId → int
-
chatId Chat identifier of the channel direct messages chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isMarkedAsUnread → bool
-
isMarkedAsUnread New value of is_marked_as_unread
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topicId → int
-
topicId Topic identifier
final
Methods
-
copyWith(
{int? chatId, int? topicId, bool? isMarkedAsUnread}) → SetDirectMessagesChatTopicIsMarkedAsUnread -
Available on SetDirectMessagesChatTopicIsMarkedAsUnread, provided by the SetDirectMessagesChatTopicIsMarkedAsUnreadExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String