SetGroupCallParticipantVolumeLevel class final
Changes volume level of a participant of an active group call; not supported for live stories. If the current user can manage the group call or is the owner of the group call, then the participant's volume level will be changed for all users with the default volume level Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetGroupCallParticipantVolumeLevel
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetGroupCallParticipantVolumeLevel({required int groupCallId, MessageSender? participantId, required int volumeLevel})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- participantId → MessageSender?
-
participantId Participant identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volumeLevel → int
-
volumeLevel New participant's volume level; 1-20000 in hundreds of
percents
final
Methods
-
copyWith(
{int? groupCallId, MessageSender? participantId, int? volumeLevel}) → SetGroupCallParticipantVolumeLevel -
Available on SetGroupCallParticipantVolumeLevel, provided by the SetGroupCallParticipantVolumeLevelExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String