SetLogStream class final
Sets new log stream for internal logging of TDLib. Can be called synchronously Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetLogStream
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetLogStream({LogStream? logStream})
Properties
Methods
-
copyWith(
{LogStream? logStream}) → SetLogStream -
Available on SetLogStream, provided by the SetLogStreamExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String