SetManagedBotAccessSettings class final
Sets access settings of a managed bot; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetManagedBotAccessSettings
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetManagedBotAccessSettings({required int botUserId, BotAccessSettings? settings})
Properties
- botUserId → int
-
botUserId Identifier of the managed bot
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → BotAccessSettings?
-
settings New access settings
final
Methods
-
copyWith(
{int? botUserId, BotAccessSettings? settings}) → SetManagedBotAccessSettings -
Available on SetManagedBotAccessSettings, provided by the SetManagedBotAccessSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String