SetMessageFactCheck class final
Changes the fact-check of a message. Can be only used if messageProperties.can_set_fact_check == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetMessageFactCheck
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetMessageFactCheck({required int chatId, required int messageId, FormattedText? text})
Properties
- chatId → int
-
chatId The channel chat the message belongs to
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text New text of the fact-check; 0-getOption("fact_check_length_max")
characters; pass null to remove it. Only Bold, Italic, and TextUrl
entities with https://t.me/ links are supported
final
Methods
-
copyWith(
{int? chatId, int? messageId, FormattedText? text}) → SetMessageFactCheck -
Available on SetMessageFactCheck, provided by the SetMessageFactCheckExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String