SetMessageReactions class final
Sets reactions on a message; for bots only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetMessageReactions
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SetMessageReactions({required int chatId, required int messageId, required List<
ReactionType> reactionTypes, required bool isBig})
Properties
- chatId → int
-
chatId Identifier of the chat to which the message belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isBig → bool
-
isBig Pass true if the reactions are added with a big animation
final
- messageId → int
-
messageId Identifier of the message
final
-
reactionTypes
→ List<
ReactionType> -
reactionTypes Types of the reaction to set; pass an empty list to remove
the reactions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, List< ReactionType> ? reactionTypes, bool? isBig}) → SetMessageReactions -
Available on SetMessageReactions, provided by the SetMessageReactionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String