SetMessageSenderBotVerification class final
Changes the verification status of a user or a chat by an owned bot Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetMessageSenderBotVerification
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetMessageSenderBotVerification({required int botUserId, MessageSender? verifiedId, required String customDescription})
Properties
- botUserId → int
-
botUserId Identifier of the owned bot, which will verify the user or the
chat
final
- customDescription → String
-
customDescription Custom description of verification reason;
0-getOption("bot_verification_custom_description_length_max"). If empty,
then "was verified by organization "organization_name"" will be used as
description. Can be specified only if the bot is allowed to provide custom
description
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifiedId → MessageSender?
-
verifiedId Identifier of the user or the supergroup or channel chat,
which will be verified by the bot
final
Methods
-
copyWith(
{int? botUserId, MessageSender? verifiedId, String? customDescription}) → SetMessageSenderBotVerification -
Available on SetMessageSenderBotVerification, provided by the SetMessageSenderBotVerificationExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String