SetNetworkType class final
Sets the current network type. Can be called before authorization. Calling this method forces all network connections to reopen, mitigating the delay in switching between different networks, so it must be called whenever the network is changed, even if the network type remains the same. Network type is used to check whether the library can use the network at all and also for collecting detailed network data usage statistics Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetNetworkType
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetNetworkType({NetworkType? type})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → NetworkType?
-
type The new network type; pass null to set network type to
networkTypeOther
final
Methods
-
copyWith(
{NetworkType? type}) → SetNetworkType -
Available on SetNetworkType, provided by the SetNetworkTypeExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String