SetPassportElement class final
Adds an element to the user's Telegram Passport. May return an error with a message "PHONE_VERIFICATION_NEEDED" or "EMAIL_VERIFICATION_NEEDED" if the chosen phone number or the chosen email address must be verified first Returns PassportElement
- Inheritance
-
- Object
- TdFunction
- SetPassportElement
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetPassportElement({InputPassportElement? element, required String password})
Properties
- element → InputPassportElement?
-
element Input Telegram Passport element
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- password → String
-
password The 2-step verification password of the current user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InputPassportElement? element, String? password}) → SetPassportElement -
Available on SetPassportElement, provided by the SetPassportElementExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String