SetPassportElementErrors class final
Informs the user that some of the elements in their Telegram Passport contain errors; for bots only. The user will not be able to resend the elements, until the errors are fixed Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetPassportElementErrors
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SetPassportElementErrors({required int userId, required List<
InputPassportElementError> errors})
Properties
Methods
-
copyWith(
{int? userId, List< InputPassportElementError> ? errors}) → SetPassportElementErrors -
Available on SetPassportElementErrors, provided by the SetPassportElementErrorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String