SetPersonalChat class final
Changes the personal chat of the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetPersonalChat
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetPersonalChat({required int chatId})
Properties
Methods
-
copyWith(
{int? chatId}) → SetPersonalChat -
Available on SetPersonalChat, provided by the SetPersonalChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String