SetPinnedSavedMessagesTopics class final

Changes the order of pinned Saved Messages topics Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetPinnedSavedMessagesTopics({required List<int> savedMessagesTopicIds})

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedMessagesTopicIds List<int>
savedMessagesTopicIds Identifiers of the new pinned Saved Messages topics
final

Methods

copyWith({List<int>? savedMessagesTopicIds}) SetPinnedSavedMessagesTopics

Available on SetPinnedSavedMessagesTopics, provided by the SetPinnedSavedMessagesTopicsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String