SetProfileAccentColor class final
Changes accent color and background custom emoji for profile of the current user; for Telegram Premium users only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetProfileAccentColor
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetProfileAccentColor({required int profileAccentColorId, required int profileBackgroundCustomEmojiId})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- profileAccentColorId → int
-
profileAccentColorId Identifier of the accent color to use for profile;
pass -1 if none
final
- profileBackgroundCustomEmojiId → int
-
profileBackgroundCustomEmojiId Identifier of a custom emoji to be shown
on the user's profile photo background; 0 if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? profileAccentColorId, int? profileBackgroundCustomEmojiId}) → SetProfileAccentColor -
Available on SetProfileAccentColor, provided by the SetProfileAccentColorExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String