afterFileId property
afterFileId Identifier of the file from profile audio files after which the file will be positioned; pass 0 to move the file to the beginning of the list
Implementation
final int afterFileId;
afterFileId Identifier of the file from profile audio files after which the file will be positioned; pass 0 to move the file to the beginning of the list
final int afterFileId;