SetSavedMessagesTagLabel class final
Changes label of a Saved Messages tag; for Telegram Premium users only Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetSavedMessagesTagLabel
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetSavedMessagesTagLabel({ReactionType? tag, required String label})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- label → String
-
label New label for the tag; 0-12 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → ReactionType?
-
tag The tag which label will be changed
final
Methods
-
copyWith(
{ReactionType? tag, String? label}) → SetSavedMessagesTagLabel -
Available on SetSavedMessagesTagLabel, provided by the SetSavedMessagesTagLabelExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String