SetScopeNotificationSettings class final
Changes notification settings for chats of a given type Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetScopeNotificationSettings
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetScopeNotificationSettings({NotificationSettingsScope? scope, ScopeNotificationSettings? notificationSettings})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- notificationSettings → ScopeNotificationSettings?
-
notificationSettings The new notification settings for the given scope
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → NotificationSettingsScope?
-
scope Types of chats for which to change the notification settings
final
Methods
-
copyWith(
{NotificationSettingsScope? scope, ScopeNotificationSettings? notificationSettings}) → SetScopeNotificationSettings -
Available on SetScopeNotificationSettings, provided by the SetScopeNotificationSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String