SetStickerEmojis class final
Changes the list of emojis corresponding to a sticker. The sticker must belong to a regular or custom emoji sticker set that is owned by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetStickerEmojis
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetStickerEmojis({InputFile? sticker, required String emojis})
Properties
Methods
-
copyWith(
{InputFile? sticker, String? emojis}) → SetStickerEmojis -
Available on SetStickerEmojis, provided by the SetStickerEmojisExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String