SetStickerKeywords class final
Changes the list of keywords of a sticker. The sticker must belong to a regular or custom emoji sticker set that is owned by the current user Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetStickerKeywords
- Available extensions
- Annotations
-
- @immutable
Constructors
-
SetStickerKeywords({InputFile? sticker, required List<
String> keywords})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
keywords
→ List<
String> -
keywords List of up to 20 keywords with total length up to 64
characters, which can be used to find the sticker
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → InputFile?
-
sticker Sticker
final
Methods
-
copyWith(
{InputFile? sticker, List< String> ? keywords}) → SetStickerKeywords -
Available on SetStickerKeywords, provided by the SetStickerKeywordsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String