SetStoryAlbumName class final
Changes name of an album of stories. If the album is owned by a supergroup or a channel chat, then requires can_edit_stories administrator right in the chat. Returns the changed album Returns StoryAlbum
- Inheritance
-
- Object
- TdFunction
- SetStoryAlbumName
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetStoryAlbumName({required int chatId, required int storyAlbumId, required String name})
Properties
- chatId → int
-
chatId Identifier of the chat that owns the stories
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
name New name of the album; 1-12 characters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyAlbumId → int
-
storyAlbumId Identifier of the story album
final
Methods
-
copyWith(
{int? chatId, int? storyAlbumId, String? name}) → SetStoryAlbumName -
Available on SetStoryAlbumName, provided by the SetStoryAlbumNameExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String