SetStoryReaction class final

Changes chosen reaction on a story that has already been sent; not supported for live stories Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetStoryReaction({required int storyPosterChatId, required int storyId, ReactionType? reactionType, required bool updateRecentReactions})

Properties

hashCode int
The hash code for this object.
no setteroverride
reactionType ReactionType?
reactionType Type of the reaction to set; pass null to remove the reaction. Custom emoji reactions can be used only by Telegram Premium users. Paid reactions can't be set
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId The identifier of the story
final
storyPosterChatId int
storyPosterChatId The identifier of the poster of the story
final
updateRecentReactions bool
updateRecentReactions Pass true if the reaction needs to be added to recent reactions
final

Methods

copyWith({int? storyPosterChatId, int? storyId, ReactionType? reactionType, bool? updateRecentReactions}) SetStoryReaction

Available on SetStoryReaction, provided by the SetStoryReactionExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String