SetUserNote class final

Changes a note of a contact user Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

SetUserNote({required int userId, FormattedText? note})

Properties

hashCode int
The hash code for this object.
no setteroverride
note FormattedText?
note Note to set for the user; 0-getOption("user_note_text_length_max") characters. Only Bold, Italic, Underline, Strikethrough, Spoiler, CustomEmoji, and DateTime entities are allowed
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
userId User identifier
final

Methods

copyWith({int? userId, FormattedText? note}) SetUserNote

Available on SetUserNote, provided by the SetUserNoteExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String