SetVideoChatDefaultParticipant class final
Changes default participant identifier, on whose behalf a video chat in the chat will be joined Returns Ok
- Inheritance
-
- Object
- TdFunction
- SetVideoChatDefaultParticipant
- Available extensions
- Annotations
-
- @immutable
Constructors
- SetVideoChatDefaultParticipant({required int chatId, MessageSender? defaultParticipantId})
Properties
- chatId → int
-
chatId Chat identifier
final
- defaultParticipantId → MessageSender?
-
defaultParticipantId Default group call participant identifier to join
the video chats in the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, MessageSender? defaultParticipantId}) → SetVideoChatDefaultParticipant -
Available on SetVideoChatDefaultParticipant, provided by the SetVideoChatDefaultParticipantExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String