ShippingOption class final
One shipping option
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
ShippingOption({required String id, required String title, required List<
LabeledPricePart> priceParts})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Shipping option identifier
final
-
priceParts
→ List<
LabeledPricePart> -
priceParts A list of objects used to calculate the total shipping costs
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Option title
final
Methods
-
copyWith(
{String? id, String? title, List< LabeledPricePart> ? priceParts}) → ShippingOption -
Available on ShippingOption, provided by the ShippingOptionExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ShippingOption?
Constants
- constructor → const String