SpeechRecognitionResultPending class final
The speech recognition is ongoing
- Inheritance
-
- Object
- TdObject
- SpeechRecognitionResult
- SpeechRecognitionResultPending
- Available extensions
- Annotations
-
- @immutable
Constructors
- SpeechRecognitionResultPending({required String partialText})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- partialText → String
-
partialText Partially recognized text
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? partialText}) → SpeechRecognitionResultPending -
Available on SpeechRecognitionResultPending, provided by the SpeechRecognitionResultPendingExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult error(SpeechRecognitionResultError value), required TResult pending(SpeechRecognitionResultPending value), required TResult text(SpeechRecognitionResultText value)}) → TResult -
Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult error(SpeechRecognitionResultError value)?, TResult pending(SpeechRecognitionResultPending value)?, TResult text(SpeechRecognitionResultText value)?, required TResult orElse()}) → TResult -
Available on SpeechRecognitionResult, provided by the SpeechRecognitionResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → SpeechRecognitionResultPending? -
Inherited by:
SpeechRecognitionResultError
SpeechRecognitionResultPending
SpeechRecognitionResultText
override
Constants
- constructor → const String