streakPrizePerMille property
streakPrizePerMille The number of Grams received by the user for each 1000 Grams staked if the dice outcome is 6 three times in a row with the same stake
Implementation
final int streakPrizePerMille;
streakPrizePerMille The number of Grams received by the user for each 1000 Grams staked if the dice outcome is 6 three times in a row with the same stake
final int streakPrizePerMille;