StarAmount class final
Describes a possibly non-integer Telegram Star amount
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- StarAmount({required int starCount, required int nanostarCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nanostarCount → int
-
nanostarCount The number of 1/1000000000 shares of Telegram Stars; from
-999999999 to 999999999
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount The integer Telegram Star amount rounded to 0
final
Methods
-
copyWith(
{int? starCount, int? nanostarCount}) → StarAmount -
Available on StarAmount, provided by the StarAmountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StarAmount?
Constants
- constructor → const String