StarGiveawayPaymentOptions class final
Contains a list of options for creating of Telegram Star giveaway
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
StarGiveawayPaymentOptions({required List<
StarGiveawayPaymentOption> options})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
options
→ List<
StarGiveawayPaymentOption> -
options The list of options
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< StarGiveawayPaymentOption> ? options}) → StarGiveawayPaymentOptions -
Available on StarGiveawayPaymentOptions, provided by the StarGiveawayPaymentOptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StarGiveawayPaymentOptions?
Constants
- constructor → const String