StarSubscriptions class final
Represents a list of Telegram Star subscriptions
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
StarSubscriptions({StarAmount? starAmount, required List<
StarSubscription> subscriptions, required int requiredStarCount, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- requiredStarCount → int
-
requiredStarCount The number of Telegram Stars required to buy to extend
subscriptions expiring soon
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starAmount → StarAmount?
-
starAmount The amount of owned Telegram Stars
final
-
subscriptions
→ List<
StarSubscription> -
subscriptions List of subscriptions for Telegram Stars
final
Methods
-
copyWith(
{StarAmount? starAmount, List< StarSubscription> ? subscriptions, int? requiredStarCount, String? nextOffset}) → StarSubscriptions -
Available on StarSubscriptions, provided by the StarSubscriptionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StarSubscriptions?
Constants
- constructor → const String