StartLiveStoryResultFail class final
The live story failed to post with an error to be handled
- Inheritance
-
- Object
- TdObject
- StartLiveStoryResult
- StartLiveStoryResultFail
- Available extensions
- Annotations
-
- @immutable
Constructors
- StartLiveStoryResultFail({CanPostStoryResult? errorType})
Properties
- errorType → CanPostStoryResult?
-
errorType Type of the error; other error types may be returned as
regular errors
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{CanPostStoryResult? errorType}) → StartLiveStoryResultFail -
Available on StartLiveStoryResultFail, provided by the StartLiveStoryResultFailExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fail(StartLiveStoryResultFail value), required TResult ok(StartLiveStoryResultOk value)}) → TResult -
Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fail(StartLiveStoryResultFail value)?, TResult ok(StartLiveStoryResultOk value)?, required TResult orElse()}) → TResult -
Available on StartLiveStoryResult, provided by the StartLiveStoryResultExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StartLiveStoryResultFail? -
Inherited by:
StartLiveStoryResultFail
StartLiveStoryResultOk
override
Constants
- constructor → const String