StatisticalGraphData class final
A graph data
- Inheritance
-
- Object
- TdObject
- StatisticalGraph
- StatisticalGraphData
- Available extensions
- Annotations
-
- @immutable
Constructors
- StatisticalGraphData({required String jsonData, required String zoomToken})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- jsonData → String
-
jsonData Graph data in JSON format
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoomToken → String
-
zoomToken If non-empty, a token which can be used to receive a zoomed in
graph
final
Methods
-
copyWith(
{String? jsonData, String? zoomToken}) → StatisticalGraphData -
Available on StatisticalGraphData, provided by the StatisticalGraphDataExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult async(StatisticalGraphAsync value), required TResult data(StatisticalGraphData value), required TResult error(StatisticalGraphError value)}) → TResult -
Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult async(StatisticalGraphAsync value)?, TResult data(StatisticalGraphData value)?, TResult error(StatisticalGraphError value)?, required TResult orElse()}) → TResult -
Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StatisticalGraphData? -
Inherited by:
StatisticalGraphAsync
StatisticalGraphData
StatisticalGraphError
override
Constants
- constructor → const String