StatisticalGraphError class final
An error message to be shown to the user instead of the graph
- Inheritance
-
- Object
- TdObject
- StatisticalGraph
- StatisticalGraphError
- Available extensions
- Annotations
-
- @immutable
Constructors
- StatisticalGraphError({required String errorMessage})
Properties
- errorMessage → String
-
errorMessage The error message
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? errorMessage}) → StatisticalGraphError -
Available on StatisticalGraphError, provided by the StatisticalGraphErrorExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult async(StatisticalGraphAsync value), required TResult data(StatisticalGraphData value), required TResult error(StatisticalGraphError value)}) → TResult -
Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult async(StatisticalGraphAsync value)?, TResult data(StatisticalGraphData value)?, TResult error(StatisticalGraphError value)?, required TResult orElse()}) → TResult -
Available on StatisticalGraph, provided by the StatisticalGraphExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StatisticalGraphError? -
Inherited by:
StatisticalGraphAsync
StatisticalGraphData
StatisticalGraphError
override
Constants
- constructor → const String