Sticker class final
Describes a sticker
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- Sticker({required int id, required int setId, required int width, required int height, required String emoji, StickerFormat? format, StickerFullType? fullType, Thumbnail? thumbnail, File? sticker})
Properties
- emoji → String
-
emoji Emoji corresponding to the sticker; may be empty if unknown
final
- format → StickerFormat?
-
format Sticker format
final
- fullType → StickerFullType?
-
fullType Sticker's full type
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → int
-
height Sticker height; as defined by the sender
final
- id → int
-
id Unique sticker identifier within the set; 0 if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setId → int
-
setId Identifier of the sticker set to which the sticker belongs; 0 if
none
final
- sticker → File?
-
sticker File containing the sticker
final
- thumbnail → Thumbnail?
-
thumbnail Sticker thumbnail in WEBP or JPEG format; may be null
final
- width → int
-
width Sticker width; as defined by the sender
final
Methods
-
copyWith(
{int? id, int? setId, int? width, int? height, String? emoji, StickerFormat? format, StickerFullType? fullType, Thumbnail? thumbnail, File? sticker}) → Sticker -
Available on Sticker, provided by the StickerExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String