StickerFullTypeCustomEmoji class final

The sticker is a custom emoji to be used inside message text and caption. Currently, only Telegram Premium users can use custom emoji

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StickerFullTypeCustomEmoji({required int customEmojiId, required bool needsRepainting})

Properties

customEmojiId int
customEmojiId Identifier of the custom emoji
final
hashCode int
The hash code for this object.
no setteroverride
needsRepainting bool
needsRepainting True, if the sticker must be repainted to a text color in messages, the color of the Telegram Premium badge in emoji status, white color on chat photos, or another appropriate color in other places
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? customEmojiId, bool? needsRepainting}) StickerFullTypeCustomEmoji

Available on StickerFullTypeCustomEmoji, provided by the StickerFullTypeCustomEmojiExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult customEmoji(StickerFullTypeCustomEmoji value), required TResult mask(StickerFullTypeMask value), required TResult regular(StickerFullTypeRegular value)}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

maybeMap<TResult extends Object?>({TResult customEmoji(StickerFullTypeCustomEmoji value)?, TResult mask(StickerFullTypeMask value)?, TResult regular(StickerFullTypeRegular value)?, required TResult orElse()}) → TResult

Available on StickerFullType, provided by the StickerFullTypeExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String