StickerFullTypeRegular class final
The sticker is a regular sticker
- Inheritance
-
- Object
- TdObject
- StickerFullType
- StickerFullTypeRegular
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
premiumAnimation Premium animation of the sticker; may be null. If
present, only Telegram Premium users can use the sticker
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{}) → StickerFullTypeRegular -
Available on StickerFullTypeRegular, provided by the StickerFullTypeRegularExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult customEmoji(StickerFullTypeCustomEmoji value), required TResult mask(StickerFullTypeMask value), required TResult regular(StickerFullTypeRegular value)}) → TResult -
Available on StickerFullType, provided by the StickerFullTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult customEmoji(StickerFullTypeCustomEmoji value)?, TResult mask(StickerFullTypeMask value)?, TResult regular(StickerFullTypeRegular value)?, required TResult orElse()}) → TResult -
Available on StickerFullType, provided by the StickerFullTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StickerFullTypeRegular? -
Inherited by:
StickerFullTypeCustomEmoji
StickerFullTypeMask
StickerFullTypeRegular
override
Constants
- constructor → const String