isAllowedAsChatEmojiStatus property
isAllowedAsChatEmojiStatus True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only
Implementation
final bool isAllowedAsChatEmojiStatus;
isAllowedAsChatEmojiStatus True, if stickers in the sticker set are custom emoji that can be used as chat emoji status; for custom emoji sticker sets only
final bool isAllowedAsChatEmojiStatus;