StopPoll class final
Stops a poll Returns Ok
- Inheritance
-
- Object
- TdFunction
- StopPoll
- Available extensions
- Annotations
-
- @immutable
Constructors
- StopPoll({required int chatId, required int messageId, ReplyMarkup? replyMarkup})
Properties
- chatId → int
-
chatId Identifier of the chat to which the poll belongs
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- messageId → int
-
messageId Identifier of the message containing the poll. Use
messageProperties.can_be_edited to check whether the poll can be stopped
final
- replyMarkup → ReplyMarkup?
-
replyMarkup The new message reply markup; pass null if none; for bots
only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? messageId, ReplyMarkup? replyMarkup}) → StopPoll -
Available on StopPoll, provided by the StopPollExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String