StorageStatisticsByChat class final
Contains the storage usage statistics for a specific chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
StorageStatisticsByChat({required int chatId, required int size, required int count, required List<
StorageStatisticsByFileType> byFileType})
Properties
-
byFileType
→ List<
StorageStatisticsByFileType> -
byFileType Statistics split by file types
final
- chatId → int
-
chatId Chat identifier; 0 if none
final
- count → int
-
count Total number of files in the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
size Total size of the files in the chat, in bytes
final
Methods
-
copyWith(
{int? chatId, int? size, int? count, List< StorageStatisticsByFileType> ? byFileType}) → StorageStatisticsByChat -
Available on StorageStatisticsByChat, provided by the StorageStatisticsByChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorageStatisticsByChat?
Constants
- constructor → const String