StorePaymentPurposePremiumGiveaway class final
The user creating a Telegram Premium giveaway
- Inheritance
-
- Object
- TdObject
- StorePaymentPurpose
- StorePaymentPurposePremiumGiveaway
- Available extensions
- Annotations
-
- @immutable
Constructors
- StorePaymentPurposePremiumGiveaway({GiveawayParameters? parameters, required String currency, required int amount})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- parameters → GiveawayParameters?
-
parameters Giveaway parameters
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{GiveawayParameters? parameters, String? currency, int? amount}) → StorePaymentPurposePremiumGiveaway -
Available on StorePaymentPurposePremiumGiveaway, provided by the StorePaymentPurposePremiumGiveawayExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorePaymentPurposePremiumGiveaway? -
Inherited by:
StorePaymentPurposeGiftedStars
StorePaymentPurposePremiumGift
StorePaymentPurposePremiumGiftCodes
StorePaymentPurposePremiumGiveaway
StorePaymentPurposePremiumSubscription
StorePaymentPurposeStarGiveaway
StorePaymentPurposeStars
override
Constants
- constructor → const String