StorePaymentPurposeStars class final
The user buying Telegram Stars
- Inheritance
-
- Object
- TdObject
- StorePaymentPurpose
- StorePaymentPurposeStars
- Available extensions
- Annotations
-
- @immutable
Constructors
- StorePaymentPurposeStars({required String currency, required int amount, required int starCount, required int chatId})
Properties
- amount → int
-
amount Paid amount, in the smallest units of the currency
final
- chatId → int
-
chatId Identifier of the chat that is supposed to receive the Telegram
Stars; pass 0 if none
final
- currency → String
-
currency ISO 4217 currency code of the payment currency
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- starCount → int
-
starCount Number of bought Telegram Stars
final
Methods
-
copyWith(
{String? currency, int? amount, int? starCount, int? chatId}) → StorePaymentPurposeStars -
Available on StorePaymentPurposeStars, provided by the StorePaymentPurposeStarsExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult giftedStars(StorePaymentPurposeGiftedStars value), required TResult starGiveaway(StorePaymentPurposeStarGiveaway value), required TResult stars(StorePaymentPurposeStars value)}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult giftedStars(StorePaymentPurposeGiftedStars value)?, TResult starGiveaway(StorePaymentPurposeStarGiveaway value)?, TResult stars(StorePaymentPurposeStars value)?, required TResult orElse()}) → TResult -
Available on StorePaymentPurpose, provided by the StorePaymentPurposeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StorePaymentPurposeStars? -
Inherited by:
StorePaymentPurposeGiftedStars
StorePaymentPurposePremiumGift
StorePaymentPurposePremiumGiftCodes
StorePaymentPurposePremiumGiveaway
StorePaymentPurposePremiumSubscription
StorePaymentPurposeStarGiveaway
StorePaymentPurposeStars
override
Constants
- constructor → const String