Story class final
Represents a story
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
Story({required int id, required int posterChatId, MessageSender? posterId, required int date, required bool isBeingPosted, required bool isBeingEdited, required bool isEdited, required bool isPostedToChatPage, required bool isVisibleOnlyForSelf, required bool canBeAddedToAlbum, required bool canBeDeleted, required bool canBeEdited, required bool canBeForwarded, required bool canBeReplied, required bool canSetPrivacySettings, required bool canToggleIsPostedToChatPage, required bool canGetStatistics, required bool canGetInteractions, required bool hasExpiredViewers, StoryRepostInfo? repostInfo, StoryInteractionInfo? interactionInfo, ReactionType? chosenReactionType, StoryPrivacySettings? privacySettings, StoryContent? content, required List<
StoryArea> areas, FormattedText? caption, required List<int> albumIds})
Properties
-
albumIds
→ List<
int> -
albumIds Identifiers of story albums to which the story is added; only
for manageable stories
final
-
areas
→ List<
StoryArea> -
areas Clickable areas to be shown on the story content
final
- canBeAddedToAlbum → bool
-
canBeAddedToAlbum True, if the story can be added to an album using
createStoryAlbum and addStoryAlbumStories
final
- canBeDeleted → bool
-
canBeDeleted True, if the story can be deleted
final
- canBeEdited → bool
-
canBeEdited True, if the story can be edited
final
- canBeForwarded → bool
-
canBeForwarded True, if the story can be forwarded as a message or
reposted as a story. Otherwise, screenshotting and saving of the story
content must be also forbidden
final
- canBeReplied → bool
-
canBeReplied True, if the story can be replied in the chat with the user
who posted the story
final
- canGetInteractions → bool
-
canGetInteractions True, if interactions with the story can be received
through getStoryInteractions
final
- canGetStatistics → bool
-
canGetStatistics True, if the story statistics are available through
getStoryStatistics
final
- canSetPrivacySettings → bool
-
canSetPrivacySettings True, if the story privacy settings can be changed
final
- canToggleIsPostedToChatPage → bool
-
canToggleIsPostedToChatPage True, if the story's is_posted_to_chat_page
value can be changed
final
- caption → FormattedText?
-
caption Caption of the story
final
- chosenReactionType → ReactionType?
-
chosenReactionType Type of the chosen reaction; may be null if none
final
- content → StoryContent?
-
content Content of the story
final
- date → int
-
date Point in time (Unix timestamp) when the story was published
final
- hasExpiredViewers → bool
-
hasExpiredViewers True, if users who viewed the story can't be received,
because the story has expired more than
getOption("story_viewers_expiration_delay") seconds ago
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique story identifier among stories posted by the given chat
final
- interactionInfo → StoryInteractionInfo?
-
interactionInfo Information about interactions with the story; may be
null if the story isn't owned or there were no interactions
final
- isBeingEdited → bool
-
isBeingEdited True, if the story is being edited by the current user
final
- isBeingPosted → bool
-
isBeingPosted True, if the story is being posted by the current user
final
- isEdited → bool
-
isEdited True, if the story was edited
final
- isPostedToChatPage → bool
-
isPostedToChatPage True, if the story is saved in the profile of the
chat that posted it and will be available there after expiration
final
- isVisibleOnlyForSelf → bool
-
isVisibleOnlyForSelf True, if the story is visible only for the current
user
final
- posterChatId → int
-
posterChatId Identifier of the chat that posted the story
final
- posterId → MessageSender?
-
posterId Identifier of the user or chat that posted the story; may be
null if the story is posted on behalf of the poster_chat_id
final
- privacySettings → StoryPrivacySettings?
-
privacySettings Privacy rules affecting story visibility; may be
approximate for non-owned stories
final
- repostInfo → StoryRepostInfo?
-
repostInfo Information about the original story; may be null if the
story wasn't reposted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? id, int? posterChatId, MessageSender? posterId, int? date, bool? isBeingPosted, bool? isBeingEdited, bool? isEdited, bool? isPostedToChatPage, bool? isVisibleOnlyForSelf, bool? canBeAddedToAlbum, bool? canBeDeleted, bool? canBeEdited, bool? canBeForwarded, bool? canBeReplied, bool? canSetPrivacySettings, bool? canToggleIsPostedToChatPage, bool? canGetStatistics, bool? canGetInteractions, bool? hasExpiredViewers, StoryRepostInfo? repostInfo, StoryInteractionInfo? interactionInfo, ReactionType? chosenReactionType, StoryPrivacySettings? privacySettings, StoryContent? content, List< StoryArea> ? areas, FormattedText? caption, List<int> ? albumIds}) → Story -
Available on Story, provided by the StoryExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String