StoryAlbum class final

Describes album of stories

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryAlbum({required int id, required String name, Photo? photoIcon, Video? videoIcon})

Properties

hashCode int
The hash code for this object.
no setteroverride
id int
id Unique identifier of the album
final
name String
name Name of the album
final
photoIcon Photo?
photoIcon Icon of the album; may be null if none
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoIcon Video?
videoIcon Video icon of the album; may be null if none
final

Methods

copyWith({int? id, String? name, Photo? photoIcon, Video? videoIcon}) StoryAlbum

Available on StoryAlbum, provided by the StoryAlbumExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryAlbum?

Constants

constructor → const String