StoryContentLive class final
A live story
- Inheritance
-
- Object
- TdObject
- StoryContent
- StoryContentLive
- Available extensions
- Annotations
-
- @immutable
Constructors
- StoryContentLive({required int groupCallId, required bool isRtmpStream})
Properties
- groupCallId → int
-
groupCallId Identifier of the corresponding group call. The group call
can be received through the method getGroupCall
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isRtmpStream → bool
-
isRtmpStream True, if the call is an RTMP stream instead of an ordinary
group call
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, bool? isRtmpStream}) → StoryContentLive -
Available on StoryContentLive, provided by the StoryContentLiveExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult live(StoryContentLive value), required TResult photo(StoryContentPhoto value), required TResult unsupported(StoryContentUnsupported value), required TResult video(StoryContentVideo value)}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult live(StoryContentLive value)?, TResult photo(StoryContentPhoto value)?, TResult unsupported(StoryContentUnsupported value)?, TResult video(StoryContentVideo value)?, required TResult orElse()}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryContentLive? -
Inherited by:
StoryContentLive
StoryContentPhoto
StoryContentUnsupported
StoryContentVideo
override
Constants
- constructor → const String