StoryContentUnsupported class final
A story content that is not supported in the current TDLib version
- Inheritance
-
- Object
- TdObject
- StoryContent
- StoryContentUnsupported
- Available extensions
- Annotations
-
- @immutable
Constructors
- StoryContentUnsupported()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult live(StoryContentLive value), required TResult photo(StoryContentPhoto value), required TResult unsupported(StoryContentUnsupported value), required TResult video(StoryContentVideo value)}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult live(StoryContentLive value)?, TResult photo(StoryContentPhoto value)?, TResult unsupported(StoryContentUnsupported value)?, TResult video(StoryContentVideo value)?, required TResult orElse()}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryContentUnsupported? -
Inherited by:
StoryContentLive
StoryContentPhoto
StoryContentUnsupported
StoryContentVideo
override
Constants
- constructor → const String