StoryContentVideo class final
A video story
- Inheritance
-
- Object
- TdObject
- StoryContent
- StoryContentVideo
- Available extensions
- Annotations
-
- @immutable
Constructors
- StoryContentVideo({StoryVideo? video, StoryVideo? alternativeVideo})
Properties
- alternativeVideo → StoryVideo?
-
alternativeVideo Alternative version of the video in MPEG4 format,
encoded with H.264 codec; may be null
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- video → StoryVideo?
-
video The video in MPEG4 format
final
Methods
-
copyWith(
{StoryVideo? video, StoryVideo? alternativeVideo}) → StoryContentVideo -
Available on StoryContentVideo, provided by the StoryContentVideoExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult live(StoryContentLive value), required TResult photo(StoryContentPhoto value), required TResult unsupported(StoryContentUnsupported value), required TResult video(StoryContentVideo value)}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult live(StoryContentLive value)?, TResult photo(StoryContentPhoto value)?, TResult unsupported(StoryContentUnsupported value)?, TResult video(StoryContentVideo value)?, required TResult orElse()}) → TResult -
Available on StoryContent, provided by the StoryContentExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryContentVideo? -
Inherited by:
StoryContentLive
StoryContentPhoto
StoryContentUnsupported
StoryContentVideo
override
Constants
- constructor → const String