StoryInfo class final
Contains basic information about a story
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- date → int
-
date Point in time (Unix timestamp) when the story was published
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isForCloseFriends → bool
-
isForCloseFriends True, if the story is available only to close friends
final
- isLive → bool
-
isLive True, if the story is a live story
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storyId → int
-
storyId Unique story identifier among stories of the chat
final
Methods
-
copyWith(
{int? storyId, int? date, bool? isForCloseFriends, bool? isLive}) → StoryInfo -
Available on StoryInfo, provided by the StoryInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String