StoryInteractions class final
Represents a list of interactions with a story
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
StoryInteractions({required int totalCount, required int totalForwardCount, required int totalReactionCount, required List<
StoryInteraction> interactions, required String nextOffset})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
-
interactions
→ List<
StoryInteraction> -
interactions List of story interactions
final
- nextOffset → String
-
nextOffset The offset for the next request. If empty, then there are no
more results
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Approximate total number of interactions found
final
- totalForwardCount → int
-
totalForwardCount Approximate total number of found forwards and
reposts; always 0 for chat stories
final
- totalReactionCount → int
-
totalReactionCount Approximate total number of found reactions; always 0
for chat stories
final
Methods
-
copyWith(
{int? totalCount, int? totalForwardCount, int? totalReactionCount, List< StoryInteraction> ? interactions, String? nextOffset}) → StoryInteractions -
Available on StoryInteractions, provided by the StoryInteractionsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryInteractions?
Constants
- constructor → const String