StoryOriginPublicStory class final

The original story was a public story that was posted by a known chat

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

StoryOriginPublicStory({required int chatId, required int storyId})

Properties

chatId int
chatId Identifier of the chat that posted original story
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storyId int
storyId Story identifier of the original story
final

Methods

copyWith({int? chatId, int? storyId}) StoryOriginPublicStory

Available on StoryOriginPublicStory, provided by the StoryOriginPublicStoryExtensions extension

getConstructor() String
override
map<TResult extends Object?>({required TResult hiddenUser(StoryOriginHiddenUser value), required TResult publicStory(StoryOriginPublicStory value)}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

maybeMap<TResult extends Object?>({TResult hiddenUser(StoryOriginHiddenUser value)?, TResult publicStory(StoryOriginPublicStory value)?, required TResult orElse()}) → TResult

Available on StoryOrigin, provided by the StoryOriginExtensions extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) StoryOriginPublicStory?
Inherited by: StoryOriginHiddenUser StoryOriginPublicStory
override

Constants

constructor → const String