StoryVideo class final
Describes a video file posted as a story
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- coverFrameTimestamp → double
-
coverFrameTimestamp Timestamp of the frame used as video thumbnail
final
- duration → double
-
duration Duration of the video, in seconds
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasStickers → bool
-
hasStickers True, if stickers were added to the video. The list of
corresponding sticker sets can be received using getAttachedStickerSets
final
- height → int
-
height Video height
final
- isAnimation → bool
-
isAnimation True, if the video has no sound
final
- minithumbnail → Minithumbnail?
-
minithumbnail Video minithumbnail; may be null
final
- preloadPrefixSize → int
-
preloadPrefixSize Size of file prefix, which is expected to be
preloaded, in bytes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → Thumbnail?
-
thumbnail Video thumbnail in JPEG or MPEG4 format; may be null
final
- video → File?
-
video File containing the video
final
- width → int
-
width Video width
final
Methods
-
copyWith(
{double? duration, int? width, int? height, bool? hasStickers, bool? isAnimation, Minithumbnail? minithumbnail, Thumbnail? thumbnail, int? preloadPrefixSize, double? coverFrameTimestamp, File? video}) → StoryVideo -
Available on StoryVideo, provided by the StoryVideoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → StoryVideo?
Constants
- constructor → const String