joinToSendMessages property
joinToSendMessages True, if users need to join the supergroup before they can send messages. May be false only for discussion supergroups and channel direct messages groups
Implementation
final bool joinToSendMessages;
joinToSendMessages True, if users need to join the supergroup before they can send messages. May be false only for discussion supergroups and channel direct messages groups
final bool joinToSendMessages;