customEmojiStickerSetId property
customEmojiStickerSetId Identifier of the custom emoji sticker set that can be used in the supergroup without Telegram Premium subscription; 0 if none
Implementation
final int customEmojiStickerSetId;
customEmojiStickerSetId Identifier of the custom emoji sticker set that can be used in the supergroup without Telegram Premium subscription; 0 if none
final int customEmojiStickerSetId;