TargetChatTypes class final
Describes allowed types for the target chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- TargetChatTypes({required bool allowUserChats, required bool allowBotChats, required bool allowGroupChats, required bool allowChannelChats})
Properties
- allowBotChats → bool
-
allowBotChats True, if private chats with other bots are allowed
final
- allowChannelChats → bool
-
allowChannelChats True, if channel chats are allowed
final
- allowGroupChats → bool
-
allowGroupChats True, if basic group and supergroup chats are allowed
final
- allowUserChats → bool
-
allowUserChats True, if private chats with ordinary users are allowed
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? allowUserChats, bool? allowBotChats, bool? allowGroupChats, bool? allowChannelChats}) → TargetChatTypes -
Available on TargetChatTypes, provided by the TargetChatTypesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TargetChatTypes?
Constants
- constructor → const String