TemporaryPasswordState class final
Returns information about the availability of a temporary password, which can be used for payments
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- TemporaryPasswordState({required bool hasPassword, required int validFor})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasPassword → bool
-
hasPassword True, if a temporary password is available
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validFor → int
-
validFor Time left before the temporary password expires, in seconds
final
Methods
-
copyWith(
{bool? hasPassword, int? validFor}) → TemporaryPasswordState -
Available on TemporaryPasswordState, provided by the TemporaryPasswordStateExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TemporaryPasswordState?
Constants
- constructor → const String