TermsOfService class final

Contains Telegram terms of service

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TermsOfService({FormattedText? text, required int minUserAge, required bool showPopup})

Properties

hashCode int
The hash code for this object.
no setteroverride
minUserAge int
minUserAge The minimum age of a user to be able to accept the terms; 0 if age isn't restricted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPopup bool
showPopup True, if a blocking popup with terms of service must be shown to the user
final
text FormattedText?
text Text of the terms of service
final

Methods

copyWith({FormattedText? text, int? minUserAge, bool? showPopup}) TermsOfService

Available on TermsOfService, provided by the TermsOfServiceExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TermsOfService?

Constants

constructor → const String