TestProxy class final
Sends a simple network request to the Telegram servers via proxy; for testing only. Can be called before authorization Returns Ok
- Inheritance
-
- Object
- TdFunction
- TestProxy
- Available extensions
- Annotations
-
- @immutable
Properties
- dcId → int
-
dcId Identifier of a datacenter with which to test connection
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- proxy → Proxy?
-
proxy The proxy to test
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → double
-
timeout The maximum overall timeout for the request
final
Methods
-
copyWith(
{Proxy? proxy, int? dcId, double? timeout}) → TestProxy -
Available on TestProxy, provided by the TestProxyExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String