TextCompositionStyle class final
Describes a style that can be used to compose a text
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- TextCompositionStyle({required String name, required int customEmojiId, required String title, required bool isCustom, required bool isCreator, required int installCount, required String prompt, required int creatorUserId, TextCompositionStyleExample? englishExample})
Properties
- creatorUserId → int
-
creatorUserId User identifier of the creator of the style; 0 if none or
unknown
final
- customEmojiId → int
-
customEmojiId Identifier of the custom emoji corresponding to the style;
0 if none
final
- englishExample → TextCompositionStyleExample?
-
englishExample Example of the style usage in English; may be null if
unknown
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- installCount → int
-
installCount Number of users that installed the style; for created
custom styles only; 0 if unknown
final
- isCreator → bool
-
isCreator True, if the user is creator of the style
final
- isCustom → bool
-
isCustom True, if the style is created by a user
final
- name → String
-
name Name of the style
final
- prompt → String
-
prompt Prompt of the style; for created custom styles only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Title of the style in the user application's language
final
Methods
-
copyWith(
{String? name, int? customEmojiId, String? title, bool? isCustom, bool? isCreator, int? installCount, String? prompt, int? creatorUserId, TextCompositionStyleExample? englishExample}) → TextCompositionStyle -
Available on TextCompositionStyle, provided by the TextCompositionStyleExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TextCompositionStyle?
Constants
- constructor → const String