TextEntities class final
Contains a list of text entities
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
TextEntities({required List<
TextEntity> entities})
Properties
-
entities
→ List<
TextEntity> -
entities List of text entities
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< TextEntity> ? entities}) → TextEntities -
Available on TextEntities, provided by the TextEntitiesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TextEntities?
Constants
- constructor → const String