TextParseMode class sealed
Describes the way the text needs to be parsed for text entities
- Inheritance
- Implementers
- Available extensions
- Annotations
-
- @immutable
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult hTML(TextParseModeHTML value), required TResult markdown(TextParseModeMarkdown value)}) → TResult -
Available on TextParseMode, provided by the TextParseModeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult hTML(TextParseModeHTML value)?, TResult markdown(TextParseModeMarkdown value)?, required TResult orElse()}) → TResult -
Available on TextParseMode, provided by the TextParseModeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TextParseMode? - Inherited by: TextParseModeHTML TextParseModeMarkdown
Constants
- constructor → const String