TextQuote class final
Describes manually or automatically chosen quote from another message
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- TextQuote({FormattedText? text, required int position, required bool isManual})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isManual → bool
-
isManual True, if the quote was manually chosen by the message sender
final
- position → int
-
position Approximate quote position in the original message in UTF-16
code units as specified by the message sender
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → FormattedText?
-
text Text of the quote. Only Bold, Italic, Underline, Strikethrough,
Spoiler, CustomEmoji, and DateTime entities can be present in the text
final
Methods
-
copyWith(
{FormattedText? text, int? position, bool? isManual}) → TextQuote -
Available on TextQuote, provided by the TextQuoteExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String