ThemeParameters class final

Contains parameters of the application theme

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ThemeParameters({required int backgroundColor, required int secondaryBackgroundColor, required int headerBackgroundColor, required int bottomBarBackgroundColor, required int sectionBackgroundColor, required int sectionSeparatorColor, required int textColor, required int accentTextColor, required int sectionHeaderTextColor, required int subtitleTextColor, required int destructiveTextColor, required int hintColor, required int linkColor, required int buttonColor, required int buttonTextColor})

Properties

accentTextColor int
accentTextColor An accent color of the text in the RGB format
final
backgroundColor int
backgroundColor A color of the background in the RGB format
final
bottomBarBackgroundColor int
bottomBarBackgroundColor A color of the bottom bar background in the RGB format
final
buttonColor int
buttonColor A color of the buttons in the RGB format
final
buttonTextColor int
buttonTextColor A color of text on the buttons in the RGB format
final
destructiveTextColor int
destructiveTextColor A color of the text for destructive actions in the RGB format
final
hashCode int
The hash code for this object.
no setteroverride
headerBackgroundColor int
headerBackgroundColor A color of the header background in the RGB format
final
hintColor int
hintColor A color of hints in the RGB format
final
linkColor int
linkColor A color of links in the RGB format
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryBackgroundColor int
secondaryBackgroundColor A secondary color for the background in the RGB format
final
sectionBackgroundColor int
sectionBackgroundColor A color of the section background in the RGB format
final
sectionHeaderTextColor int
sectionHeaderTextColor A color of text on the section headers in the RGB format
final
sectionSeparatorColor int
sectionSeparatorColor A color of the section separator in the RGB format
final
subtitleTextColor int
subtitleTextColor A color of the subtitle text in the RGB format
final
textColor int
textColor A color of text in the RGB format
final

Methods

copyWith({int? backgroundColor, int? secondaryBackgroundColor, int? headerBackgroundColor, int? bottomBarBackgroundColor, int? sectionBackgroundColor, int? sectionSeparatorColor, int? textColor, int? accentTextColor, int? sectionHeaderTextColor, int? subtitleTextColor, int? destructiveTextColor, int? hintColor, int? linkColor, int? buttonColor, int? buttonTextColor}) ThemeParameters

Available on ThemeParameters, provided by the ThemeParametersExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) ThemeParameters?

Constants

constructor → const String