ThemeSettings class final
Describes theme settings
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- ThemeSettings({BuiltInTheme? baseTheme, required int accentColor, Background? background, BackgroundFill? outgoingMessageFill, required bool animateOutgoingMessageFill, required int outgoingMessageAccentColor})
Properties
- accentColor → int
-
accentColor Theme accent color in ARGB format
final
- animateOutgoingMessageFill → bool
-
animateOutgoingMessageFill If true, the freeform gradient fill needs to
be animated on every sent message
final
- background → Background?
-
background The background to be used in chats; may be null
final
- baseTheme → BuiltInTheme?
-
baseTheme Base theme for this theme
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- outgoingMessageAccentColor → int
-
outgoingMessageAccentColor Accent color of outgoing messages in ARGB
format
final
- outgoingMessageFill → BackgroundFill?
-
outgoingMessageFill The fill to be used as a background for outgoing
messages; may be null if the fill from the base theme must be used instead
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{BuiltInTheme? baseTheme, int? accentColor, Background? background, BackgroundFill? outgoingMessageFill, bool? animateOutgoingMessageFill, int? outgoingMessageAccentColor}) → ThemeSettings -
Available on ThemeSettings, provided by the ThemeSettingsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → ThemeSettings?
Constants
- constructor → const String