outgoingMessageFill property
outgoingMessageFill The fill to be used as a background for outgoing messages; may be null if the fill from the base theme must be used instead
Implementation
final BackgroundFill? outgoingMessageFill;
outgoingMessageFill The fill to be used as a background for outgoing messages; may be null if the fill from the base theme must be used instead
final BackgroundFill? outgoingMessageFill;