Thumbnail class final

Represents a thumbnail

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Thumbnail({ThumbnailFormat? format, required int width, required int height, File? file})

Properties

file File?
file The thumbnail
final
format ThumbnailFormat?
format Thumbnail format
final
hashCode int
The hash code for this object.
no setteroverride
height int
height Thumbnail height
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
width Thumbnail width
final

Methods

copyWith({ThumbnailFormat? format, int? width, int? height, File? file}) Thumbnail

Available on Thumbnail, provided by the ThumbnailExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Thumbnail?

Constants

constructor → const String