TimeZone class final

Describes a time zone

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TimeZone({required String id, required String name, required int utcTimeOffset})

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
id Unique time zone identifier
final
name String
name Time zone name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
utcTimeOffset int
utcTimeOffset Current UTC time offset for the time zone
final

Methods

copyWith({String? id, String? name, int? utcTimeOffset}) TimeZone

Available on TimeZone, provided by the TimeZoneExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) TimeZone?

Constants

constructor → const String