ToggleBotIsAddedToAttachmentMenu class final
Adds or removes a bot to attachment and side menu. Bot can be added to the menu, only if userTypeBot.can_be_added_to_attachment_menu == true Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleBotIsAddedToAttachmentMenu
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleBotIsAddedToAttachmentMenu({required int botUserId, required bool isAdded, required bool allowWriteAccess})
Properties
- allowWriteAccess → bool
-
allowWriteAccess Pass true if the current user allowed the bot to send
them messages. Ignored if is_added is false
final
- botUserId → int
-
botUserId Bot's user identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isAdded → bool
-
isAdded Pass true to add the bot to attachment menu; pass false to
remove the bot from attachment menu
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? botUserId, bool? isAdded, bool? allowWriteAccess}) → ToggleBotIsAddedToAttachmentMenu -
Available on ToggleBotIsAddedToAttachmentMenu, provided by the ToggleBotIsAddedToAttachmentMenuExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String