ToggleChatFolderTags class final
Toggles whether chat folder tags are enabled Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleChatFolderTags
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleChatFolderTags({required bool areTagsEnabled})
Properties
- areTagsEnabled → bool
-
areTagsEnabled Pass true to enable folder tags; pass false to disable
them
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? areTagsEnabled}) → ToggleChatFolderTags -
Available on ToggleChatFolderTags, provided by the ToggleChatFolderTagsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String