ToggleDownloadIsPaused class final
Changes pause state of a file in the file download list Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleDownloadIsPaused
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleDownloadIsPaused({required int fileId, required bool isPaused})
Properties
Methods
-
copyWith(
{int? fileId, bool? isPaused}) → ToggleDownloadIsPaused -
Available on ToggleDownloadIsPaused, provided by the ToggleDownloadIsPausedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String