ToggleForumTopicIsPinned class final
Changes the pinned state of a topic in a forum supergroup chat or a chat with a bot with topics; requires can_manage_topics administrator right in the supergroup. There can be up to getOption("pinned_forum_topic_count_max") pinned forum topics Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleForumTopicIsPinned
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleForumTopicIsPinned({required int chatId, required int forumTopicId, required bool isPinned})
Properties
- chatId → int
-
chatId Chat identifier
final
- forumTopicId → int
-
forumTopicId Forum topic identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isPinned → bool
-
isPinned Pass true to pin the topic; pass false to unpin it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId, bool? isPinned}) → ToggleForumTopicIsPinned -
Available on ToggleForumTopicIsPinned, provided by the ToggleForumTopicIsPinnedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String