ToggleGeneralForumTopicIsHidden class final
Toggles whether a General topic is hidden in a forum supergroup chat; requires can_manage_topics administrator right in the supergroup Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleGeneralForumTopicIsHidden
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleGeneralForumTopicIsHidden({required int chatId, required bool isHidden})
Properties
- chatId → int
-
chatId Identifier of the chat
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isHidden → bool
-
isHidden Pass true to hide and close the General topic; pass false to
unhide it
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, bool? isHidden}) → ToggleGeneralForumTopicIsHidden -
Available on ToggleGeneralForumTopicIsHidden, provided by the ToggleGeneralForumTopicIsHiddenExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String