ToggleGroupCallIsMyVideoEnabled class final
Toggles whether current user's video is enabled Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleGroupCallIsMyVideoEnabled
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleGroupCallIsMyVideoEnabled({required int groupCallId, required bool isMyVideoEnabled})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isMyVideoEnabled → bool
-
isMyVideoEnabled Pass true if the current user's video is enabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, bool? isMyVideoEnabled}) → ToggleGroupCallIsMyVideoEnabled -
Available on ToggleGroupCallIsMyVideoEnabled, provided by the ToggleGroupCallIsMyVideoEnabledExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String