ToggleGroupCallParticipantIsHandRaised class final
Toggles whether a group call participant hand is rased; for video chats only Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleGroupCallParticipantIsHandRaised
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleGroupCallParticipantIsHandRaised({required int groupCallId, MessageSender? participantId, required bool isHandRaised})
Properties
- groupCallId → int
-
groupCallId Group call identifier
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isHandRaised → bool
-
isHandRaised Pass true if the user's hand needs to be raised. Only self
hand can be raised. Requires groupCall.can_be_managed right to lower
other's hand
final
- participantId → MessageSender?
-
participantId Participant identifier
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, MessageSender? participantId, bool? isHandRaised}) → ToggleGroupCallParticipantIsHandRaised -
Available on ToggleGroupCallParticipantIsHandRaised, provided by the ToggleGroupCallParticipantIsHandRaisedExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String