ToggleSessionCanAcceptCalls class final

Toggles whether a session can accept incoming calls Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSessionCanAcceptCalls({required int sessionId, required bool canAcceptCalls})

Properties

canAcceptCalls bool
canAcceptCalls Pass true to allow accepting incoming calls by the session; pass false otherwise
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
sessionId Session identifier
final

Methods

copyWith({int? sessionId, bool? canAcceptCalls}) ToggleSessionCanAcceptCalls

Available on ToggleSessionCanAcceptCalls, provided by the ToggleSessionCanAcceptCallsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String