ToggleSessionCanAcceptSecretChats class final

Toggles whether a session can accept incoming secret chats Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSessionCanAcceptSecretChats({required int sessionId, required bool canAcceptSecretChats})

Properties

canAcceptSecretChats bool
canAcceptSecretChats Pass true to allow accepting secret chats by the session; pass false otherwise
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId int
sessionId Session identifier
final

Methods

copyWith({int? sessionId, bool? canAcceptSecretChats}) ToggleSessionCanAcceptSecretChats

Available on ToggleSessionCanAcceptSecretChats, provided by the ToggleSessionCanAcceptSecretChatsExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String