ToggleSupergroupSignMessages class final
Toggles whether sender signature or link to the account is added to sent messages in a channel; requires can_change_info member right Returns Ok
- Inheritance
-
- Object
- TdFunction
- ToggleSupergroupSignMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- ToggleSupergroupSignMessages({required int supergroupId, required bool signMessages, required bool showMessageSender})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showMessageSender → bool
-
showMessageSender New value of show_message_sender
final
- signMessages → bool
-
signMessages New value of sign_messages
final
- supergroupId → int
-
supergroupId Identifier of the channel
final
Methods
-
copyWith(
{int? supergroupId, bool? signMessages, bool? showMessageSender}) → ToggleSupergroupSignMessages -
Available on ToggleSupergroupSignMessages, provided by the ToggleSupergroupSignMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String