ToggleSupergroupUsernameIsActive class final

Changes active state for a username of a supergroup or channel, requires owner privileges in the supergroup or channel. The editable username can't be disabled. May return an error with a message "USERNAMES_ACTIVE_TOO_MUCH" if the maximum number of active usernames has been reached Returns Ok

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

ToggleSupergroupUsernameIsActive({required int supergroupId, required String username, required bool isActive})

Properties

hashCode int
The hash code for this object.
no setteroverride
isActive bool
isActive Pass true to activate the username; pass false to disable it
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supergroupId int
supergroupId Identifier of the supergroup or channel
final
username String
username The username to change
final

Methods

copyWith({int? supergroupId, String? username, bool? isActive}) ToggleSupergroupUsernameIsActive

Available on ToggleSupergroupUsernameIsActive, provided by the ToggleSupergroupUsernameIsActiveExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String