TonTransactionTypeFragmentDeposit class final
The transaction is a deposit of Grams from Fragment
- Inheritance
-
- Object
- TdObject
- TonTransactionType
- TonTransactionTypeFragmentDeposit
- Available extensions
- Annotations
-
- @immutable
Constructors
- TonTransactionTypeFragmentDeposit({required bool isGift, Sticker? sticker})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- isGift → bool
-
isGift True, if the transaction is a gift from another user
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sticker → Sticker?
-
sticker The sticker to be shown in the transaction information; may be
null if unknown
final
Methods
-
copyWith(
{bool? isGift, Sticker? sticker}) → TonTransactionTypeFragmentDeposit -
Available on TonTransactionTypeFragmentDeposit, provided by the TonTransactionTypeFragmentDepositExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult fragmentDeposit(TonTransactionTypeFragmentDeposit value), required TResult fragmentWithdrawal(TonTransactionTypeFragmentWithdrawal value), required TResult giftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer value), required TResult stakeDicePayout(TonTransactionTypeStakeDicePayout value), required TResult stakeDiceStake(TonTransactionTypeStakeDiceStake value), required TResult suggestedPostPayment(TonTransactionTypeSuggestedPostPayment value), required TResult unsupported(TonTransactionTypeUnsupported value), required TResult upgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase value), required TResult upgradedGiftSale(TonTransactionTypeUpgradedGiftSale value)}) → TResult -
Available on TonTransactionType, provided by the TonTransactionTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult fragmentDeposit(TonTransactionTypeFragmentDeposit value)?, TResult fragmentWithdrawal(TonTransactionTypeFragmentWithdrawal value)?, TResult giftPurchaseOffer(TonTransactionTypeGiftPurchaseOffer value)?, TResult stakeDicePayout(TonTransactionTypeStakeDicePayout value)?, TResult stakeDiceStake(TonTransactionTypeStakeDiceStake value)?, TResult suggestedPostPayment(TonTransactionTypeSuggestedPostPayment value)?, TResult unsupported(TonTransactionTypeUnsupported value)?, TResult upgradedGiftPurchase(TonTransactionTypeUpgradedGiftPurchase value)?, TResult upgradedGiftSale(TonTransactionTypeUpgradedGiftSale value)?, required TResult orElse()}) → TResult -
Available on TonTransactionType, provided by the TonTransactionTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → TonTransactionTypeFragmentDeposit? -
Inherited by:
TonTransactionTypeFragmentDeposit
TonTransactionTypeFragmentWithdrawal
TonTransactionTypeGiftPurchaseOffer
TonTransactionTypeStakeDicePayout
TonTransactionTypeStakeDiceStake
TonTransactionTypeSuggestedPostPayment
TonTransactionTypeUnsupported
TonTransactionTypeUpgradedGiftPurchase
TonTransactionTypeUpgradedGiftSale
override
Constants
- constructor → const String