TranslateRichMessage class final

Translates a rich message to the given language Returns RichMessage

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

TranslateRichMessage({InputRichMessage? message, required String toLanguageCode, required String tone})

Properties

hashCode int
The hash code for this object.
no setteroverride
message InputRichMessage?
message Rich message to translate
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toLanguageCode String
toLanguageCode Language code of the language to which the message is translated. See translateText.to_language_code for the list of supported values
final
tone String
tone Tone of the translation; see translateText.tone for the list of supported values
final

Methods

copyWith({InputRichMessage? message, String? toLanguageCode, String? tone}) TranslateRichMessage

Available on TranslateRichMessage, provided by the TranslateRichMessageExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

constructor → const String