UnpinAllForumTopicMessages class final
Removes all pinned messages from a topic in a forum supergroup chat or a chat with a bot with topics; requires can_pin_messages member right in the supergroup Returns Ok
- Inheritance
-
- Object
- TdFunction
- UnpinAllForumTopicMessages
- Available extensions
- Annotations
-
- @immutable
Constructors
- UnpinAllForumTopicMessages({required int chatId, required int forumTopicId})
Properties
- chatId → int
-
chatId Identifier of the chat
final
- forumTopicId → int
-
forumTopicId Forum topic identifier in which messages will be unpinned
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? chatId, int? forumTopicId}) → UnpinAllForumTopicMessages -
Available on UnpinAllForumTopicMessages, provided by the UnpinAllForumTopicMessagesExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String