UnpinChatMessage class final
Removes a pinned message from a chat; requires can_pin_messages member right if the chat is a basic group or supergroup, or can_edit_messages administrator right if the chat is a channel Returns Ok
- Inheritance
-
- Object
- TdFunction
- UnpinChatMessage
- Available extensions
- Annotations
-
- @immutable
Constructors
- UnpinChatMessage({required int chatId, required int messageId})
Properties
Methods
-
copyWith(
{int? chatId, int? messageId}) → UnpinChatMessage -
Available on UnpinChatMessage, provided by the UnpinChatMessageExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String