viaJoinRequest property
viaJoinRequest True, if the user has joined the chat after sending a join request and being approved by an administrator
Implementation
final bool viaJoinRequest;
viaJoinRequest True, if the user has joined the chat after sending a join request and being approved by an administrator
final bool viaJoinRequest;