availableAccentColorIds property
availableAccentColorIds The list of accent color identifiers, which can be set through setProfileAccentColor and setChatProfileAccentColor. The colors must be shown in the specified order
Implementation
final List<int> availableAccentColorIds;