state property
state The new state. The state can be used only if it was received recently enough. Otherwise, a new state must be requested using getStakeDiceState
Implementation
final StakeDiceState? state;
state The new state. The state can be used only if it was received recently enough. Otherwise, a new state must be requested using getStakeDiceState
final StakeDiceState? state;