hostId property
hostId Identifier of the user or the chat to which the upgraded gift was assigned from blockchain; may be null if none or unknown
Implementation
final MessageSender? hostId;
hostId Identifier of the user or the chat to which the upgraded gift was assigned from blockchain; may be null if none or unknown
final MessageSender? hostId;