UpgradedGiftAttributeRarityPerMille class final
The rarity is represented as the numeric frequency of the model
- Inheritance
-
- Object
- TdObject
- UpgradedGiftAttributeRarity
- UpgradedGiftAttributeRarityPerMille
- Available extensions
- Annotations
-
- @immutable
Constructors
- UpgradedGiftAttributeRarityPerMille({required int perMille})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- perMille → int
-
perMille The number of upgraded gifts that receive this attribute for
each 1000 gifts upgraded; if 0, then it can be shown as "
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? perMille}) → UpgradedGiftAttributeRarityPerMille -
Available on UpgradedGiftAttributeRarityPerMille, provided by the UpgradedGiftAttributeRarityPerMilleExtensions extension
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult epic(UpgradedGiftAttributeRarityEpic value), required TResult legendary(UpgradedGiftAttributeRarityLegendary value), required TResult perMille(UpgradedGiftAttributeRarityPerMille value), required TResult rare(UpgradedGiftAttributeRarityRare value), required TResult uncommon(UpgradedGiftAttributeRarityUncommon value)}) → TResult -
Available on UpgradedGiftAttributeRarity, provided by the UpgradedGiftAttributeRarityExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult epic(UpgradedGiftAttributeRarityEpic value)?, TResult legendary(UpgradedGiftAttributeRarityLegendary value)?, TResult perMille(UpgradedGiftAttributeRarityPerMille value)?, TResult rare(UpgradedGiftAttributeRarityRare value)?, TResult uncommon(UpgradedGiftAttributeRarityUncommon value)?, required TResult orElse()}) → TResult -
Available on UpgradedGiftAttributeRarity, provided by the UpgradedGiftAttributeRarityExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
Constants
- constructor → const String