UpgradedGiftColors class final
Contains information about color scheme for user's name, background of empty chat photo, replies to messages and link previews
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- darkThemeAccentColor → int
-
darkThemeAccentColor Accent color to use in dark themes in RGB format
final
-
darkThemeColors
→ List<
int> -
darkThemeColors The list of 1-3 colors in RGB format, describing the
accent color, as expected to be shown in dark themes
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → int
-
id Unique identifier of the upgraded gift colors
final
- lightThemeAccentColor → int
-
lightThemeAccentColor Accent color to use in light themes in RGB format
final
-
lightThemeColors
→ List<
int> -
lightThemeColors The list of 1-3 colors in RGB format, describing the
accent color, as expected to be shown in light themes
final
- modelCustomEmojiId → int
-
modelCustomEmojiId Custom emoji identifier of the model of the upgraded
gift
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbolCustomEmojiId → int
-
symbolCustomEmojiId Custom emoji identifier of the symbol of the
upgraded gift
final
Methods
-
copyWith(
{int? id, int? modelCustomEmojiId, int? symbolCustomEmojiId, int? lightThemeAccentColor, List< int> ? lightThemeColors, int? darkThemeAccentColor, List<int> ? darkThemeColors}) → UpgradedGiftColors -
Available on UpgradedGiftColors, provided by the UpgradedGiftColorsExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UpgradedGiftColors?
Constants
- constructor → const String