UpgradedGiftModelCount class final
Describes a model of an upgraded gift with the number of gifts found
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- UpgradedGiftModelCount({UpgradedGiftModel? model, required int totalCount})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- model → UpgradedGiftModel?
-
model The model
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
totalCount Total number of gifts with the model
final
Methods
-
copyWith(
{UpgradedGiftModel? model, int? totalCount}) → UpgradedGiftModelCount -
Available on UpgradedGiftModelCount, provided by the UpgradedGiftModelCountExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UpgradedGiftModelCount?
Constants
- constructor → const String