UpgradedGiftValueInfo class final
Contains information about value of an upgraded gift
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- UpgradedGiftValueInfo({required String currency, required int value, required bool isValueAverage, required int initialSaleDate, required int initialSaleStarCount, required int initialSalePrice, required int lastSaleDate, required int lastSalePrice, required bool isLastSaleOnFragment, required int minimumPrice, required int averageSalePrice, required int telegramListedGiftCount, required int fragmentListedGiftCount, required String fragmentUrl})
Properties
- averageSalePrice → int
-
averageSalePrice The average sale price in the last month of gifts
upgraded from the same gift; in the smallest units of the currency; 0 if
there were no such sales
final
- currency → String
-
currency ISO 4217 currency code of the currency in which the prices are
represented
final
- fragmentListedGiftCount → int
-
fragmentListedGiftCount Number of gifts upgraded from the same gift
being resold on Fragment
final
- fragmentUrl → String
-
fragmentUrl The HTTPS link to the Fragment for the gift; may be empty if
there are no such gifts being sold on Fragment
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- initialSaleDate → int
-
initialSaleDate Point in time (Unix timestamp) when the corresponding
regular gift was originally purchased
final
- initialSalePrice → int
-
initialSalePrice Initial price of the gift; in the smallest units of the
currency
final
- initialSaleStarCount → int
-
initialSaleStarCount The Telegram Star amount that was paid for the gift
final
- isLastSaleOnFragment → bool
-
isLastSaleOnFragment True, if the last sale was completed on Fragment
final
- isValueAverage → bool
-
isValueAverage True, if the value is calculated as average value of
similar sold gifts. Otherwise, it is based on the sale price of the gift
final
- lastSaleDate → int
-
lastSaleDate Point in time (Unix timestamp) when the upgraded gift was
purchased last time; 0 if never
final
- lastSalePrice → int
-
lastSalePrice Last purchase price of the gift; in the smallest units of
the currency; 0 if the gift has never been resold
final
- minimumPrice → int
-
minimumPrice The current minimum price of gifts upgraded from the same
gift; in the smallest units of the currency; 0 if there are no such gifts
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- telegramListedGiftCount → int
-
telegramListedGiftCount Number of gifts upgraded from the same gift
being resold on Telegram
final
- value → int
-
value Estimated value of the gift; in the smallest units of the currency
final
Methods
-
copyWith(
{String? currency, int? value, bool? isValueAverage, int? initialSaleDate, int? initialSaleStarCount, int? initialSalePrice, int? lastSaleDate, int? lastSalePrice, bool? isLastSaleOnFragment, int? minimumPrice, int? averageSalePrice, int? telegramListedGiftCount, int? fragmentListedGiftCount, String? fragmentUrl}) → UpgradedGiftValueInfo -
Available on UpgradedGiftValueInfo, provided by the UpgradedGiftValueInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UpgradedGiftValueInfo?
Constants
- constructor → const String