restrictsNewChats property
restrictsNewChats True, if the user may restrict new chats with non-contacts. Use canSendMessageToUser to check whether the current user can message the user or try to create a chat with them
Implementation
final bool restrictsNewChats;