ownerId property
ownerId Identifier of the user or the chat that will receive the auctioned item. If the auction is opened in context of another user or chat, then a warning is supposed to be shown to the current user
Implementation
final MessageSender? ownerId;