UserFullInfo class final
Contains full information about a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- UserFullInfo({ChatPhoto? personalPhoto, ChatPhoto? photo, ChatPhoto? publicPhoto, int? communityId, BlockList? blockList, required bool canBeCalled, required bool supportsVideoCalls, required bool hasPrivateCalls, required bool hasPrivateForwards, required bool hasRestrictedVoiceAndVideoNoteMessages, required bool hasPostedToProfileStories, required bool hasSponsoredMessagesEnabled, required bool needPhoneNumberPrivacyException, required bool setChatBackground, required bool usesUnofficialApp, FormattedText? bio, Birthdate? birthdate, required int personalChatId, required int giftCount, required int groupInCommonCount, required int incomingPaidMessageStarCount, required int outgoingPaidMessageStarCount, GiftSettings? giftSettings, BotVerification? botVerification, ProfileTab? mainProfileTab, Audio? firstProfileAudio, UserRating? rating, UserRating? pendingRating, required int pendingRatingDate, FormattedText? note, BusinessInfo? businessInfo, BotInfo? botInfo})
Properties
- bio → FormattedText?
-
bio A short user bio; may be null for bots
final
- birthdate → Birthdate?
-
birthdate Birthdate of the user; may be null if unknown
final
- blockList → BlockList?
-
blockList Block list to which the user is added; may be null if none
final
- botInfo → BotInfo?
-
botInfo For bots, information about the bot; may be null if the user
isn't a bot
final
- botVerification → BotVerification?
-
botVerification Information about verification status of the user
provided by a bot; may be null if none or unknown
final
- businessInfo → BusinessInfo?
-
businessInfo Information about business settings for Telegram Business
accounts; may be null if none
final
- canBeCalled → bool
-
canBeCalled True, if the user can be called
final
- communityId → int?
-
communityId Identifier of the community to which chat with the bot was
added; for bots only
final
- firstProfileAudio → Audio?
-
firstProfileAudio The first audio file added to the user's profile; may
be null if none
final
- giftCount → int
-
giftCount Number of saved to profile gifts for other users or the total
number of received gifts for the current user
final
- giftSettings → GiftSettings?
-
giftSettings Settings for gift receiving for the user
final
- groupInCommonCount → int
-
groupInCommonCount Number of group chats where both the other user and
the current user are a member; 0 for the current user
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasPostedToProfileStories → bool
-
hasPostedToProfileStories True, if the user has posted to profile
stories
final
- hasPrivateCalls → bool
-
hasPrivateCalls True, if the user can't be called due to their privacy
settings
final
- hasPrivateForwards → bool
-
hasPrivateForwards True, if the user can't be linked in forwarded
messages due to their privacy settings
final
- hasRestrictedVoiceAndVideoNoteMessages → bool
-
hasRestrictedVoiceAndVideoNoteMessages True, if voice and video notes
can't be sent or forwarded to the user
final
- hasSponsoredMessagesEnabled → bool
-
hasSponsoredMessagesEnabled True, if the user always enabled sponsored
messages; known only for the current user
final
- incomingPaidMessageStarCount → int
-
incomingPaidMessageStarCount Number of Telegram Stars that must be paid
by the user for each sent message to the current user
final
- mainProfileTab → ProfileTab?
-
mainProfileTab The main tab chosen by the user; may be null if not
chosen manually
final
- needPhoneNumberPrivacyException → bool
-
needPhoneNumberPrivacyException True, if the current user needs to
explicitly allow to share their phone number with the user when the method
addContact is used
final
- note → FormattedText?
-
note Note added to the user's contact; may be null if none
final
- outgoingPaidMessageStarCount → int
-
outgoingPaidMessageStarCount Number of Telegram Stars that must be paid
by the current user for each sent message to the user
final
- pendingRating → UserRating?
-
pendingRating The rating of the user after the next change; may be null
if the user isn't the current user or there are no pending rating changes
final
- pendingRatingDate → int
-
pendingRatingDate Unix timestamp when rating of the user will change to
pending_rating; 0 if the user isn't the current user or there are no
pending rating changes
final
- personalChatId → int
-
personalChatId Identifier of the personal chat of the user; 0 if none
final
- personalPhoto → ChatPhoto?
-
personalPhoto User profile photo set by the current user for the
contact; may be null. If null and user.profile_photo is null, then the
photo is empty; otherwise, it is unknown. If non-null, then it is the same
photo as in user.profile_photo and chat.photo. This photo isn't returned
in the list of user photos
final
- photo → ChatPhoto?
-
photo User profile photo; may be null. If null and user.profile_photo is
null, then the photo is empty; otherwise, it is unknown. If non-null and
personal_photo is null, then it is the same photo as in user.profile_photo
and chat.photo
final
- publicPhoto → ChatPhoto?
-
publicPhoto User profile photo visible if the main photo is hidden by
privacy settings; may be null. If null and user.profile_photo is null,
then the photo is empty; otherwise, it is unknown. If non-null and both
photo and personal_photo are null, then it is the same photo as in
user.profile_photo and chat.photo. This photo isn't returned in the list
of user photos
final
- rating → UserRating?
-
rating The current rating of the user; may be null if none
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setChatBackground → bool
-
setChatBackground True, if the user set chat background for both chat
users and it wasn't reverted yet
final
- supportsVideoCalls → bool
-
supportsVideoCalls True, if a video call can be created with the user
final
- usesUnofficialApp → bool
-
usesUnofficialApp True, if the user uses an unofficial application that
poses a security risk
final
Methods
-
copyWith(
{ChatPhoto? personalPhoto, ChatPhoto? photo, ChatPhoto? publicPhoto, int? communityId, BlockList? blockList, bool? canBeCalled, bool? supportsVideoCalls, bool? hasPrivateCalls, bool? hasPrivateForwards, bool? hasRestrictedVoiceAndVideoNoteMessages, bool? hasPostedToProfileStories, bool? hasSponsoredMessagesEnabled, bool? needPhoneNumberPrivacyException, bool? setChatBackground, bool? usesUnofficialApp, FormattedText? bio, Birthdate? birthdate, int? personalChatId, int? giftCount, int? groupInCommonCount, int? incomingPaidMessageStarCount, int? outgoingPaidMessageStarCount, GiftSettings? giftSettings, BotVerification? botVerification, ProfileTab? mainProfileTab, Audio? firstProfileAudio, UserRating? rating, UserRating? pendingRating, int? pendingRatingDate, FormattedText? note, BusinessInfo? businessInfo, BotInfo? botInfo}) → UserFullInfo -
Available on UserFullInfo, provided by the UserFullInfoExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UserFullInfo?
Constants
- constructor → const String