incomingPaidMessageStarCount property
incomingPaidMessageStarCount Number of Telegram Stars that must be paid by the user for each sent message to the current user
Implementation
final int incomingPaidMessageStarCount;
incomingPaidMessageStarCount Number of Telegram Stars that must be paid by the user for each sent message to the current user
final int incomingPaidMessageStarCount;