outgoingPaidMessageStarCount property
outgoingPaidMessageStarCount Number of Telegram Stars that must be paid by the current user for each sent message to the user
Implementation
final int outgoingPaidMessageStarCount;
outgoingPaidMessageStarCount Number of Telegram Stars that must be paid by the current user for each sent message to the user
final int outgoingPaidMessageStarCount;