pendingRating property
pendingRating The rating of the user after the next change; may be null if the user isn't the current user or there are no pending rating changes
Implementation
final UserRating? pendingRating;
pendingRating The rating of the user after the next change; may be null if the user isn't the current user or there are no pending rating changes
final UserRating? pendingRating;