UserLink class final
Contains an HTTPS URL, which can be used to get information about a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Properties
- expiresIn → int
-
expiresIn Left time for which the link is valid, in seconds; 0 if the
link is a public username link
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
url The URL
final
Methods
-
copyWith(
{String? url, int? expiresIn}) → UserLink -
Available on UserLink, provided by the UserLinkExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String