UserPrivacySettingAllowFindingByPhoneNumber class final
A privacy setting for managing whether the user can be found by their phone number. Checked only if the phone number is not known to the other user. Can be set only to "Allow contacts" or "Allow all"
- Inheritance
-
- Object
- TdObject
- UserPrivacySetting
- UserPrivacySettingAllowFindingByPhoneNumber
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult allowCalls(UserPrivacySettingAllowCalls value), required TResult allowChatInvites(UserPrivacySettingAllowChatInvites value), required TResult allowFindingByPhoneNumber(UserPrivacySettingAllowFindingByPhoneNumber value), required TResult allowPeerToPeerCalls(UserPrivacySettingAllowPeerToPeerCalls value), required TResult allowPrivateVoiceAndVideoNoteMessages(UserPrivacySettingAllowPrivateVoiceAndVideoNoteMessages value), required TResult allowUnpaidMessages(UserPrivacySettingAllowUnpaidMessages value), required TResult autosaveGifts(UserPrivacySettingAutosaveGifts value), required TResult showBio(UserPrivacySettingShowBio value), required TResult showBirthdate(UserPrivacySettingShowBirthdate value), required TResult showLinkInForwardedMessages(UserPrivacySettingShowLinkInForwardedMessages value), required TResult showPhoneNumber(UserPrivacySettingShowPhoneNumber value), required TResult showProfileAudio(UserPrivacySettingShowProfileAudio value), required TResult showProfilePhoto(UserPrivacySettingShowProfilePhoto value), required TResult showStatus(UserPrivacySettingShowStatus value)}) → TResult -
Available on UserPrivacySetting, provided by the UserPrivacySettingExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult allowCalls(UserPrivacySettingAllowCalls value)?, TResult allowChatInvites(UserPrivacySettingAllowChatInvites value)?, TResult allowFindingByPhoneNumber(UserPrivacySettingAllowFindingByPhoneNumber value)?, TResult allowPeerToPeerCalls(UserPrivacySettingAllowPeerToPeerCalls value)?, TResult allowPrivateVoiceAndVideoNoteMessages(UserPrivacySettingAllowPrivateVoiceAndVideoNoteMessages value)?, TResult allowUnpaidMessages(UserPrivacySettingAllowUnpaidMessages value)?, TResult autosaveGifts(UserPrivacySettingAutosaveGifts value)?, TResult showBio(UserPrivacySettingShowBio value)?, TResult showBirthdate(UserPrivacySettingShowBirthdate value)?, TResult showLinkInForwardedMessages(UserPrivacySettingShowLinkInForwardedMessages value)?, TResult showPhoneNumber(UserPrivacySettingShowPhoneNumber value)?, TResult showProfileAudio(UserPrivacySettingShowProfileAudio value)?, TResult showProfilePhoto(UserPrivacySettingShowProfilePhoto value)?, TResult showStatus(UserPrivacySettingShowStatus value)?, required TResult orElse()}) → TResult -
Available on UserPrivacySetting, provided by the UserPrivacySettingExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UserPrivacySettingAllowFindingByPhoneNumber? -
Inherited by:
UserPrivacySettingAllowCalls
UserPrivacySettingAllowChatInvites
UserPrivacySettingAllowFindingByPhoneNumber
UserPrivacySettingAllowPeerToPeerCalls
UserPrivacySettingAllowPrivateVoiceAndVideoNoteMessages
UserPrivacySettingAllowUnpaidMessages
UserPrivacySettingAutosaveGifts
UserPrivacySettingShowBio
UserPrivacySettingShowBirthdate
UserPrivacySettingShowLinkInForwardedMessages
UserPrivacySettingShowPhoneNumber
UserPrivacySettingShowProfileAudio
UserPrivacySettingShowProfilePhoto
UserPrivacySettingShowStatus
override
Constants
- constructor → const String