UserTypeUnknown class final
No information on the user besides the user identifier is available, yet this user has not been deleted. This object is extremely rare and must be handled like a deleted user. It is not possible to perform any actions on users of this type
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- UserTypeUnknown()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConstructor(
) → String -
override
-
map<
TResult extends Object?> ({required TResult bot(UserTypeBot value), required TResult deleted(UserTypeDeleted value), required TResult regular(UserTypeRegular value), required TResult unknown(UserTypeUnknown value)}) → TResult -
Available on UserType, provided by the UserTypeExtensions extension
-
maybeMap<
TResult extends Object?> ({TResult bot(UserTypeBot value)?, TResult deleted(UserTypeDeleted value)?, TResult regular(UserTypeRegular value)?, TResult unknown(UserTypeUnknown value)?, required TResult orElse()}) → TResult -
Available on UserType, provided by the UserTypeExtensions extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → UserTypeUnknown? -
Inherited by:
UserTypeBot
UserTypeDeleted
UserTypeRegular
UserTypeUnknown
override
Constants
- constructor → const String