Usernames class final

Describes usernames assigned to a user, a supergroup, or a channel

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

Usernames({required List<String> activeUsernames, required List<String> disabledUsernames, required String editableUsername, required List<String> collectibleUsernames})

Properties

activeUsernames List<String>
activeUsernames List of active usernames; the first one must be shown as the primary username. The order of active usernames can be changed with reorderActiveUsernames, reorderBotActiveUsernames or reorderSupergroupActiveUsernames
final
collectibleUsernames List<String>
collectibleUsernames Collectible usernames that were purchased at https://fragment.com and can be passed to getCollectibleItemInfo for more details
final
disabledUsernames List<String>
disabledUsernames List of currently disabled usernames; the username can be activated with toggleUsernameIsActive, toggleBotUsernameIsActive, or toggleSupergroupUsernameIsActive
final
editableUsername String
editableUsername Active or disabled username, which may be changed with setUsername or setSupergroupUsername
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? activeUsernames, List<String>? disabledUsernames, String? editableUsername, List<String>? collectibleUsernames}) Usernames

Available on Usernames, provided by the UsernamesExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) Usernames?

Constants

constructor → const String