Venue class final
Describes a venue
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
Properties
- address → String
-
address Venue address; as defined by the sender
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
id Identifier of the venue in the provider database; as defined by the
sender
final
- location → Location?
-
location Venue location; as defined by the sender
final
- provider → String
-
provider Provider of the venue database; as defined by the sender.
Currently, only "foursquare" and "gplaces" (Google Places) need to be
supported
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title Venue name; as defined by the sender
final
- type → String
-
type Type of the venue in the provider database; as defined by the
sender
final
Methods
-
copyWith(
{Location? location, String? title, String? address, String? provider, String? id, String? type}) → Venue -
Available on Venue, provided by the VenueExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String