VerificationStatus class final
Contains information about verification status of a chat or a user
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- VerificationStatus({required bool isVerified, required bool isScam, required bool isFake, required int botVerificationIconCustomEmojiId})
Properties
- botVerificationIconCustomEmojiId → int
-
botVerificationIconCustomEmojiId Identifier of the custom emoji to be
shown as verification sign provided by a bot for the user; 0 if none
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFake → bool
-
isFake True, if the chat or the user is marked as fake by Telegram
final
- isScam → bool
-
isScam True, if the chat or the user is marked as scam by Telegram
final
- isVerified → bool
-
isVerified True, if the chat or the user is verified by Telegram
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{bool? isVerified, bool? isScam, bool? isFake, int? botVerificationIconCustomEmojiId}) → VerificationStatus -
Available on VerificationStatus, provided by the VerificationStatusExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → VerificationStatus?
Constants
- constructor → const String