VideoChat class final
Describes a video chat, i.e. a group call bound to a chat
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- VideoChat({required int groupCallId, required bool hasParticipants, MessageSender? defaultParticipantId})
Properties
- defaultParticipantId → MessageSender?
-
defaultParticipantId Default group call participant identifier to join
the video chat; may be null
final
- groupCallId → int
-
groupCallId Group call identifier of an active video chat; 0 if none.
Full information about the video chat can be received through the method
getGroupCall
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasParticipants → bool
-
hasParticipants True, if the video chat has participants
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? groupCallId, bool? hasParticipants, MessageSender? defaultParticipantId}) → VideoChat -
Available on VideoChat, provided by the VideoChatExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- constructor → const String