VideoMessageAdvertisement class final
Describes an advertisement to be shown while a video from a message is watched
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- VideoMessageAdvertisement({required int uniqueId, required String text, required int minDisplayDuration, required int maxDisplayDuration, required bool canBeReported, AdvertisementSponsor? sponsor, required String title, required String additionalInfo})
Properties
- additionalInfo → String
-
additionalInfo If non-empty, additional information about the sponsored
message to be shown along with the message
final
- canBeReported → bool
-
canBeReported True, if the advertisement can be reported to Telegram
moderators through reportVideoMessageAdvertisement
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- maxDisplayDuration → int
-
maxDisplayDuration The maximum amount of time the advertisement must be
displayed before it must be automatically hidden, in seconds
final
- minDisplayDuration → int
-
minDisplayDuration The minimum amount of time the advertisement must be
displayed before it can be hidden by the user, in seconds
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sponsor → AdvertisementSponsor?
-
sponsor Information about the sponsor of the advertisement
final
- text → String
-
text Text of the advertisement
final
- title → String
-
title Title of the sponsored message
final
- uniqueId → int
-
uniqueId Unique identifier of this result
final
Methods
-
copyWith(
{int? uniqueId, String? text, int? minDisplayDuration, int? maxDisplayDuration, bool? canBeReported, AdvertisementSponsor? sponsor, String? title, String? additionalInfo}) → VideoMessageAdvertisement -
Available on VideoMessageAdvertisement, provided by the VideoMessageAdvertisementExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → VideoMessageAdvertisement?
Constants
- constructor → const String