VoiceNote class final

Describes a voice note

Inheritance
Available extensions
Annotations
  • @immutable

Constructors

VoiceNote({required int duration, required String waveform, required String mimeType, SpeechRecognitionResult? speechRecognitionResult, File? voice})

Properties

duration int
duration Duration of the voice note, in seconds; as defined by the sender
final
hashCode int
The hash code for this object.
no setteroverride
mimeType String
mimeType MIME type of the file; as defined by the sender. Usually, one of "audio/ogg" for Opus in an OGG container, "audio/mpeg" for an MP3 audio, or "audio/mp4" for an M4A audio
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speechRecognitionResult SpeechRecognitionResult?
speechRecognitionResult Result of speech recognition in the voice note; may be null
final
voice File?
voice File containing the voice note
final
waveform String
waveform A waveform representation of the voice note in 5-bit format
final

Methods

copyWith({int? duration, String? waveform, String? mimeType, SpeechRecognitionResult? speechRecognitionResult, File? voice}) VoiceNote

Available on VoiceNote, provided by the VoiceNoteExtensions extension

getConstructor() String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(Map<String, dynamic>? json) VoiceNote?

Constants

constructor → const String