WebAppOpenParameters class final
Options to be used when a Web App is opened
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
- WebAppOpenParameters({ThemeParameters? theme, required String applicationName, WebAppOpenMode? mode})
Properties
- applicationName → String
-
applicationName Short name of the current application; 0-64 English
letters, digits, and underscores
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- mode → WebAppOpenMode?
-
mode The mode in which the Web App is opened; pass null to open in
webAppOpenModeFullSize
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeParameters?
-
theme Preferred Web App theme; pass null to use the default theme
final
Methods
-
copyWith(
{ThemeParameters? theme, String? applicationName, WebAppOpenMode? mode}) → WebAppOpenParameters -
Available on WebAppOpenParameters, provided by the WebAppOpenParametersExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → WebAppOpenParameters?
Constants
- constructor → const String