requireSameOrigin property
requireSameOrigin True, if events from the Web App must be accepted only from the same origin as the URL
Implementation
final bool requireSameOrigin;
requireSameOrigin True, if events from the Web App must be accepted only from the same origin as the URL
final bool requireSameOrigin;