WebPageInstantView class final
Describes an instant view page for a web page
- Inheritance
- Available extensions
- Annotations
-
- @immutable
Constructors
-
WebPageInstantView({required List<
PageBlock> blocks, required int viewCount, required int version, required bool isRtl, required bool isFull, InternalLinkType? feedbackLink})
Properties
-
blocks
→ List<
PageBlock> -
blocks Content of the instant view page
final
- feedbackLink → InternalLinkType?
-
feedbackLink An internal link to be opened to leave feedback about the
instant view
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFull → bool
-
isFull True, if the instant view contains the full page. A network
request might be needed to get the full instant view
final
- isRtl → bool
-
isRtl True, if the instant view must be shown from right to left
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
version Version of the instant view; currently, can be 1 or 2
final
- viewCount → int
-
viewCount Number of the instant view views; 0 if unknown
final
Methods
-
copyWith(
{List< PageBlock> ? blocks, int? viewCount, int? version, bool? isRtl, bool? isFull, InternalLinkType? feedbackLink}) → WebPageInstantView -
Available on WebPageInstantView, provided by the WebPageInstantViewExtensions extension
-
getConstructor(
) → String -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
Map< String, dynamic> ? json) → WebPageInstantView?
Constants
- constructor → const String